/*
 * Autogenerated by $Id: IEMAllIntprA64Tables-armv8.cpp $
 * from the open source v9Ap6-A specs, build 406 (5e0a212688c6bd7aee92394b6f5e491b4d0fee1d)
 * dated Sun Dec 15 22:18:44 2024 UTC.
 *
 * Do not edit!
 */

/*
 * Copyright (C) 2025 Oracle and/or its affiliates.
 *
 * This file is part of VirtualBox base platform packages, as
 * available from https://www.virtualbox.org.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, in version 3 of the
 * License.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <https://www.gnu.org/licenses>.
 *
 * SPDX-License-Identifier: GPL-3.0-only
 */


#define LOG_GROUP LOG_GROUP_IEM
#define VMCPU_INCL_CPUM_GST_CTX
#include "IEMInternal.h"
#include <VBox/vmm/vm.h>
#include "VBox/err.h"

#include "iprt/armv8.h"

#include "IEMMc.h"
#include "IEMInline-armv8.h"

#include "IEMAllIntprA64Tables-armv8.h"
#include "IEMAllInstrA64Impl.h"


/** Invalid instruction decoder function. */
FNIEMOP_DEF_1(iemDecodeA64_Invalid, uint32_t, uOpcode)
{
    Log(("Invalid instruction %#x at %x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    RT_NOREF_PV(uOpcode);
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ac02000: ABS  <Wd>, <Wn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ABS_32_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ac02000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
        {
            LogFlow(("%018x/%010x: ABS_32_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__ABS_32_dp_1src
            IEM_INSTR_IMPL_A64__ABS_32_dp_1src(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac02000: ABS  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ABS_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: ABS_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__ABS_64_dp_1src
        IEM_INSTR_IMPL_A64__ABS_64_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e20b800: ABS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ABS_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e20b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ABS_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ABS_asimdmisc_R
            IEM_INSTR_IMPL_A64__ABS_asimdmisc_R(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ee0b800: ABS  D<d>, D<n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ABS_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ee0b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ABS_asisdmisc_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__ABS_asisdmisc_R
            IEM_INSTR_IMPL_A64__ABS_asisdmisc_R(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3a000000: ADCS  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: addsub_carry, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADCS_32_addsub_carry, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ADCS_32_addsub_carry Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADCS_32_addsub_carry
    IEM_INSTR_IMPL_A64__ADCS_32_addsub_carry(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/ba000000: ADCS  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: addsub_carry, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADCS_64_addsub_carry, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ADCS_64_addsub_carry Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADCS_64_addsub_carry
    IEM_INSTR_IMPL_A64__ADCS_64_addsub_carry(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/1a000000: ADC  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: addsub_carry, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADC_32_addsub_carry, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ADC_32_addsub_carry Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADC_32_addsub_carry
    IEM_INSTR_IMPL_A64__ADC_32_addsub_carry(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9a000000: ADC  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: addsub_carry, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADC_64_addsub_carry, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ADC_64_addsub_carry Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADC_64_addsub_carry
    IEM_INSTR_IMPL_A64__ADC_64_addsub_carry(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc0c000/91800000: ADDG  <Xd|SP>, <Xn|SP>, #<uimm6>, #<uimm4>
   Instruction Set: A64  Groups: addsub_immtags, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ADDG_64_addsub_immtags, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 10) & 0x0000000f;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: ADDG_64_addsub_immtags Rd=%#x Rn=%#x imm4=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm4, imm6));
#ifdef IEM_INSTR_IMPL_A64__ADDG_64_addsub_immtags
        IEM_INSTR_IMPL_A64__ADDG_64_addsub_immtags(Rd, Rn, imm4, imm6);
#else
        RT_NOREF(Rd, Rn, imm4, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e204000: ADDHN2  <Vd>.<Tb>, <Vn>.<Ta>, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ADDHN_asimddiff_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ADDHN_asimddiff_N Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ADDHN_asimddiff_N
        IEM_INSTR_IMPL_A64__ADDHN_asimddiff_N(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/9a002000: ADDPT  <Xd|SP>, <Xn|SP>, <Xm>{, LSL #<amount>}
   Instruction Set: A64  Groups: addsub_pt, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADDPT_64_addsub_pt, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
    {
        LogFlow(("%018x/%010x: ADDPT_64_addsub_pt Rd=%#x Rn=%#x imm3=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADDPT_64_addsub_pt
        IEM_INSTR_IMPL_A64__ADDPT_64_addsub_pt(Rd, Rn, imm3, Rm);
#else
        RT_NOREF(Rd, Rn, imm3, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e20bc00: ADDP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ADDP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20bc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ADDP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ADDP_asimdsame_only
            IEM_INSTR_IMPL_A64__ADDP_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ef1b800: ADDP  D<d>, <Vn>.2D
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ADDP_asisdpair_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ef1b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ADDP_asisdpair_only Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__ADDP_asisdpair_only
            IEM_INSTR_IMPL_A64__ADDP_asisdpair_only(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/2b200000: ADDS  <Wd>, <Wn|WSP>, <Wm>{, <extend>{ #<amount>}}
   Instruction Set: A64  Groups: addsub_ext, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADDS_32S_addsub_ext, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ADDS_32S_addsub_ext Rd=%#x Rn=%#x imm3=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADDS_32S_addsub_ext
    IEM_INSTR_IMPL_A64__ADDS_32S_addsub_ext(Rd, Rn, imm3, option, Rm);
#else
    RT_NOREF(Rd, Rn, imm3, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/31000000: ADDS  <Wd>, <Wn|WSP>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: addsub_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ADDS_32S_addsub_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    uint32_t const sh         = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: ADDS_32S_addsub_imm Rd=%#x Rn=%#x imm12=%#x sh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm12, sh));
#ifdef IEM_INSTR_IMPL_A64__ADDS_32S_addsub_imm
    IEM_INSTR_IMPL_A64__ADDS_32S_addsub_imm(Rd, Rn, imm12, sh);
#else
    RT_NOREF(Rd, Rn, imm12, sh, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/2b000000: ADDS  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: addsub_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADDS_32_addsub_shift, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff200000)) == UINT32_C(0x2b000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
        LogFlow(("%018x/%010x: ADDS_32_addsub_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ADDS_32_addsub_shift
        IEM_INSTR_IMPL_A64__ADDS_32_addsub_shift(Rd, Rn, imm6, Rm, shift);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/ab200000: ADDS  <Xd>, <Xn|SP>, <R><m>{, <extend>{ #<amount>}}
   Instruction Set: A64  Groups: addsub_ext, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADDS_64S_addsub_ext, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ADDS_64S_addsub_ext Rd=%#x Rn=%#x imm3=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADDS_64S_addsub_ext
    IEM_INSTR_IMPL_A64__ADDS_64S_addsub_ext(Rd, Rn, imm3, option, Rm);
#else
    RT_NOREF(Rd, Rn, imm3, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/b1000000: ADDS  <Xd>, <Xn|SP>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: addsub_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ADDS_64S_addsub_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    uint32_t const sh         = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: ADDS_64S_addsub_imm Rd=%#x Rn=%#x imm12=%#x sh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm12, sh));
#ifdef IEM_INSTR_IMPL_A64__ADDS_64S_addsub_imm
    IEM_INSTR_IMPL_A64__ADDS_64S_addsub_imm(Rd, Rn, imm12, sh);
#else
    RT_NOREF(Rd, Rn, imm12, sh, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/ab000000: ADDS  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: addsub_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADDS_64_addsub_shift, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff200000)) == UINT32_C(0xab000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
        LogFlow(("%018x/%010x: ADDS_64_addsub_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ADDS_64_addsub_shift
        IEM_INSTR_IMPL_A64__ADDS_64_addsub_shift(Rd, Rn, imm6, Rm, shift);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e31b800: ADDV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ADDV_asimdall_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e31b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ADDV_asimdall_only Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ADDV_asimdall_only
            IEM_INSTR_IMPL_A64__ADDV_asimdall_only(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/0b200000: ADD  <Wd|WSP>, <Wn|WSP>, <Wm>{, <extend>{ #<amount>}}
   Instruction Set: A64  Groups: addsub_ext, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADD_32_addsub_ext, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ADD_32_addsub_ext Rd=%#x Rn=%#x imm3=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADD_32_addsub_ext
    IEM_INSTR_IMPL_A64__ADD_32_addsub_ext(Rd, Rn, imm3, option, Rm);
#else
    RT_NOREF(Rd, Rn, imm3, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/11000000: ADD  <Wd|WSP>, <Wn|WSP>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: addsub_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ADD_32_addsub_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    uint32_t const sh         = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: ADD_32_addsub_imm Rd=%#x Rn=%#x imm12=%#x sh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm12, sh));
#ifdef IEM_INSTR_IMPL_A64__ADD_32_addsub_imm
    IEM_INSTR_IMPL_A64__ADD_32_addsub_imm(Rd, Rn, imm12, sh);
#else
    RT_NOREF(Rd, Rn, imm12, sh, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/0b000000: ADD  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: addsub_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADD_32_addsub_shift, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff200000)) == UINT32_C(0x0b000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
        LogFlow(("%018x/%010x: ADD_32_addsub_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ADD_32_addsub_shift
        IEM_INSTR_IMPL_A64__ADD_32_addsub_shift(Rd, Rn, imm6, Rm, shift);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/8b200000: ADD  <Xd|SP>, <Xn|SP>, <R><m>{, <extend>{ #<amount>}}
   Instruction Set: A64  Groups: addsub_ext, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADD_64_addsub_ext, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ADD_64_addsub_ext Rd=%#x Rn=%#x imm3=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADD_64_addsub_ext
    IEM_INSTR_IMPL_A64__ADD_64_addsub_ext(Rd, Rn, imm3, option, Rm);
#else
    RT_NOREF(Rd, Rn, imm3, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/91000000: ADD  <Xd|SP>, <Xn|SP>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: addsub_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ADD_64_addsub_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    uint32_t const sh         = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: ADD_64_addsub_imm Rd=%#x Rn=%#x imm12=%#x sh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm12, sh));
#ifdef IEM_INSTR_IMPL_A64__ADD_64_addsub_imm
    IEM_INSTR_IMPL_A64__ADD_64_addsub_imm(Rd, Rn, imm12, sh);
#else
    RT_NOREF(Rd, Rn, imm12, sh, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/8b000000: ADD  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: addsub_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ADD_64_addsub_shift, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff200000)) == UINT32_C(0x8b000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
        LogFlow(("%018x/%010x: ADD_64_addsub_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ADD_64_addsub_shift
        IEM_INSTR_IMPL_A64__ADD_64_addsub_shift(Rd, Rn, imm6, Rm, shift);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e208400: ADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ADD_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ADD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ADD_asimdsame_only
        IEM_INSTR_IMPL_A64__ADD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5ee08400: ADD  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ADD_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ADD_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__ADD_asisdsame_only
        IEM_INSTR_IMPL_A64__ADD_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 9f000000/90000000: ADRP  <Xd>, <label>
   Instruction Set: A64  Groups: pcreladdr, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ADRP_only_pcreladdr, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const immhi      = (uOpcode >>  5) & 0x0007ffff;
    uint32_t const immlo      = (uOpcode >> 29) & 0x00000003;
    LogFlow(("%018x/%010x: ADRP_only_pcreladdr Rd=%#x immhi=%#x immlo=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, immhi, immlo));
#ifdef IEM_INSTR_IMPL_A64__ADRP_only_pcreladdr
    IEM_INSTR_IMPL_A64__ADRP_only_pcreladdr(Rd, immhi, immlo);
#else
    RT_NOREF(Rd, immhi, immlo, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* 9f000000/10000000: ADR  <Xd>, <label>
   Instruction Set: A64  Groups: pcreladdr, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ADR_only_pcreladdr, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const immhi      = (uOpcode >>  5) & 0x0007ffff;
    uint32_t const immlo      = (uOpcode >> 29) & 0x00000003;
    LogFlow(("%018x/%010x: ADR_only_pcreladdr Rd=%#x immhi=%#x immlo=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, immhi, immlo));
#ifdef IEM_INSTR_IMPL_A64__ADR_only_pcreladdr
    IEM_INSTR_IMPL_A64__ADR_only_pcreladdr(Rd, immhi, immlo);
#else
    RT_NOREF(Rd, immhi, immlo, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffffc00/4e285800: AESD  <Vd>.16B, <Vn>.16B
   Instruction Set: A64  Groups: cryptoaes, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_AESD_B_cryptoaes, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAes /*FEAT_AES*/)
    {
        LogFlow(("%018x/%010x: AESD_B_cryptoaes Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__AESD_B_cryptoaes
        IEM_INSTR_IMPL_A64__AESD_B_cryptoaes(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/4e284800: AESE  <Vd>.16B, <Vn>.16B
   Instruction Set: A64  Groups: cryptoaes, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_AESE_B_cryptoaes, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAes /*FEAT_AES*/)
    {
        LogFlow(("%018x/%010x: AESE_B_cryptoaes Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__AESE_B_cryptoaes
        IEM_INSTR_IMPL_A64__AESE_B_cryptoaes(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/4e287800: AESIMC  <Vd>.16B, <Vn>.16B
   Instruction Set: A64  Groups: cryptoaes, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_AESIMC_B_cryptoaes, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAes /*FEAT_AES*/)
    {
        LogFlow(("%018x/%010x: AESIMC_B_cryptoaes Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__AESIMC_B_cryptoaes
        IEM_INSTR_IMPL_A64__AESIMC_B_cryptoaes(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/4e286800: AESMC  <Vd>.16B, <Vn>.16B
   Instruction Set: A64  Groups: cryptoaes, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_AESMC_B_cryptoaes, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAes /*FEAT_AES*/)
    {
        LogFlow(("%018x/%010x: AESMC_B_cryptoaes Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__AESMC_B_cryptoaes
        IEM_INSTR_IMPL_A64__AESMC_B_cryptoaes(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/72000000: ANDS  <Wd>, <Wn>, #<imm>
   Instruction Set: A64  Groups: log_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ANDS_32S_log_imm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x72000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
        LogFlow(("%018x/%010x: ANDS_32S_log_imm Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__ANDS_32S_log_imm
        IEM_INSTR_IMPL_A64__ANDS_32S_log_imm(Rd, Rn, imms, immr);
#else
        RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff200000/6a000000: ANDS  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ANDS_32_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: ANDS_32_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ANDS_32_log_shift
    IEM_INSTR_IMPL_A64__ANDS_32_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/f2000000: ANDS  <Xd>, <Xn>, #<imm>
   Instruction Set: A64  Groups: log_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ANDS_64S_log_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    uint32_t const N          = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: ANDS_64S_log_imm Rd=%#x Rn=%#x imms=%#x immr=%#x N=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr, N));
#ifdef IEM_INSTR_IMPL_A64__ANDS_64S_log_imm
    IEM_INSTR_IMPL_A64__ANDS_64S_log_imm(Rd, Rn, imms, immr, N);
#else
    RT_NOREF(Rd, Rn, imms, immr, N, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/ea000000: ANDS  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ANDS_64_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: ANDS_64_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ANDS_64_log_shift
    IEM_INSTR_IMPL_A64__ANDS_64_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/12000000: AND  <Wd|WSP>, <Wn>, #<imm>
   Instruction Set: A64  Groups: log_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_AND_32_log_imm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x12000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
        LogFlow(("%018x/%010x: AND_32_log_imm Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__AND_32_log_imm
        IEM_INSTR_IMPL_A64__AND_32_log_imm(Rd, Rn, imms, immr);
#else
        RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff200000/0a000000: AND  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AND_32_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: AND_32_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__AND_32_log_shift
    IEM_INSTR_IMPL_A64__AND_32_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/92000000: AND  <Xd|SP>, <Xn>, #<imm>
   Instruction Set: A64  Groups: log_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_AND_64_log_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    uint32_t const N          = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: AND_64_log_imm Rd=%#x Rn=%#x imms=%#x immr=%#x N=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr, N));
#ifdef IEM_INSTR_IMPL_A64__AND_64_log_imm
    IEM_INSTR_IMPL_A64__AND_64_log_imm(Rd, Rn, imms, immr, N);
#else
    RT_NOREF(Rd, Rn, imms, immr, N, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/8a000000: AND  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AND_64_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: AND_64_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__AND_64_log_shift
    IEM_INSTR_IMPL_A64__AND_64_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bfe0fc00/0e201c00: AND  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_AND_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: AND_asimdsame_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__AND_asimdsame_only
        IEM_INSTR_IMPL_A64__AND_asimdsame_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac02800: ASRV  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ASRV_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ASRV_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__ASRV_32_dp_2src
    IEM_INSTR_IMPL_A64__ASRV_32_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9ac02800: ASRV  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ASRV_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: ASRV_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__ASRV_64_dp_2src
    IEM_INSTR_IMPL_A64__ASRV_64_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffffc00/dac11800: AUTDA  <Xd>, <Xn|SP>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTDA_64P_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTDA_64P_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__AUTDA_64P_dp_1src
        IEM_INSTR_IMPL_A64__AUTDA_64P_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac11c00: AUTDB  <Xd>, <Xn|SP>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTDB_64P_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTDB_64P_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__AUTDB_64P_dp_1src
        IEM_INSTR_IMPL_A64__AUTDB_64P_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac13be0: AUTDZA  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTDZA_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac13be0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: AUTDZA_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__AUTDZA_64Z_dp_1src
            IEM_INSTR_IMPL_A64__AUTDZA_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac13fe0: AUTDZB  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTDZB_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac13fe0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: AUTDZB_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__AUTDZB_64Z_dp_1src
            IEM_INSTR_IMPL_A64__AUTDZB_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/dac1bbfe: AUTIA171615
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTIA171615_64LR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xdac1bbfe))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: AUTIA171615_64LR_dp_1src\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AUTIA171615_64LR_dp_1src
            IEM_INSTR_IMPL_A64__AUTIA171615_64LR_dp_1src();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503219f: AUTIA1716
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_AUTIA1716_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTIA1716_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AUTIA1716_HI_hints
        IEM_INSTR_IMPL_A64__AUTIA1716_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/dac1901e: AUTIASPPCR  <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTIASPPCR_64LRR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xdac1901e))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: AUTIASPPCR_64LRR_dp_1src Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__AUTIASPPCR_64LRR_dp_1src
            IEM_INSTR_IMPL_A64__AUTIASPPCR_64LRR_dp_1src(Rn);
#else
            RT_NOREF(Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/f380001f: AUTIASPPC  <label>
   Instruction Set: A64  Groups: dp_1src_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_AUTIASPPC_only_dp_1src_imm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xf380001f))
    {
        uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: AUTIASPPC_only_dp_1src_imm imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__AUTIASPPC_only_dp_1src_imm
            IEM_INSTR_IMPL_A64__AUTIASPPC_only_dp_1src_imm(imm16);
#else
            RT_NOREF(imm16, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d50323bf: AUTIASP
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_AUTIASP_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTIASP_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AUTIASP_HI_hints
        IEM_INSTR_IMPL_A64__AUTIASP_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503239f: AUTIAZ
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_AUTIAZ_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTIAZ_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AUTIAZ_HI_hints
        IEM_INSTR_IMPL_A64__AUTIAZ_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac11000: AUTIA  <Xd>, <Xn|SP>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTIA_64P_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTIA_64P_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__AUTIA_64P_dp_1src
        IEM_INSTR_IMPL_A64__AUTIA_64P_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/dac1bffe: AUTIB171615
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTIB171615_64LR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xdac1bffe))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: AUTIB171615_64LR_dp_1src\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AUTIB171615_64LR_dp_1src
            IEM_INSTR_IMPL_A64__AUTIB171615_64LR_dp_1src();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d50321df: AUTIB1716
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_AUTIB1716_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTIB1716_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AUTIB1716_HI_hints
        IEM_INSTR_IMPL_A64__AUTIB1716_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/dac1941e: AUTIBSPPCR  <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTIBSPPCR_64LRR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xdac1941e))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: AUTIBSPPCR_64LRR_dp_1src Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__AUTIBSPPCR_64LRR_dp_1src
            IEM_INSTR_IMPL_A64__AUTIBSPPCR_64LRR_dp_1src(Rn);
#else
            RT_NOREF(Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/f3a0001f: AUTIBSPPC  <label>
   Instruction Set: A64  Groups: dp_1src_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_AUTIBSPPC_only_dp_1src_imm, uint32_t, uOpcode)
{
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
    {
        LogFlow(("%018x/%010x: AUTIBSPPC_only_dp_1src_imm imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__AUTIBSPPC_only_dp_1src_imm
        IEM_INSTR_IMPL_A64__AUTIBSPPC_only_dp_1src_imm(imm16);
#else
        RT_NOREF(imm16, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d50323ff: AUTIBSP
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_AUTIBSP_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTIBSP_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AUTIBSP_HI_hints
        IEM_INSTR_IMPL_A64__AUTIBSP_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d50323df: AUTIBZ
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_AUTIBZ_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTIBZ_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AUTIBZ_HI_hints
        IEM_INSTR_IMPL_A64__AUTIBZ_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac11400: AUTIB  <Xd>, <Xn|SP>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTIB_64P_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: AUTIB_64P_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__AUTIB_64P_dp_1src
        IEM_INSTR_IMPL_A64__AUTIB_64P_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac133e0: AUTIZA  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTIZA_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac133e0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: AUTIZA_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__AUTIZA_64Z_dp_1src
            IEM_INSTR_IMPL_A64__AUTIZA_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac137e0: AUTIZB  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_AUTIZB_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac137e0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: AUTIZB_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__AUTIZB_64Z_dp_1src
            IEM_INSTR_IMPL_A64__AUTIZB_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d500405f: AXFLAG
   Instruction Set: A64  Groups: pstate, control */
FNIEMOP_DEF_1(iemDecodeA64_AXFLAG_M_pstate, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFlagM2 /*FEAT_FlagM2*/)
    {
        LogFlow(("%018x/%010x: AXFLAG_M_pstate\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__AXFLAG_M_pstate
        IEM_INSTR_IMPL_A64__AXFLAG_M_pstate();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/ce200000: BCAX  <Vd>.16B, <Vn>.16B, <Vm>.16B, <Va>.16B
   Instruction Set: A64  Groups: crypto4, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BCAX_VVV16_crypto4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce200000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha3 /*FEAT_SHA3*/)
        {
            LogFlow(("%018x/%010x: BCAX_VVV16_crypto4 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__BCAX_VVV16_crypto4
            IEM_INSTR_IMPL_A64__BCAX_VVV16_crypto4(Rd, Rn, Ra, Rm);
#else
            RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff000010/54000010: BC.<cond>  <label>
   Instruction Set: A64  Groups: condbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_BC_only_condbranch, uint32_t, uOpcode)
{
    uint32_t const cond       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fHbc /*FEAT_HBC*/)
    {
        LogFlow(("%018x/%010x: BC_only_condbranch cond=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, cond, imm19));
#ifdef IEM_INSTR_IMPL_A64__BC_only_condbranch
        IEM_INSTR_IMPL_A64__BC_only_condbranch(cond, imm19);
#else
        RT_NOREF(cond, imm19, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ea17800: BF1CVTL2  <Vd>.8H, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BF1CVTL_asimdmisc_V, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: BF1CVTL_asimdmisc_V Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__BF1CVTL_asimdmisc_V
        IEM_INSTR_IMPL_A64__BF1CVTL_asimdmisc_V(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ee17800: BF2CVTL2  <Vd>.8H, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BF2CVTL_asimdmisc_V, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: BF2CVTL_asimdmisc_V Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__BF2CVTL_asimdmisc_V
        IEM_INSTR_IMPL_A64__BF2CVTL_asimdmisc_V(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ea16800: BFCVTN2  <Vd>.<Ta>, <Vn>.4S
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BFCVTN_asimdmisc_4S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: BFCVTN_asimdmisc_4S Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__BFCVTN_asimdmisc_4S
        IEM_INSTR_IMPL_A64__BFCVTN_asimdmisc_4S(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e634000: BFCVT  <Hd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BFCVT_BS_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: BFCVT_BS_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__BFCVT_BS_floatdp1
        IEM_INSTR_IMPL_A64__BFCVT_BS_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f40f000: BFDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.2H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BFDOT_asimdelem_E, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f40f000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
        {
            LogFlow(("%018x/%010x: BFDOT_asimdelem_E Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__BFDOT_asimdelem_E
            IEM_INSTR_IMPL_A64__BFDOT_asimdelem_E(Rd, Rn, H, Rm, M, L, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e40fc00: BFDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BFDOT_asimdsame2_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e40fc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
        {
            LogFlow(("%018x/%010x: BFDOT_asimdsame2_D Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__BFDOT_asimdsame2_D
            IEM_INSTR_IMPL_A64__BFDOT_asimdsame2_D(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0fc0f000: BFMLAL<bt>  <Vd>.4S, <Vn>.8H, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BFMLAL_asimdelem_F, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0fc0f000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
        {
            LogFlow(("%018x/%010x: BFMLAL_asimdelem_F Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__BFMLAL_asimdelem_F
            IEM_INSTR_IMPL_A64__BFMLAL_asimdelem_F(Rd, Rn, H, Rm, M, L, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ec0fc00: BFMLAL<bt>  <Vd>.4S, <Vn>.8H, <Vm>.8H
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BFMLAL_asimdsame2_F, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ec0fc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
        {
            LogFlow(("%018x/%010x: BFMLAL_asimdsame2_F Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__BFMLAL_asimdsame2_F
            IEM_INSTR_IMPL_A64__BFMLAL_asimdsame2_F(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6e40ec00: BFMMLA  <Vd>.4S, <Vn>.8H, <Vm>.8H
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BFMMLA_asimdsame2_E, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x6e40ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
        {
            LogFlow(("%018x/%010x: BFMMLA_asimdsame2_E Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__BFMMLA_asimdsame2_E
            IEM_INSTR_IMPL_A64__BFMMLA_asimdsame2_E(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/33000000: BFM  <Wd>, <Wn>, #<immr>, #<imms>
   Instruction Set: A64  Groups: bitfield, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_BFM_32M_bitfield, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    LogFlow(("%018x/%010x: BFM_32M_bitfield Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__BFM_32M_bitfield
    IEM_INSTR_IMPL_A64__BFM_32M_bitfield(Rd, Rn, imms, immr);
#else
    RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/b3400000: BFM  <Xd>, <Xn>, #<immr>, #<imms>
   Instruction Set: A64  Groups: bitfield, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_BFM_64M_bitfield, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    LogFlow(("%018x/%010x: BFM_64M_bitfield Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__BFM_64M_bitfield
    IEM_INSTR_IMPL_A64__BFM_64M_bitfield(Rd, Rn, imms, immr);
#else
    RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/6a200000: BICS  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_BICS_32_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: BICS_32_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__BICS_32_log_shift
    IEM_INSTR_IMPL_A64__BICS_32_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/ea200000: BICS  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_BICS_64_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: BICS_64_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__BICS_64_log_shift
    IEM_INSTR_IMPL_A64__BICS_64_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/0a200000: BIC  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_BIC_32_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: BIC_32_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__BIC_32_log_shift
    IEM_INSTR_IMPL_A64__BIC_32_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/8a200000: BIC  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_BIC_64_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: BIC_64_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__BIC_64_log_shift
    IEM_INSTR_IMPL_A64__BIC_64_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bff8dc00/2f009400: BIC  <Vd>.<T>, #<imm8>{, LSL #<amount>}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BIC_asimdimm_L_hl, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbff8dc00)) == UINT32_C(0x2f009400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const h          = (uOpcode >>  5) & 0x00000001;
        uint32_t const g          = (uOpcode >>  6) & 0x00000001;
        uint32_t const f          = (uOpcode >>  7) & 0x00000001;
        uint32_t const e          = (uOpcode >>  8) & 0x00000001;
        uint32_t const d          = (uOpcode >>  9) & 0x00000001;
        uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
        uint32_t const c          = (uOpcode >> 16) & 0x00000001;
        uint32_t const b          = (uOpcode >> 17) & 0x00000001;
        uint32_t const a          = (uOpcode >> 18) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: BIC_asimdimm_L_hl Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__BIC_asimdimm_L_hl
            IEM_INSTR_IMPL_A64__BIC_asimdimm_L_hl(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
            RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff89c00/2f001400: BIC  <Vd>.<T>, #<imm8>{, LSL #<amount>}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BIC_asimdimm_L_sl, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: BIC_asimdimm_L_sl Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__BIC_asimdimm_L_sl
        IEM_INSTR_IMPL_A64__BIC_asimdimm_L_sl(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
        RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e601c00: BIC  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BIC_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e601c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: BIC_asimdsame_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__BIC_asimdsame_only
            IEM_INSTR_IMPL_A64__BIC_asimdsame_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ee01c00: BIF  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BIF_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ee01c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: BIF_asimdsame_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__BIF_asimdsame_only
            IEM_INSTR_IMPL_A64__BIF_asimdsame_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ea01c00: BIT  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BIT_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: BIT_asimdsame_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__BIT_asimdsame_only
        IEM_INSTR_IMPL_A64__BIT_asimdsame_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/d63f081f: BLRAAZ  <Xn>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BLRAAZ_64_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xd63f081f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: BLRAAZ_64_branch_reg Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__BLRAAZ_64_branch_reg
            IEM_INSTR_IMPL_A64__BLRAAZ_64_branch_reg(Rn);
#else
            RT_NOREF(Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d73f0800: BLRAA  <Xn>, <Xm|SP>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BLRAA_64P_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd73f0800))
    {
        uint32_t const Rm         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: BLRAA_64P_branch_reg Rm=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rm, Rn));
#ifdef IEM_INSTR_IMPL_A64__BLRAA_64P_branch_reg
            IEM_INSTR_IMPL_A64__BLRAA_64P_branch_reg(Rm, Rn);
#else
            RT_NOREF(Rm, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/d63f0c1f: BLRABZ  <Xn>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BLRABZ_64_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xd63f0c1f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: BLRABZ_64_branch_reg Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__BLRABZ_64_branch_reg
            IEM_INSTR_IMPL_A64__BLRABZ_64_branch_reg(Rn);
#else
            RT_NOREF(Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d73f0c00: BLRAB  <Xn>, <Xm|SP>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BLRAB_64P_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd73f0c00))
    {
        uint32_t const Rm         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: BLRAB_64P_branch_reg Rm=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rm, Rn));
#ifdef IEM_INSTR_IMPL_A64__BLRAB_64P_branch_reg
            IEM_INSTR_IMPL_A64__BLRAB_64P_branch_reg(Rm, Rn);
#else
            RT_NOREF(Rm, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/d63f0000: BLR  <Xn>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BLR_64_branch_reg, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    LogFlow(("%018x/%010x: BLR_64_branch_reg Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__BLR_64_branch_reg
    IEM_INSTR_IMPL_A64__BLR_64_branch_reg(Rn);
#else
    RT_NOREF(Rn, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fc000000/94000000: BL  <label>
   Instruction Set: A64  Groups: branch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_BL_only_branch_imm, uint32_t, uOpcode)
{
    uint32_t const imm26      = (uOpcode >>  0) & 0x03ffffff;
    LogFlow(("%018x/%010x: BL_only_branch_imm imm26=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm26));
#ifdef IEM_INSTR_IMPL_A64__BL_only_branch_imm
    IEM_INSTR_IMPL_A64__BL_only_branch_imm(imm26);
#else
    RT_NOREF(imm26, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffffc1f/d61f081f: BRAAZ  <Xn>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BRAAZ_64_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xd61f081f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: BRAAZ_64_branch_reg Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__BRAAZ_64_branch_reg
            IEM_INSTR_IMPL_A64__BRAAZ_64_branch_reg(Rn);
#else
            RT_NOREF(Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d71f0800: BRAA  <Xn>, <Xm|SP>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BRAA_64P_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd71f0800))
    {
        uint32_t const Rm         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: BRAA_64P_branch_reg Rm=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rm, Rn));
#ifdef IEM_INSTR_IMPL_A64__BRAA_64P_branch_reg
            IEM_INSTR_IMPL_A64__BRAA_64P_branch_reg(Rm, Rn);
#else
            RT_NOREF(Rm, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/d61f0c1f: BRABZ  <Xn>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BRABZ_64_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xd61f0c1f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: BRABZ_64_branch_reg Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__BRABZ_64_branch_reg
            IEM_INSTR_IMPL_A64__BRABZ_64_branch_reg(Rn);
#else
            RT_NOREF(Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d71f0c00: BRAB  <Xn>, <Xm|SP>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BRAB_64P_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd71f0c00))
    {
        uint32_t const Rm         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: BRAB_64P_branch_reg Rm=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rm, Rn));
#ifdef IEM_INSTR_IMPL_A64__BRAB_64P_branch_reg
            IEM_INSTR_IMPL_A64__BRAB_64P_branch_reg(Rm, Rn);
#else
            RT_NOREF(Rm, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/d4200000: BRK  #<imm>
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_BRK_EX_exception, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4200000))
    {
        uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
        LogFlow(("%018x/%010x: BRK_EX_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__BRK_EX_exception
        IEM_INSTR_IMPL_A64__BRK_EX_exception(imm16);
#else
        RT_NOREF(imm16, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/d61f0000: BR  <Xn>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_BR_64_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xd61f0000))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: BR_64_branch_reg Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__BR_64_branch_reg
        IEM_INSTR_IMPL_A64__BR_64_branch_reg(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e601c00: BSL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_BSL_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e601c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: BSL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__BSL_asimdsame_only
            IEM_INSTR_IMPL_A64__BSL_asimdsame_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffff1f/d503241f: BTI{  <targets>}
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_BTI_HB_hints, uint32_t, uOpcode)
{
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBti /*FEAT_BTI*/ && ((op2 & 1) == 0))
    {
        LogFlow(("%018x/%010x: BTI_HB_hints op2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, op2));
#ifdef IEM_INSTR_IMPL_A64__BTI_HB_hints
        IEM_INSTR_IMPL_A64__BTI_HB_hints(op2);
#else
        RT_NOREF(op2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fc000000/14000000: B  <label>
   Instruction Set: A64  Groups: branch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_B_only_branch_imm, uint32_t, uOpcode)
{
    uint32_t const imm26      = (uOpcode >>  0) & 0x03ffffff;
    LogFlow(("%018x/%010x: B_only_branch_imm imm26=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm26));
#ifdef IEM_INSTR_IMPL_A64__B_only_branch_imm
    IEM_INSTR_IMPL_A64__B_only_branch_imm(imm26);
#else
    RT_NOREF(imm26, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff000010/54000000: B.<cond>  <label>
   Instruction Set: A64  Groups: condbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_B_only_condbranch, uint32_t, uOpcode)
{
    uint32_t const cond       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    LogFlow(("%018x/%010x: B_only_condbranch cond=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, cond, imm19));
#ifdef IEM_INSTR_IMPL_A64__B_only_condbranch
    IEM_INSTR_IMPL_A64__B_only_condbranch(cond, imm19);
#else
    RT_NOREF(cond, imm19, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/08e07c00: CASAB  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASAB_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASAB_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASAB_C32_comswap
        IEM_INSTR_IMPL_A64__CASAB_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/48e07c00: CASAH  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASAH_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASAH_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASAH_C32_comswap
        IEM_INSTR_IMPL_A64__CASAH_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/08e0fc00: CASALB  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASALB_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASALB_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASALB_C32_comswap
        IEM_INSTR_IMPL_A64__CASALB_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/48e0fc00: CASALH  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASALH_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASALH_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASALH_C32_comswap
        IEM_INSTR_IMPL_A64__CASALH_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c9c0fc00: CASALT  <Xs>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASALT_C64_comswap_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: CASALT_C64_comswap_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASALT_C64_comswap_unpriv
        IEM_INSTR_IMPL_A64__CASALT_C64_comswap_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/88e0fc00: CASAL  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASAL_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASAL_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASAL_C32_comswap
        IEM_INSTR_IMPL_A64__CASAL_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c8e0fc00: CASAL  <Xs>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASAL_C64_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASAL_C64_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASAL_C64_comswap
        IEM_INSTR_IMPL_A64__CASAL_C64_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c9c07c00: CASAT  <Xs>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASAT_C64_comswap_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: CASAT_C64_comswap_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASAT_C64_comswap_unpriv
        IEM_INSTR_IMPL_A64__CASAT_C64_comswap_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/88e07c00: CASA  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASA_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASA_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASA_C32_comswap
        IEM_INSTR_IMPL_A64__CASA_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c8e07c00: CASA  <Xs>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASA_C64_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASA_C64_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASA_C64_comswap
        IEM_INSTR_IMPL_A64__CASA_C64_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/08a07c00: CASB  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASB_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASB_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASB_C32_comswap
        IEM_INSTR_IMPL_A64__CASB_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/48a07c00: CASH  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASH_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASH_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASH_C32_comswap
        IEM_INSTR_IMPL_A64__CASH_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/08a0fc00: CASLB  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASLB_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASLB_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASLB_C32_comswap
        IEM_INSTR_IMPL_A64__CASLB_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/48a0fc00: CASLH  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASLH_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASLH_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASLH_C32_comswap
        IEM_INSTR_IMPL_A64__CASLH_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c980fc00: CASLT  <Xs>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASLT_C64_comswap_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: CASLT_C64_comswap_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASLT_C64_comswap_unpriv
        IEM_INSTR_IMPL_A64__CASLT_C64_comswap_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/88a0fc00: CASL  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASL_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASL_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASL_C32_comswap
        IEM_INSTR_IMPL_A64__CASL_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c8a0fc00: CASL  <Xs>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASL_C64_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASL_C64_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASL_C64_comswap
        IEM_INSTR_IMPL_A64__CASL_C64_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/49c0fc00: CASPALT  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPALT_CP64_comswappr_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: CASPALT_CP64_comswappr_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPALT_CP64_comswappr_unpriv
        IEM_INSTR_IMPL_A64__CASPALT_CP64_comswappr_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/0860fc00: CASPAL  <Ws>, <W(s+1)>, <Wt>, <W(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPAL_CP32_comswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASPAL_CP32_comswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPAL_CP32_comswappr
        IEM_INSTR_IMPL_A64__CASPAL_CP32_comswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4860fc00: CASPAL  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPAL_CP64_comswappr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4860fc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
        {
            LogFlow(("%018x/%010x: CASPAL_CP64_comswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPAL_CP64_comswappr
            IEM_INSTR_IMPL_A64__CASPAL_CP64_comswappr(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/49c07c00: CASPAT  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPAT_CP64_comswappr_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: CASPAT_CP64_comswappr_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPAT_CP64_comswappr_unpriv
        IEM_INSTR_IMPL_A64__CASPAT_CP64_comswappr_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/08607c00: CASPA  <Ws>, <W(s+1)>, <Wt>, <W(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPA_CP32_comswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASPA_CP32_comswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPA_CP32_comswappr
        IEM_INSTR_IMPL_A64__CASPA_CP32_comswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/48607c00: CASPA  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPA_CP64_comswappr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x48607c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
        {
            LogFlow(("%018x/%010x: CASPA_CP64_comswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPA_CP64_comswappr
            IEM_INSTR_IMPL_A64__CASPA_CP64_comswappr(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4980fc00: CASPLT  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPLT_CP64_comswappr_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: CASPLT_CP64_comswappr_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPLT_CP64_comswappr_unpriv
        IEM_INSTR_IMPL_A64__CASPLT_CP64_comswappr_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/0820fc00: CASPL  <Ws>, <W(s+1)>, <Wt>, <W(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPL_CP32_comswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASPL_CP32_comswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPL_CP32_comswappr
        IEM_INSTR_IMPL_A64__CASPL_CP32_comswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4820fc00: CASPL  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPL_CP64_comswappr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4820fc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
        {
            LogFlow(("%018x/%010x: CASPL_CP64_comswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPL_CP64_comswappr
            IEM_INSTR_IMPL_A64__CASPL_CP64_comswappr(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/49807c00: CASPT  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASPT_CP64_comswappr_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: CASPT_CP64_comswappr_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASPT_CP64_comswappr_unpriv
        IEM_INSTR_IMPL_A64__CASPT_CP64_comswappr_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/08207c00: CASP  <Ws>, <W(s+1)>, <Wt>, <W(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASP_CP32_comswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CASP_CP32_comswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASP_CP32_comswappr
        IEM_INSTR_IMPL_A64__CASP_CP32_comswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/48207c00: CASP  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CASP_CP64_comswappr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x48207c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
        {
            LogFlow(("%018x/%010x: CASP_CP64_comswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CASP_CP64_comswappr
            IEM_INSTR_IMPL_A64__CASP_CP64_comswappr(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c9807c00: CAST  <Xs>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CAST_C64_comswap_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: CAST_C64_comswap_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CAST_C64_comswap_unpriv
        IEM_INSTR_IMPL_A64__CAST_C64_comswap_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/88a07c00: CAS  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CAS_C32_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CAS_C32_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CAS_C32_comswap
        IEM_INSTR_IMPL_A64__CAS_C32_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c8a07c00: CAS  <Xs>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: comswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CAS_C64_comswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: CAS_C64_comswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__CAS_C64_comswap
        IEM_INSTR_IMPL_A64__CAS_C64_comswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74c08000: CBBEQ  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBBEQ_8_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBBEQ_8_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBBEQ_8_regs
        IEM_INSTR_IMPL_A64__CBBEQ_8_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74208000: CBBGE  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBBGE_8_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBBGE_8_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBBGE_8_regs
        IEM_INSTR_IMPL_A64__CBBGE_8_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74008000: CBBGT  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBBGT_8_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBBGT_8_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBBGT_8_regs
        IEM_INSTR_IMPL_A64__CBBGT_8_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74408000: CBBHI  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBBHI_8_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBBHI_8_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBBHI_8_regs
        IEM_INSTR_IMPL_A64__CBBHI_8_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74608000: CBBHS  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBBHS_8_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBBHS_8_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBBHS_8_regs
        IEM_INSTR_IMPL_A64__CBBHS_8_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74e08000: CBBNE  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBBNE_8_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBBNE_8_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBBNE_8_regs
        IEM_INSTR_IMPL_A64__CBBNE_8_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/75c00000: CBEQ  <Wt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBEQ_32_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBEQ_32_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBEQ_32_imm
        IEM_INSTR_IMPL_A64__CBEQ_32_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74c00000: CBEQ  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBEQ_32_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBEQ_32_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBEQ_32_regs
        IEM_INSTR_IMPL_A64__CBEQ_32_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/f5c00000: CBEQ  <Xt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBEQ_64_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBEQ_64_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBEQ_64_imm
        IEM_INSTR_IMPL_A64__CBEQ_64_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/f4c00000: CBEQ  <Xt>, <Xm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBEQ_64_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBEQ_64_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBEQ_64_regs
        IEM_INSTR_IMPL_A64__CBEQ_64_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74200000: CBGE  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBGE_32_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBGE_32_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBGE_32_regs
        IEM_INSTR_IMPL_A64__CBGE_32_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/f4200000: CBGE  <Xt>, <Xm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBGE_64_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBGE_64_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBGE_64_regs
        IEM_INSTR_IMPL_A64__CBGE_64_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/75000000: CBGT  <Wt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBGT_32_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBGT_32_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBGT_32_imm
        IEM_INSTR_IMPL_A64__CBGT_32_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74000000: CBGT  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBGT_32_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBGT_32_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBGT_32_regs
        IEM_INSTR_IMPL_A64__CBGT_32_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/f5000000: CBGT  <Xt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBGT_64_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBGT_64_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBGT_64_imm
        IEM_INSTR_IMPL_A64__CBGT_64_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/f4000000: CBGT  <Xt>, <Xm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBGT_64_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBGT_64_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBGT_64_regs
        IEM_INSTR_IMPL_A64__CBGT_64_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74c0c000: CBHEQ  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHEQ_16_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHEQ_16_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHEQ_16_regs
        IEM_INSTR_IMPL_A64__CBHEQ_16_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/7420c000: CBHGE  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHGE_16_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHGE_16_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHGE_16_regs
        IEM_INSTR_IMPL_A64__CBHGE_16_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/7400c000: CBHGT  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHGT_16_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHGT_16_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHGT_16_regs
        IEM_INSTR_IMPL_A64__CBHGT_16_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/7440c000: CBHHI  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHHI_16_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHHI_16_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHHI_16_regs
        IEM_INSTR_IMPL_A64__CBHHI_16_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/7460c000: CBHHS  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHHS_16_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHHS_16_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHHS_16_regs
        IEM_INSTR_IMPL_A64__CBHHS_16_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/75400000: CBHI  <Wt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHI_32_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHI_32_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBHI_32_imm
        IEM_INSTR_IMPL_A64__CBHI_32_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74400000: CBHI  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHI_32_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHI_32_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHI_32_regs
        IEM_INSTR_IMPL_A64__CBHI_32_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/f5400000: CBHI  <Xt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHI_64_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHI_64_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBHI_64_imm
        IEM_INSTR_IMPL_A64__CBHI_64_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/f4400000: CBHI  <Xt>, <Xm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHI_64_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHI_64_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHI_64_regs
        IEM_INSTR_IMPL_A64__CBHI_64_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74e0c000: CBHNE  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs2, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHNE_16_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHNE_16_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHNE_16_regs
        IEM_INSTR_IMPL_A64__CBHNE_16_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74600000: CBHS  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHS_32_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHS_32_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHS_32_regs
        IEM_INSTR_IMPL_A64__CBHS_32_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/f4600000: CBHS  <Xt>, <Xm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBHS_64_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBHS_64_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBHS_64_regs
        IEM_INSTR_IMPL_A64__CBHS_64_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/75600000: CBLO  <Wt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBLO_32_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBLO_32_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBLO_32_imm
        IEM_INSTR_IMPL_A64__CBLO_32_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/f5600000: CBLO  <Xt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBLO_64_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBLO_64_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBLO_64_imm
        IEM_INSTR_IMPL_A64__CBLO_64_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/75200000: CBLT  <Wt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBLT_32_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBLT_32_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBLT_32_imm
        IEM_INSTR_IMPL_A64__CBLT_32_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/f5200000: CBLT  <Xt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBLT_64_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBLT_64_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBLT_64_imm
        IEM_INSTR_IMPL_A64__CBLT_64_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/75e00000: CBNE  <Wt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBNE_32_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBNE_32_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBNE_32_imm
        IEM_INSTR_IMPL_A64__CBNE_32_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/74e00000: CBNE  <Wt>, <Wm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBNE_32_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBNE_32_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBNE_32_regs
        IEM_INSTR_IMPL_A64__CBNE_32_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe04000/f5e00000: CBNE  <Xt>, #<imm>, <label>
   Instruction Set: A64  Groups: compbranch_imm, control */
FNIEMOP_DEF_1(iemDecodeA64_CBNE_64_imm, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBNE_64_imm Rt=%#x imm9=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, imm6));
#ifdef IEM_INSTR_IMPL_A64__CBNE_64_imm
        IEM_INSTR_IMPL_A64__CBNE_64_imm(Rt, imm9, imm6);
#else
        RT_NOREF(Rt, imm9, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0c000/f4e00000: CBNE  <Xt>, <Xm>, <label>
   Instruction Set: A64  Groups: compbranch_regs, control */
FNIEMOP_DEF_1(iemDecodeA64_CBNE_64_regs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >>  5) & 0x000001ff;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCmpBr /*FEAT_CMPBR*/)
    {
        LogFlow(("%018x/%010x: CBNE_64_regs Rt=%#x imm9=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm9, Rm));
#ifdef IEM_INSTR_IMPL_A64__CBNE_64_regs
        IEM_INSTR_IMPL_A64__CBNE_64_regs(Rt, imm9, Rm);
#else
        RT_NOREF(Rt, imm9, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff000000/35000000: CBNZ  <Wt>, <label>
   Instruction Set: A64  Groups: compbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_CBNZ_32_compbranch, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    LogFlow(("%018x/%010x: CBNZ_32_compbranch Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__CBNZ_32_compbranch
    IEM_INSTR_IMPL_A64__CBNZ_32_compbranch(Rt, imm19);
#else
    RT_NOREF(Rt, imm19, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff000000/b5000000: CBNZ  <Xt>, <label>
   Instruction Set: A64  Groups: compbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_CBNZ_64_compbranch, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    LogFlow(("%018x/%010x: CBNZ_64_compbranch Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__CBNZ_64_compbranch
    IEM_INSTR_IMPL_A64__CBNZ_64_compbranch(Rt, imm19);
#else
    RT_NOREF(Rt, imm19, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff000000/34000000: CBZ  <Wt>, <label>
   Instruction Set: A64  Groups: compbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_CBZ_32_compbranch, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    LogFlow(("%018x/%010x: CBZ_32_compbranch Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__CBZ_32_compbranch
    IEM_INSTR_IMPL_A64__CBZ_32_compbranch(Rt, imm19);
#else
    RT_NOREF(Rt, imm19, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff000000/b4000000: CBZ  <Xt>, <label>
   Instruction Set: A64  Groups: compbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_CBZ_64_compbranch, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    LogFlow(("%018x/%010x: CBZ_64_compbranch Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__CBZ_64_compbranch
    IEM_INSTR_IMPL_A64__CBZ_64_compbranch(Rt, imm19);
#else
    RT_NOREF(Rt, imm19, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c10/3a400800: CCMN  <Wn>, #<imm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: condcmp_imm, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CCMN_32_condcmp_imm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x3a400800))
    {
        uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        LogFlow(("%018x/%010x: CCMN_32_condcmp_imm nzcv=%#x Rn=%#x cond=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, imm5));
#ifdef IEM_INSTR_IMPL_A64__CCMN_32_condcmp_imm
        IEM_INSTR_IMPL_A64__CCMN_32_condcmp_imm(nzcv, Rn, cond, imm5);
#else
        RT_NOREF(nzcv, Rn, cond, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/3a400000: CCMN  <Wn>, <Wm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: condcmp_reg, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CCMN_32_condcmp_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x3a400000))
    {
        uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        LogFlow(("%018x/%010x: CCMN_32_condcmp_reg nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CCMN_32_condcmp_reg
        IEM_INSTR_IMPL_A64__CCMN_32_condcmp_reg(nzcv, Rn, cond, Rm);
#else
        RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/ba400800: CCMN  <Xn>, #<imm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: condcmp_imm, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CCMN_64_condcmp_imm, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CCMN_64_condcmp_imm nzcv=%#x Rn=%#x cond=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, imm5));
#ifdef IEM_INSTR_IMPL_A64__CCMN_64_condcmp_imm
    IEM_INSTR_IMPL_A64__CCMN_64_condcmp_imm(nzcv, Rn, cond, imm5);
#else
    RT_NOREF(nzcv, Rn, cond, imm5, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c10/ba400000: CCMN  <Xn>, <Xm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: condcmp_reg, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CCMN_64_condcmp_reg, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CCMN_64_condcmp_reg nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CCMN_64_condcmp_reg
    IEM_INSTR_IMPL_A64__CCMN_64_condcmp_reg(nzcv, Rn, cond, Rm);
#else
    RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c10/7a400800: CCMP  <Wn>, #<imm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: condcmp_imm, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CCMP_32_condcmp_imm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x7a400800))
    {
        uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        LogFlow(("%018x/%010x: CCMP_32_condcmp_imm nzcv=%#x Rn=%#x cond=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, imm5));
#ifdef IEM_INSTR_IMPL_A64__CCMP_32_condcmp_imm
        IEM_INSTR_IMPL_A64__CCMP_32_condcmp_imm(nzcv, Rn, cond, imm5);
#else
        RT_NOREF(nzcv, Rn, cond, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/7a400000: CCMP  <Wn>, <Wm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: condcmp_reg, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CCMP_32_condcmp_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x7a400000))
    {
        uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        LogFlow(("%018x/%010x: CCMP_32_condcmp_reg nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CCMP_32_condcmp_reg
        IEM_INSTR_IMPL_A64__CCMP_32_condcmp_reg(nzcv, Rn, cond, Rm);
#else
        RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/fa400800: CCMP  <Xn>, #<imm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: condcmp_imm, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CCMP_64_condcmp_imm, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CCMP_64_condcmp_imm nzcv=%#x Rn=%#x cond=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, imm5));
#ifdef IEM_INSTR_IMPL_A64__CCMP_64_condcmp_imm
    IEM_INSTR_IMPL_A64__CCMP_64_condcmp_imm(nzcv, Rn, cond, imm5);
#else
    RT_NOREF(nzcv, Rn, cond, imm5, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c10/fa400000: CCMP  <Xn>, <Xm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: condcmp_reg, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CCMP_64_condcmp_reg, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CCMP_64_condcmp_reg nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CCMP_64_condcmp_reg
    IEM_INSTR_IMPL_A64__CCMP_64_condcmp_reg(nzcv, Rn, cond, Rm);
#else
    RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffffffff/d500401f: CFINV
   Instruction Set: A64  Groups: pstate, control */
FNIEMOP_DEF_1(iemDecodeA64_CFINV_M_pstate, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFlagM /*FEAT_FlagM*/)
    {
        LogFlow(("%018x/%010x: CFINV_M_pstate\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__CFINV_M_pstate
        IEM_INSTR_IMPL_A64__CFINV_M_pstate();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503251f: CHKFEAT  X16
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_CHKFEAT_HF_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fChk /*FEAT_CHK*/)
    {
        LogFlow(("%018x/%010x: CHKFEAT_HF_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__CHKFEAT_HF_hints
        IEM_INSTR_IMPL_A64__CHKFEAT_HF_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d50322df: CLRBHB
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_CLRBHB_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fClrBhb /*FEAT_CLRBHB*/)
    {
        LogFlow(("%018x/%010x: CLRBHB_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__CLRBHB_HI_hints
        IEM_INSTR_IMPL_A64__CLRBHB_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffff0ff/d503305f: CLREX{  #<imm>}
   Instruction Set: A64  Groups: barriers, control */
FNIEMOP_DEF_1(iemDecodeA64_CLREX_BN_barriers, uint32_t, uOpcode)
{
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    LogFlow(("%018x/%010x: CLREX_BN_barriers CRm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, CRm));
#ifdef IEM_INSTR_IMPL_A64__CLREX_BN_barriers
    IEM_INSTR_IMPL_A64__CLREX_BN_barriers(CRm);
#else
    RT_NOREF(CRm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffffc00/5ac01400: CLS  <Wd>, <Wn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CLS_32_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ac01400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: CLS_32_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CLS_32_dp_1src
        IEM_INSTR_IMPL_A64__CLS_32_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac01400: CLS  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CLS_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    LogFlow(("%018x/%010x: CLS_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CLS_64_dp_1src
    IEM_INSTR_IMPL_A64__CLS_64_dp_1src(Rd, Rn);
#else
    RT_NOREF(Rd, Rn, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf3ffc00/0e204800: CLS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CLS_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CLS_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CLS_asimdmisc_R
        IEM_INSTR_IMPL_A64__CLS_asimdmisc_R(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ac01000: CLZ  <Wd>, <Wn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CLZ_32_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ac01000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: CLZ_32_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CLZ_32_dp_1src
        IEM_INSTR_IMPL_A64__CLZ_32_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac01000: CLZ  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CLZ_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    LogFlow(("%018x/%010x: CLZ_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CLZ_64_dp_1src
    IEM_INSTR_IMPL_A64__CLZ_64_dp_1src(Rd, Rn);
#else
    RT_NOREF(Rd, Rn, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf3ffc00/2e204800: CLZ  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CLZ_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CLZ_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CLZ_asimdmisc_R
        IEM_INSTR_IMPL_A64__CLZ_asimdmisc_R(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e209800: CMEQ  <Vd>.<T>, <Vn>.<T>, #0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMEQ_asimdmisc_Z, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMEQ_asimdmisc_Z Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMEQ_asimdmisc_Z
        IEM_INSTR_IMPL_A64__CMEQ_asimdmisc_Z(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e208c00: CMEQ  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMEQ_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMEQ_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMEQ_asimdsame_only
        IEM_INSTR_IMPL_A64__CMEQ_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ee09800: CMEQ  D<d>, D<n>, #0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMEQ_asisdmisc_Z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ee09800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: CMEQ_asisdmisc_Z Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CMEQ_asisdmisc_Z
            IEM_INSTR_IMPL_A64__CMEQ_asisdmisc_Z(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ee08c00: CMEQ  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMEQ_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7ee08c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: CMEQ_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CMEQ_asisdsame_only
            IEM_INSTR_IMPL_A64__CMEQ_asisdsame_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e208800: CMGE  <Vd>.<T>, <Vn>.<T>, #0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMGE_asimdmisc_Z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e208800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: CMGE_asimdmisc_Z Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMGE_asimdmisc_Z
            IEM_INSTR_IMPL_A64__CMGE_asimdmisc_Z(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e203c00: CMGE  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMGE_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMGE_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMGE_asimdsame_only
        IEM_INSTR_IMPL_A64__CMGE_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7ee08800: CMGE  D<d>, D<n>, #0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMGE_asisdmisc_Z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7ee08800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: CMGE_asisdmisc_Z Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CMGE_asisdmisc_Z
            IEM_INSTR_IMPL_A64__CMGE_asisdmisc_Z(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5ee03c00: CMGE  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMGE_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMGE_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CMGE_asisdsame_only
        IEM_INSTR_IMPL_A64__CMGE_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e208800: CMGT  <Vd>.<T>, <Vn>.<T>, #0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMGT_asimdmisc_Z, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMGT_asimdmisc_Z Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMGT_asimdmisc_Z
        IEM_INSTR_IMPL_A64__CMGT_asimdmisc_Z(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e203400: CMGT  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMGT_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMGT_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMGT_asimdsame_only
        IEM_INSTR_IMPL_A64__CMGT_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ee08800: CMGT  D<d>, D<n>, #0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMGT_asisdmisc_Z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ee08800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: CMGT_asisdmisc_Z Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CMGT_asisdmisc_Z
            IEM_INSTR_IMPL_A64__CMGT_asisdmisc_Z(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5ee03400: CMGT  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMGT_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMGT_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CMGT_asisdsame_only
        IEM_INSTR_IMPL_A64__CMGT_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e203400: CMHI  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMHI_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMHI_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMHI_asimdsame_only
        IEM_INSTR_IMPL_A64__CMHI_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ee03400: CMHI  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMHI_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMHI_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CMHI_asisdsame_only
        IEM_INSTR_IMPL_A64__CMHI_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e203c00: CMHS  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMHS_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMHS_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMHS_asimdsame_only
        IEM_INSTR_IMPL_A64__CMHS_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ee03c00: CMHS  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMHS_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7ee03c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: CMHS_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CMHS_asisdsame_only
            IEM_INSTR_IMPL_A64__CMHS_asisdsame_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e209800: CMLE  <Vd>.<T>, <Vn>.<T>, #0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMLE_asimdmisc_Z, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMLE_asimdmisc_Z Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMLE_asimdmisc_Z
        IEM_INSTR_IMPL_A64__CMLE_asimdmisc_Z(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7ee09800: CMLE  D<d>, D<n>, #0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMLE_asisdmisc_Z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7ee09800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: CMLE_asisdmisc_Z Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CMLE_asisdmisc_Z
            IEM_INSTR_IMPL_A64__CMLE_asisdmisc_Z(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e20a800: CMLT  <Vd>.<T>, <Vn>.<T>, #0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMLT_asimdmisc_Z, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMLT_asimdmisc_Z Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMLT_asimdmisc_Z
        IEM_INSTR_IMPL_A64__CMLT_asimdmisc_Z(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ee0a800: CMLT  D<d>, D<n>, #0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMLT_asisdmisc_Z, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMLT_asisdmisc_Z Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CMLT_asisdmisc_Z
        IEM_INSTR_IMPL_A64__CMLT_asisdmisc_Z(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e208c00: CMTST  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMTST_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMTST_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CMTST_asimdsame_only
        IEM_INSTR_IMPL_A64__CMTST_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5ee08c00: CMTST  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CMTST_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: CMTST_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CMTST_asisdsame_only
        IEM_INSTR_IMPL_A64__CMTST_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ac01c00: CNT  <Wd>, <Wn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CNT_32_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ac01c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
        {
            LogFlow(("%018x/%010x: CNT_32_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CNT_32_dp_1src
            IEM_INSTR_IMPL_A64__CNT_32_dp_1src(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac01c00: CNT  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CNT_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: CNT_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CNT_64_dp_1src
        IEM_INSTR_IMPL_A64__CNT_64_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e205800: CNT  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_CNT_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e205800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: CNT_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__CNT_asimdmisc_R
            IEM_INSTR_IMPL_A64__CNT_asimdmisc_R(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d80c400: CPYEN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYEN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYEN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYEN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYEN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d808400: CPYERN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYERN_CPY_memcms, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1d808400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
        {
            LogFlow(("%018x/%010x: CPYERN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYERN_CPY_memcms
            IEM_INSTR_IMPL_A64__CPYERN_CPY_memcms(Rd, Rn, Rs, sz);
#else
            RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d80e400: CPYERTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYERTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYERTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYERTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYERTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d80a400: CPYERTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYERTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYERTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYERTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYERTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d806400: CPYERTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYERTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYERTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYERTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYERTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d802400: CPYERT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYERT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYERT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYERT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYERT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d80f400: CPYETN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYETN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYETN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYETN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYETN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d80b400: CPYETRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYETRN_CPY_memcms, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1d80b400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
        {
            LogFlow(("%018x/%010x: CPYETRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYETRN_CPY_memcms
            IEM_INSTR_IMPL_A64__CPYETRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
            RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d807400: CPYETWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYETWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYETWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYETWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYETWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d803400: CPYET  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYET_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYET_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYET_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYET_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d804400: CPYEWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYEWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYEWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYEWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYEWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d80d400: CPYEWTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYEWTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYEWTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYEWTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYEWTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d809400: CPYEWTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYEWTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYEWTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYEWTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYEWTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d805400: CPYEWTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYEWTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYEWTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYEWTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYEWTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d801400: CPYEWT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYEWT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYEWT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYEWT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYEWT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d800400: CPYE  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYE_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYE_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYE_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYE_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1980c400: CPYFEN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFEN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFEN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFEN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFEN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19808400: CPYFERN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFERN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFERN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFERN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFERN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1980e400: CPYFERTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFERTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFERTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFERTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFERTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1980a400: CPYFERTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFERTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFERTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFERTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFERTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19806400: CPYFERTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFERTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFERTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFERTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFERTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19802400: CPYFERT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFERT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFERT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFERT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFERT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1980f400: CPYFETN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFETN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFETN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFETN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFETN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1980b400: CPYFETRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFETRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFETRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFETRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFETRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19807400: CPYFETWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFETWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFETWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFETWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFETWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19803400: CPYFET  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFET_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFET_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFET_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFET_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19804400: CPYFEWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFEWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFEWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFEWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFEWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1980d400: CPYFEWTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFEWTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFEWTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFEWTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFEWTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19809400: CPYFEWTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFEWTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFEWTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFEWTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFEWTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19805400: CPYFEWTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFEWTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFEWTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFEWTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFEWTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19801400: CPYFEWT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFEWT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFEWT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFEWT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFEWT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19800400: CPYFE  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFE_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFE_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFE_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFE_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1940c400: CPYFMN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19408400: CPYFMRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1940e400: CPYFMRTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMRTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMRTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMRTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMRTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1940a400: CPYFMRTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMRTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMRTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMRTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMRTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19406400: CPYFMRTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMRTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMRTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMRTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMRTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19402400: CPYFMRT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMRT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMRT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMRT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMRT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1940f400: CPYFMTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1940b400: CPYFMTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19407400: CPYFMTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19403400: CPYFMT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19404400: CPYFMWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1940d400: CPYFMWTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMWTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMWTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMWTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMWTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19409400: CPYFMWTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMWTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMWTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMWTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMWTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19405400: CPYFMWTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMWTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMWTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMWTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMWTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19401400: CPYFMWT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFMWT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFMWT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFMWT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFMWT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19400400: CPYFM  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFM_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFM_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFM_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFM_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1900c400: CPYFPN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19008400: CPYFPRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1900e400: CPYFPRTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPRTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPRTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPRTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPRTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1900a400: CPYFPRTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPRTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPRTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPRTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPRTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19006400: CPYFPRTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPRTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPRTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPRTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPRTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19002400: CPYFPRT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPRT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPRT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPRT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPRT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1900f400: CPYFPTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1900b400: CPYFPTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19007400: CPYFPTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19003400: CPYFPT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19004400: CPYFPWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1900d400: CPYFPWTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPWTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPWTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPWTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPWTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19009400: CPYFPWTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPWTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPWTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPWTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPWTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19005400: CPYFPWTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPWTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPWTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPWTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPWTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19001400: CPYFPWT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFPWT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFPWT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFPWT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFPWT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19000400: CPYFP  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYFP_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYFP_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYFP_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYFP_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d40c400: CPYMN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d408400: CPYMRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d40e400: CPYMRTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMRTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMRTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMRTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMRTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d40a400: CPYMRTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMRTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMRTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMRTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMRTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d406400: CPYMRTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMRTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMRTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMRTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMRTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d402400: CPYMRT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMRT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMRT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMRT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMRT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d40f400: CPYMTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d40b400: CPYMTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d407400: CPYMTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d403400: CPYMT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d404400: CPYMWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d40d400: CPYMWTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMWTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMWTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMWTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMWTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d409400: CPYMWTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMWTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMWTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMWTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMWTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d405400: CPYMWTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMWTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMWTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMWTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMWTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d401400: CPYMWT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYMWT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYMWT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYMWT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYMWT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d400400: CPYM  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYM_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYM_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYM_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYM_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d00c400: CPYPN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d008400: CPYPRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d00e400: CPYPRTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPRTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPRTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPRTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPRTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d00a400: CPYPRTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPRTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPRTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPRTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPRTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d006400: CPYPRTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPRTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPRTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPRTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPRTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d002400: CPYPRT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPRT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPRT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPRT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPRT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d00f400: CPYPTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d00b400: CPYPTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d007400: CPYPTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d003400: CPYPT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d004400: CPYPWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d00d400: CPYPWTN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPWTN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPWTN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPWTN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPWTN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d009400: CPYPWTRN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPWTRN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPWTRN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPWTRN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPWTRN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d005400: CPYPWTWN  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPWTWN_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPWTWN_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPWTWN_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPWTWN_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d001400: CPYPWT  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYPWT_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYPWT_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYPWT_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYPWT_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1d000400: CPYP  [<Xd>]!, [<Xs>]!, <Xn>!
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_CPYP_CPY_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: CPYP_CPY_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__CPYP_CPY_memcms
        IEM_INSTR_IMPL_A64__CPYP_CPY_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac04000: CRC32B  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CRC32B_32C_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCrc32 /*FEAT_CRC32*/)
    {
        LogFlow(("%018x/%010x: CRC32B_32C_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CRC32B_32C_dp_2src
        IEM_INSTR_IMPL_A64__CRC32B_32C_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac05000: CRC32CB  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CRC32CB_32C_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCrc32 /*FEAT_CRC32*/)
    {
        LogFlow(("%018x/%010x: CRC32CB_32C_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CRC32CB_32C_dp_2src
        IEM_INSTR_IMPL_A64__CRC32CB_32C_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac05400: CRC32CH  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CRC32CH_32C_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCrc32 /*FEAT_CRC32*/)
    {
        LogFlow(("%018x/%010x: CRC32CH_32C_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CRC32CH_32C_dp_2src
        IEM_INSTR_IMPL_A64__CRC32CH_32C_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac05800: CRC32CW  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CRC32CW_32C_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCrc32 /*FEAT_CRC32*/)
    {
        LogFlow(("%018x/%010x: CRC32CW_32C_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CRC32CW_32C_dp_2src
        IEM_INSTR_IMPL_A64__CRC32CW_32C_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac05c00: CRC32CX  <Wd>, <Wn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CRC32CX_64C_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCrc32 /*FEAT_CRC32*/)
    {
        LogFlow(("%018x/%010x: CRC32CX_64C_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CRC32CX_64C_dp_2src
        IEM_INSTR_IMPL_A64__CRC32CX_64C_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac04400: CRC32H  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CRC32H_32C_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCrc32 /*FEAT_CRC32*/)
    {
        LogFlow(("%018x/%010x: CRC32H_32C_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CRC32H_32C_dp_2src
        IEM_INSTR_IMPL_A64__CRC32H_32C_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac04800: CRC32W  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CRC32W_32C_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCrc32 /*FEAT_CRC32*/)
    {
        LogFlow(("%018x/%010x: CRC32W_32C_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CRC32W_32C_dp_2src
        IEM_INSTR_IMPL_A64__CRC32W_32C_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac04c00: CRC32X  <Wd>, <Wn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CRC32X_64C_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCrc32 /*FEAT_CRC32*/)
    {
        LogFlow(("%018x/%010x: CRC32X_64C_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__CRC32X_64C_dp_2src
        IEM_INSTR_IMPL_A64__CRC32X_64C_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503229f: CSDB
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_CSDB_HI_hints, uint32_t, uOpcode)
{
    LogFlow(("%018x/%010x: CSDB_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__CSDB_HI_hints
    IEM_INSTR_IMPL_A64__CSDB_HI_hints();
#else
    RT_NOREF(pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/1a800000: CSEL  <Wd>, <Wn>, <Wm>, <cond>
   Instruction Set: A64  Groups: condsel, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CSEL_32_condsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CSEL_32_condsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CSEL_32_condsel
    IEM_INSTR_IMPL_A64__CSEL_32_condsel(Rd, Rn, cond, Rm);
#else
    RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/9a800000: CSEL  <Xd>, <Xn>, <Xm>, <cond>
   Instruction Set: A64  Groups: condsel, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CSEL_64_condsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CSEL_64_condsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CSEL_64_condsel
    IEM_INSTR_IMPL_A64__CSEL_64_condsel(Rd, Rn, cond, Rm);
#else
    RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/1a800400: CSINC  <Wd>, <Wn>, <Wm>, <cond>
   Instruction Set: A64  Groups: condsel, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CSINC_32_condsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CSINC_32_condsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CSINC_32_condsel
    IEM_INSTR_IMPL_A64__CSINC_32_condsel(Rd, Rn, cond, Rm);
#else
    RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/9a800400: CSINC  <Xd>, <Xn>, <Xm>, <cond>
   Instruction Set: A64  Groups: condsel, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CSINC_64_condsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CSINC_64_condsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CSINC_64_condsel
    IEM_INSTR_IMPL_A64__CSINC_64_condsel(Rd, Rn, cond, Rm);
#else
    RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/5a800000: CSINV  <Wd>, <Wn>, <Wm>, <cond>
   Instruction Set: A64  Groups: condsel, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CSINV_32_condsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CSINV_32_condsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CSINV_32_condsel
    IEM_INSTR_IMPL_A64__CSINV_32_condsel(Rd, Rn, cond, Rm);
#else
    RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/da800000: CSINV  <Xd>, <Xn>, <Xm>, <cond>
   Instruction Set: A64  Groups: condsel, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CSINV_64_condsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CSINV_64_condsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CSINV_64_condsel
    IEM_INSTR_IMPL_A64__CSINV_64_condsel(Rd, Rn, cond, Rm);
#else
    RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/5a800400: CSNEG  <Wd>, <Wn>, <Wm>, <cond>
   Instruction Set: A64  Groups: condsel, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CSNEG_32_condsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CSNEG_32_condsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CSNEG_32_condsel
    IEM_INSTR_IMPL_A64__CSNEG_32_condsel(Rd, Rn, cond, Rm);
#else
    RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/da800400: CSNEG  <Xd>, <Xn>, <Xm>, <cond>
   Instruction Set: A64  Groups: condsel, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CSNEG_64_condsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: CSNEG_64_condsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__CSNEG_64_condsel
    IEM_INSTR_IMPL_A64__CSNEG_64_condsel(Rd, Rn, cond, Rm);
#else
    RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffffc00/5ac01800: CTZ  <Wd>, <Wn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CTZ_32_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ac01800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
        {
            LogFlow(("%018x/%010x: CTZ_32_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CTZ_32_dp_1src
            IEM_INSTR_IMPL_A64__CTZ_32_dp_1src(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac01800: CTZ  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_CTZ_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: CTZ_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__CTZ_64_dp_1src
        IEM_INSTR_IMPL_A64__CTZ_64_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/d4a00001: DCPS1{  #<imm>}
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_DCPS1_DC_exception, uint32_t, uOpcode)
{
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    LogFlow(("%018x/%010x: DCPS1_DC_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__DCPS1_DC_exception
    IEM_INSTR_IMPL_A64__DCPS1_DC_exception(imm16);
#else
    RT_NOREF(imm16, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0001f/d4a00002: DCPS2{  #<imm>}
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_DCPS2_DC_exception, uint32_t, uOpcode)
{
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    LogFlow(("%018x/%010x: DCPS2_DC_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__DCPS2_DC_exception
    IEM_INSTR_IMPL_A64__DCPS2_DC_exception(imm16);
#else
    RT_NOREF(imm16, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0001f/d4a00003: DCPS3{  #<imm>}
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_DCPS3_DC_exception, uint32_t, uOpcode)
{
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    LogFlow(("%018x/%010x: DCPS3_DC_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__DCPS3_DC_exception
    IEM_INSTR_IMPL_A64__DCPS3_DC_exception(imm16);
#else
    RT_NOREF(imm16, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffffffff/d50320df: DGH
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_DGH_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fDgh /*FEAT_DGH*/)
    {
        LogFlow(("%018x/%010x: DGH_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__DGH_HI_hints
        IEM_INSTR_IMPL_A64__DGH_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffff0ff/d50330bf: DMB  {<option> | #<imm>}
   Instruction Set: A64  Groups: barriers, control */
FNIEMOP_DEF_1(iemDecodeA64_DMB_BO_barriers, uint32_t, uOpcode)
{
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    LogFlow(("%018x/%010x: DMB_BO_barriers CRm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, CRm));
#ifdef IEM_INSTR_IMPL_A64__DMB_BO_barriers
    IEM_INSTR_IMPL_A64__DMB_BO_barriers(CRm);
#else
    RT_NOREF(CRm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffffffff/d6bf03e0: DRPS
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_DRPS_64E_branch_reg, uint32_t, uOpcode)
{
    LogFlow(("%018x/%010x: DRPS_64E_branch_reg\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__DRPS_64E_branch_reg
    IEM_INSTR_IMPL_A64__DRPS_64E_branch_reg();
#else
    RT_NOREF(pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffff0ff/d503309f: DSB  {<option> | #<imm>}
   Instruction Set: A64  Groups: barriers, control */
FNIEMOP_DEF_1(iemDecodeA64_DSB_BO_barriers, uint32_t, uOpcode)
{
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    LogFlow(("%018x/%010x: DSB_BO_barriers CRm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, CRm));
#ifdef IEM_INSTR_IMPL_A64__DSB_BO_barriers
    IEM_INSTR_IMPL_A64__DSB_BO_barriers(CRm);
#else
    RT_NOREF(CRm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffff3ff/d503323f: DSB  <option>nXS
   Instruction Set: A64  Groups: barriers, control */
FNIEMOP_DEF_1(iemDecodeA64_DSB_BOn_barriers, uint32_t, uOpcode)
{
    uint32_t const imm2       = (uOpcode >> 10) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fXs /*FEAT_XS*/)
    {
        LogFlow(("%018x/%010x: DSB_BOn_barriers imm2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm2));
#ifdef IEM_INSTR_IMPL_A64__DSB_BOn_barriers
        IEM_INSTR_IMPL_A64__DSB_BOn_barriers(imm2);
#else
        RT_NOREF(imm2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e000c00: DUP  <Vd>.<T>, <R><n>
   Instruction Set: A64  Groups: asimdins, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_DUP_asimdins_DR_r, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: DUP_asimdins_DR_r Rd=%#x Rn=%#x imm5=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm5, Q));
#ifdef IEM_INSTR_IMPL_A64__DUP_asimdins_DR_r
        IEM_INSTR_IMPL_A64__DUP_asimdins_DR_r(Rd, Rn, imm5, Q);
#else
        RT_NOREF(Rd, Rn, imm5, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e000400: DUP  <Vd>.<T>, <Vn>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdins, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_DUP_asimdins_DV_v, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: DUP_asimdins_DV_v Rd=%#x Rn=%#x imm5=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm5, Q));
#ifdef IEM_INSTR_IMPL_A64__DUP_asimdins_DV_v
        IEM_INSTR_IMPL_A64__DUP_asimdins_DV_v(Rd, Rn, imm5, Q);
#else
        RT_NOREF(Rd, Rn, imm5, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e000400: DUP  <V><d>, <Vn>.<T>[<index>]
   Instruction Set: A64  Groups: asisdone, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_DUP_asisdone_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e000400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: DUP_asisdone_only Rd=%#x Rn=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm5));
#ifdef IEM_INSTR_IMPL_A64__DUP_asisdone_only
            IEM_INSTR_IMPL_A64__DUP_asisdone_only(Rd, Rn, imm5);
#else
            RT_NOREF(Rd, Rn, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff200000/4a200000: EON  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_EON_32_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: EON_32_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__EON_32_log_shift
    IEM_INSTR_IMPL_A64__EON_32_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/ca200000: EON  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_EON_64_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: EON_64_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__EON_64_log_shift
    IEM_INSTR_IMPL_A64__EON_64_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe08000/ce000000: EOR3  <Vd>.16B, <Vn>.16B, <Vm>.16B, <Va>.16B
   Instruction Set: A64  Groups: crypto4, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_EOR3_VVV16_crypto4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha3 /*FEAT_SHA3*/)
        {
            LogFlow(("%018x/%010x: EOR3_VVV16_crypto4 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__EOR3_VVV16_crypto4
            IEM_INSTR_IMPL_A64__EOR3_VVV16_crypto4(Rd, Rn, Ra, Rm);
#else
            RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/52000000: EOR  <Wd|WSP>, <Wn>, #<imm>
   Instruction Set: A64  Groups: log_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_EOR_32_log_imm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x52000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
        LogFlow(("%018x/%010x: EOR_32_log_imm Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__EOR_32_log_imm
        IEM_INSTR_IMPL_A64__EOR_32_log_imm(Rd, Rn, imms, immr);
#else
        RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff200000/4a000000: EOR  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_EOR_32_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: EOR_32_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__EOR_32_log_shift
    IEM_INSTR_IMPL_A64__EOR_32_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/d2000000: EOR  <Xd|SP>, <Xn>, #<imm>
   Instruction Set: A64  Groups: log_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_EOR_64_log_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    uint32_t const N          = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: EOR_64_log_imm Rd=%#x Rn=%#x imms=%#x immr=%#x N=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr, N));
#ifdef IEM_INSTR_IMPL_A64__EOR_64_log_imm
    IEM_INSTR_IMPL_A64__EOR_64_log_imm(Rd, Rn, imms, immr, N);
#else
    RT_NOREF(Rd, Rn, imms, immr, N, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/ca000000: EOR  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_EOR_64_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: EOR_64_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__EOR_64_log_shift
    IEM_INSTR_IMPL_A64__EOR_64_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bfe0fc00/2e201c00: EOR  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_EOR_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e201c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: EOR_asimdsame_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__EOR_asimdsame_only
            IEM_INSTR_IMPL_A64__EOR_asimdsame_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d69f0bff: ERETAA
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_ERETAA_64E_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd69f0bff))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: ERETAA_64E_branch_reg\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__ERETAA_64E_branch_reg
            IEM_INSTR_IMPL_A64__ERETAA_64E_branch_reg();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d69f0fff: ERETAB
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_ERETAB_64E_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd69f0fff))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: ERETAB_64E_branch_reg\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__ERETAB_64E_branch_reg
            IEM_INSTR_IMPL_A64__ERETAB_64E_branch_reg();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d69f03e0: ERET
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_ERET_64E_branch_reg, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd69f03e0))
    {
        LogFlow(("%018x/%010x: ERET_64E_branch_reg\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__ERET_64E_branch_reg
        IEM_INSTR_IMPL_A64__ERET_64E_branch_reg();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503221f: ESB
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_ESB_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRas /*FEAT_RAS*/)
    {
        LogFlow(("%018x/%010x: ESB_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__ESB_HI_hints
        IEM_INSTR_IMPL_A64__ESB_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/13800000: EXTR  <Wd>, <Wn>, <Wm>, #<lsb>
   Instruction Set: A64  Groups: extract, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_EXTR_32_extract, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (0x0 /*op21@29*/ != 3)
    {
        LogFlow(("%018x/%010x: EXTR_32_extract Rd=%#x Rn=%#x imms=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, Rm));
#ifdef IEM_INSTR_IMPL_A64__EXTR_32_extract
        IEM_INSTR_IMPL_A64__EXTR_32_extract(Rd, Rn, imms, Rm);
#else
        RT_NOREF(Rd, Rn, imms, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/93c00000: EXTR  <Xd>, <Xn>, <Xm>, #<lsb>
   Instruction Set: A64  Groups: extract, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_EXTR_64_extract, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00000)) == UINT32_C(0x93c00000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (0x0 /*op21@29*/ != 3)
        {
            LogFlow(("%018x/%010x: EXTR_64_extract Rd=%#x Rn=%#x imms=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, Rm));
#ifdef IEM_INSTR_IMPL_A64__EXTR_64_extract
            IEM_INSTR_IMPL_A64__EXTR_64_extract(Rd, Rn, imms, Rm);
#else
            RT_NOREF(Rd, Rn, imms, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe08400/2e000000: EXT  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>, #<index>
   Instruction Set: A64  Groups: asimdext, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_EXT_asimdext_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe08400)) == UINT32_C(0x2e000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 11) & 0x0000000f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: EXT_asimdext_only Rd=%#x Rn=%#x imm4=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm4, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__EXT_asimdext_only
            IEM_INSTR_IMPL_A64__EXT_asimdext_only(Rd, Rn, imm4, Rm, Q);
#else
            RT_NOREF(Rd, Rn, imm4, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e217800: F1CVTL2  <Vd>.8H, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_F1CVTL_asimdmisc_V, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: F1CVTL_asimdmisc_V Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__F1CVTL_asimdmisc_V
        IEM_INSTR_IMPL_A64__F1CVTL_asimdmisc_V(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e617800: F2CVTL2  <Vd>.8H, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_F2CVTL_asimdmisc_V, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: F2CVTL_asimdmisc_V Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__F2CVTL_asimdmisc_V
        IEM_INSTR_IMPL_A64__F2CVTL_asimdmisc_V(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2ea0d400: FABD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABD_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FABD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FABD_asimdsame_only
        IEM_INSTR_IMPL_A64__FABD_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ec01400: FABD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABD_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ec01400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FABD_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FABD_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FABD_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/7ea0d400: FABD  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABD_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x7ea0d400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FABD_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FABD_asisdsame_only
            IEM_INSTR_IMPL_A64__FABD_asisdsame_only(Rd, Rn, Rm, sz);
#else
            RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ec01400: FABD  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABD_asisdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7ec01400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FABD_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FABD_asisdsamefp16_only
            IEM_INSTR_IMPL_A64__FABD_asisdsamefp16_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e60c000: FABS  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABS_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FABS_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FABS_D_floatdp1
        IEM_INSTR_IMPL_A64__FABS_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee0c000: FABS  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABS_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FABS_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FABS_H_floatdp1
        IEM_INSTR_IMPL_A64__FABS_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e20c000: FABS  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABS_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FABS_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FABS_S_floatdp1
        IEM_INSTR_IMPL_A64__FABS_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea0f800: FABS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABS_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FABS_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FABS_asimdmisc_R
        IEM_INSTR_IMPL_A64__FABS_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef8f800: FABS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FABS_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FABS_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FABS_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FABS_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2e20ec00: FACGE  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FACGE_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2e20ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FACGE_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FACGE_asimdsame_only
            IEM_INSTR_IMPL_A64__FACGE_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e402c00: FACGE  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FACGE_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e402c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FACGE_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FACGE_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FACGE_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/7e20ec00: FACGE  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FACGE_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x7e20ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FACGE_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FACGE_asisdsame_only
            IEM_INSTR_IMPL_A64__FACGE_asisdsame_only(Rd, Rn, Rm, sz);
#else
            RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7e402c00: FACGE  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FACGE_asisdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7e402c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FACGE_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FACGE_asisdsamefp16_only
            IEM_INSTR_IMPL_A64__FACGE_asisdsamefp16_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2ea0ec00: FACGT  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FACGT_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2ea0ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FACGT_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FACGT_asimdsame_only
            IEM_INSTR_IMPL_A64__FACGT_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ec02c00: FACGT  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FACGT_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ec02c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FACGT_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FACGT_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FACGT_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/7ea0ec00: FACGT  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FACGT_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x7ea0ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FACGT_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FACGT_asisdsame_only
            IEM_INSTR_IMPL_A64__FACGT_asisdsame_only(Rd, Rn, Rm, sz);
#else
            RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ec02c00: FACGT  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FACGT_asisdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7ec02c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FACGT_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FACGT_asisdsamefp16_only
            IEM_INSTR_IMPL_A64__FACGT_asisdsamefp16_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2e20d400: FADDP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADDP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2e20d400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FADDP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FADDP_asimdsame_only
            IEM_INSTR_IMPL_A64__FADDP_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e401400: FADDP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADDP_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e401400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FADDP_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FADDP_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FADDP_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e30d800: FADDP  H<d>, <Vn>.2H
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADDP_asisdpair_only_H, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e30d800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FADDP_asisdpair_only_H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FADDP_asisdpair_only_H
            IEM_INSTR_IMPL_A64__FADDP_asisdpair_only_H(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7e30d800: FADDP  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADDP_asisdpair_only_SD, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e30d800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FADDP_asisdpair_only_SD Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FADDP_asisdpair_only_SD
            IEM_INSTR_IMPL_A64__FADDP_asisdpair_only_SD(Rd, Rn, sz);
#else
            RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e602800: FADD  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADD_D_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e602800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FADD_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FADD_D_floatdp2
            IEM_INSTR_IMPL_A64__FADD_D_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee02800: FADD  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADD_H_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1ee02800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FADD_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FADD_H_floatdp2
            IEM_INSTR_IMPL_A64__FADD_H_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e202800: FADD  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADD_S_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FADD_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FADD_S_floatdp2
        IEM_INSTR_IMPL_A64__FADD_S_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0e20d400: FADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADD_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0e20d400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FADD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FADD_asimdsame_only
            IEM_INSTR_IMPL_A64__FADD_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e401400: FADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FADD_asimdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FADD_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FADD_asimdsamefp16_only
        IEM_INSTR_IMPL_A64__FADD_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e20dc00: FAMAX  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FAMAX_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20dc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/ && ((size & 2) == 2))
        {
            LogFlow(("%018x/%010x: FAMAX_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__FAMAX_asimdsame_only
            IEM_INSTR_IMPL_A64__FAMAX_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0ec01c00: FAMAX  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FAMAX_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0ec01c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/)
        {
            LogFlow(("%018x/%010x: FAMAX_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FAMAX_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FAMAX_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e20dc00: FAMIN  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FAMIN_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20dc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/ && ((size & 2) == 2))
        {
            LogFlow(("%018x/%010x: FAMIN_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__FAMIN_asimdsame_only
            IEM_INSTR_IMPL_A64__FAMIN_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ec01c00: FAMIN  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FAMIN_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ec01c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/)
        {
            LogFlow(("%018x/%010x: FAMIN_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FAMIN_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FAMIN_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20ec00/2e00e400: FCADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>, #<rotate>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCADD_asimdsame2_C, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20ec00)) == UINT32_C(0x2e00e400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const rot        = (uOpcode >> 12) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFcma /*FEAT_FCMA*/)
        {
            LogFlow(("%018x/%010x: FCADD_asimdsame2_C Rd=%#x Rn=%#x rot=%u Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, rot, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__FCADD_asimdsame2_C
            IEM_INSTR_IMPL_A64__FCADD_asimdsame2_C(Rd, Rn, rot, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, rot, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/1e600410: FCCMPE  <Dn>, <Dm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: floatccmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCCMPE_D_floatccmp, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCCMPE_D_floatccmp nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCCMPE_D_floatccmp
        IEM_INSTR_IMPL_A64__FCCMPE_D_floatccmp(nzcv, Rn, cond, Rm);
#else
        RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/1ee00410: FCCMPE  <Hn>, <Hm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: floatccmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCCMPE_H_floatccmp, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCCMPE_H_floatccmp nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCCMPE_H_floatccmp
        IEM_INSTR_IMPL_A64__FCCMPE_H_floatccmp(nzcv, Rn, cond, Rm);
#else
        RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/1e200410: FCCMPE  <Sn>, <Sm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: floatccmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCCMPE_S_floatccmp, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCCMPE_S_floatccmp nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCCMPE_S_floatccmp
        IEM_INSTR_IMPL_A64__FCCMPE_S_floatccmp(nzcv, Rn, cond, Rm);
#else
        RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/1e600400: FCCMP  <Dn>, <Dm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: floatccmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCCMP_D_floatccmp, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCCMP_D_floatccmp nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCCMP_D_floatccmp
        IEM_INSTR_IMPL_A64__FCCMP_D_floatccmp(nzcv, Rn, cond, Rm);
#else
        RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/1ee00400: FCCMP  <Hn>, <Hm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: floatccmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCCMP_H_floatccmp, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCCMP_H_floatccmp nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCCMP_H_floatccmp
        IEM_INSTR_IMPL_A64__FCCMP_H_floatccmp(nzcv, Rn, cond, Rm);
#else
        RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c10/1e200400: FCCMP  <Sn>, <Sm>, #<nzcv>, <cond>
   Instruction Set: A64  Groups: floatccmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCCMP_S_floatccmp, uint32_t, uOpcode)
{
    uint32_t const nzcv       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCCMP_S_floatccmp nzcv=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, nzcv, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCCMP_S_floatccmp
        IEM_INSTR_IMPL_A64__FCCMP_S_floatccmp(nzcv, Rn, cond, Rm);
#else
        RT_NOREF(nzcv, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea0d800: FCMEQ  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMEQ_asimdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMEQ_asimdmisc_FZ Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMEQ_asimdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMEQ_asimdmisc_FZ(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef8d800: FCMEQ  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMEQ_asimdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMEQ_asimdmiscfp16_FZ Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMEQ_asimdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMEQ_asimdmiscfp16_FZ(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0e20e400: FCMEQ  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMEQ_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMEQ_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMEQ_asimdsame_only
        IEM_INSTR_IMPL_A64__FCMEQ_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e402400: FCMEQ  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMEQ_asimdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMEQ_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMEQ_asimdsamefp16_only
        IEM_INSTR_IMPL_A64__FCMEQ_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5ea0d800: FCMEQ  <V><d>, <V><n>, #0.0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMEQ_asisdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMEQ_asisdmisc_FZ Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCMEQ_asisdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMEQ_asisdmisc_FZ(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ef8d800: FCMEQ  <Hd>, <Hn>, #0.0
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMEQ_asisdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMEQ_asisdmiscfp16_FZ Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMEQ_asisdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMEQ_asisdmiscfp16_FZ(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/5e20e400: FCMEQ  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMEQ_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMEQ_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FCMEQ_asisdsame_only
        IEM_INSTR_IMPL_A64__FCMEQ_asisdsame_only(Rd, Rn, Rm, sz);
#else
        RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e402400: FCMEQ  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMEQ_asisdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMEQ_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMEQ_asisdsamefp16_only
        IEM_INSTR_IMPL_A64__FCMEQ_asisdsamefp16_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea0c800: FCMGE  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGE_asimdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMGE_asimdmisc_FZ Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMGE_asimdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMGE_asimdmisc_FZ(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ef8c800: FCMGE  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGE_asimdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMGE_asimdmiscfp16_FZ Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMGE_asimdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMGE_asimdmiscfp16_FZ(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2e20e400: FCMGE  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGE_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMGE_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMGE_asimdsame_only
        IEM_INSTR_IMPL_A64__FCMGE_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e402400: FCMGE  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGE_asimdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMGE_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMGE_asimdsamefp16_only
        IEM_INSTR_IMPL_A64__FCMGE_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7ea0c800: FCMGE  <V><d>, <V><n>, #0.0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGE_asisdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMGE_asisdmisc_FZ Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCMGE_asisdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMGE_asisdmisc_FZ(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7ef8c800: FCMGE  <Hd>, <Hn>, #0.0
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGE_asisdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMGE_asisdmiscfp16_FZ Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMGE_asisdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMGE_asisdmiscfp16_FZ(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/7e20e400: FCMGE  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGE_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMGE_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FCMGE_asisdsame_only
        IEM_INSTR_IMPL_A64__FCMGE_asisdsame_only(Rd, Rn, Rm, sz);
#else
        RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7e402400: FCMGE  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGE_asisdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMGE_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMGE_asisdsamefp16_only
        IEM_INSTR_IMPL_A64__FCMGE_asisdsamefp16_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea0c800: FCMGT  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGT_asimdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMGT_asimdmisc_FZ Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMGT_asimdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMGT_asimdmisc_FZ(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef8c800: FCMGT  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGT_asimdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMGT_asimdmiscfp16_FZ Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMGT_asimdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMGT_asimdmiscfp16_FZ(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2ea0e400: FCMGT  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGT_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2ea0e400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCMGT_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMGT_asimdsame_only
            IEM_INSTR_IMPL_A64__FCMGT_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ec02400: FCMGT  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGT_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ec02400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCMGT_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMGT_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FCMGT_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5ea0c800: FCMGT  <V><d>, <V><n>, #0.0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGT_asisdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMGT_asisdmisc_FZ Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCMGT_asisdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMGT_asisdmisc_FZ(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ef8c800: FCMGT  <Hd>, <Hn>, #0.0
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGT_asisdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMGT_asisdmiscfp16_FZ Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMGT_asisdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMGT_asisdmiscfp16_FZ(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/7ea0e400: FCMGT  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGT_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x7ea0e400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCMGT_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FCMGT_asisdsame_only
            IEM_INSTR_IMPL_A64__FCMGT_asisdsame_only(Rd, Rn, Rm, sz);
#else
            RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ec02400: FCMGT  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMGT_asisdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7ec02400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCMGT_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMGT_asisdsamefp16_only
            IEM_INSTR_IMPL_A64__FCMGT_asisdsamefp16_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf009400/2f001000: FCMLA  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>], #<rotate>
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLA_advsimd_elt, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf009400)) == UINT32_C(0x2f001000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const rot        = (uOpcode >> 13) & 0x00000003;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFcma /*FEAT_FCMA*/)
        {
            LogFlow(("%018x/%010x: FCMLA_advsimd_elt Rd=%#x Rn=%#x H=%u rot=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, rot, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMLA_advsimd_elt
            IEM_INSTR_IMPL_A64__FCMLA_advsimd_elt(Rd, Rn, H, rot, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, rot, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20e400/2e00c400: FCMLA  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>, #<rotate>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLA_asimdsame2_C, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20e400)) == UINT32_C(0x2e00c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const rot        = (uOpcode >> 11) & 0x00000003;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFcma /*FEAT_FCMA*/)
        {
            LogFlow(("%018x/%010x: FCMLA_asimdsame2_C Rd=%#x Rn=%#x rot=%u Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, rot, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMLA_asimdsame2_C
            IEM_INSTR_IMPL_A64__FCMLA_asimdsame2_C(Rd, Rn, rot, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, rot, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea0d800: FCMLE  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLE_asimdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMLE_asimdmisc_FZ Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMLE_asimdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMLE_asimdmisc_FZ(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ef8d800: FCMLE  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLE_asimdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMLE_asimdmiscfp16_FZ Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMLE_asimdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMLE_asimdmiscfp16_FZ(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7ea0d800: FCMLE  <V><d>, <V><n>, #0.0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLE_asisdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMLE_asisdmisc_FZ Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCMLE_asisdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMLE_asisdmisc_FZ(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7ef8d800: FCMLE  <Hd>, <Hn>, #0.0
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLE_asisdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMLE_asisdmiscfp16_FZ Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMLE_asisdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMLE_asisdmiscfp16_FZ(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea0e800: FCMLT  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLT_asimdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMLT_asimdmisc_FZ Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMLT_asimdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMLT_asimdmisc_FZ(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef8e800: FCMLT  <Vd>.<T>, <Vn>.<T>, #0.0
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLT_asimdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMLT_asimdmiscfp16_FZ Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCMLT_asimdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMLT_asimdmiscfp16_FZ(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5ea0e800: FCMLT  <V><d>, <V><n>, #0.0
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLT_asisdmisc_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCMLT_asisdmisc_FZ Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCMLT_asisdmisc_FZ
        IEM_INSTR_IMPL_A64__FCMLT_asisdmisc_FZ(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ef8e800: FCMLT  <Hd>, <Hn>, #0.0
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMLT_asisdmiscfp16_FZ, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMLT_asisdmiscfp16_FZ Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMLT_asisdmiscfp16_FZ
        IEM_INSTR_IMPL_A64__FCMLT_asisdmiscfp16_FZ(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/1e602018: FCMPE  <Dn>, #0.0
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMPE_DZ_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCMPE_DZ_floatcmp Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMPE_DZ_floatcmp
        IEM_INSTR_IMPL_A64__FCMPE_DZ_floatcmp(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/1e602010: FCMPE  <Dn>, <Dm>
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMPE_D_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCMPE_D_floatcmp Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMPE_D_floatcmp
        IEM_INSTR_IMPL_A64__FCMPE_D_floatcmp(Rn, Rm);
#else
        RT_NOREF(Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/1ee02018: FCMPE  <Hn>, #0.0
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMPE_HZ_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMPE_HZ_floatcmp Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMPE_HZ_floatcmp
        IEM_INSTR_IMPL_A64__FCMPE_HZ_floatcmp(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/1ee02010: FCMPE  <Hn>, <Hm>
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMPE_H_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMPE_H_floatcmp Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMPE_H_floatcmp
        IEM_INSTR_IMPL_A64__FCMPE_H_floatcmp(Rn, Rm);
#else
        RT_NOREF(Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/1e202018: FCMPE  <Sn>, #0.0
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMPE_SZ_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCMPE_SZ_floatcmp Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMPE_SZ_floatcmp
        IEM_INSTR_IMPL_A64__FCMPE_SZ_floatcmp(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/1e202010: FCMPE  <Sn>, <Sm>
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMPE_S_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCMPE_S_floatcmp Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMPE_S_floatcmp
        IEM_INSTR_IMPL_A64__FCMPE_S_floatcmp(Rn, Rm);
#else
        RT_NOREF(Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/1e602008: FCMP  <Dn>, #0.0
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMP_DZ_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCMP_DZ_floatcmp Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMP_DZ_floatcmp
        IEM_INSTR_IMPL_A64__FCMP_DZ_floatcmp(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/1e602000: FCMP  <Dn>, <Dm>
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMP_D_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCMP_D_floatcmp Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMP_D_floatcmp
        IEM_INSTR_IMPL_A64__FCMP_D_floatcmp(Rn, Rm);
#else
        RT_NOREF(Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/1ee02008: FCMP  <Hn>, #0.0
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMP_HZ_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMP_HZ_floatcmp Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMP_HZ_floatcmp
        IEM_INSTR_IMPL_A64__FCMP_HZ_floatcmp(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/1ee02000: FCMP  <Hn>, <Hm>
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMP_H_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCMP_H_floatcmp Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMP_H_floatcmp
        IEM_INSTR_IMPL_A64__FCMP_H_floatcmp(Rn, Rm);
#else
        RT_NOREF(Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/1e202008: FCMP  <Sn>, #0.0
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMP_SZ_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCMP_SZ_floatcmp Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCMP_SZ_floatcmp
        IEM_INSTR_IMPL_A64__FCMP_SZ_floatcmp(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/1e202000: FCMP  <Sn>, <Sm>
   Instruction Set: A64  Groups: floatcmp, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCMP_S_floatcmp, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCMP_S_floatcmp Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCMP_S_floatcmp
        IEM_INSTR_IMPL_A64__FCMP_S_floatcmp(Rn, Rm);
#else
        RT_NOREF(Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/1e600c00: FCSEL  <Dd>, <Dn>, <Dm>, <cond>
   Instruction Set: A64  Groups: floatsel, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCSEL_D_floatsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCSEL_D_floatsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCSEL_D_floatsel
        IEM_INSTR_IMPL_A64__FCSEL_D_floatsel(Rd, Rn, cond, Rm);
#else
        RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/1ee00c00: FCSEL  <Hd>, <Hn>, <Hm>, <cond>
   Instruction Set: A64  Groups: floatsel, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCSEL_H_floatsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCSEL_H_floatsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCSEL_H_floatsel
        IEM_INSTR_IMPL_A64__FCSEL_H_floatsel(Rd, Rn, cond, Rm);
#else
        RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/1e200c00: FCSEL  <Sd>, <Sn>, <Sm>, <cond>
   Instruction Set: A64  Groups: floatsel, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCSEL_S_floatsel, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const cond       = (uOpcode >> 12) & 0x0000000f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCSEL_S_floatsel Rd=%#x Rn=%#x cond=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, cond, Rm));
#ifdef IEM_INSTR_IMPL_A64__FCSEL_S_floatsel
        IEM_INSTR_IMPL_A64__FCSEL_S_floatsel(Rd, Rn, cond, Rm);
#else
        RT_NOREF(Rd, Rn, cond, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e640000: FCVTAS  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTAS_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee40000: FCVTAS  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTAS_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e240000: FCVTAS  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTAS_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e640000: FCVTAS  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTAS_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee40000: FCVTAS  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTAS_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e240000: FCVTAS  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTAS_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e21c800: FCVTAS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_asimdmisc_R
        IEM_INSTR_IMPL_A64__FCVTAS_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0e79c800: FCVTAS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTAS_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5e21c800: FCVTAS  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5e21c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTAS_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_asisdmisc_R
            IEM_INSTR_IMPL_A64__FCVTAS_asisdmisc_R(Rd, Rn, sz);
#else
            RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e79c800: FCVTAS  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_asisdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e79c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCVTAS_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_asisdmiscfp16_R
            IEM_INSTR_IMPL_A64__FCVTAS_asisdmiscfp16_R(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e7a0000: FCVTAS  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTAS_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1efa0000: FCVTAS  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTAS_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9efa0000: FCVTAS  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTAS_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e3a0000: FCVTAS  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAS_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTAS_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAS_sisd_64S
        IEM_INSTR_IMPL_A64__FCVTAS_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e650000: FCVTAU  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTAU_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee50000: FCVTAU  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTAU_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e250000: FCVTAU  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTAU_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e650000: FCVTAU  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTAU_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee50000: FCVTAU  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTAU_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e250000: FCVTAU  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTAU_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2e21c800: FCVTAU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTAU_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_asimdmisc_R
            IEM_INSTR_IMPL_A64__FCVTAU_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e79c800: FCVTAU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_asimdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e79c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCVTAU_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_asimdmiscfp16_R
            IEM_INSTR_IMPL_A64__FCVTAU_asimdmiscfp16_R(Rd, Rn, Q);
#else
            RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7e21c800: FCVTAU  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e21c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTAU_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_asisdmisc_R
            IEM_INSTR_IMPL_A64__FCVTAU_asisdmisc_R(Rd, Rn, sz);
#else
            RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7e79c800: FCVTAU  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_asisdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7e79c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCVTAU_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_asisdmiscfp16_R
            IEM_INSTR_IMPL_A64__FCVTAU_asisdmiscfp16_R(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e7b0000: FCVTAU  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTAU_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1efb0000: FCVTAU  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTAU_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9efb0000: FCVTAU  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTAU_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e3b0000: FCVTAU  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTAU_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTAU_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTAU_sisd_64S
        IEM_INSTR_IMPL_A64__FCVTAU_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e217800: FCVTL2  <Vd>.<Ta>, <Vn>.<Tb>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTL_asimdmisc_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTL_asimdmisc_L Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTL_asimdmisc_L
        IEM_INSTR_IMPL_A64__FCVTL_asimdmisc_L(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e700000: FCVTMS  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTMS_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef00000: FCVTMS  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTMS_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e300000: FCVTMS  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTMS_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e700000: FCVTMS  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTMS_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef00000: FCVTMS  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTMS_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e300000: FCVTMS  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTMS_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e21b800: FCVTMS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_asimdmisc_R
        IEM_INSTR_IMPL_A64__FCVTMS_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0e79b800: FCVTMS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTMS_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5e21b800: FCVTMS  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_asisdmisc_R
        IEM_INSTR_IMPL_A64__FCVTMS_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e79b800: FCVTMS  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTMS_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e740000: FCVTMS  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTMS_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef40000: FCVTMS  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTMS_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef40000: FCVTMS  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTMS_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e340000: FCVTMS  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMS_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTMS_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMS_sisd_64S
        IEM_INSTR_IMPL_A64__FCVTMS_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e710000: FCVTMU  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTMU_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef10000: FCVTMU  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTMU_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e310000: FCVTMU  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTMU_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e710000: FCVTMU  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTMU_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef10000: FCVTMU  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTMU_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e310000: FCVTMU  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTMU_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2e21b800: FCVTMU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_asimdmisc_R
        IEM_INSTR_IMPL_A64__FCVTMU_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e79b800: FCVTMU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTMU_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7e21b800: FCVTMU  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_asisdmisc_R
        IEM_INSTR_IMPL_A64__FCVTMU_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7e79b800: FCVTMU  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTMU_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e750000: FCVTMU  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTMU_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef50000: FCVTMU  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTMU_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef50000: FCVTMU  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTMU_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e350000: FCVTMU  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTMU_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTMU_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTMU_sisd_64S
        IEM_INSTR_IMPL_A64__FCVTMU_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e600000: FCVTNS  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTNS_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee00000: FCVTNS  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTNS_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e200000: FCVTNS  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTNS_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e600000: FCVTNS  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTNS_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee00000: FCVTNS  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTNS_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e200000: FCVTNS  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTNS_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e21a800: FCVTNS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21a800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTNS_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_asimdmisc_R
            IEM_INSTR_IMPL_A64__FCVTNS_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0e79a800: FCVTNS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_asimdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0e79a800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCVTNS_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_asimdmiscfp16_R
            IEM_INSTR_IMPL_A64__FCVTNS_asimdmiscfp16_R(Rd, Rn, Q);
#else
            RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5e21a800: FCVTNS  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_asisdmisc_R
        IEM_INSTR_IMPL_A64__FCVTNS_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e79a800: FCVTNS  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTNS_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e6a0000: FCVTNS  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTNS_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1eea0000: FCVTNS  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTNS_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9eea0000: FCVTNS  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTNS_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e2a0000: FCVTNS  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNS_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTNS_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNS_sisd_64S
        IEM_INSTR_IMPL_A64__FCVTNS_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e610000: FCVTNU  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTNU_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee10000: FCVTNU  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTNU_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e210000: FCVTNU  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTNU_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e610000: FCVTNU  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTNU_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee10000: FCVTNU  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTNU_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e210000: FCVTNU  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTNU_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2e21a800: FCVTNU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_asimdmisc_R
        IEM_INSTR_IMPL_A64__FCVTNU_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e79a800: FCVTNU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTNU_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7e21a800: FCVTNU  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_asisdmisc_R
        IEM_INSTR_IMPL_A64__FCVTNU_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7e79a800: FCVTNU  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTNU_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e6b0000: FCVTNU  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTNU_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1eeb0000: FCVTNU  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTNU_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9eeb0000: FCVTNU  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTNU_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e2b0000: FCVTNU  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTNU_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTNU_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTNU_sisd_64S
        IEM_INSTR_IMPL_A64__FCVTNU_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e216800: FCVTN2  <Vd>.<Tb>, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTN_asimdmisc_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTN_asimdmisc_N Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTN_asimdmisc_N
        IEM_INSTR_IMPL_A64__FCVTN_asimdmisc_N(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e40f400: FCVTN  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTN_asimdsame2_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e40f400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: FCVTN_asimdsame2_D Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTN_asimdsame2_D
            IEM_INSTR_IMPL_A64__FCVTN_asimdsame2_D(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e00f400: FCVTN2  <Vd>.<Ta>, <Vn>.4S, <Vm>.4S
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTN_asimdsame2_H, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e00f400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: FCVTN_asimdsame2_H Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTN_asimdsame2_H
            IEM_INSTR_IMPL_A64__FCVTN_asimdsame2_H(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e680000: FCVTPS  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTPS_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee80000: FCVTPS  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTPS_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e280000: FCVTPS  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTPS_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e680000: FCVTPS  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTPS_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee80000: FCVTPS  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTPS_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e280000: FCVTPS  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTPS_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea1a800: FCVTPS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_asimdmisc_R
        IEM_INSTR_IMPL_A64__FCVTPS_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef9a800: FCVTPS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTPS_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5ea1a800: FCVTPS  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_asisdmisc_R
        IEM_INSTR_IMPL_A64__FCVTPS_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ef9a800: FCVTPS  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTPS_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e720000: FCVTPS  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTPS_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef20000: FCVTPS  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTPS_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef20000: FCVTPS  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTPS_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e320000: FCVTPS  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPS_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTPS_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPS_sisd_64S
        IEM_INSTR_IMPL_A64__FCVTPS_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e690000: FCVTPU  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTPU_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee90000: FCVTPU  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTPU_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e290000: FCVTPU  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTPU_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e690000: FCVTPU  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTPU_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee90000: FCVTPU  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTPU_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e290000: FCVTPU  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTPU_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea1a800: FCVTPU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_asimdmisc_R
        IEM_INSTR_IMPL_A64__FCVTPU_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ef9a800: FCVTPU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTPU_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7ea1a800: FCVTPU  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_asisdmisc_R
        IEM_INSTR_IMPL_A64__FCVTPU_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7ef9a800: FCVTPU  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FCVTPU_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e730000: FCVTPU  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTPU_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef30000: FCVTPU  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTPU_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef30000: FCVTPU  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTPU_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e330000: FCVTPU  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTPU_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTPU_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTPU_sisd_64S
        IEM_INSTR_IMPL_A64__FCVTPU_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e616800: FCVTXN2  <Vd>.<Tb>, <Vn>.2D
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTXN_asimdmisc_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FCVTXN_asimdmisc_N Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTXN_asimdmisc_N
        IEM_INSTR_IMPL_A64__FCVTXN_asimdmisc_N(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7e616800: FCVTXN  S<d>, D<n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTXN_asisdmisc_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7e616800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTXN_asisdmisc_N Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTXN_asisdmisc_N
            IEM_INSTR_IMPL_A64__FCVTXN_asisdmisc_N(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1e580000: FCVTZS  <Wd>, <Dn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_32D_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_32D_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_32D_float2fix
        IEM_INSTR_IMPL_A64__FCVTZS_32D_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e780000: FCVTZS  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTZS_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1ed80000: FCVTZS  <Wd>, <Hn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_32H_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_32H_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_32H_float2fix
        IEM_INSTR_IMPL_A64__FCVTZS_32H_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef80000: FCVTZS  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTZS_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1e180000: FCVTZS  <Wd>, <Sn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_32S_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_32S_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_32S_float2fix
        IEM_INSTR_IMPL_A64__FCVTZS_32S_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e380000: FCVTZS  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTZS_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9e580000: FCVTZS  <Xd>, <Dn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_64D_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_64D_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_64D_float2fix
        IEM_INSTR_IMPL_A64__FCVTZS_64D_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e780000: FCVTZS  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTZS_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9ed80000: FCVTZS  <Xd>, <Hn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_64H_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_64H_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_64H_float2fix
        IEM_INSTR_IMPL_A64__FCVTZS_64H_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef80000: FCVTZS  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTZS_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9e180000: FCVTZS  <Xd>, <Sn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_64S_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_64S_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_64S_float2fix
        IEM_INSTR_IMPL_A64__FCVTZS_64S_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e380000: FCVTZS  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTZS_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea1b800: FCVTZS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea1b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTZS_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_asimdmisc_R
            IEM_INSTR_IMPL_A64__FCVTZS_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef9b800: FCVTZS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_asimdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef9b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCVTZS_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_asimdmiscfp16_R
            IEM_INSTR_IMPL_A64__FCVTZS_asimdmiscfp16_R(Rd, Rn, Q);
#else
            RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f00fc00: FCVTZS  <Vd>.<T>, <Vn>.<T>, #<fbits>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_asimdshf_C, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: FCVTZS_asimdshf_C Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_asimdshf_C
        IEM_INSTR_IMPL_A64__FCVTZS_asimdshf_C(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5ea1b800: FCVTZS  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea1b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTZS_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_asisdmisc_R
            IEM_INSTR_IMPL_A64__FCVTZS_asisdmisc_R(Rd, Rn, sz);
#else
            RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ef9b800: FCVTZS  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_asisdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ef9b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCVTZS_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_asisdmiscfp16_R
            IEM_INSTR_IMPL_A64__FCVTZS_asisdmiscfp16_R(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f00fc00: FCVTZS  <V><d>, <V><n>, #<fbits>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_asisdshf_C, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
    {
        LogFlow(("%018x/%010x: FCVTZS_asisdshf_C Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_asisdshf_C
        IEM_INSTR_IMPL_A64__FCVTZS_asisdshf_C(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e760000: FCVTZS  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_sisd_32D
        IEM_INSTR_IMPL_A64__FCVTZS_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef60000: FCVTZS  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTZS_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef60000: FCVTZS  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTZS_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTZS_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e360000: FCVTZS  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZS_sisd_64S, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e360000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
        {
            LogFlow(("%018x/%010x: FCVTZS_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZS_sisd_64S
            IEM_INSTR_IMPL_A64__FCVTZS_sisd_64S(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1e590000: FCVTZU  <Wd>, <Dn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_32D_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_32D_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_32D_float2fix
        IEM_INSTR_IMPL_A64__FCVTZU_32D_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e790000: FCVTZU  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_32D_float2int
        IEM_INSTR_IMPL_A64__FCVTZU_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1ed90000: FCVTZU  <Wd>, <Hn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_32H_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_32H_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_32H_float2fix
        IEM_INSTR_IMPL_A64__FCVTZU_32H_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef90000: FCVTZU  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_32H_float2int
        IEM_INSTR_IMPL_A64__FCVTZU_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1e190000: FCVTZU  <Wd>, <Sn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_32S_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_32S_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_32S_float2fix
        IEM_INSTR_IMPL_A64__FCVTZU_32S_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e390000: FCVTZU  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_32S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_32S_float2int
        IEM_INSTR_IMPL_A64__FCVTZU_32S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9e590000: FCVTZU  <Xd>, <Dn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_64D_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_64D_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_64D_float2fix
        IEM_INSTR_IMPL_A64__FCVTZU_64D_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e790000: FCVTZU  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_64D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_64D_float2int
        IEM_INSTR_IMPL_A64__FCVTZU_64D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9ed90000: FCVTZU  <Xd>, <Hn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_64H_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_64H_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_64H_float2fix
        IEM_INSTR_IMPL_A64__FCVTZU_64H_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef90000: FCVTZU  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_64H_float2int
        IEM_INSTR_IMPL_A64__FCVTZU_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9e190000: FCVTZU  <Xd>, <Sn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_64S_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_64S_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_64S_float2fix
        IEM_INSTR_IMPL_A64__FCVTZU_64S_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e390000: FCVTZU  <Xd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_64S_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_64S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_64S_float2int
        IEM_INSTR_IMPL_A64__FCVTZU_64S_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea1b800: FCVTZU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTZU_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_asimdmisc_R
            IEM_INSTR_IMPL_A64__FCVTZU_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ef9b800: FCVTZU  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_asimdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef9b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCVTZU_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_asimdmiscfp16_R
            IEM_INSTR_IMPL_A64__FCVTZU_asimdmiscfp16_R(Rd, Rn, Q);
#else
            RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f00fc00: FCVTZU  <Vd>.<T>, <Vn>.<T>, #<fbits>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_asimdshf_C, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: FCVTZU_asimdshf_C Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_asimdshf_C
        IEM_INSTR_IMPL_A64__FCVTZU_asimdshf_C(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7ea1b800: FCVTZU  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7ea1b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FCVTZU_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_asisdmisc_R
            IEM_INSTR_IMPL_A64__FCVTZU_asisdmisc_R(Rd, Rn, sz);
#else
            RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7ef9b800: FCVTZU  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_asisdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7ef9b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FCVTZU_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_asisdmiscfp16_R
            IEM_INSTR_IMPL_A64__FCVTZU_asisdmiscfp16_R(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f00fc00: FCVTZU  <V><d>, <V><n>, #<fbits>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_asisdshf_C, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f00fc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
        {
            LogFlow(("%018x/%010x: FCVTZU_asisdshf_C Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_asisdshf_C
            IEM_INSTR_IMPL_A64__FCVTZU_asisdshf_C(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e770000: FCVTZU  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_sisd_32D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e770000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
        {
            LogFlow(("%018x/%010x: FCVTZU_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_sisd_32D
            IEM_INSTR_IMPL_A64__FCVTZU_sisd_32D(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ef70000: FCVTZU  <Sd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_sisd_32H
        IEM_INSTR_IMPL_A64__FCVTZU_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ef70000: FCVTZU  <Dd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: FCVTZU_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_sisd_64H
        IEM_INSTR_IMPL_A64__FCVTZU_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e370000: FCVTZU  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVTZU_sisd_64S, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e370000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
        {
            LogFlow(("%018x/%010x: FCVTZU_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVTZU_sisd_64S
            IEM_INSTR_IMPL_A64__FCVTZU_sisd_64S(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee2c000: FCVT  <Dd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVT_DH_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVT_DH_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVT_DH_floatdp1
        IEM_INSTR_IMPL_A64__FCVT_DH_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e22c000: FCVT  <Dd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVT_DS_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVT_DS_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVT_DS_floatdp1
        IEM_INSTR_IMPL_A64__FCVT_DS_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e63c000: FCVT  <Hd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVT_HD_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVT_HD_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVT_HD_floatdp1
        IEM_INSTR_IMPL_A64__FCVT_HD_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e23c000: FCVT  <Hd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVT_HS_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVT_HS_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVT_HS_floatdp1
        IEM_INSTR_IMPL_A64__FCVT_HS_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e624000: FCVT  <Sd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVT_SD_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVT_SD_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVT_SD_floatdp1
        IEM_INSTR_IMPL_A64__FCVT_SD_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee24000: FCVT  <Sd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FCVT_SH_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FCVT_SH_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FCVT_SH_floatdp1
        IEM_INSTR_IMPL_A64__FCVT_SH_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e601800: FDIV  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDIV_D_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e601800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FDIV_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FDIV_D_floatdp2
            IEM_INSTR_IMPL_A64__FDIV_D_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee01800: FDIV  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDIV_H_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1ee01800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FDIV_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FDIV_H_floatdp2
            IEM_INSTR_IMPL_A64__FDIV_H_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e201800: FDIV  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDIV_S_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FDIV_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FDIV_S_floatdp2
        IEM_INSTR_IMPL_A64__FDIV_S_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2e20fc00: FDIV  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDIV_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FDIV_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FDIV_asimdsame_only
        IEM_INSTR_IMPL_A64__FDIV_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e403c00: FDIV  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDIV_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e403c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FDIV_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FDIV_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FDIV_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f000000: FDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.4B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDOT_asimdelem_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Dot4 /*FEAT_FP8DOT4*/)
        {
            LogFlow(("%018x/%010x: FDOT_asimdelem_D Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FDOT_asimdelem_D
            IEM_INSTR_IMPL_A64__FDOT_asimdelem_D(Rd, Rn, H, Rm, M, L, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f400000: FDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.2B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDOT_asimdelem_G, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f400000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Dot2 /*FEAT_FP8DOT2*/)
        {
            LogFlow(("%018x/%010x: FDOT_asimdelem_G Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FDOT_asimdelem_G
            IEM_INSTR_IMPL_A64__FDOT_asimdelem_G(Rd, Rn, H, Rm, M, L, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e40fc00: FDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDOT_asimdsame2_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e40fc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Dot2 /*FEAT_FP8DOT2*/)
        {
            LogFlow(("%018x/%010x: FDOT_asimdsame2_D Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FDOT_asimdsame2_D
            IEM_INSTR_IMPL_A64__FDOT_asimdsame2_D(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e00fc00: FDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FDOT_asimdsame2_DD, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e00fc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Dot4 /*FEAT_FP8DOT4*/)
        {
            LogFlow(("%018x/%010x: FDOT_asimdsame2_DD Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FDOT_asimdsame2_DD
            IEM_INSTR_IMPL_A64__FDOT_asimdsame2_DD(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e7e0000: FJCVTZS  <Wd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FJCVTZS_32D_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fJscvt /*FEAT_JSCVT*/)
    {
        LogFlow(("%018x/%010x: FJCVTZS_32D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FJCVTZS_32D_float2int
        IEM_INSTR_IMPL_A64__FJCVTZS_32D_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1f400000: FMADD  <Dd>, <Dn>, <Dm>, <Da>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMADD_D_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMADD_D_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMADD_D_floatdp3
        IEM_INSTR_IMPL_A64__FMADD_D_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1fc00000: FMADD  <Hd>, <Hn>, <Hm>, <Ha>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMADD_H_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMADD_H_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMADD_H_floatdp3
        IEM_INSTR_IMPL_A64__FMADD_H_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1f000000: FMADD  <Sd>, <Sn>, <Sm>, <Sa>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMADD_S_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMADD_S_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMADD_S_floatdp3
        IEM_INSTR_IMPL_A64__FMADD_S_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2e20c400: FMAXNMP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNMP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2e20c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMAXNMP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAXNMP_asimdsame_only
            IEM_INSTR_IMPL_A64__FMAXNMP_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e400400: FMAXNMP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNMP_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e400400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMAXNMP_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAXNMP_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FMAXNMP_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e30c800: FMAXNMP  H<d>, <Vn>.2H
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNMP_asisdpair_only_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMAXNMP_asisdpair_only_H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMAXNMP_asisdpair_only_H
        IEM_INSTR_IMPL_A64__FMAXNMP_asisdpair_only_H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7e30c800: FMAXNMP  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNMP_asisdpair_only_SD, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e30c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMAXNMP_asisdpair_only_SD Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FMAXNMP_asisdpair_only_SD
            IEM_INSTR_IMPL_A64__FMAXNMP_asisdpair_only_SD(Rd, Rn, sz);
#else
            RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0e30c800: FMAXNMV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNMV_asimdall_only_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMAXNMV_asimdall_only_H Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAXNMV_asimdall_only_H
        IEM_INSTR_IMPL_A64__FMAXNMV_asimdall_only_H(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/6e30c800: FMAXNMV  S<d>, <Vn>.4S
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNMV_asimdall_only_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMAXNMV_asimdall_only_SD Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMAXNMV_asimdall_only_SD
        IEM_INSTR_IMPL_A64__FMAXNMV_asimdall_only_SD(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e606800: FMAXNM  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNM_D_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e606800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMAXNM_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMAXNM_D_floatdp2
            IEM_INSTR_IMPL_A64__FMAXNM_D_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee06800: FMAXNM  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNM_H_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1ee06800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMAXNM_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMAXNM_H_floatdp2
            IEM_INSTR_IMPL_A64__FMAXNM_H_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e206800: FMAXNM  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNM_S_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e206800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMAXNM_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMAXNM_S_floatdp2
            IEM_INSTR_IMPL_A64__FMAXNM_S_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0e20c400: FMAXNM  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNM_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMAXNM_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAXNM_asimdsame_only
        IEM_INSTR_IMPL_A64__FMAXNM_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e400400: FMAXNM  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXNM_asimdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMAXNM_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAXNM_asimdsamefp16_only
        IEM_INSTR_IMPL_A64__FMAXNM_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2e20f400: FMAXP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2e20f400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMAXP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAXP_asimdsame_only
            IEM_INSTR_IMPL_A64__FMAXP_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e403400: FMAXP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXP_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e403400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMAXP_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAXP_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FMAXP_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e30f800: FMAXP  H<d>, <Vn>.2H
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXP_asisdpair_only_H, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e30f800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMAXP_asisdpair_only_H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMAXP_asisdpair_only_H
            IEM_INSTR_IMPL_A64__FMAXP_asisdpair_only_H(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7e30f800: FMAXP  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXP_asisdpair_only_SD, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e30f800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMAXP_asisdpair_only_SD Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FMAXP_asisdpair_only_SD
            IEM_INSTR_IMPL_A64__FMAXP_asisdpair_only_SD(Rd, Rn, sz);
#else
            RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0e30f800: FMAXV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXV_asimdall_only_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMAXV_asimdall_only_H Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAXV_asimdall_only_H
        IEM_INSTR_IMPL_A64__FMAXV_asimdall_only_H(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/6e30f800: FMAXV  S<d>, <Vn>.4S
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAXV_asimdall_only_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMAXV_asimdall_only_SD Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMAXV_asimdall_only_SD
        IEM_INSTR_IMPL_A64__FMAXV_asimdall_only_SD(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e604800: FMAX  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAX_D_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e604800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMAX_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMAX_D_floatdp2
            IEM_INSTR_IMPL_A64__FMAX_D_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee04800: FMAX  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAX_H_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1ee04800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMAX_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMAX_H_floatdp2
            IEM_INSTR_IMPL_A64__FMAX_H_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e204800: FMAX  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAX_S_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMAX_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMAX_S_floatdp2
        IEM_INSTR_IMPL_A64__FMAX_S_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0e20f400: FMAX  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAX_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0e20f400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMAX_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAX_asimdsame_only
            IEM_INSTR_IMPL_A64__FMAX_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e403400: FMAX  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMAX_asimdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMAX_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMAX_asimdsamefp16_only
        IEM_INSTR_IMPL_A64__FMAX_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2ea0c400: FMINNMP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNMP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2ea0c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMINNMP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMINNMP_asimdsame_only
            IEM_INSTR_IMPL_A64__FMINNMP_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ec00400: FMINNMP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNMP_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ec00400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMINNMP_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMINNMP_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FMINNMP_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5eb0c800: FMINNMP  H<d>, <Vn>.2H
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNMP_asisdpair_only_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMINNMP_asisdpair_only_H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMINNMP_asisdpair_only_H
        IEM_INSTR_IMPL_A64__FMINNMP_asisdpair_only_H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7eb0c800: FMINNMP  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNMP_asisdpair_only_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMINNMP_asisdpair_only_SD Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FMINNMP_asisdpair_only_SD
        IEM_INSTR_IMPL_A64__FMINNMP_asisdpair_only_SD(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0eb0c800: FMINNMV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNMV_asimdall_only_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMINNMV_asimdall_only_H Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FMINNMV_asimdall_only_H
        IEM_INSTR_IMPL_A64__FMINNMV_asimdall_only_H(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/6eb0c800: FMINNMV  S<d>, <Vn>.4S
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNMV_asimdall_only_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMINNMV_asimdall_only_SD Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMINNMV_asimdall_only_SD
        IEM_INSTR_IMPL_A64__FMINNMV_asimdall_only_SD(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e607800: FMINNM  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNM_D_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e607800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMINNM_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMINNM_D_floatdp2
            IEM_INSTR_IMPL_A64__FMINNM_D_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee07800: FMINNM  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNM_H_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMINNM_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMINNM_H_floatdp2
        IEM_INSTR_IMPL_A64__FMINNM_H_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e207800: FMINNM  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNM_S_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMINNM_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMINNM_S_floatdp2
        IEM_INSTR_IMPL_A64__FMINNM_S_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0ea0c400: FMINNM  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNM_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0ea0c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMINNM_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMINNM_asimdsame_only
            IEM_INSTR_IMPL_A64__FMINNM_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0ec00400: FMINNM  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINNM_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0ec00400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMINNM_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMINNM_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FMINNM_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2ea0f400: FMINP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2ea0f400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMINP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMINP_asimdsame_only
            IEM_INSTR_IMPL_A64__FMINP_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ec03400: FMINP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINP_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ec03400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMINP_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMINP_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FMINP_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5eb0f800: FMINP  H<d>, <Vn>.2H
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINP_asisdpair_only_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMINP_asisdpair_only_H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMINP_asisdpair_only_H
        IEM_INSTR_IMPL_A64__FMINP_asisdpair_only_H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7eb0f800: FMINP  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asisdpair, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINP_asisdpair_only_SD, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7eb0f800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMINP_asisdpair_only_SD Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FMINP_asisdpair_only_SD
            IEM_INSTR_IMPL_A64__FMINP_asisdpair_only_SD(Rd, Rn, sz);
#else
            RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0eb0f800: FMINV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINV_asimdall_only_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMINV_asimdall_only_H Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FMINV_asimdall_only_H
        IEM_INSTR_IMPL_A64__FMINV_asimdall_only_H(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/6eb0f800: FMINV  S<d>, <Vn>.4S
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMINV_asimdall_only_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMINV_asimdall_only_SD Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMINV_asimdall_only_SD
        IEM_INSTR_IMPL_A64__FMINV_asimdall_only_SD(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e605800: FMIN  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMIN_D_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e605800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMIN_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMIN_D_floatdp2
            IEM_INSTR_IMPL_A64__FMIN_D_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee05800: FMIN  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMIN_H_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1ee05800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMIN_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMIN_H_floatdp2
            IEM_INSTR_IMPL_A64__FMIN_H_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e205800: FMIN  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMIN_S_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMIN_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMIN_S_floatdp2
        IEM_INSTR_IMPL_A64__FMIN_S_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0ea0f400: FMIN  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMIN_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0ea0f400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMIN_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMIN_asimdsame_only
            IEM_INSTR_IMPL_A64__FMIN_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0ec03400: FMIN  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMIN_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0ec03400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMIN_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMIN_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FMIN_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/2f808000: FMLAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLAL2_asimdelem_LH, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFhm /*FEAT_FHM*/)
    {
        LogFlow(("%018x/%010x: FMLAL2_asimdelem_LH Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLAL2_asimdelem_LH
        IEM_INSTR_IMPL_A64__FMLAL2_asimdelem_LH(Rd, Rn, H, Rm, M, L, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e20cc00: FMLAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLAL2_asimdsame_F, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e20cc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFhm /*FEAT_FHM*/)
        {
            LogFlow(("%018x/%010x: FMLAL2_asimdsame_F Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLAL2_asimdsame_F
            IEM_INSTR_IMPL_A64__FMLAL2_asimdsame_F(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/0fc00000: FMLALB  <Vd>.8H, <Vn>.16B, <Vm>.B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALB_asimdelem_H, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x0fc00000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALB_asimdelem_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMLALB_asimdelem_H
            IEM_INSTR_IMPL_A64__FMLALB_asimdelem_H(Rd, Rn, H, Rm, M, L);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/0ec0fc00: FMLALB  <Vd>.8H, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALB_asimdsame2_J, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0ec0fc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALB_asimdsame2_J Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMLALB_asimdsame2_J
            IEM_INSTR_IMPL_A64__FMLALB_asimdsame2_J(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/2f008000: FMLALLBB  <Vd>.4S, <Vn>.16B, <Vm>.B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALLBB_asimdelem_J, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x2f008000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALLBB_asimdelem_J Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMLALLBB_asimdelem_J
            IEM_INSTR_IMPL_A64__FMLALLBB_asimdelem_J(Rd, Rn, H, Rm, M, L);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/0e00c400: FMLALLBB  <Vd>.4S, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALLBB_asimdsame2_G, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0e00c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALLBB_asimdsame2_G Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMLALLBB_asimdsame2_G
            IEM_INSTR_IMPL_A64__FMLALLBB_asimdsame2_G(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/2f408000: FMLALLBT  <Vd>.4S, <Vn>.16B, <Vm>.B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALLBT_asimdelem_J, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x2f408000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALLBT_asimdelem_J Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMLALLBT_asimdelem_J
            IEM_INSTR_IMPL_A64__FMLALLBT_asimdelem_J(Rd, Rn, H, Rm, M, L);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/0e40c400: FMLALLBT  <Vd>.4S, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALLBT_asimdsame2_G, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0e40c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALLBT_asimdsame2_G Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMLALLBT_asimdsame2_G
            IEM_INSTR_IMPL_A64__FMLALLBT_asimdsame2_G(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/6f008000: FMLALLTB  <Vd>.4S, <Vn>.16B, <Vm>.B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALLTB_asimdelem_J, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x6f008000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALLTB_asimdelem_J Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMLALLTB_asimdelem_J
            IEM_INSTR_IMPL_A64__FMLALLTB_asimdelem_J(Rd, Rn, H, Rm, M, L);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4e00c400: FMLALLTB  <Vd>.4S, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALLTB_asimdsame2_G, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4e00c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALLTB_asimdsame2_G Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMLALLTB_asimdsame2_G
            IEM_INSTR_IMPL_A64__FMLALLTB_asimdsame2_G(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/6f408000: FMLALLTT  <Vd>.4S, <Vn>.16B, <Vm>.B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALLTT_asimdelem_J, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x6f408000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALLTT_asimdelem_J Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMLALLTT_asimdelem_J
            IEM_INSTR_IMPL_A64__FMLALLTT_asimdelem_J(Rd, Rn, H, Rm, M, L);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4e40c400: FMLALLTT  <Vd>.4S, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALLTT_asimdsame2_G, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4e40c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALLTT_asimdsame2_G Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMLALLTT_asimdsame2_G
            IEM_INSTR_IMPL_A64__FMLALLTT_asimdsame2_G(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/4fc00000: FMLALT  <Vd>.8H, <Vn>.16B, <Vm>.B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALT_asimdelem_H, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x4fc00000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALT_asimdelem_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMLALT_asimdelem_H
            IEM_INSTR_IMPL_A64__FMLALT_asimdelem_H(Rd, Rn, H, Rm, M, L);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4ec0fc00: FMLALT  <Vd>.8H, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLALT_asimdsame2_J, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4ec0fc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/)
        {
            LogFlow(("%018x/%010x: FMLALT_asimdsame2_J Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMLALT_asimdsame2_J
            IEM_INSTR_IMPL_A64__FMLALT_asimdsame2_J(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f800000: FMLAL  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLAL_asimdelem_LH, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFhm /*FEAT_FHM*/)
    {
        LogFlow(("%018x/%010x: FMLAL_asimdelem_LH Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLAL_asimdelem_LH
        IEM_INSTR_IMPL_A64__FMLAL_asimdelem_LH(Rd, Rn, H, Rm, M, L, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e20ec00: FMLAL  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLAL_asimdsame_F, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e20ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFhm /*FEAT_FHM*/)
        {
            LogFlow(("%018x/%010x: FMLAL_asimdsame_F Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLAL_asimdsame_F
            IEM_INSTR_IMPL_A64__FMLAL_asimdsame_F(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f001000: FMLA  <Vd>.<T>, <Vn>.<T>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLA_asimdelem_RH_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMLA_asimdelem_RH_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLA_asimdelem_RH_H
        IEM_INSTR_IMPL_A64__FMLA_asimdelem_RH_H(Rd, Rn, H, Rm, M, L, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80f400/0f801000: FMLA  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLA_asimdelem_R_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMLA_asimdelem_R_SD Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLA_asimdelem_R_SD
        IEM_INSTR_IMPL_A64__FMLA_asimdelem_R_SD(Rd, Rn, H, Rm, M, L, sz, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0e20cc00: FMLA  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLA_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0e20cc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMLA_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLA_asimdsame_only
            IEM_INSTR_IMPL_A64__FMLA_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e400c00: FMLA  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLA_asimdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMLA_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLA_asimdsamefp16_only
        IEM_INSTR_IMPL_A64__FMLA_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/5f001000: FMLA  <Hd>, <Hn>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLA_asisdelem_RH_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMLA_asisdelem_RH_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMLA_asisdelem_RH_H
        IEM_INSTR_IMPL_A64__FMLA_asisdelem_RH_H(Rd, Rn, H, Rm, M, L);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80f400/5f801000: FMLA  <V><d>, <V><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLA_asisdelem_R_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMLA_asisdelem_R_SD Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, sz));
#ifdef IEM_INSTR_IMPL_A64__FMLA_asisdelem_R_SD
        IEM_INSTR_IMPL_A64__FMLA_asisdelem_R_SD(Rd, Rn, H, Rm, M, L, sz);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/2f80c000: FMLSL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLSL2_asimdelem_LH, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x2f80c000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFhm /*FEAT_FHM*/)
        {
            LogFlow(("%018x/%010x: FMLSL2_asimdelem_LH Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLSL2_asimdelem_LH
            IEM_INSTR_IMPL_A64__FMLSL2_asimdelem_LH(Rd, Rn, H, Rm, M, L, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ea0cc00: FMLSL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLSL2_asimdsame_F, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFhm /*FEAT_FHM*/)
    {
        LogFlow(("%018x/%010x: FMLSL2_asimdsame_F Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLSL2_asimdsame_F
        IEM_INSTR_IMPL_A64__FMLSL2_asimdsame_F(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f804000: FMLSL  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLSL_asimdelem_LH, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFhm /*FEAT_FHM*/)
    {
        LogFlow(("%018x/%010x: FMLSL_asimdelem_LH Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLSL_asimdelem_LH
        IEM_INSTR_IMPL_A64__FMLSL_asimdelem_LH(Rd, Rn, H, Rm, M, L, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0ea0ec00: FMLSL  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLSL_asimdsame_F, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0ea0ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFhm /*FEAT_FHM*/)
        {
            LogFlow(("%018x/%010x: FMLSL_asimdsame_F Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLSL_asimdsame_F
            IEM_INSTR_IMPL_A64__FMLSL_asimdsame_F(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f005000: FMLS  <Vd>.<T>, <Vn>.<T>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLS_asimdelem_RH_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMLS_asimdelem_RH_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLS_asimdelem_RH_H
        IEM_INSTR_IMPL_A64__FMLS_asimdelem_RH_H(Rd, Rn, H, Rm, M, L, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80f400/0f805000: FMLS  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLS_asimdelem_R_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMLS_asimdelem_R_SD Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLS_asimdelem_R_SD
        IEM_INSTR_IMPL_A64__FMLS_asimdelem_R_SD(Rd, Rn, H, Rm, M, L, sz, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0ea0cc00: FMLS  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLS_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0ea0cc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMLS_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLS_asimdsame_only
            IEM_INSTR_IMPL_A64__FMLS_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
            RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0ec00c00: FMLS  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLS_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0ec00c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMLS_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMLS_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FMLS_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/5f005000: FMLS  <Hd>, <Hn>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLS_asisdelem_RH_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMLS_asisdelem_RH_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMLS_asisdelem_RH_H
        IEM_INSTR_IMPL_A64__FMLS_asisdelem_RH_H(Rd, Rn, H, Rm, M, L);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80f400/5f805000: FMLS  <V><d>, <V><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMLS_asisdelem_R_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMLS_asisdelem_R_SD Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, sz));
#ifdef IEM_INSTR_IMPL_A64__FMLS_asisdelem_R_SD
        IEM_INSTR_IMPL_A64__FMLS_asisdelem_R_SD(Rd, Rn, H, Rm, M, L, sz);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6e00ec00: FMMLA  <Vd>.8H, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMMLA_asimd_FP8FP16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x6e00ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF8F16mm /*FEAT_F8F16MM*/)
        {
            LogFlow(("%018x/%010x: FMMLA_asimd_FP8FP16 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMMLA_asimd_FP8FP16
            IEM_INSTR_IMPL_A64__FMMLA_asimd_FP8FP16(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6e80ec00: FMMLA  <Vd>.4S, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMMLA_asimd_FP8FP32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x6e80ec00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF8F32mm /*FEAT_F8F32MM*/)
        {
            LogFlow(("%018x/%010x: FMMLA_asimd_FP8FP32 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMMLA_asimd_FP8FP32
            IEM_INSTR_IMPL_A64__FMMLA_asimd_FP8FP32(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee60000: FMOV  <Wd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_32H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMOV_32H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_32H_float2int
        IEM_INSTR_IMPL_A64__FMOV_32H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e260000: FMOV  <Wd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_32S_float2int, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e260000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMOV_32S_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_32S_float2int
            IEM_INSTR_IMPL_A64__FMOV_32S_float2int(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e660000: FMOV  <Xd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_64D_float2int, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e660000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMOV_64D_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_64D_float2int
            IEM_INSTR_IMPL_A64__FMOV_64D_float2int(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee60000: FMOV  <Xd>, <Hn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_64H_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMOV_64H_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_64H_float2int
        IEM_INSTR_IMPL_A64__FMOV_64H_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9eae0000: FMOV  <Xd>, <Vn>.D[1]
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_64VX_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMOV_64VX_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_64VX_float2int
        IEM_INSTR_IMPL_A64__FMOV_64VX_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e670000: FMOV  <Dd>, <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_D64_float2int, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e670000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMOV_D64_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_D64_float2int
            IEM_INSTR_IMPL_A64__FMOV_D64_float2int(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e604000: FMOV  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMOV_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_D_floatdp1
        IEM_INSTR_IMPL_A64__FMOV_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe01fe0/1e601000: FMOV  <Dd>, #<imm>
   Instruction Set: A64  Groups: floatimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_D_floatimm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 13) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMOV_D_floatimm Rd=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm8));
#ifdef IEM_INSTR_IMPL_A64__FMOV_D_floatimm
        IEM_INSTR_IMPL_A64__FMOV_D_floatimm(Rd, imm8);
#else
        RT_NOREF(Rd, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee70000: FMOV  <Hd>, <Wn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_H32_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMOV_H32_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_H32_float2int
        IEM_INSTR_IMPL_A64__FMOV_H32_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee70000: FMOV  <Hd>, <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_H64_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMOV_H64_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_H64_float2int
        IEM_INSTR_IMPL_A64__FMOV_H64_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee04000: FMOV  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMOV_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_H_floatdp1
        IEM_INSTR_IMPL_A64__FMOV_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe01fe0/1ee01000: FMOV  <Hd>, #<imm>
   Instruction Set: A64  Groups: floatimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_H_floatimm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 13) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMOV_H_floatimm Rd=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm8));
#ifdef IEM_INSTR_IMPL_A64__FMOV_H_floatimm
        IEM_INSTR_IMPL_A64__FMOV_H_floatimm(Rd, imm8);
#else
        RT_NOREF(Rd, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e270000: FMOV  <Sd>, <Wn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_S32_float2int, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e270000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMOV_S32_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_S32_float2int
            IEM_INSTR_IMPL_A64__FMOV_S32_float2int(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e204000: FMOV  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMOV_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_S_floatdp1
        IEM_INSTR_IMPL_A64__FMOV_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe01fe0/1e201000: FMOV  <Sd>, #<imm>
   Instruction Set: A64  Groups: floatimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_S_floatimm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 13) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMOV_S_floatimm Rd=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm8));
#ifdef IEM_INSTR_IMPL_A64__FMOV_S_floatimm
        IEM_INSTR_IMPL_A64__FMOV_S_floatimm(Rd, imm8);
#else
        RT_NOREF(Rd, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9eaf0000: FMOV  <Vd>.D[1], <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_V64I_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMOV_V64I_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FMOV_V64I_float2int
        IEM_INSTR_IMPL_A64__FMOV_V64I_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff8fc00/6f00f400: FMOV  <Vd>.2D, #<imm>
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_asimdimm_D2_d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff8fc00)) == UINT32_C(0x6f00f400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const h          = (uOpcode >>  5) & 0x00000001;
        uint32_t const g          = (uOpcode >>  6) & 0x00000001;
        uint32_t const f          = (uOpcode >>  7) & 0x00000001;
        uint32_t const e          = (uOpcode >>  8) & 0x00000001;
        uint32_t const d          = (uOpcode >>  9) & 0x00000001;
        uint32_t const c          = (uOpcode >> 16) & 0x00000001;
        uint32_t const b          = (uOpcode >> 17) & 0x00000001;
        uint32_t const a          = (uOpcode >> 18) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMOV_asimdimm_D2_d Rd=%#x h=%u g=%u f=%u e=%u d=%u c=%u b=%u a=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, c, b, a));
#ifdef IEM_INSTR_IMPL_A64__FMOV_asimdimm_D2_d
            IEM_INSTR_IMPL_A64__FMOV_asimdimm_D2_d(Rd, h, g, f, e, d, c, b, a);
#else
            RT_NOREF(Rd, h, g, f, e, d, c, b, a, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff8fc00/0f00fc00: FMOV  <Vd>.<T>, #<imm>
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_asimdimm_H_h, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMOV_asimdimm_H_h Rd=%#x h=%u g=%u f=%u e=%u d=%u c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__FMOV_asimdimm_H_h
        IEM_INSTR_IMPL_A64__FMOV_asimdimm_H_h(Rd, h, g, f, e, d, c, b, a, Q);
#else
        RT_NOREF(Rd, h, g, f, e, d, c, b, a, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff8fc00/0f00f400: FMOV  <Vd>.<T>, #<imm>
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMOV_asimdimm_S_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbff8fc00)) == UINT32_C(0x0f00f400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const h          = (uOpcode >>  5) & 0x00000001;
        uint32_t const g          = (uOpcode >>  6) & 0x00000001;
        uint32_t const f          = (uOpcode >>  7) & 0x00000001;
        uint32_t const e          = (uOpcode >>  8) & 0x00000001;
        uint32_t const d          = (uOpcode >>  9) & 0x00000001;
        uint32_t const c          = (uOpcode >> 16) & 0x00000001;
        uint32_t const b          = (uOpcode >> 17) & 0x00000001;
        uint32_t const a          = (uOpcode >> 18) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMOV_asimdimm_S_s Rd=%#x h=%u g=%u f=%u e=%u d=%u c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__FMOV_asimdimm_S_s
            IEM_INSTR_IMPL_A64__FMOV_asimdimm_S_s(Rd, h, g, f, e, d, c, b, a, Q);
#else
            RT_NOREF(Rd, h, g, f, e, d, c, b, a, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1f408000: FMSUB  <Dd>, <Dn>, <Dm>, <Da>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMSUB_D_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMSUB_D_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMSUB_D_floatdp3
        IEM_INSTR_IMPL_A64__FMSUB_D_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1fc08000: FMSUB  <Hd>, <Hn>, <Hm>, <Ha>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMSUB_H_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMSUB_H_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMSUB_H_floatdp3
        IEM_INSTR_IMPL_A64__FMSUB_H_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1f008000: FMSUB  <Sd>, <Sn>, <Sm>, <Sa>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMSUB_S_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMSUB_S_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMSUB_S_floatdp3
        IEM_INSTR_IMPL_A64__FMSUB_S_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/2f009000: FMULX  <Vd>.<T>, <Vn>.<T>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMULX_asimdelem_RH_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMULX_asimdelem_RH_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FMULX_asimdelem_RH_H
        IEM_INSTR_IMPL_A64__FMULX_asimdelem_RH_H(Rd, Rn, H, Rm, M, L, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80f400/2f809000: FMULX  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMULX_asimdelem_R_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMULX_asimdelem_R_SD Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMULX_asimdelem_R_SD
        IEM_INSTR_IMPL_A64__FMULX_asimdelem_R_SD(Rd, Rn, H, Rm, M, L, sz, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0e20dc00: FMULX  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMULX_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMULX_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMULX_asimdsame_only
        IEM_INSTR_IMPL_A64__FMULX_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e401c00: FMULX  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMULX_asimdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMULX_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMULX_asimdsamefp16_only
        IEM_INSTR_IMPL_A64__FMULX_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/7f009000: FMULX  <Hd>, <Hn>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMULX_asisdelem_RH_H, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x7f009000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMULX_asisdelem_RH_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMULX_asisdelem_RH_H
            IEM_INSTR_IMPL_A64__FMULX_asisdelem_RH_H(Rd, Rn, H, Rm, M, L);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80f400/7f809000: FMULX  <V><d>, <V><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMULX_asisdelem_R_SD, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80f400)) == UINT32_C(0x7f809000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FMULX_asisdelem_R_SD Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, sz));
#ifdef IEM_INSTR_IMPL_A64__FMULX_asisdelem_R_SD
            IEM_INSTR_IMPL_A64__FMULX_asisdelem_R_SD(Rd, Rn, H, Rm, M, L, sz);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/5e20dc00: FMULX  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMULX_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMULX_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FMULX_asisdsame_only
        IEM_INSTR_IMPL_A64__FMULX_asisdsame_only(Rd, Rn, Rm, sz);
#else
        RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e401c00: FMULX  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMULX_asisdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e401c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMULX_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMULX_asisdsamefp16_only
            IEM_INSTR_IMPL_A64__FMULX_asisdsamefp16_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e600800: FMUL  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_D_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e600800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FMUL_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMUL_D_floatdp2
            IEM_INSTR_IMPL_A64__FMUL_D_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee00800: FMUL  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_H_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1ee00800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMUL_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMUL_H_floatdp2
            IEM_INSTR_IMPL_A64__FMUL_H_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e200800: FMUL  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_S_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FMUL_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FMUL_S_floatdp2
        IEM_INSTR_IMPL_A64__FMUL_S_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f009000: FMUL  <Vd>.<T>, <Vn>.<T>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_asimdelem_RH_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMUL_asimdelem_RH_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__FMUL_asimdelem_RH_H
        IEM_INSTR_IMPL_A64__FMUL_asimdelem_RH_H(Rd, Rn, H, Rm, M, L, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80f400/0f809000: FMUL  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_asimdelem_R_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMUL_asimdelem_R_SD Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMUL_asimdelem_R_SD
        IEM_INSTR_IMPL_A64__FMUL_asimdelem_R_SD(Rd, Rn, H, Rm, M, L, sz, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/2e20dc00: FMUL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMUL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FMUL_asimdsame_only
        IEM_INSTR_IMPL_A64__FMUL_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2e401c00: FMUL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e401c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FMUL_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FMUL_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FMUL_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0f400/5f009000: FMUL  <Hd>, <Hn>, <Vm>.H[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_asisdelem_RH_H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FMUL_asisdelem_RH_H Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L));
#ifdef IEM_INSTR_IMPL_A64__FMUL_asisdelem_RH_H
        IEM_INSTR_IMPL_A64__FMUL_asisdelem_RH_H(Rd, Rn, H, Rm, M, L);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80f400/5f809000: FMUL  <V><d>, <V><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FMUL_asisdelem_R_SD, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FMUL_asisdelem_R_SD Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, sz));
#ifdef IEM_INSTR_IMPL_A64__FMUL_asisdelem_R_SD
        IEM_INSTR_IMPL_A64__FMUL_asisdelem_R_SD(Rd, Rn, H, Rm, M, L, sz);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e614000: FNEG  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNEG_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FNEG_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FNEG_D_floatdp1
        IEM_INSTR_IMPL_A64__FNEG_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee14000: FNEG  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNEG_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FNEG_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FNEG_H_floatdp1
        IEM_INSTR_IMPL_A64__FNEG_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e214000: FNEG  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNEG_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FNEG_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FNEG_S_floatdp1
        IEM_INSTR_IMPL_A64__FNEG_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea0f800: FNEG  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNEG_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FNEG_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FNEG_asimdmisc_R
        IEM_INSTR_IMPL_A64__FNEG_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ef8f800: FNEG  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNEG_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FNEG_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FNEG_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FNEG_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1f600000: FNMADD  <Dd>, <Dn>, <Dm>, <Da>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMADD_D_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FNMADD_D_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMADD_D_floatdp3
        IEM_INSTR_IMPL_A64__FNMADD_D_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1fe00000: FNMADD  <Hd>, <Hn>, <Hm>, <Ha>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMADD_H_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FNMADD_H_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMADD_H_floatdp3
        IEM_INSTR_IMPL_A64__FNMADD_H_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1f200000: FNMADD  <Sd>, <Sn>, <Sm>, <Sa>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMADD_S_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FNMADD_S_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMADD_S_floatdp3
        IEM_INSTR_IMPL_A64__FNMADD_S_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1f608000: FNMSUB  <Dd>, <Dn>, <Dm>, <Da>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMSUB_D_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FNMSUB_D_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMSUB_D_floatdp3
        IEM_INSTR_IMPL_A64__FNMSUB_D_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1fe08000: FNMSUB  <Hd>, <Hn>, <Hm>, <Ha>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMSUB_H_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FNMSUB_H_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMSUB_H_floatdp3
        IEM_INSTR_IMPL_A64__FNMSUB_H_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1f208000: FNMSUB  <Sd>, <Sn>, <Sm>, <Sa>
   Instruction Set: A64  Groups: floatdp3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMSUB_S_floatdp3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FNMSUB_S_floatdp3 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMSUB_S_floatdp3
        IEM_INSTR_IMPL_A64__FNMSUB_S_floatdp3(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e608800: FNMUL  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMUL_D_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e608800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FNMUL_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMUL_D_floatdp2
            IEM_INSTR_IMPL_A64__FNMUL_D_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee08800: FNMUL  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMUL_H_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1ee08800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FNMUL_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMUL_H_floatdp2
            IEM_INSTR_IMPL_A64__FNMUL_H_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e208800: FNMUL  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FNMUL_S_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e208800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FNMUL_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FNMUL_S_floatdp2
            IEM_INSTR_IMPL_A64__FNMUL_S_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea1d800: FRECPE  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPE_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRECPE_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRECPE_asimdmisc_R
        IEM_INSTR_IMPL_A64__FRECPE_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef9d800: FRECPE  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPE_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRECPE_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRECPE_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRECPE_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5ea1d800: FRECPE  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPE_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRECPE_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FRECPE_asisdmisc_R
        IEM_INSTR_IMPL_A64__FRECPE_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ef9d800: FRECPE  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPE_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRECPE_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRECPE_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRECPE_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0e20fc00: FRECPS  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPS_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRECPS_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRECPS_asimdsame_only
        IEM_INSTR_IMPL_A64__FRECPS_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e403c00: FRECPS  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPS_asimdsamefp16_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRECPS_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FRECPS_asimdsamefp16_only
        IEM_INSTR_IMPL_A64__FRECPS_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/5e20fc00: FRECPS  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPS_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRECPS_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FRECPS_asisdsame_only
        IEM_INSTR_IMPL_A64__FRECPS_asisdsame_only(Rd, Rn, Rm, sz);
#else
        RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e403c00: FRECPS  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPS_asisdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e403c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FRECPS_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FRECPS_asisdsamefp16_only
            IEM_INSTR_IMPL_A64__FRECPS_asisdsamefp16_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5ea1f800: FRECPX  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPX_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRECPX_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FRECPX_asisdmisc_R
        IEM_INSTR_IMPL_A64__FRECPX_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ef9f800: FRECPX  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRECPX_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRECPX_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRECPX_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRECPX_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e68c000: FRINT32X  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT32X_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
    {
        LogFlow(("%018x/%010x: FRINT32X_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINT32X_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINT32X_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e28c000: FRINT32X  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT32X_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
    {
        LogFlow(("%018x/%010x: FRINT32X_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINT32X_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINT32X_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2e21e800: FRINT32X  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT32X_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21e800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
        {
            LogFlow(("%018x/%010x: FRINT32X_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINT32X_asimdmisc_R
            IEM_INSTR_IMPL_A64__FRINT32X_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e684000: FRINT32Z  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT32Z_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
    {
        LogFlow(("%018x/%010x: FRINT32Z_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINT32Z_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINT32Z_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e284000: FRINT32Z  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT32Z_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
    {
        LogFlow(("%018x/%010x: FRINT32Z_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINT32Z_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINT32Z_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e21e800: FRINT32Z  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT32Z_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21e800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
        {
            LogFlow(("%018x/%010x: FRINT32Z_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINT32Z_asimdmisc_R
            IEM_INSTR_IMPL_A64__FRINT32Z_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e69c000: FRINT64X  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT64X_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
    {
        LogFlow(("%018x/%010x: FRINT64X_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINT64X_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINT64X_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e29c000: FRINT64X  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT64X_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
    {
        LogFlow(("%018x/%010x: FRINT64X_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINT64X_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINT64X_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2e21f800: FRINT64X  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT64X_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21f800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
        {
            LogFlow(("%018x/%010x: FRINT64X_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINT64X_asimdmisc_R
            IEM_INSTR_IMPL_A64__FRINT64X_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e694000: FRINT64Z  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT64Z_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
    {
        LogFlow(("%018x/%010x: FRINT64Z_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINT64Z_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINT64Z_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e294000: FRINT64Z  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT64Z_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
    {
        LogFlow(("%018x/%010x: FRINT64Z_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINT64Z_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINT64Z_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e21f800: FRINT64Z  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINT64Z_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21f800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFrintts /*FEAT_FRINTTS*/)
        {
            LogFlow(("%018x/%010x: FRINT64Z_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINT64Z_asimdmisc_R
            IEM_INSTR_IMPL_A64__FRINT64Z_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e664000: FRINTA  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTA_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTA_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTA_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINTA_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee64000: FRINTA  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTA_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTA_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTA_H_floatdp1
        IEM_INSTR_IMPL_A64__FRINTA_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e264000: FRINTA  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTA_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTA_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTA_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINTA_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2e218800: FRINTA  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTA_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRINTA_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTA_asimdmisc_R
        IEM_INSTR_IMPL_A64__FRINTA_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e798800: FRINTA  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTA_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTA_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTA_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRINTA_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e67c000: FRINTI  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTI_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTI_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTI_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINTI_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee7c000: FRINTI  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTI_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTI_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTI_H_floatdp1
        IEM_INSTR_IMPL_A64__FRINTI_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e27c000: FRINTI  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTI_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTI_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTI_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINTI_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea19800: FRINTI  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTI_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRINTI_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTI_asimdmisc_R
        IEM_INSTR_IMPL_A64__FRINTI_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ef99800: FRINTI  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTI_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTI_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTI_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRINTI_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e654000: FRINTM  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTM_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTM_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTM_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINTM_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee54000: FRINTM  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTM_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTM_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTM_H_floatdp1
        IEM_INSTR_IMPL_A64__FRINTM_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e254000: FRINTM  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTM_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTM_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTM_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINTM_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e219800: FRINTM  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTM_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e219800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FRINTM_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTM_asimdmisc_R
            IEM_INSTR_IMPL_A64__FRINTM_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0e799800: FRINTM  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTM_asimdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0e799800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FRINTM_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTM_asimdmiscfp16_R
            IEM_INSTR_IMPL_A64__FRINTM_asimdmiscfp16_R(Rd, Rn, Q);
#else
            RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e644000: FRINTN  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTN_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTN_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTN_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINTN_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee44000: FRINTN  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTN_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTN_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTN_H_floatdp1
        IEM_INSTR_IMPL_A64__FRINTN_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e244000: FRINTN  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTN_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTN_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTN_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINTN_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e218800: FRINTN  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTN_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRINTN_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTN_asimdmisc_R
        IEM_INSTR_IMPL_A64__FRINTN_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0e798800: FRINTN  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTN_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTN_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTN_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRINTN_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e64c000: FRINTP  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTP_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTP_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTP_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINTP_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee4c000: FRINTP  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTP_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTP_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTP_H_floatdp1
        IEM_INSTR_IMPL_A64__FRINTP_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e24c000: FRINTP  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTP_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTP_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTP_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINTP_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea18800: FRINTP  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTP_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRINTP_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTP_asimdmisc_R
        IEM_INSTR_IMPL_A64__FRINTP_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef98800: FRINTP  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTP_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTP_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTP_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRINTP_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e674000: FRINTX  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTX_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTX_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTX_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINTX_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee74000: FRINTX  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTX_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTX_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTX_H_floatdp1
        IEM_INSTR_IMPL_A64__FRINTX_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e274000: FRINTX  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTX_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTX_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTX_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINTX_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2e219800: FRINTX  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTX_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e219800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: FRINTX_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTX_asimdmisc_R
            IEM_INSTR_IMPL_A64__FRINTX_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e799800: FRINTX  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTX_asimdmiscfp16_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e799800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FRINTX_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTX_asimdmiscfp16_R
            IEM_INSTR_IMPL_A64__FRINTX_asimdmiscfp16_R(Rd, Rn, Q);
#else
            RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e65c000: FRINTZ  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTZ_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTZ_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTZ_D_floatdp1
        IEM_INSTR_IMPL_A64__FRINTZ_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee5c000: FRINTZ  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTZ_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTZ_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTZ_H_floatdp1
        IEM_INSTR_IMPL_A64__FRINTZ_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e25c000: FRINTZ  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTZ_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FRINTZ_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRINTZ_S_floatdp1
        IEM_INSTR_IMPL_A64__FRINTZ_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea19800: FRINTZ  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTZ_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRINTZ_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTZ_asimdmisc_R
        IEM_INSTR_IMPL_A64__FRINTZ_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ef99800: FRINTZ  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRINTZ_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRINTZ_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRINTZ_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRINTZ_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea1d800: FRSQRTE  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRSQRTE_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRSQRTE_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRSQRTE_asimdmisc_R
        IEM_INSTR_IMPL_A64__FRSQRTE_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ef9d800: FRSQRTE  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRSQRTE_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRSQRTE_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FRSQRTE_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRSQRTE_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7ea1d800: FRSQRTE  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRSQRTE_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRSQRTE_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__FRSQRTE_asisdmisc_R
        IEM_INSTR_IMPL_A64__FRSQRTE_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7ef9d800: FRSQRTE  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRSQRTE_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FRSQRTE_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FRSQRTE_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__FRSQRTE_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0ea0fc00: FRSQRTS  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRSQRTS_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRSQRTS_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FRSQRTS_asimdsame_only
        IEM_INSTR_IMPL_A64__FRSQRTS_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0ec03c00: FRSQRTS  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRSQRTS_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0ec03c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FRSQRTS_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FRSQRTS_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FRSQRTS_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/5ea0fc00: FRSQRTS  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRSQRTS_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FRSQRTS_asisdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__FRSQRTS_asisdsame_only
        IEM_INSTR_IMPL_A64__FRSQRTS_asisdsame_only(Rd, Rn, Rm, sz);
#else
        RT_NOREF(Rd, Rn, Rm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5ec03c00: FRSQRTS  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: asisdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FRSQRTS_asisdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5ec03c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FRSQRTS_asisdsamefp16_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FRSQRTS_asisdsamefp16_only
            IEM_INSTR_IMPL_A64__FRSQRTS_asisdsamefp16_only(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e20fc00: FSCALE  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSCALE_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20fc00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/ && ((size & 2) == 2))
        {
            LogFlow(("%018x/%010x: FSCALE_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__FSCALE_asimdsame_only
            IEM_INSTR_IMPL_A64__FSCALE_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/2ec03c00: FSCALE  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSCALE_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2ec03c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: FSCALE_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FSCALE_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FSCALE_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e61c000: FSQRT  <Dd>, <Dn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSQRT_D_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FSQRT_D_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FSQRT_D_floatdp1
        IEM_INSTR_IMPL_A64__FSQRT_D_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee1c000: FSQRT  <Hd>, <Hn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSQRT_H_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FSQRT_H_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FSQRT_H_floatdp1
        IEM_INSTR_IMPL_A64__FSQRT_H_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e21c000: FSQRT  <Sd>, <Sn>
   Instruction Set: A64  Groups: floatdp1, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSQRT_S_floatdp1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FSQRT_S_floatdp1 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__FSQRT_S_floatdp1
        IEM_INSTR_IMPL_A64__FSQRT_S_floatdp1(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea1f800: FSQRT  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSQRT_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FSQRT_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FSQRT_asimdmisc_R
        IEM_INSTR_IMPL_A64__FSQRT_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2ef9f800: FSQRT  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSQRT_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FSQRT_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__FSQRT_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__FSQRT_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e603800: FSUB  <Dd>, <Dn>, <Dm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSUB_D_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: FSUB_D_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FSUB_D_floatdp2
        IEM_INSTR_IMPL_A64__FSUB_D_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ee03800: FSUB  <Hd>, <Hn>, <Hm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSUB_H_floatdp2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: FSUB_H_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FSUB_H_floatdp2
        IEM_INSTR_IMPL_A64__FSUB_H_floatdp2(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1e203800: FSUB  <Sd>, <Sn>, <Sm>
   Instruction Set: A64  Groups: floatdp2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSUB_S_floatdp2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e203800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
        {
            LogFlow(("%018x/%010x: FSUB_S_floatdp2 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__FSUB_S_floatdp2
            IEM_INSTR_IMPL_A64__FSUB_S_floatdp2(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfa0fc00/0ea0d400: FSUB  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSUB_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: FSUB_asimdsame_only Rd=%#x Rn=%#x Rm=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__FSUB_asimdsame_only
        IEM_INSTR_IMPL_A64__FSUB_asimdsame_only(Rd, Rn, Rm, sz, Q);
#else
        RT_NOREF(Rd, Rn, Rm, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0ec01400: FSUB  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsamefp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_FSUB_asimdsamefp16_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0ec01400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
        {
            LogFlow(("%018x/%010x: FSUB_asimdsamefp16_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__FSUB_asimdsamefp16_only
            IEM_INSTR_IMPL_A64__FSUB_asimdsamefp16_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503227f: GCSB  DSYNC
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_GCSB_HD_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fGcs /*FEAT_GCS*/)
    {
        LogFlow(("%018x/%010x: GCSB_HD_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__GCSB_HD_hints
        IEM_INSTR_IMPL_A64__GCSB_HD_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d91f0c00: GCSSTR  <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldst_gcs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_GCSSTR_64_ldst_gcs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd91f0c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fGcs /*FEAT_GCS*/)
        {
            LogFlow(("%018x/%010x: GCSSTR_64_ldst_gcs Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__GCSSTR_64_ldst_gcs
            IEM_INSTR_IMPL_A64__GCSSTR_64_ldst_gcs(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d91f1c00: GCSSTTR  <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldst_gcs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_GCSSTTR_64_ldst_gcs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd91f1c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fGcs /*FEAT_GCS*/)
        {
            LogFlow(("%018x/%010x: GCSSTTR_64_ldst_gcs Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__GCSSTTR_64_ldst_gcs
            IEM_INSTR_IMPL_A64__GCSSTTR_64_ldst_gcs(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac01400: GMI  <Xd>, <Xn|SP>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_GMI_64G_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: GMI_64G_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__GMI_64G_dp_2src
        IEM_INSTR_IMPL_A64__GMI_64G_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffff01f/d503201f: HINT  #<imm>
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_HINT_HM_hints, uint32_t, uOpcode)
{
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    LogFlow(("%018x/%010x: HINT_HM_hints op2=%u CRm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, op2, CRm));
#ifdef IEM_INSTR_IMPL_A64__HINT_HM_hints
    IEM_INSTR_IMPL_A64__HINT_HM_hints(op2, CRm);
#else
    RT_NOREF(op2, CRm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0001f/d4400000: HLT  #<imm>
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_HLT_EX_exception, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4400000))
    {
        uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
        LogFlow(("%018x/%010x: HLT_EX_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__HLT_EX_exception
        IEM_INSTR_IMPL_A64__HLT_EX_exception(imm16);
#else
        RT_NOREF(imm16, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/d4000002: HVC  #<imm>
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_HVC_EX_exception, uint32_t, uOpcode)
{
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    LogFlow(("%018x/%010x: HVC_EX_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__HVC_EX_exception
    IEM_INSTR_IMPL_A64__HVC_EX_exception(imm16);
#else
    RT_NOREF(imm16, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/4e001c00: INS  <Vd>.<Ts>[<index>], <R><n>
   Instruction Set: A64  Groups: asimdins, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_INS_asimdins_IR_r, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4e001c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: INS_asimdins_IR_r Rd=%#x Rn=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm5));
#ifdef IEM_INSTR_IMPL_A64__INS_asimdins_IR_r
            IEM_INSTR_IMPL_A64__INS_asimdins_IR_r(Rd, Rn, imm5);
#else
            RT_NOREF(Rd, Rn, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08400/6e000400: INS  <Vd>.<Ts>[<index1>], <Vn>.<Ts>[<index2>]
   Instruction Set: A64  Groups: asimdins, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_INS_asimdins_IV_v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe08400)) == UINT32_C(0x6e000400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 11) & 0x0000000f;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: INS_asimdins_IV_v Rd=%#x Rn=%#x imm4=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm4, imm5));
#ifdef IEM_INSTR_IMPL_A64__INS_asimdins_IV_v
            IEM_INSTR_IMPL_A64__INS_asimdins_IV_v(Rd, Rn, imm4, imm5);
#else
            RT_NOREF(Rd, Rn, imm4, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac01000: IRG  <Xd|SP>, <Xn|SP>{, <Xm>}
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_IRG_64I_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: IRG_64I_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__IRG_64I_dp_2src
        IEM_INSTR_IMPL_A64__IRG_64I_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffff0ff/d50330df: ISB{  <option> |   #<imm>}
   Instruction Set: A64  Groups: barriers, control */
FNIEMOP_DEF_1(iemDecodeA64_ISB_BI_barriers, uint32_t, uOpcode)
{
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    LogFlow(("%018x/%010x: ISB_BI_barriers CRm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, CRm));
#ifdef IEM_INSTR_IMPL_A64__ISB_BI_barriers
    IEM_INSTR_IMPL_A64__ISB_BI_barriers(CRm);
#else
    RT_NOREF(CRm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bffff000/0d40c000: LD1R  { <Vt>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1R_asisdlso_R1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0d40c000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD1R_asisdlso_R1 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1R_asisdlso_R1
            IEM_INSTR_IMPL_A64__LD1R_asisdlso_R1(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0ddfc000: LD1R  { <Vt>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1R_asisdlsop_R1_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1R_asisdlsop_R1_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1R_asisdlsop_R1_i
        IEM_INSTR_IMPL_A64__LD1R_asisdlsop_R1_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0dc0c000: LD1R  { <Vt>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1R_asisdlsop_RX1_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1R_asisdlsop_RX1_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1R_asisdlsop_RX1_r
        IEM_INSTR_IMPL_A64__LD1R_asisdlsop_RX1_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c407000: LD1  { <Vt>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlse_R1_1v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c407000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD1_asisdlse_R1_1v Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlse_R1_1v
            IEM_INSTR_IMPL_A64__LD1_asisdlse_R1_1v(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c40a000: LD1  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlse_R2_2v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c40a000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD1_asisdlse_R2_2v Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlse_R2_2v
            IEM_INSTR_IMPL_A64__LD1_asisdlse_R2_2v(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c406000: LD1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlse_R3_3v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c406000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD1_asisdlse_R3_3v Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlse_R3_3v
            IEM_INSTR_IMPL_A64__LD1_asisdlse_R3_3v(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c402000: LD1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlse_R4_4v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c402000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD1_asisdlse_R4_4v Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlse_R4_4v
            IEM_INSTR_IMPL_A64__LD1_asisdlse_R4_4v(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0cdf7000: LD1  { <Vt>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsep_I1_i1, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlsep_I1_i1 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsep_I1_i1
        IEM_INSTR_IMPL_A64__LD1_asisdlsep_I1_i1(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0cdfa000: LD1  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsep_I2_i2, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlsep_I2_i2 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsep_I2_i2
        IEM_INSTR_IMPL_A64__LD1_asisdlsep_I2_i2(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0cdf6000: LD1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsep_I3_i3, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlsep_I3_i3 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsep_I3_i3
        IEM_INSTR_IMPL_A64__LD1_asisdlsep_I3_i3(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0cdf2000: LD1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsep_I4_i4, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlsep_I4_i4 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsep_I4_i4
        IEM_INSTR_IMPL_A64__LD1_asisdlsep_I4_i4(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0cc07000: LD1  { <Vt>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsep_R1_r1, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1_asisdlsep_R1_r1 Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsep_R1_r1
        IEM_INSTR_IMPL_A64__LD1_asisdlsep_R1_r1(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0cc0a000: LD1  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsep_R2_r2, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1_asisdlsep_R2_r2 Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsep_R2_r2
        IEM_INSTR_IMPL_A64__LD1_asisdlsep_R2_r2(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0cc06000: LD1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsep_R3_r3, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1_asisdlsep_R3_r3 Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsep_R3_r3
        IEM_INSTR_IMPL_A64__LD1_asisdlsep_R3_r3(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0cc02000: LD1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsep_R4_r4, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1_asisdlsep_R4_r4 Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsep_R4_r4
        IEM_INSTR_IMPL_A64__LD1_asisdlsep_R4_r4(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d400000: LD1  { <Vt>.B }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlso_B1_1b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d400000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD1_asisdlso_B1_1b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlso_B1_1b
            IEM_INSTR_IMPL_A64__LD1_asisdlso_B1_1b(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d408400: LD1  { <Vt>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlso_D1_1d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlso_D1_1d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlso_D1_1d
        IEM_INSTR_IMPL_A64__LD1_asisdlso_D1_1d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d404000: LD1  { <Vt>.H }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlso_H1_1h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d404000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD1_asisdlso_H1_1h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlso_H1_1h
            IEM_INSTR_IMPL_A64__LD1_asisdlso_H1_1h(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d408000: LD1  { <Vt>.S }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlso_S1_1s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d408000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD1_asisdlso_S1_1s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlso_S1_1s
            IEM_INSTR_IMPL_A64__LD1_asisdlso_S1_1s(Rt, Rn, S, Q);
#else
            RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0ddf0000: LD1  { <Vt>.B }[<index>], [<Xn|SP>], #1
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsop_B1_i1b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlsop_B1_i1b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsop_B1_i1b
        IEM_INSTR_IMPL_A64__LD1_asisdlsop_B1_i1b(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e000/0dc00000: LD1  { <Vt>.B }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsop_BX1_r1b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1_asisdlsop_BX1_r1b Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsop_BX1_r1b
        IEM_INSTR_IMPL_A64__LD1_asisdlsop_BX1_r1b(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ddf8400: LD1  { <Vt>.D }[<index>], [<Xn|SP>], #8
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsop_D1_i1d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlsop_D1_i1d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsop_D1_i1d
        IEM_INSTR_IMPL_A64__LD1_asisdlsop_D1_i1d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0dc08400: LD1  { <Vt>.D }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsop_DX1_r1d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1_asisdlsop_DX1_r1d Rt=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsop_DX1_r1d
        IEM_INSTR_IMPL_A64__LD1_asisdlsop_DX1_r1d(Rt, Rn, Rm, Q);
#else
        RT_NOREF(Rt, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0ddf4000: LD1  { <Vt>.H }[<index>], [<Xn|SP>], #2
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsop_H1_i1h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlsop_H1_i1h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsop_H1_i1h
        IEM_INSTR_IMPL_A64__LD1_asisdlsop_H1_i1h(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e400/0dc04000: LD1  { <Vt>.H }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsop_HX1_r1h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1_asisdlsop_HX1_r1h Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsop_HX1_r1h
        IEM_INSTR_IMPL_A64__LD1_asisdlsop_HX1_r1h(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0ddf8000: LD1  { <Vt>.S }[<index>], [<Xn|SP>], #4
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsop_S1_i1s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD1_asisdlsop_S1_i1s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsop_S1_i1s
        IEM_INSTR_IMPL_A64__LD1_asisdlsop_S1_i1s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0ec00/0dc08000: LD1  { <Vt>.S }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD1_asisdlsop_SX1_r1s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD1_asisdlsop_SX1_r1s Rt=%#x Rn=%#x S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD1_asisdlsop_SX1_r1s
        IEM_INSTR_IMPL_A64__LD1_asisdlsop_SX1_r1s(Rt, Rn, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0d60c000: LD2R  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2R_asisdlso_R2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0d60c000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD2R_asisdlso_R2 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2R_asisdlso_R2
            IEM_INSTR_IMPL_A64__LD2R_asisdlso_R2(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0dffc000: LD2R  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2R_asisdlsop_R2_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD2R_asisdlsop_R2_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2R_asisdlsop_R2_i
        IEM_INSTR_IMPL_A64__LD2R_asisdlsop_R2_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0de0c000: LD2R  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2R_asisdlsop_RX2_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD2R_asisdlsop_RX2_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2R_asisdlsop_RX2_r
        IEM_INSTR_IMPL_A64__LD2R_asisdlsop_RX2_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c408000: LD2  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlse_R2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c408000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD2_asisdlse_R2 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlse_R2
            IEM_INSTR_IMPL_A64__LD2_asisdlse_R2(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0cdf8000: LD2  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsep_I2_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD2_asisdlsep_I2_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsep_I2_i
        IEM_INSTR_IMPL_A64__LD2_asisdlsep_I2_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0cc08000: LD2  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsep_R2_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD2_asisdlsep_R2_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsep_R2_r
        IEM_INSTR_IMPL_A64__LD2_asisdlsep_R2_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d600000: LD2  { <Vt>.B, <Vt2>.B }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlso_B2_2b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d600000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD2_asisdlso_B2_2b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlso_B2_2b
            IEM_INSTR_IMPL_A64__LD2_asisdlso_B2_2b(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d608400: LD2  { <Vt>.D, <Vt2>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlso_D2_2d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d608400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD2_asisdlso_D2_2d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlso_D2_2d
            IEM_INSTR_IMPL_A64__LD2_asisdlso_D2_2d(Rt, Rn, Q);
#else
            RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d604000: LD2  { <Vt>.H, <Vt2>.H }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlso_H2_2h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d604000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD2_asisdlso_H2_2h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlso_H2_2h
            IEM_INSTR_IMPL_A64__LD2_asisdlso_H2_2h(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d608000: LD2  { <Vt>.S, <Vt2>.S }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlso_S2_2s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d608000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD2_asisdlso_S2_2s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlso_S2_2s
            IEM_INSTR_IMPL_A64__LD2_asisdlso_S2_2s(Rt, Rn, S, Q);
#else
            RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0dff0000: LD2  { <Vt>.B, <Vt2>.B }[<index>], [<Xn|SP>], #2
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsop_B2_i2b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD2_asisdlsop_B2_i2b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsop_B2_i2b
        IEM_INSTR_IMPL_A64__LD2_asisdlsop_B2_i2b(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e000/0de00000: LD2  { <Vt>.B, <Vt2>.B }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsop_BX2_r2b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD2_asisdlsop_BX2_r2b Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsop_BX2_r2b
        IEM_INSTR_IMPL_A64__LD2_asisdlsop_BX2_r2b(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0dff8400: LD2  { <Vt>.D, <Vt2>.D }[<index>], [<Xn|SP>], #16
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsop_D2_i2d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD2_asisdlsop_D2_i2d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsop_D2_i2d
        IEM_INSTR_IMPL_A64__LD2_asisdlsop_D2_i2d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0de08400: LD2  { <Vt>.D, <Vt2>.D }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsop_DX2_r2d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD2_asisdlsop_DX2_r2d Rt=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsop_DX2_r2d
        IEM_INSTR_IMPL_A64__LD2_asisdlsop_DX2_r2d(Rt, Rn, Rm, Q);
#else
        RT_NOREF(Rt, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0dff4000: LD2  { <Vt>.H, <Vt2>.H }[<index>], [<Xn|SP>], #4
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsop_H2_i2h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD2_asisdlsop_H2_i2h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsop_H2_i2h
        IEM_INSTR_IMPL_A64__LD2_asisdlsop_H2_i2h(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e400/0de04000: LD2  { <Vt>.H, <Vt2>.H }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsop_HX2_r2h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD2_asisdlsop_HX2_r2h Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsop_HX2_r2h
        IEM_INSTR_IMPL_A64__LD2_asisdlsop_HX2_r2h(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0dff8000: LD2  { <Vt>.S, <Vt2>.S }[<index>], [<Xn|SP>], #8
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsop_S2_i2s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD2_asisdlsop_S2_i2s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsop_S2_i2s
        IEM_INSTR_IMPL_A64__LD2_asisdlsop_S2_i2s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0ec00/0de08000: LD2  { <Vt>.S, <Vt2>.S }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD2_asisdlsop_SX2_r2s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD2_asisdlsop_SX2_r2s Rt=%#x Rn=%#x S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD2_asisdlsop_SX2_r2s
        IEM_INSTR_IMPL_A64__LD2_asisdlsop_SX2_r2s(Rt, Rn, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0d40e000: LD3R  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3R_asisdlso_R3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0d40e000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD3R_asisdlso_R3 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3R_asisdlso_R3
            IEM_INSTR_IMPL_A64__LD3R_asisdlso_R3(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0ddfe000: LD3R  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3R_asisdlsop_R3_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD3R_asisdlsop_R3_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3R_asisdlsop_R3_i
        IEM_INSTR_IMPL_A64__LD3R_asisdlsop_R3_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0dc0e000: LD3R  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3R_asisdlsop_RX3_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD3R_asisdlsop_RX3_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3R_asisdlsop_RX3_r
        IEM_INSTR_IMPL_A64__LD3R_asisdlsop_RX3_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c404000: LD3  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlse_R3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c404000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD3_asisdlse_R3 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlse_R3
            IEM_INSTR_IMPL_A64__LD3_asisdlse_R3(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0cdf4000: LD3  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsep_I3_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD3_asisdlsep_I3_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsep_I3_i
        IEM_INSTR_IMPL_A64__LD3_asisdlsep_I3_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0cc04000: LD3  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsep_R3_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD3_asisdlsep_R3_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsep_R3_r
        IEM_INSTR_IMPL_A64__LD3_asisdlsep_R3_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d402000: LD3  { <Vt>.B, <Vt2>.B, <Vt3>.B }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlso_B3_3b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d402000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD3_asisdlso_B3_3b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlso_B3_3b
            IEM_INSTR_IMPL_A64__LD3_asisdlso_B3_3b(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d40a400: LD3  { <Vt>.D, <Vt2>.D, <Vt3>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlso_D3_3d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD3_asisdlso_D3_3d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlso_D3_3d
        IEM_INSTR_IMPL_A64__LD3_asisdlso_D3_3d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d406000: LD3  { <Vt>.H, <Vt2>.H, <Vt3>.H }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlso_H3_3h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d406000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD3_asisdlso_H3_3h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlso_H3_3h
            IEM_INSTR_IMPL_A64__LD3_asisdlso_H3_3h(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d40a000: LD3  { <Vt>.S, <Vt2>.S, <Vt3>.S }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlso_S3_3s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD3_asisdlso_S3_3s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlso_S3_3s
        IEM_INSTR_IMPL_A64__LD3_asisdlso_S3_3s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0ddf2000: LD3  { <Vt>.B, <Vt2>.B, <Vt3>.B }[<index>], [<Xn|SP>], #3
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsop_B3_i3b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD3_asisdlsop_B3_i3b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsop_B3_i3b
        IEM_INSTR_IMPL_A64__LD3_asisdlsop_B3_i3b(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e000/0dc02000: LD3  { <Vt>.B, <Vt2>.B, <Vt3>.B }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsop_BX3_r3b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD3_asisdlsop_BX3_r3b Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsop_BX3_r3b
        IEM_INSTR_IMPL_A64__LD3_asisdlsop_BX3_r3b(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0ddfa400: LD3  { <Vt>.D, <Vt2>.D, <Vt3>.D }[<index>], [<Xn|SP>], #24
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsop_D3_i3d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD3_asisdlsop_D3_i3d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsop_D3_i3d
        IEM_INSTR_IMPL_A64__LD3_asisdlsop_D3_i3d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0dc0a400: LD3  { <Vt>.D, <Vt2>.D, <Vt3>.D }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsop_DX3_r3d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD3_asisdlsop_DX3_r3d Rt=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsop_DX3_r3d
        IEM_INSTR_IMPL_A64__LD3_asisdlsop_DX3_r3d(Rt, Rn, Rm, Q);
#else
        RT_NOREF(Rt, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0ddf6000: LD3  { <Vt>.H, <Vt2>.H, <Vt3>.H }[<index>], [<Xn|SP>], #6
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsop_H3_i3h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD3_asisdlsop_H3_i3h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsop_H3_i3h
        IEM_INSTR_IMPL_A64__LD3_asisdlsop_H3_i3h(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e400/0dc06000: LD3  { <Vt>.H, <Vt2>.H, <Vt3>.H }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsop_HX3_r3h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD3_asisdlsop_HX3_r3h Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsop_HX3_r3h
        IEM_INSTR_IMPL_A64__LD3_asisdlsop_HX3_r3h(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0ddfa000: LD3  { <Vt>.S, <Vt2>.S, <Vt3>.S }[<index>], [<Xn|SP>], #12
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsop_S3_i3s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD3_asisdlsop_S3_i3s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsop_S3_i3s
        IEM_INSTR_IMPL_A64__LD3_asisdlsop_S3_i3s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0ec00/0dc0a000: LD3  { <Vt>.S, <Vt2>.S, <Vt3>.S }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD3_asisdlsop_SX3_r3s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD3_asisdlsop_SX3_r3s Rt=%#x Rn=%#x S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD3_asisdlsop_SX3_r3s
        IEM_INSTR_IMPL_A64__LD3_asisdlsop_SX3_r3s(Rt, Rn, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0d60e000: LD4R  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4R_asisdlso_R4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0d60e000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD4R_asisdlso_R4 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4R_asisdlso_R4
            IEM_INSTR_IMPL_A64__LD4R_asisdlso_R4(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0dffe000: LD4R  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4R_asisdlsop_R4_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD4R_asisdlsop_R4_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4R_asisdlsop_R4_i
        IEM_INSTR_IMPL_A64__LD4R_asisdlsop_R4_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0de0e000: LD4R  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4R_asisdlsop_RX4_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD4R_asisdlsop_RX4_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4R_asisdlsop_RX4_r
        IEM_INSTR_IMPL_A64__LD4R_asisdlsop_RX4_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c400000: LD4  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlse_R4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c400000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD4_asisdlse_R4 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlse_R4
            IEM_INSTR_IMPL_A64__LD4_asisdlse_R4(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0cdf0000: LD4  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsep_I4_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD4_asisdlsep_I4_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsep_I4_i
        IEM_INSTR_IMPL_A64__LD4_asisdlsep_I4_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0cc00000: LD4  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsep_R4_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD4_asisdlsep_R4_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsep_R4_r
        IEM_INSTR_IMPL_A64__LD4_asisdlsep_R4_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d602000: LD4  { <Vt>.B, <Vt2>.B, <Vt3>.B, <Vt4>.B }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlso_B4_4b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d602000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD4_asisdlso_B4_4b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlso_B4_4b
            IEM_INSTR_IMPL_A64__LD4_asisdlso_B4_4b(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d60a400: LD4  { <Vt>.D, <Vt2>.D, <Vt3>.D, <Vt4>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlso_D4_4d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d60a400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD4_asisdlso_D4_4d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlso_D4_4d
            IEM_INSTR_IMPL_A64__LD4_asisdlso_D4_4d(Rt, Rn, Q);
#else
            RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d606000: LD4  { <Vt>.H, <Vt2>.H, <Vt3>.H, <Vt4>.H }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlso_H4_4h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d606000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD4_asisdlso_H4_4h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlso_H4_4h
            IEM_INSTR_IMPL_A64__LD4_asisdlso_H4_4h(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d60a000: LD4  { <Vt>.S, <Vt2>.S, <Vt3>.S, <Vt4>.S }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlso_S4_4s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d60a000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: LD4_asisdlso_S4_4s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlso_S4_4s
            IEM_INSTR_IMPL_A64__LD4_asisdlso_S4_4s(Rt, Rn, S, Q);
#else
            RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0dff2000: LD4  { <Vt>.B, <Vt2>.B, <Vt3>.B, <Vt4>.B }[<index>], [<Xn|SP>], #4
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsop_B4_i4b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD4_asisdlsop_B4_i4b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsop_B4_i4b
        IEM_INSTR_IMPL_A64__LD4_asisdlsop_B4_i4b(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e000/0de02000: LD4  { <Vt>.B, <Vt2>.B, <Vt3>.B, <Vt4>.B }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsop_BX4_r4b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD4_asisdlsop_BX4_r4b Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsop_BX4_r4b
        IEM_INSTR_IMPL_A64__LD4_asisdlsop_BX4_r4b(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0dffa400: LD4  { <Vt>.D, <Vt2>.D, <Vt3>.D, <Vt4>.D }[<index>], [<Xn|SP>], #32
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsop_D4_i4d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD4_asisdlsop_D4_i4d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsop_D4_i4d
        IEM_INSTR_IMPL_A64__LD4_asisdlsop_D4_i4d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0de0a400: LD4  { <Vt>.D, <Vt2>.D, <Vt3>.D, <Vt4>.D }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsop_DX4_r4d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD4_asisdlsop_DX4_r4d Rt=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsop_DX4_r4d
        IEM_INSTR_IMPL_A64__LD4_asisdlsop_DX4_r4d(Rt, Rn, Rm, Q);
#else
        RT_NOREF(Rt, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0dff6000: LD4  { <Vt>.H, <Vt2>.H, <Vt3>.H, <Vt4>.H }[<index>], [<Xn|SP>], #8
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsop_H4_i4h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD4_asisdlsop_H4_i4h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsop_H4_i4h
        IEM_INSTR_IMPL_A64__LD4_asisdlsop_H4_i4h(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e400/0de06000: LD4  { <Vt>.H, <Vt2>.H, <Vt3>.H, <Vt4>.H }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsop_HX4_r4h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD4_asisdlsop_HX4_r4h Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsop_HX4_r4h
        IEM_INSTR_IMPL_A64__LD4_asisdlsop_HX4_r4h(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0dffa000: LD4  { <Vt>.S, <Vt2>.S, <Vt3>.S, <Vt4>.S }[<index>], [<Xn|SP>], #16
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsop_S4_i4s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: LD4_asisdlsop_S4_i4s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsop_S4_i4s
        IEM_INSTR_IMPL_A64__LD4_asisdlsop_S4_i4s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0ec00/0de0a000: LD4  { <Vt>.S, <Vt2>.S, <Vt3>.S, <Vt4>.S }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD4_asisdlsop_SX4_r4s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: LD4_asisdlsop_SX4_r4s Rt=%#x Rn=%#x S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__LD4_asisdlsop_SX4_r4s
        IEM_INSTR_IMPL_A64__LD4_asisdlsop_SX4_r4s(Rt, Rn, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/f83fd000: LD64B  <Xt>, [<Xn|SP>{ , #0}]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LD64B_64L_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLs64 /*FEAT_LS64*/)
    {
        LogFlow(("%018x/%010x: LD64B_64L_memop Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LD64B_64L_memop
        IEM_INSTR_IMPL_A64__LD64B_64L_memop(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a00000: LDADDAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDAB_32_memop
        IEM_INSTR_IMPL_A64__LDADDAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a00000: LDADDAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDAH_32_memop
        IEM_INSTR_IMPL_A64__LDADDAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e00000: LDADDALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDALB_32_memop
        IEM_INSTR_IMPL_A64__LDADDALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e00000: LDADDALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDALH_32_memop
        IEM_INSTR_IMPL_A64__LDADDALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e00000: LDADDAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDAL_32_memop
        IEM_INSTR_IMPL_A64__LDADDAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e00000: LDADDAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDAL_64_memop
        IEM_INSTR_IMPL_A64__LDADDAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a00000: LDADDA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDA_32_memop
        IEM_INSTR_IMPL_A64__LDADDA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a00000: LDADDA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDA_64_memop
        IEM_INSTR_IMPL_A64__LDADDA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38200000: LDADDB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDB_32_memop
        IEM_INSTR_IMPL_A64__LDADDB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78200000: LDADDH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDH_32_memop
        IEM_INSTR_IMPL_A64__LDADDH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38600000: LDADDLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDLB_32_memop
        IEM_INSTR_IMPL_A64__LDADDLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78600000: LDADDLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDLH_32_memop
        IEM_INSTR_IMPL_A64__LDADDLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8600000: LDADDL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDL_32_memop
        IEM_INSTR_IMPL_A64__LDADDL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8600000: LDADDL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADDL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADDL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADDL_64_memop
        IEM_INSTR_IMPL_A64__LDADDL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8200000: LDADD  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADD_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADD_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADD_32_memop
        IEM_INSTR_IMPL_A64__LDADD_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8200000: LDADD  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDADD_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDADD_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDADD_64_memop
        IEM_INSTR_IMPL_A64__LDADD_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d418400: LDAP1  { <Vt>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAP1_asisdlso_D1, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDAP1_asisdlso_D1 Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__LDAP1_asisdlso_D1
        IEM_INSTR_IMPL_A64__LDAP1_asisdlso_D1(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/38bfc000: LDAPRB  <Wt>, [<Xn|SP>{ , #0}]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPRB_32L_memop, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x38bfc000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc /*FEAT_LRCPC*/)
        {
            LogFlow(("%018x/%010x: LDAPRB_32L_memop Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAPRB_32L_memop
            IEM_INSTR_IMPL_A64__LDAPRB_32L_memop(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/78bfc000: LDAPRH  <Wt>, [<Xn|SP>{ , #0}]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPRH_32L_memop, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x78bfc000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc /*FEAT_LRCPC*/)
        {
            LogFlow(("%018x/%010x: LDAPRH_32L_memop Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAPRH_32L_memop
            IEM_INSTR_IMPL_A64__LDAPRH_32L_memop(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/99c00800: LDAPR  <Wt>, [<Xn|SP>], #4
   Instruction Set: A64  Groups: ldapstl_writeback, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPR_32L_ldapstl_writeback, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x99c00800))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
        {
            LogFlow(("%018x/%010x: LDAPR_32L_ldapstl_writeback Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAPR_32L_ldapstl_writeback
            IEM_INSTR_IMPL_A64__LDAPR_32L_ldapstl_writeback(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/b8bfc000: LDAPR  <Wt>, [<Xn|SP>{ , #0}]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPR_32L_memop, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xb8bfc000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc /*FEAT_LRCPC*/)
        {
            LogFlow(("%018x/%010x: LDAPR_32L_memop Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAPR_32L_memop
            IEM_INSTR_IMPL_A64__LDAPR_32L_memop(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d9c00800: LDAPR  <Xt>, [<Xn|SP>], #8
   Instruction Set: A64  Groups: ldapstl_writeback, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPR_64L_ldapstl_writeback, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd9c00800))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
        {
            LogFlow(("%018x/%010x: LDAPR_64L_ldapstl_writeback Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAPR_64L_ldapstl_writeback
            IEM_INSTR_IMPL_A64__LDAPR_64L_ldapstl_writeback(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/f8bfc000: LDAPR  <Xt>, [<Xn|SP>{ , #0}]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPR_64L_memop, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xf8bfc000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc /*FEAT_LRCPC*/)
        {
            LogFlow(("%018x/%010x: LDAPR_64L_memop Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAPR_64L_memop
            IEM_INSTR_IMPL_A64__LDAPR_64L_memop(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/19400000: LDAPURB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPURB_32_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPURB_32_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPURB_32_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPURB_32_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/59400000: LDAPURH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPURH_32_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPURH_32_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPURH_32_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPURH_32_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/19c00000: LDAPURSB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPURSB_32_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPURSB_32_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPURSB_32_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPURSB_32_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/19800000: LDAPURSB  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPURSB_64_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPURSB_64_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPURSB_64_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPURSB_64_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/59c00000: LDAPURSH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPURSH_32_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPURSH_32_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPURSH_32_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPURSH_32_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/59800000: LDAPURSH  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPURSH_64_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPURSH_64_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPURSH_64_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPURSH_64_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/99800000: LDAPURSW  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPURSW_64_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPURSW_64_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPURSW_64_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPURSW_64_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/99400000: LDAPUR  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPUR_32_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPUR_32_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPUR_32_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPUR_32_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9400000: LDAPUR  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPUR_64_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: LDAPUR_64_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPUR_64_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__LDAPUR_64_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/1d400800: LDAPUR  <Bt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPUR_B_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDAPUR_B_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPUR_B_ldapstl_simd
        IEM_INSTR_IMPL_A64__LDAPUR_B_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/dd400800: LDAPUR  <Dt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPUR_D_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDAPUR_D_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPUR_D_ldapstl_simd
        IEM_INSTR_IMPL_A64__LDAPUR_D_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/5d400800: LDAPUR  <Ht>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPUR_H_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDAPUR_H_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPUR_H_ldapstl_simd
        IEM_INSTR_IMPL_A64__LDAPUR_H_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/1dc00800: LDAPUR  <Qt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPUR_Q_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDAPUR_Q_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPUR_Q_ldapstl_simd
        IEM_INSTR_IMPL_A64__LDAPUR_Q_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/9d400800: LDAPUR  <St>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAPUR_S_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDAPUR_S_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDAPUR_S_ldapstl_simd
        IEM_INSTR_IMPL_A64__LDAPUR_S_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/08dffc00: LDARB  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDARB_LR32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x08dffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDARB_LR32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDARB_LR32_ldstord
        IEM_INSTR_IMPL_A64__LDARB_LR32_ldstord(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/48dffc00: LDARH  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDARH_LR32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x48dffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDARH_LR32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDARH_LR32_ldstord
        IEM_INSTR_IMPL_A64__LDARH_LR32_ldstord(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/88dffc00: LDAR  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAR_LR32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x88dffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDAR_LR32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAR_LR32_ldstord
        IEM_INSTR_IMPL_A64__LDAR_LR32_ldstord(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/c8dffc00: LDAR  <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAR_LR64_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xc8dffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDAR_LR64_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAR_LR64_ldstord
        IEM_INSTR_IMPL_A64__LDAR_LR64_ldstord(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/895ffc00: LDATXR  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDATXR_LR32_ldstexclr_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x895ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDATXR_LR32_ldstexclr_unpriv Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDATXR_LR32_ldstexclr_unpriv
            IEM_INSTR_IMPL_A64__LDATXR_LR32_ldstexclr_unpriv(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/c95ffc00: LDATXR  <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDATXR_LR64_ldstexclr_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xc95ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDATXR_LR64_ldstexclr_unpriv Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDATXR_LR64_ldstexclr_unpriv
            IEM_INSTR_IMPL_A64__LDATXR_LR64_ldstexclr_unpriv(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff8000/887f8000: LDAXP  <Wt1>, <Wt2>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAXP_LP32_ldstexclp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    LogFlow(("%018x/%010x: LDAXP_LP32_ldstexclp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDAXP_LP32_ldstexclp
    IEM_INSTR_IMPL_A64__LDAXP_LP32_ldstexclp(Rt, Rn, Rt2);
#else
    RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffff8000/c87f8000: LDAXP  <Xt1>, <Xt2>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAXP_LP64_ldstexclp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    LogFlow(("%018x/%010x: LDAXP_LP64_ldstexclp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDAXP_LP64_ldstexclp
    IEM_INSTR_IMPL_A64__LDAXP_LP64_ldstexclp(Rt, Rn, Rt2);
#else
    RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffffc00/085ffc00: LDAXRB  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAXRB_LR32_ldstexclr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x085ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDAXRB_LR32_ldstexclr Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAXRB_LR32_ldstexclr
        IEM_INSTR_IMPL_A64__LDAXRB_LR32_ldstexclr(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/485ffc00: LDAXRH  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAXRH_LR32_ldstexclr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x485ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDAXRH_LR32_ldstexclr Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAXRH_LR32_ldstexclr
        IEM_INSTR_IMPL_A64__LDAXRH_LR32_ldstexclr(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/885ffc00: LDAXR  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAXR_LR32_ldstexclr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x885ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDAXR_LR32_ldstexclr Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAXR_LR32_ldstexclr
        IEM_INSTR_IMPL_A64__LDAXR_LR32_ldstexclr(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/c85ffc00: LDAXR  <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDAXR_LR64_ldstexclr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xc85ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDAXR_LR64_ldstexclr Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDAXR_LR64_ldstexclr
        IEM_INSTR_IMPL_A64__LDAXR_LR64_ldstexclr(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ce00000: LDBFADDAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFADDAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFADDAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFADDAL_16
        IEM_INSTR_IMPL_A64__LDBFADDAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ca00000: LDBFADDA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFADDA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFADDA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFADDA_16
        IEM_INSTR_IMPL_A64__LDBFADDA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c600000: LDBFADDL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFADDL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFADDL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFADDL_16
        IEM_INSTR_IMPL_A64__LDBFADDL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c200000: LDBFADD  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFADD_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFADD_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFADD_16
        IEM_INSTR_IMPL_A64__LDBFADD_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ce04000: LDBFMAXAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMAXAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMAXAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMAXAL_16
        IEM_INSTR_IMPL_A64__LDBFMAXAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ca04000: LDBFMAXA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMAXA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMAXA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMAXA_16
        IEM_INSTR_IMPL_A64__LDBFMAXA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c604000: LDBFMAXL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMAXL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMAXL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMAXL_16
        IEM_INSTR_IMPL_A64__LDBFMAXL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ce06000: LDBFMAXNMAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMAXNMAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMAXNMAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMAXNMAL_16
        IEM_INSTR_IMPL_A64__LDBFMAXNMAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ca06000: LDBFMAXNMA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMAXNMA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMAXNMA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMAXNMA_16
        IEM_INSTR_IMPL_A64__LDBFMAXNMA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c606000: LDBFMAXNML  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMAXNML_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMAXNML_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMAXNML_16
        IEM_INSTR_IMPL_A64__LDBFMAXNML_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c206000: LDBFMAXNM  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMAXNM_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMAXNM_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMAXNM_16
        IEM_INSTR_IMPL_A64__LDBFMAXNM_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c204000: LDBFMAX  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMAX_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMAX_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMAX_16
        IEM_INSTR_IMPL_A64__LDBFMAX_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ce05000: LDBFMINAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMINAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMINAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMINAL_16
        IEM_INSTR_IMPL_A64__LDBFMINAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ca05000: LDBFMINA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMINA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMINA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMINA_16
        IEM_INSTR_IMPL_A64__LDBFMINA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c605000: LDBFMINL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMINL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMINL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMINL_16
        IEM_INSTR_IMPL_A64__LDBFMINL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ce07000: LDBFMINNMAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMINNMAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMINNMAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMINNMAL_16
        IEM_INSTR_IMPL_A64__LDBFMINNMAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3ca07000: LDBFMINNMA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMINNMA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMINNMA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMINNMA_16
        IEM_INSTR_IMPL_A64__LDBFMINNMA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c607000: LDBFMINNML  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMINNML_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMINNML_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMINNML_16
        IEM_INSTR_IMPL_A64__LDBFMINNML_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c207000: LDBFMINNM  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMINNM_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMINNM_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMINNM_16
        IEM_INSTR_IMPL_A64__LDBFMINNM_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3c205000: LDBFMIN  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDBFMIN_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDBFMIN_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDBFMIN_16
        IEM_INSTR_IMPL_A64__LDBFMIN_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a01000: LDCLRAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRAB_32_memop
        IEM_INSTR_IMPL_A64__LDCLRAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a01000: LDCLRAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRAH_32_memop
        IEM_INSTR_IMPL_A64__LDCLRAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e01000: LDCLRALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRALB_32_memop
        IEM_INSTR_IMPL_A64__LDCLRALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e01000: LDCLRALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRALH_32_memop
        IEM_INSTR_IMPL_A64__LDCLRALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e01000: LDCLRAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRAL_32_memop
        IEM_INSTR_IMPL_A64__LDCLRAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e01000: LDCLRAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRAL_64_memop
        IEM_INSTR_IMPL_A64__LDCLRAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a01000: LDCLRA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRA_32_memop
        IEM_INSTR_IMPL_A64__LDCLRA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a01000: LDCLRA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRA_64_memop
        IEM_INSTR_IMPL_A64__LDCLRA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38201000: LDCLRB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRB_32_memop
        IEM_INSTR_IMPL_A64__LDCLRB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78201000: LDCLRH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRH_32_memop
        IEM_INSTR_IMPL_A64__LDCLRH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38601000: LDCLRLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRLB_32_memop
        IEM_INSTR_IMPL_A64__LDCLRLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78601000: LDCLRLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRLH_32_memop
        IEM_INSTR_IMPL_A64__LDCLRLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8601000: LDCLRL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRL_32_memop
        IEM_INSTR_IMPL_A64__LDCLRL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8601000: LDCLRL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLRL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLRL_64_memop
        IEM_INSTR_IMPL_A64__LDCLRL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e01000: LDCLRPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRPAL_128_memop_128, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e01000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
        {
            LogFlow(("%018x/%010x: LDCLRPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDCLRPAL_128_memop_128
            IEM_INSTR_IMPL_A64__LDCLRPAL_128_memop_128(Rt, Rn, Rt2);
#else
            RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a01000: LDCLRPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRPA_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: LDCLRPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDCLRPA_128_memop_128
        IEM_INSTR_IMPL_A64__LDCLRPA_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19601000: LDCLRPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: LDCLRPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDCLRPL_128_memop_128
        IEM_INSTR_IMPL_A64__LDCLRPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19201000: LDCLRP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLRP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: LDCLRP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDCLRP_128_memop_128
        IEM_INSTR_IMPL_A64__LDCLRP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8201000: LDCLR  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLR_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLR_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLR_32_memop
        IEM_INSTR_IMPL_A64__LDCLR_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8201000: LDCLR  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDCLR_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDCLR_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDCLR_64_memop
        IEM_INSTR_IMPL_A64__LDCLR_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a02000: LDEORAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORAB_32_memop
        IEM_INSTR_IMPL_A64__LDEORAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a02000: LDEORAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORAH_32_memop
        IEM_INSTR_IMPL_A64__LDEORAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e02000: LDEORALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORALB_32_memop
        IEM_INSTR_IMPL_A64__LDEORALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e02000: LDEORALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORALH_32_memop
        IEM_INSTR_IMPL_A64__LDEORALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e02000: LDEORAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORAL_32_memop
        IEM_INSTR_IMPL_A64__LDEORAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e02000: LDEORAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORAL_64_memop
        IEM_INSTR_IMPL_A64__LDEORAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a02000: LDEORA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORA_32_memop
        IEM_INSTR_IMPL_A64__LDEORA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a02000: LDEORA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORA_64_memop
        IEM_INSTR_IMPL_A64__LDEORA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38202000: LDEORB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORB_32_memop
        IEM_INSTR_IMPL_A64__LDEORB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78202000: LDEORH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORH_32_memop
        IEM_INSTR_IMPL_A64__LDEORH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38602000: LDEORLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORLB_32_memop
        IEM_INSTR_IMPL_A64__LDEORLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78602000: LDEORLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORLH_32_memop
        IEM_INSTR_IMPL_A64__LDEORLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8602000: LDEORL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORL_32_memop
        IEM_INSTR_IMPL_A64__LDEORL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8602000: LDEORL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEORL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEORL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEORL_64_memop
        IEM_INSTR_IMPL_A64__LDEORL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8202000: LDEOR  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEOR_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEOR_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEOR_32_memop
        IEM_INSTR_IMPL_A64__LDEOR_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8202000: LDEOR  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDEOR_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDEOR_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDEOR_64_memop
        IEM_INSTR_IMPL_A64__LDEOR_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ce00000: LDFADDAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDAL_16
        IEM_INSTR_IMPL_A64__LDFADDAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bce00000: LDFADDAL  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDAL_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDAL_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDAL_32
        IEM_INSTR_IMPL_A64__LDFADDAL_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fce00000: LDFADDAL  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDAL_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDAL_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDAL_64
        IEM_INSTR_IMPL_A64__LDFADDAL_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ca00000: LDFADDA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDA_16
        IEM_INSTR_IMPL_A64__LDFADDA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bca00000: LDFADDA  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDA_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDA_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDA_32
        IEM_INSTR_IMPL_A64__LDFADDA_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fca00000: LDFADDA  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDA_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDA_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDA_64
        IEM_INSTR_IMPL_A64__LDFADDA_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c600000: LDFADDL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDL_16
        IEM_INSTR_IMPL_A64__LDFADDL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc600000: LDFADDL  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDL_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDL_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDL_32
        IEM_INSTR_IMPL_A64__LDFADDL_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc600000: LDFADDL  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADDL_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADDL_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADDL_64
        IEM_INSTR_IMPL_A64__LDFADDL_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c200000: LDFADD  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADD_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADD_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADD_16
        IEM_INSTR_IMPL_A64__LDFADD_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc200000: LDFADD  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADD_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADD_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADD_32
        IEM_INSTR_IMPL_A64__LDFADD_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc200000: LDFADD  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFADD_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFADD_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFADD_64
        IEM_INSTR_IMPL_A64__LDFADD_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ce04000: LDFMAXAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXAL_16
        IEM_INSTR_IMPL_A64__LDFMAXAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bce04000: LDFMAXAL  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXAL_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXAL_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXAL_32
        IEM_INSTR_IMPL_A64__LDFMAXAL_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fce04000: LDFMAXAL  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXAL_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXAL_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXAL_64
        IEM_INSTR_IMPL_A64__LDFMAXAL_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ca04000: LDFMAXA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXA_16
        IEM_INSTR_IMPL_A64__LDFMAXA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bca04000: LDFMAXA  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXA_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXA_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXA_32
        IEM_INSTR_IMPL_A64__LDFMAXA_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fca04000: LDFMAXA  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXA_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXA_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXA_64
        IEM_INSTR_IMPL_A64__LDFMAXA_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c604000: LDFMAXL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXL_16
        IEM_INSTR_IMPL_A64__LDFMAXL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc604000: LDFMAXL  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXL_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXL_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXL_32
        IEM_INSTR_IMPL_A64__LDFMAXL_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc604000: LDFMAXL  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXL_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXL_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXL_64
        IEM_INSTR_IMPL_A64__LDFMAXL_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ce06000: LDFMAXNMAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNMAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNMAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNMAL_16
        IEM_INSTR_IMPL_A64__LDFMAXNMAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bce06000: LDFMAXNMAL  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNMAL_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNMAL_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNMAL_32
        IEM_INSTR_IMPL_A64__LDFMAXNMAL_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fce06000: LDFMAXNMAL  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNMAL_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNMAL_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNMAL_64
        IEM_INSTR_IMPL_A64__LDFMAXNMAL_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ca06000: LDFMAXNMA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNMA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNMA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNMA_16
        IEM_INSTR_IMPL_A64__LDFMAXNMA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bca06000: LDFMAXNMA  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNMA_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNMA_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNMA_32
        IEM_INSTR_IMPL_A64__LDFMAXNMA_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fca06000: LDFMAXNMA  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNMA_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNMA_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNMA_64
        IEM_INSTR_IMPL_A64__LDFMAXNMA_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c606000: LDFMAXNML  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNML_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNML_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNML_16
        IEM_INSTR_IMPL_A64__LDFMAXNML_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc606000: LDFMAXNML  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNML_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNML_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNML_32
        IEM_INSTR_IMPL_A64__LDFMAXNML_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc606000: LDFMAXNML  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNML_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNML_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNML_64
        IEM_INSTR_IMPL_A64__LDFMAXNML_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c206000: LDFMAXNM  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNM_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNM_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNM_16
        IEM_INSTR_IMPL_A64__LDFMAXNM_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc206000: LDFMAXNM  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNM_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNM_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNM_32
        IEM_INSTR_IMPL_A64__LDFMAXNM_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc206000: LDFMAXNM  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAXNM_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAXNM_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAXNM_64
        IEM_INSTR_IMPL_A64__LDFMAXNM_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c204000: LDFMAX  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAX_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAX_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAX_16
        IEM_INSTR_IMPL_A64__LDFMAX_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc204000: LDFMAX  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAX_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAX_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAX_32
        IEM_INSTR_IMPL_A64__LDFMAX_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc204000: LDFMAX  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMAX_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMAX_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMAX_64
        IEM_INSTR_IMPL_A64__LDFMAX_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ce05000: LDFMINAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINAL_16
        IEM_INSTR_IMPL_A64__LDFMINAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bce05000: LDFMINAL  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINAL_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINAL_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINAL_32
        IEM_INSTR_IMPL_A64__LDFMINAL_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fce05000: LDFMINAL  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINAL_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINAL_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINAL_64
        IEM_INSTR_IMPL_A64__LDFMINAL_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ca05000: LDFMINA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINA_16
        IEM_INSTR_IMPL_A64__LDFMINA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bca05000: LDFMINA  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINA_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINA_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINA_32
        IEM_INSTR_IMPL_A64__LDFMINA_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fca05000: LDFMINA  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINA_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINA_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINA_64
        IEM_INSTR_IMPL_A64__LDFMINA_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c605000: LDFMINL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINL_16
        IEM_INSTR_IMPL_A64__LDFMINL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc605000: LDFMINL  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINL_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINL_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINL_32
        IEM_INSTR_IMPL_A64__LDFMINL_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc605000: LDFMINL  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINL_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINL_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINL_64
        IEM_INSTR_IMPL_A64__LDFMINL_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ce07000: LDFMINNMAL  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNMAL_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNMAL_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNMAL_16
        IEM_INSTR_IMPL_A64__LDFMINNMAL_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bce07000: LDFMINNMAL  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNMAL_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNMAL_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNMAL_32
        IEM_INSTR_IMPL_A64__LDFMINNMAL_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fce07000: LDFMINNMAL  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNMAL_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNMAL_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNMAL_64
        IEM_INSTR_IMPL_A64__LDFMINNMAL_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ca07000: LDFMINNMA  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNMA_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNMA_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNMA_16
        IEM_INSTR_IMPL_A64__LDFMINNMA_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bca07000: LDFMINNMA  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNMA_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNMA_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNMA_32
        IEM_INSTR_IMPL_A64__LDFMINNMA_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fca07000: LDFMINNMA  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNMA_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNMA_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNMA_64
        IEM_INSTR_IMPL_A64__LDFMINNMA_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c607000: LDFMINNML  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNML_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNML_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNML_16
        IEM_INSTR_IMPL_A64__LDFMINNML_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc607000: LDFMINNML  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNML_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNML_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNML_32
        IEM_INSTR_IMPL_A64__LDFMINNML_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc607000: LDFMINNML  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNML_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNML_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNML_64
        IEM_INSTR_IMPL_A64__LDFMINNML_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c207000: LDFMINNM  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNM_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNM_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNM_16
        IEM_INSTR_IMPL_A64__LDFMINNM_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc207000: LDFMINNM  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNM_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNM_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNM_32
        IEM_INSTR_IMPL_A64__LDFMINNM_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc207000: LDFMINNM  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMINNM_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMINNM_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMINNM_64
        IEM_INSTR_IMPL_A64__LDFMINNM_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7c205000: LDFMIN  <Hs>, <Ht>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMIN_16, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMIN_16 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMIN_16
        IEM_INSTR_IMPL_A64__LDFMIN_16(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bc205000: LDFMIN  <Ss>, <St>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMIN_32, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMIN_32 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMIN_32
        IEM_INSTR_IMPL_A64__LDFMIN_32(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/fc205000: LDFMIN  <Ds>, <Dt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDFMIN_64, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
    {
        LogFlow(("%018x/%010x: LDFMIN_64 Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDFMIN_64
        IEM_INSTR_IMPL_A64__LDFMIN_64(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d9e00000: LDGM  <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDGM_64bulk_ldsttags, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd9e00000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte2 /*FEAT_MTE2*/)
        {
            LogFlow(("%018x/%010x: LDGM_64bulk_ldsttags Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDGM_64bulk_ldsttags
            IEM_INSTR_IMPL_A64__LDGM_64bulk_ldsttags(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9600000: LDG  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDG_64Loffset_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: LDG_64Loffset_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDG_64Loffset_ldsttags
        IEM_INSTR_IMPL_A64__LDG_64Loffset_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/99400800: LDIAPP  <Wt1>, <Wt2>, [<Xn|SP>], #8
   Instruction Set: A64  Groups: ldiappstilp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDIAPP_32LE_ldiappstilp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDIAPP_32LE_ldiappstilp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDIAPP_32LE_ldiappstilp
        IEM_INSTR_IMPL_A64__LDIAPP_32LE_ldiappstilp(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/99401800: LDIAPP  <Wt1>, <Wt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldiappstilp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDIAPP_32L_ldiappstilp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDIAPP_32L_ldiappstilp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDIAPP_32L_ldiappstilp
        IEM_INSTR_IMPL_A64__LDIAPP_32L_ldiappstilp(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/d9400800: LDIAPP  <Xt1>, <Xt2>, [<Xn|SP>], #16
   Instruction Set: A64  Groups: ldiappstilp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDIAPP_64LS_ldiappstilp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDIAPP_64LS_ldiappstilp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDIAPP_64LS_ldiappstilp
        IEM_INSTR_IMPL_A64__LDIAPP_64LS_ldiappstilp(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/d9401800: LDIAPP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldiappstilp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDIAPP_64L_ldiappstilp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: LDIAPP_64L_ldiappstilp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDIAPP_64L_ldiappstilp
        IEM_INSTR_IMPL_A64__LDIAPP_64L_ldiappstilp(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/08df7c00: LDLARB  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDLARB_LR32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x08df7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLor /*FEAT_LOR*/)
        {
            LogFlow(("%018x/%010x: LDLARB_LR32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDLARB_LR32_ldstord
            IEM_INSTR_IMPL_A64__LDLARB_LR32_ldstord(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/48df7c00: LDLARH  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDLARH_LR32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x48df7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLor /*FEAT_LOR*/)
        {
            LogFlow(("%018x/%010x: LDLARH_LR32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDLARH_LR32_ldstord
            IEM_INSTR_IMPL_A64__LDLARH_LR32_ldstord(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/88df7c00: LDLAR  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDLAR_LR32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x88df7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLor /*FEAT_LOR*/)
        {
            LogFlow(("%018x/%010x: LDLAR_LR32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDLAR_LR32_ldstord
            IEM_INSTR_IMPL_A64__LDLAR_LR32_ldstord(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/c8df7c00: LDLAR  <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDLAR_LR64_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xc8df7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLor /*FEAT_LOR*/)
        {
            LogFlow(("%018x/%010x: LDLAR_LR64_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDLAR_LR64_ldstord
            IEM_INSTR_IMPL_A64__LDLAR_LR64_ldstord(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/28400000: LDNP  <Wt1>, <Wt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDNP_32_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDNP_32_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDNP_32_ldstnapair_offs
    IEM_INSTR_IMPL_A64__LDNP_32_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/a8400000: LDNP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDNP_64_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDNP_64_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDNP_64_ldstnapair_offs
    IEM_INSTR_IMPL_A64__LDNP_64_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/6c400000: LDNP  <Dt1>, <Dt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDNP_D_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDNP_D_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDNP_D_ldstnapair_offs
        IEM_INSTR_IMPL_A64__LDNP_D_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ac400000: LDNP  <Qt1>, <Qt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDNP_Q_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDNP_Q_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDNP_Q_ldstnapair_offs
        IEM_INSTR_IMPL_A64__LDNP_Q_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/2c400000: LDNP  <St1>, <St2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDNP_S_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDNP_S_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDNP_S_ldstnapair_offs
        IEM_INSTR_IMPL_A64__LDNP_S_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/69400000: LDPSW  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDPSW_64_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDPSW_64_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDPSW_64_ldstpair_off
    IEM_INSTR_IMPL_A64__LDPSW_64_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/68c00000: LDPSW  <Xt1>, <Xt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDPSW_64_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDPSW_64_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDPSW_64_ldstpair_post
    IEM_INSTR_IMPL_A64__LDPSW_64_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/69c00000: LDPSW  <Xt1>, <Xt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDPSW_64_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDPSW_64_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDPSW_64_ldstpair_pre
    IEM_INSTR_IMPL_A64__LDPSW_64_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/29400000: LDP  <Wt1>, <Wt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_32_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDP_32_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_32_ldstpair_off
    IEM_INSTR_IMPL_A64__LDP_32_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/28c00000: LDP  <Wt1>, <Wt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_32_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDP_32_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_32_ldstpair_post
    IEM_INSTR_IMPL_A64__LDP_32_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/29c00000: LDP  <Wt1>, <Wt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_32_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDP_32_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_32_ldstpair_pre
    IEM_INSTR_IMPL_A64__LDP_32_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/a9400000: LDP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_64_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDP_64_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_64_ldstpair_off
    IEM_INSTR_IMPL_A64__LDP_64_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/a8c00000: LDP  <Xt1>, <Xt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_64_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDP_64_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_64_ldstpair_post
    IEM_INSTR_IMPL_A64__LDP_64_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/a9c00000: LDP  <Xt1>, <Xt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_64_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: LDP_64_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_64_ldstpair_pre
    IEM_INSTR_IMPL_A64__LDP_64_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/6d400000: LDP  <Dt1>, <Dt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_D_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_D_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_D_ldstpair_off
        IEM_INSTR_IMPL_A64__LDP_D_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/6cc00000: LDP  <Dt1>, <Dt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_D_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_D_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_D_ldstpair_post
        IEM_INSTR_IMPL_A64__LDP_D_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/6dc00000: LDP  <Dt1>, <Dt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_D_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_D_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_D_ldstpair_pre
        IEM_INSTR_IMPL_A64__LDP_D_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ad400000: LDP  <Qt1>, <Qt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_Q_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_Q_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_Q_ldstpair_off
        IEM_INSTR_IMPL_A64__LDP_Q_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/acc00000: LDP  <Qt1>, <Qt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_Q_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_Q_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_Q_ldstpair_post
        IEM_INSTR_IMPL_A64__LDP_Q_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/adc00000: LDP  <Qt1>, <Qt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_Q_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_Q_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_Q_ldstpair_pre
        IEM_INSTR_IMPL_A64__LDP_Q_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/2d400000: LDP  <St1>, <St2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_S_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_S_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_S_ldstpair_off
        IEM_INSTR_IMPL_A64__LDP_S_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/2cc00000: LDP  <St1>, <St2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_S_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_S_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_S_ldstpair_post
        IEM_INSTR_IMPL_A64__LDP_S_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/2dc00000: LDP  <St1>, <St2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDP_S_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDP_S_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDP_S_ldstpair_pre
        IEM_INSTR_IMPL_A64__LDP_S_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa00c00/f8200c00: LDRAA  <Xt>, [<Xn|SP>{, #<simm>}]!
   Instruction Set: A64  Groups: ldst_pac, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRAA_64W_ldst_pac, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    uint32_t const S          = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: LDRAA_64W_ldst_pac Rt=%#x Rn=%#x imm9=%#x S=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9, S));
#ifdef IEM_INSTR_IMPL_A64__LDRAA_64W_ldst_pac
        IEM_INSTR_IMPL_A64__LDRAA_64W_ldst_pac(Rt, Rn, imm9, S);
#else
        RT_NOREF(Rt, Rn, imm9, S, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa00c00/f8200400: LDRAA  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_pac, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRAA_64_ldst_pac, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    uint32_t const S          = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: LDRAA_64_ldst_pac Rt=%#x Rn=%#x imm9=%#x S=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9, S));
#ifdef IEM_INSTR_IMPL_A64__LDRAA_64_ldst_pac
        IEM_INSTR_IMPL_A64__LDRAA_64_ldst_pac(Rt, Rn, imm9, S);
#else
        RT_NOREF(Rt, Rn, imm9, S, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa00c00/f8a00c00: LDRAB  <Xt>, [<Xn|SP>{, #<simm>}]!
   Instruction Set: A64  Groups: ldst_pac, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRAB_64W_ldst_pac, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    uint32_t const S          = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: LDRAB_64W_ldst_pac Rt=%#x Rn=%#x imm9=%#x S=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9, S));
#ifdef IEM_INSTR_IMPL_A64__LDRAB_64W_ldst_pac
        IEM_INSTR_IMPL_A64__LDRAB_64W_ldst_pac(Rt, Rn, imm9, S);
#else
        RT_NOREF(Rt, Rn, imm9, S, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa00c00/f8a00400: LDRAB  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_pac, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRAB_64_ldst_pac, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    uint32_t const S          = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: LDRAB_64_ldst_pac Rt=%#x Rn=%#x imm9=%#x S=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9, S));
#ifdef IEM_INSTR_IMPL_A64__LDRAB_64_ldst_pac
        IEM_INSTR_IMPL_A64__LDRAB_64_ldst_pac(Rt, Rn, imm9, S);
#else
        RT_NOREF(Rt, Rn, imm9, S, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0ec00/38606800: LDRB  <Wt>, [<Xn|SP>, <Xm>{, LSL <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRB_32BL_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDRB_32BL_ldst_regoff Rt=%#x Rn=%#x S=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRB_32BL_ldst_regoff
    IEM_INSTR_IMPL_A64__LDRB_32BL_ldst_regoff(Rt, Rn, S, Rm);
#else
    RT_NOREF(Rt, Rn, S, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38600800: LDRB  <Wt>, [<Xn|SP>, {<Wm> | <Xm>}, <extend>{ <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRB_32B_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (option != 3)
    {
        LogFlow(("%018x/%010x: LDRB_32B_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRB_32B_ldst_regoff
        IEM_INSTR_IMPL_A64__LDRB_32B_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/38400400: LDRB  <Wt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRB_32_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRB_32_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRB_32_ldst_immpost
    IEM_INSTR_IMPL_A64__LDRB_32_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38400c00: LDRB  <Wt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRB_32_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRB_32_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRB_32_ldst_immpre
    IEM_INSTR_IMPL_A64__LDRB_32_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/39400000: LDRB  <Wt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRB_32_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: LDRB_32_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDRB_32_ldst_pos
    IEM_INSTR_IMPL_A64__LDRB_32_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78400400: LDRH  <Wt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRH_32_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRH_32_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRH_32_ldst_immpost
    IEM_INSTR_IMPL_A64__LDRH_32_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78400c00: LDRH  <Wt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRH_32_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRH_32_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRH_32_ldst_immpre
    IEM_INSTR_IMPL_A64__LDRH_32_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/79400000: LDRH  <Wt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRH_32_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: LDRH_32_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDRH_32_ldst_pos
    IEM_INSTR_IMPL_A64__LDRH_32_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78600800: LDRH  <Wt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRH_32_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDRH_32_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRH_32_ldst_regoff
    IEM_INSTR_IMPL_A64__LDRH_32_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0ec00/38e06800: LDRSB  <Wt>, [<Xn|SP>, <Xm>{, LSL <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_32BL_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDRSB_32BL_ldst_regoff Rt=%#x Rn=%#x S=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_32BL_ldst_regoff
    IEM_INSTR_IMPL_A64__LDRSB_32BL_ldst_regoff(Rt, Rn, S, Rm);
#else
    RT_NOREF(Rt, Rn, S, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38e00800: LDRSB  <Wt>, [<Xn|SP>, {<Wm> | <Xm>}, <extend>{ <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_32B_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (option != 3)
    {
        LogFlow(("%018x/%010x: LDRSB_32B_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_32B_ldst_regoff
        IEM_INSTR_IMPL_A64__LDRSB_32B_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/38c00400: LDRSB  <Wt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_32_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSB_32_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_32_ldst_immpost
    IEM_INSTR_IMPL_A64__LDRSB_32_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38c00c00: LDRSB  <Wt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_32_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSB_32_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_32_ldst_immpre
    IEM_INSTR_IMPL_A64__LDRSB_32_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/39c00000: LDRSB  <Wt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_32_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: LDRSB_32_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_32_ldst_pos
    IEM_INSTR_IMPL_A64__LDRSB_32_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0ec00/38a06800: LDRSB  <Xt>, [<Xn|SP>, <Xm>{, LSL <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_64BL_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDRSB_64BL_ldst_regoff Rt=%#x Rn=%#x S=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_64BL_ldst_regoff
    IEM_INSTR_IMPL_A64__LDRSB_64BL_ldst_regoff(Rt, Rn, S, Rm);
#else
    RT_NOREF(Rt, Rn, S, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38a00800: LDRSB  <Xt>, [<Xn|SP>, {<Wm> | <Xm>}, <extend>{ <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_64B_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (option != 3)
    {
        LogFlow(("%018x/%010x: LDRSB_64B_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_64B_ldst_regoff
        IEM_INSTR_IMPL_A64__LDRSB_64B_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/38800400: LDRSB  <Xt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_64_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSB_64_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_64_ldst_immpost
    IEM_INSTR_IMPL_A64__LDRSB_64_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38800c00: LDRSB  <Xt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_64_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSB_64_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_64_ldst_immpre
    IEM_INSTR_IMPL_A64__LDRSB_64_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/39800000: LDRSB  <Xt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSB_64_ldst_pos, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x39800000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
        LogFlow(("%018x/%010x: LDRSB_64_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDRSB_64_ldst_pos
        IEM_INSTR_IMPL_A64__LDRSB_64_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/78c00400: LDRSH  <Wt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSH_32_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSH_32_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSH_32_ldst_immpost
    IEM_INSTR_IMPL_A64__LDRSH_32_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78c00c00: LDRSH  <Wt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSH_32_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSH_32_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSH_32_ldst_immpre
    IEM_INSTR_IMPL_A64__LDRSH_32_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/79c00000: LDRSH  <Wt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSH_32_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: LDRSH_32_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDRSH_32_ldst_pos
    IEM_INSTR_IMPL_A64__LDRSH_32_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78e00800: LDRSH  <Wt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSH_32_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDRSH_32_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRSH_32_ldst_regoff
    IEM_INSTR_IMPL_A64__LDRSH_32_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78800400: LDRSH  <Xt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSH_64_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSH_64_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSH_64_ldst_immpost
    IEM_INSTR_IMPL_A64__LDRSH_64_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78800c00: LDRSH  <Xt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSH_64_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSH_64_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSH_64_ldst_immpre
    IEM_INSTR_IMPL_A64__LDRSH_64_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/79800000: LDRSH  <Xt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSH_64_ldst_pos, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x79800000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
        LogFlow(("%018x/%010x: LDRSH_64_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDRSH_64_ldst_pos
        IEM_INSTR_IMPL_A64__LDRSH_64_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/78a00800: LDRSH  <Xt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSH_64_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDRSH_64_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRSH_64_ldst_regoff
    IEM_INSTR_IMPL_A64__LDRSH_64_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8800400: LDRSW  <Xt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSW_64_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSW_64_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSW_64_ldst_immpost
    IEM_INSTR_IMPL_A64__LDRSW_64_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8800c00: LDRSW  <Xt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSW_64_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDRSW_64_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDRSW_64_ldst_immpre
    IEM_INSTR_IMPL_A64__LDRSW_64_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/b9800000: LDRSW  <Xt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSW_64_ldst_pos, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xb9800000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
        LogFlow(("%018x/%010x: LDRSW_64_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDRSW_64_ldst_pos
        IEM_INSTR_IMPL_A64__LDRSW_64_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/b8a00800: LDRSW  <Xt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSW_64_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDRSW_64_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDRSW_64_ldst_regoff
    IEM_INSTR_IMPL_A64__LDRSW_64_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff000000/98000000: LDRSW  <Xt>, <label>
   Instruction Set: A64  Groups: loadlit, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDRSW_64_loadlit, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x98000000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
        LogFlow(("%018x/%010x: LDRSW_64_loadlit Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__LDRSW_64_loadlit
        IEM_INSTR_IMPL_A64__LDRSW_64_loadlit(Rt, imm19);
#else
        RT_NOREF(Rt, imm19, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/b8400400: LDR  <Wt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_32_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDR_32_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_32_ldst_immpost
    IEM_INSTR_IMPL_A64__LDR_32_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8400c00: LDR  <Wt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_32_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDR_32_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_32_ldst_immpre
    IEM_INSTR_IMPL_A64__LDR_32_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/b9400000: LDR  <Wt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_32_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: LDR_32_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDR_32_ldst_pos
    IEM_INSTR_IMPL_A64__LDR_32_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8600800: LDR  <Wt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_32_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDR_32_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDR_32_ldst_regoff
    IEM_INSTR_IMPL_A64__LDR_32_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff000000/18000000: LDR  <Wt>, <label>
   Instruction Set: A64  Groups: loadlit, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_32_loadlit, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x18000000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
        LogFlow(("%018x/%010x: LDR_32_loadlit Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__LDR_32_loadlit
        IEM_INSTR_IMPL_A64__LDR_32_loadlit(Rt, imm19);
#else
        RT_NOREF(Rt, imm19, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/f8400400: LDR  <Xt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_64_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDR_64_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_64_ldst_immpost
    IEM_INSTR_IMPL_A64__LDR_64_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8400c00: LDR  <Xt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_64_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDR_64_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_64_ldst_immpre
    IEM_INSTR_IMPL_A64__LDR_64_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/f9400000: LDR  <Xt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_64_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: LDR_64_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDR_64_ldst_pos
    IEM_INSTR_IMPL_A64__LDR_64_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8600800: LDR  <Xt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_64_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LDR_64_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDR_64_ldst_regoff
    IEM_INSTR_IMPL_A64__LDR_64_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff000000/58000000: LDR  <Xt>, <label>
   Instruction Set: A64  Groups: loadlit, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_64_loadlit, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x58000000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
        LogFlow(("%018x/%010x: LDR_64_loadlit Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__LDR_64_loadlit
        IEM_INSTR_IMPL_A64__LDR_64_loadlit(Rt, imm19);
#else
        RT_NOREF(Rt, imm19, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0ec00/3c606800: LDR  <Bt>, [<Xn|SP>, <Xm>{, LSL <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_BL_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_BL_ldst_regoff Rt=%#x Rn=%#x S=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDR_BL_ldst_regoff
        IEM_INSTR_IMPL_A64__LDR_BL_ldst_regoff(Rt, Rn, S, Rm);
#else
        RT_NOREF(Rt, Rn, S, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c400400: LDR  <Bt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_B_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_B_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_B_ldst_immpost
        IEM_INSTR_IMPL_A64__LDR_B_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c400c00: LDR  <Bt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_B_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_B_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_B_ldst_immpre
        IEM_INSTR_IMPL_A64__LDR_B_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/3d400000: LDR  <Bt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_B_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_B_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDR_B_ldst_pos
        IEM_INSTR_IMPL_A64__LDR_B_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c600800: LDR  <Bt>, [<Xn|SP>, {<Wm> | <Xm>}, <extend>{ <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_B_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && (option != 3))
    {
        LogFlow(("%018x/%010x: LDR_B_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDR_B_ldst_regoff
        IEM_INSTR_IMPL_A64__LDR_B_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/fc400400: LDR  <Dt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_D_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_D_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_D_ldst_immpost
        IEM_INSTR_IMPL_A64__LDR_D_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/fc400c00: LDR  <Dt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_D_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_D_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_D_ldst_immpre
        IEM_INSTR_IMPL_A64__LDR_D_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/fd400000: LDR  <Dt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_D_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_D_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDR_D_ldst_pos
        IEM_INSTR_IMPL_A64__LDR_D_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/fc600800: LDR  <Dt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_D_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_D_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDR_D_ldst_regoff
        IEM_INSTR_IMPL_A64__LDR_D_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff000000/5c000000: LDR  <Dt>, <label>
   Instruction Set: A64  Groups: loadlit, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_D_loadlit, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_D_loadlit Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__LDR_D_loadlit
        IEM_INSTR_IMPL_A64__LDR_D_loadlit(Rt, imm19);
#else
        RT_NOREF(Rt, imm19, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/7c400400: LDR  <Ht>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_H_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_H_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_H_ldst_immpost
        IEM_INSTR_IMPL_A64__LDR_H_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/7c400c00: LDR  <Ht>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_H_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_H_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_H_ldst_immpre
        IEM_INSTR_IMPL_A64__LDR_H_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/7d400000: LDR  <Ht>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_H_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_H_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDR_H_ldst_pos
        IEM_INSTR_IMPL_A64__LDR_H_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/7c600800: LDR  <Ht>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_H_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_H_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDR_H_ldst_regoff
        IEM_INSTR_IMPL_A64__LDR_H_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3cc00400: LDR  <Qt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_Q_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_Q_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_Q_ldst_immpost
        IEM_INSTR_IMPL_A64__LDR_Q_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3cc00c00: LDR  <Qt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_Q_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_Q_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_Q_ldst_immpre
        IEM_INSTR_IMPL_A64__LDR_Q_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/3dc00000: LDR  <Qt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_Q_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_Q_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDR_Q_ldst_pos
        IEM_INSTR_IMPL_A64__LDR_Q_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3ce00800: LDR  <Qt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_Q_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_Q_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDR_Q_ldst_regoff
        IEM_INSTR_IMPL_A64__LDR_Q_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff000000/9c000000: LDR  <Qt>, <label>
   Instruction Set: A64  Groups: loadlit, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_Q_loadlit, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_Q_loadlit Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__LDR_Q_loadlit
        IEM_INSTR_IMPL_A64__LDR_Q_loadlit(Rt, imm19);
#else
        RT_NOREF(Rt, imm19, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/bc400400: LDR  <St>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_S_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_S_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_S_ldst_immpost
        IEM_INSTR_IMPL_A64__LDR_S_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/bc400c00: LDR  <St>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_S_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_S_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDR_S_ldst_immpre
        IEM_INSTR_IMPL_A64__LDR_S_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/bd400000: LDR  <St>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_S_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_S_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__LDR_S_ldst_pos
        IEM_INSTR_IMPL_A64__LDR_S_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/bc600800: LDR  <St>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_S_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_S_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__LDR_S_ldst_regoff
        IEM_INSTR_IMPL_A64__LDR_S_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff000000/1c000000: LDR  <St>, <label>
   Instruction Set: A64  Groups: loadlit, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDR_S_loadlit, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDR_S_loadlit Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__LDR_S_loadlit
        IEM_INSTR_IMPL_A64__LDR_S_loadlit(Rt, imm19);
#else
        RT_NOREF(Rt, imm19, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a03000: LDSETAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETAB_32_memop
        IEM_INSTR_IMPL_A64__LDSETAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a03000: LDSETAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETAH_32_memop
        IEM_INSTR_IMPL_A64__LDSETAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e03000: LDSETALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETALB_32_memop
        IEM_INSTR_IMPL_A64__LDSETALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e03000: LDSETALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETALH_32_memop
        IEM_INSTR_IMPL_A64__LDSETALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e03000: LDSETAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETAL_32_memop
        IEM_INSTR_IMPL_A64__LDSETAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e03000: LDSETAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETAL_64_memop
        IEM_INSTR_IMPL_A64__LDSETAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a03000: LDSETA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETA_32_memop
        IEM_INSTR_IMPL_A64__LDSETA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a03000: LDSETA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETA_64_memop
        IEM_INSTR_IMPL_A64__LDSETA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38203000: LDSETB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETB_32_memop
        IEM_INSTR_IMPL_A64__LDSETB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78203000: LDSETH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETH_32_memop
        IEM_INSTR_IMPL_A64__LDSETH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38603000: LDSETLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETLB_32_memop
        IEM_INSTR_IMPL_A64__LDSETLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78603000: LDSETLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETLH_32_memop
        IEM_INSTR_IMPL_A64__LDSETLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8603000: LDSETL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETL_32_memop
        IEM_INSTR_IMPL_A64__LDSETL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8603000: LDSETL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSETL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSETL_64_memop
        IEM_INSTR_IMPL_A64__LDSETL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e03000: LDSETPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETPAL_128_memop_128, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e03000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
        {
            LogFlow(("%018x/%010x: LDSETPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDSETPAL_128_memop_128
            IEM_INSTR_IMPL_A64__LDSETPAL_128_memop_128(Rt, Rn, Rt2);
#else
            RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a03000: LDSETPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETPA_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: LDSETPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDSETPA_128_memop_128
        IEM_INSTR_IMPL_A64__LDSETPA_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19603000: LDSETPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: LDSETPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDSETPL_128_memop_128
        IEM_INSTR_IMPL_A64__LDSETPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19203000: LDSETP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSETP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: LDSETP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDSETP_128_memop_128
        IEM_INSTR_IMPL_A64__LDSETP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8203000: LDSET  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSET_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSET_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSET_32_memop
        IEM_INSTR_IMPL_A64__LDSET_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8203000: LDSET  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSET_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSET_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSET_64_memop
        IEM_INSTR_IMPL_A64__LDSET_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a04000: LDSMAXAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXAB_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a04000: LDSMAXAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXAH_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e04000: LDSMAXALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXALB_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e04000: LDSMAXALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXALH_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e04000: LDSMAXAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXAL_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e04000: LDSMAXAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXAL_64_memop
        IEM_INSTR_IMPL_A64__LDSMAXAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a04000: LDSMAXA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXA_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a04000: LDSMAXA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXA_64_memop
        IEM_INSTR_IMPL_A64__LDSMAXA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38204000: LDSMAXB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXB_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78204000: LDSMAXH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXH_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38604000: LDSMAXLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXLB_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78604000: LDSMAXLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXLH_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8604000: LDSMAXL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXL_32_memop
        IEM_INSTR_IMPL_A64__LDSMAXL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8604000: LDSMAXL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAXL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAXL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAXL_64_memop
        IEM_INSTR_IMPL_A64__LDSMAXL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8204000: LDSMAX  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAX_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAX_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAX_32_memop
        IEM_INSTR_IMPL_A64__LDSMAX_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8204000: LDSMAX  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMAX_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMAX_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMAX_64_memop
        IEM_INSTR_IMPL_A64__LDSMAX_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a05000: LDSMINAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINAB_32_memop
        IEM_INSTR_IMPL_A64__LDSMINAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a05000: LDSMINAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINAH_32_memop
        IEM_INSTR_IMPL_A64__LDSMINAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e05000: LDSMINALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINALB_32_memop
        IEM_INSTR_IMPL_A64__LDSMINALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e05000: LDSMINALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINALH_32_memop
        IEM_INSTR_IMPL_A64__LDSMINALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e05000: LDSMINAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINAL_32_memop
        IEM_INSTR_IMPL_A64__LDSMINAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e05000: LDSMINAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINAL_64_memop
        IEM_INSTR_IMPL_A64__LDSMINAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a05000: LDSMINA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINA_32_memop
        IEM_INSTR_IMPL_A64__LDSMINA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a05000: LDSMINA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINA_64_memop
        IEM_INSTR_IMPL_A64__LDSMINA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38205000: LDSMINB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINB_32_memop
        IEM_INSTR_IMPL_A64__LDSMINB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78205000: LDSMINH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINH_32_memop
        IEM_INSTR_IMPL_A64__LDSMINH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38605000: LDSMINLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINLB_32_memop
        IEM_INSTR_IMPL_A64__LDSMINLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78605000: LDSMINLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINLH_32_memop
        IEM_INSTR_IMPL_A64__LDSMINLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8605000: LDSMINL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINL_32_memop
        IEM_INSTR_IMPL_A64__LDSMINL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8605000: LDSMINL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMINL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMINL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMINL_64_memop
        IEM_INSTR_IMPL_A64__LDSMINL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8205000: LDSMIN  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMIN_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMIN_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMIN_32_memop
        IEM_INSTR_IMPL_A64__LDSMIN_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8205000: LDSMIN  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDSMIN_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDSMIN_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDSMIN_64_memop
        IEM_INSTR_IMPL_A64__LDSMIN_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e00400: LDTADDAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTADDAL_32_memop_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e00400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDTADDAL_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTADDAL_32_memop_unpriv
            IEM_INSTR_IMPL_A64__LDTADDAL_32_memop_unpriv(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e00400: LDTADDAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTADDAL_64_memop_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59e00400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDTADDAL_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTADDAL_64_memop_unpriv
            IEM_INSTR_IMPL_A64__LDTADDAL_64_memop_unpriv(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a00400: LDTADDA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTADDA_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTADDA_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTADDA_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTADDA_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a00400: LDTADDA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTADDA_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTADDA_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTADDA_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTADDA_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19600400: LDTADDL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTADDL_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTADDL_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTADDL_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTADDL_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59600400: LDTADDL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTADDL_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTADDL_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTADDL_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTADDL_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19200400: LDTADD  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTADD_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTADD_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTADD_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTADD_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59200400: LDTADD  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTADD_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTADD_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTADD_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTADD_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e01400: LDTCLRAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTCLRAL_32_memop_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e01400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDTCLRAL_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTCLRAL_32_memop_unpriv
            IEM_INSTR_IMPL_A64__LDTCLRAL_32_memop_unpriv(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e01400: LDTCLRAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTCLRAL_64_memop_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59e01400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDTCLRAL_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTCLRAL_64_memop_unpriv
            IEM_INSTR_IMPL_A64__LDTCLRAL_64_memop_unpriv(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a01400: LDTCLRA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTCLRA_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTCLRA_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTCLRA_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTCLRA_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a01400: LDTCLRA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTCLRA_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTCLRA_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTCLRA_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTCLRA_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19601400: LDTCLRL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTCLRL_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTCLRL_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTCLRL_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTCLRL_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59601400: LDTCLRL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTCLRL_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTCLRL_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTCLRL_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTCLRL_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19201400: LDTCLR  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTCLR_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTCLR_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTCLR_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTCLR_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59201400: LDTCLR  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTCLR_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTCLR_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTCLR_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTCLR_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/e8400000: LDTNP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTNP_64_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTNP_64_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDTNP_64_ldstnapair_offs
        IEM_INSTR_IMPL_A64__LDTNP_64_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ec400000: LDTNP  <Qt1>, <Qt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTNP_Q_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTNP_Q_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDTNP_Q_ldstnapair_offs
        IEM_INSTR_IMPL_A64__LDTNP_Q_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/e9400000: LDTP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTP_64_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTP_64_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDTP_64_ldstpair_off
        IEM_INSTR_IMPL_A64__LDTP_64_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/e8c00000: LDTP  <Xt1>, <Xt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTP_64_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTP_64_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDTP_64_ldstpair_post
        IEM_INSTR_IMPL_A64__LDTP_64_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/e9c00000: LDTP  <Xt1>, <Xt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTP_64_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTP_64_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDTP_64_ldstpair_pre
        IEM_INSTR_IMPL_A64__LDTP_64_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ed400000: LDTP  <Qt1>, <Qt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTP_Q_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTP_Q_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDTP_Q_ldstpair_off
        IEM_INSTR_IMPL_A64__LDTP_Q_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ecc00000: LDTP  <Qt1>, <Qt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTP_Q_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTP_Q_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDTP_Q_ldstpair_post
        IEM_INSTR_IMPL_A64__LDTP_Q_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/edc00000: LDTP  <Qt1>, <Qt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTP_Q_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTP_Q_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__LDTP_Q_ldstpair_pre
        IEM_INSTR_IMPL_A64__LDTP_Q_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/38400800: LDTRB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTRB_32_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTRB_32_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTRB_32_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTRB_32_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78400800: LDTRH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTRH_32_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTRH_32_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTRH_32_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTRH_32_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38c00800: LDTRSB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTRSB_32_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTRSB_32_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTRSB_32_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTRSB_32_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38800800: LDTRSB  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTRSB_64_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTRSB_64_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTRSB_64_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTRSB_64_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78c00800: LDTRSH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTRSH_32_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTRSH_32_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTRSH_32_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTRSH_32_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78800800: LDTRSH  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTRSH_64_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTRSH_64_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTRSH_64_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTRSH_64_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8800800: LDTRSW  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTRSW_64_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTRSW_64_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTRSW_64_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTRSW_64_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8400800: LDTR  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTR_32_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTR_32_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTR_32_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTR_32_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8400800: LDTR  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTR_64_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDTR_64_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDTR_64_ldst_unpriv
    IEM_INSTR_IMPL_A64__LDTR_64_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/19e03400: LDTSETAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTSETAL_32_memop_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e03400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDTSETAL_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTSETAL_32_memop_unpriv
            IEM_INSTR_IMPL_A64__LDTSETAL_32_memop_unpriv(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e03400: LDTSETAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTSETAL_64_memop_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59e03400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDTSETAL_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTSETAL_64_memop_unpriv
            IEM_INSTR_IMPL_A64__LDTSETAL_64_memop_unpriv(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a03400: LDTSETA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTSETA_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTSETA_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTSETA_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTSETA_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a03400: LDTSETA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTSETA_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTSETA_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTSETA_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTSETA_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19603400: LDTSETL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTSETL_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTSETL_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTSETL_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTSETL_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59603400: LDTSETL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTSETL_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTSETL_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTSETL_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTSETL_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19203400: LDTSET  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTSET_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTSET_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTSET_32_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTSET_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59203400: LDTSET  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTSET_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: LDTSET_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDTSET_64_memop_unpriv
        IEM_INSTR_IMPL_A64__LDTSET_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/895f7c00: LDTXR  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTXR_LR32_ldstexclr_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x895f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDTXR_LR32_ldstexclr_unpriv Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDTXR_LR32_ldstexclr_unpriv
            IEM_INSTR_IMPL_A64__LDTXR_LR32_ldstexclr_unpriv(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/c95f7c00: LDTXR  <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDTXR_LR64_ldstexclr_unpriv, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xc95f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: LDTXR_LR64_ldstexclr_unpriv Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDTXR_LR64_ldstexclr_unpriv
            IEM_INSTR_IMPL_A64__LDTXR_LR64_ldstexclr_unpriv(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a06000: LDUMAXAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXAB_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a06000: LDUMAXAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXAH_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e06000: LDUMAXALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXALB_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e06000: LDUMAXALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXALH_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e06000: LDUMAXAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXAL_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e06000: LDUMAXAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXAL_64_memop
        IEM_INSTR_IMPL_A64__LDUMAXAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a06000: LDUMAXA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXA_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a06000: LDUMAXA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXA_64_memop
        IEM_INSTR_IMPL_A64__LDUMAXA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38206000: LDUMAXB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXB_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78206000: LDUMAXH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXH_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38606000: LDUMAXLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXLB_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78606000: LDUMAXLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXLH_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8606000: LDUMAXL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXL_32_memop
        IEM_INSTR_IMPL_A64__LDUMAXL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8606000: LDUMAXL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAXL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAXL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAXL_64_memop
        IEM_INSTR_IMPL_A64__LDUMAXL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8206000: LDUMAX  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAX_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAX_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAX_32_memop
        IEM_INSTR_IMPL_A64__LDUMAX_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8206000: LDUMAX  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMAX_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMAX_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMAX_64_memop
        IEM_INSTR_IMPL_A64__LDUMAX_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a07000: LDUMINAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINAB_32_memop
        IEM_INSTR_IMPL_A64__LDUMINAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a07000: LDUMINAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINAH_32_memop
        IEM_INSTR_IMPL_A64__LDUMINAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e07000: LDUMINALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINALB_32_memop
        IEM_INSTR_IMPL_A64__LDUMINALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e07000: LDUMINALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINALH_32_memop
        IEM_INSTR_IMPL_A64__LDUMINALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e07000: LDUMINAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINAL_32_memop
        IEM_INSTR_IMPL_A64__LDUMINAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e07000: LDUMINAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINAL_64_memop
        IEM_INSTR_IMPL_A64__LDUMINAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a07000: LDUMINA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINA_32_memop
        IEM_INSTR_IMPL_A64__LDUMINA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a07000: LDUMINA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINA_64_memop
        IEM_INSTR_IMPL_A64__LDUMINA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38207000: LDUMINB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINB_32_memop
        IEM_INSTR_IMPL_A64__LDUMINB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78207000: LDUMINH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINH_32_memop
        IEM_INSTR_IMPL_A64__LDUMINH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38607000: LDUMINLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINLB_32_memop
        IEM_INSTR_IMPL_A64__LDUMINLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78607000: LDUMINLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINLH_32_memop
        IEM_INSTR_IMPL_A64__LDUMINLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8607000: LDUMINL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINL_32_memop
        IEM_INSTR_IMPL_A64__LDUMINL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8607000: LDUMINL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMINL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMINL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMINL_64_memop
        IEM_INSTR_IMPL_A64__LDUMINL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8207000: LDUMIN  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMIN_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMIN_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMIN_32_memop
        IEM_INSTR_IMPL_A64__LDUMIN_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8207000: LDUMIN  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUMIN_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: LDUMIN_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__LDUMIN_64_memop
        IEM_INSTR_IMPL_A64__LDUMIN_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/38400000: LDURB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDURB_32_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDURB_32_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDURB_32_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDURB_32_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78400000: LDURH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDURH_32_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDURH_32_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDURH_32_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDURH_32_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38c00000: LDURSB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDURSB_32_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDURSB_32_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDURSB_32_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDURSB_32_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38800000: LDURSB  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDURSB_64_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDURSB_64_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDURSB_64_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDURSB_64_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78c00000: LDURSH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDURSH_32_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDURSH_32_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDURSH_32_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDURSH_32_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78800000: LDURSH  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDURSH_64_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDURSH_64_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDURSH_64_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDURSH_64_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8800000: LDURSW  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDURSW_64_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDURSW_64_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDURSW_64_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDURSW_64_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8400000: LDUR  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUR_32_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDUR_32_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDUR_32_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDUR_32_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8400000: LDUR  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUR_64_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: LDUR_64_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDUR_64_ldst_unscaled
    IEM_INSTR_IMPL_A64__LDUR_64_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/3c400000: LDUR  <Bt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUR_B_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDUR_B_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDUR_B_ldst_unscaled
        IEM_INSTR_IMPL_A64__LDUR_B_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/fc400000: LDUR  <Dt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUR_D_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDUR_D_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDUR_D_ldst_unscaled
        IEM_INSTR_IMPL_A64__LDUR_D_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/7c400000: LDUR  <Ht>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUR_H_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDUR_H_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDUR_H_ldst_unscaled
        IEM_INSTR_IMPL_A64__LDUR_H_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3cc00000: LDUR  <Qt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUR_Q_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDUR_Q_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDUR_Q_ldst_unscaled
        IEM_INSTR_IMPL_A64__LDUR_Q_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/bc400000: LDUR  <St>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDUR_S_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: LDUR_S_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__LDUR_S_ldst_unscaled
        IEM_INSTR_IMPL_A64__LDUR_S_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff8000/887f0000: LDXP  <Wt1>, <Wt2>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDXP_LP32_ldstexclp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    LogFlow(("%018x/%010x: LDXP_LP32_ldstexclp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDXP_LP32_ldstexclp
    IEM_INSTR_IMPL_A64__LDXP_LP32_ldstexclp(Rt, Rn, Rt2);
#else
    RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffff8000/c87f0000: LDXP  <Xt1>, <Xt2>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDXP_LP64_ldstexclp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    LogFlow(("%018x/%010x: LDXP_LP64_ldstexclp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__LDXP_LP64_ldstexclp
    IEM_INSTR_IMPL_A64__LDXP_LP64_ldstexclp(Rt, Rn, Rt2);
#else
    RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffffc00/085f7c00: LDXRB  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDXRB_LR32_ldstexclr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x085f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDXRB_LR32_ldstexclr Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDXRB_LR32_ldstexclr
        IEM_INSTR_IMPL_A64__LDXRB_LR32_ldstexclr(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/485f7c00: LDXRH  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDXRH_LR32_ldstexclr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x485f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDXRH_LR32_ldstexclr Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDXRH_LR32_ldstexclr
        IEM_INSTR_IMPL_A64__LDXRH_LR32_ldstexclr(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/885f7c00: LDXR  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDXR_LR32_ldstexclr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x885f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDXR_LR32_ldstexclr Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDXR_LR32_ldstexclr
        IEM_INSTR_IMPL_A64__LDXR_LR32_ldstexclr(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/c85f7c00: LDXR  <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_LDXR_LR64_ldstexclr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xc85f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: LDXR_LR64_ldstexclr Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__LDXR_LR64_ldstexclr
        IEM_INSTR_IMPL_A64__LDXR_LR64_ldstexclr(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac02000: LSLV  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_LSLV_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LSLV_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__LSLV_32_dp_2src
    IEM_INSTR_IMPL_A64__LSLV_32_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9ac02000: LSLV  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_LSLV_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LSLV_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__LSLV_64_dp_2src
    IEM_INSTR_IMPL_A64__LSLV_64_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/1ac02400: LSRV  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_LSRV_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LSRV_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__LSRV_32_dp_2src
    IEM_INSTR_IMPL_A64__LSRV_32_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9ac02400: LSRV  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_LSRV_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: LSRV_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__LSRV_64_dp_2src
    IEM_INSTR_IMPL_A64__LSRV_64_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe09c00/4e801000: LUTI2  <Vd>.16B, { <Vn>.16B }, <Vm>[<index>]
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_LUTI2_asimdtbl_L5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe09c00)) == UINT32_C(0x4e801000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const len        = (uOpcode >> 13) & 0x00000003;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
        {
            LogFlow(("%018x/%010x: LUTI2_asimdtbl_L5 Rd=%#x Rn=%#x len=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, len, Rm));
#ifdef IEM_INSTR_IMPL_A64__LUTI2_asimdtbl_L5
            IEM_INSTR_IMPL_A64__LUTI2_asimdtbl_L5(Rd, Rn, len, Rm);
#else
            RT_NOREF(Rd, Rn, len, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08c00/4ec00000: LUTI2  <Vd>.8H, { <Vn>.8H }, <Vm>[<index>]
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_LUTI2_asimdtbl_L6, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe08c00)) == UINT32_C(0x4ec00000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const op         = (uOpcode >> 12) & 0x00000001;
        uint32_t const len        = (uOpcode >> 13) & 0x00000003;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
        {
            LogFlow(("%018x/%010x: LUTI2_asimdtbl_L6 Rd=%#x Rn=%#x op=%u len=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, op, len, Rm));
#ifdef IEM_INSTR_IMPL_A64__LUTI2_asimdtbl_L6
            IEM_INSTR_IMPL_A64__LUTI2_asimdtbl_L6(Rd, Rn, op, len, Rm);
#else
            RT_NOREF(Rd, Rn, op, len, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0bc00/4e402000: LUTI4  <Vd>.16B, { <Vn>.16B }, <Vm>[<index>]
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_LUTI4_asimdtbl_L5, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const len        = (uOpcode >> 13) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
    {
        LogFlow(("%018x/%010x: LUTI4_asimdtbl_L5 Rd=%#x Rn=%#x len=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, len, Rm));
#ifdef IEM_INSTR_IMPL_A64__LUTI4_asimdtbl_L5
        IEM_INSTR_IMPL_A64__LUTI4_asimdtbl_L5(Rd, Rn, len, Rm);
#else
        RT_NOREF(Rd, Rn, len, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe09c00/4e401000: LUTI4  <Vd>.8H, { <Vn1>.8H, <Vn2>.8H }, <Vm>[<index>]
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_LUTI4_asimdtbl_L7, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const len        = (uOpcode >> 13) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
    {
        LogFlow(("%018x/%010x: LUTI4_asimdtbl_L7 Rd=%#x Rn=%#x len=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, len, Rm));
#ifdef IEM_INSTR_IMPL_A64__LUTI4_asimdtbl_L7
        IEM_INSTR_IMPL_A64__LUTI4_asimdtbl_L7(Rd, Rn, len, Rm);
#else
        RT_NOREF(Rd, Rn, len, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/9b600000: MADDPT  <Xd>, <Xn>, <Xm>, <Xa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_MADDPT_64A_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
    {
        LogFlow(("%018x/%010x: MADDPT_64A_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__MADDPT_64A_dp_3src
        IEM_INSTR_IMPL_A64__MADDPT_64A_dp_3src(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1b000000: MADD  <Wd>, <Wn>, <Wm>, <Wa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_MADD_32A_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: MADD_32A_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__MADD_32A_dp_3src
    IEM_INSTR_IMPL_A64__MADD_32A_dp_3src(Rd, Rn, Ra, Rm);
#else
    RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe08000/9b000000: MADD  <Xd>, <Xn>, <Xm>, <Xa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_MADD_64A_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: MADD_64A_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__MADD_64A_dp_3src
    IEM_INSTR_IMPL_A64__MADD_64A_dp_3src(Rd, Rn, Ra, Rm);
#else
    RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf00f400/2f000000: MLA  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MLA_asimdelem_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x2f000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MLA_asimdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__MLA_asimdelem_R
            IEM_INSTR_IMPL_A64__MLA_asimdelem_R(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e209400: MLA  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MLA_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e209400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MLA_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__MLA_asimdsame_only
            IEM_INSTR_IMPL_A64__MLA_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/2f004000: MLS  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MLS_asimdelem_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x2f004000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MLS_asimdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__MLS_asimdelem_R
            IEM_INSTR_IMPL_A64__MLS_asimdelem_R(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e209400: MLS  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MLS_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e209400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MLS_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__MLS_asimdsame_only
            IEM_INSTR_IMPL_A64__MLS_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff8fc00/6f00e400: MOVI  <Vd>.2D, #<imm>
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MOVI_asimdimm_D2_d, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: MOVI_asimdimm_D2_d Rd=%#x h=%u g=%u f=%u e=%u d=%u c=%u b=%u a=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, c, b, a));
#ifdef IEM_INSTR_IMPL_A64__MOVI_asimdimm_D2_d
        IEM_INSTR_IMPL_A64__MOVI_asimdimm_D2_d(Rd, h, g, f, e, d, c, b, a);
#else
        RT_NOREF(Rd, h, g, f, e, d, c, b, a, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff8fc00/2f00e400: MOVI  <Dd>, #<imm>
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MOVI_asimdimm_D_ds, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: MOVI_asimdimm_D_ds Rd=%#x h=%u g=%u f=%u e=%u d=%u c=%u b=%u a=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, c, b, a));
#ifdef IEM_INSTR_IMPL_A64__MOVI_asimdimm_D_ds
        IEM_INSTR_IMPL_A64__MOVI_asimdimm_D_ds(Rd, h, g, f, e, d, c, b, a);
#else
        RT_NOREF(Rd, h, g, f, e, d, c, b, a, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff8dc00/0f008400: MOVI  <Vd>.<T>, #<imm8>{, LSL #<amount>}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MOVI_asimdimm_L_hl, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: MOVI_asimdimm_L_hl Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__MOVI_asimdimm_L_hl
        IEM_INSTR_IMPL_A64__MOVI_asimdimm_L_hl(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
        RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff89c00/0f000400: MOVI  <Vd>.<T>, #<imm8>{, LSL #<amount>}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MOVI_asimdimm_L_sl, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x0f000400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const h          = (uOpcode >>  5) & 0x00000001;
        uint32_t const g          = (uOpcode >>  6) & 0x00000001;
        uint32_t const f          = (uOpcode >>  7) & 0x00000001;
        uint32_t const e          = (uOpcode >>  8) & 0x00000001;
        uint32_t const d          = (uOpcode >>  9) & 0x00000001;
        uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
        uint32_t const c          = (uOpcode >> 16) & 0x00000001;
        uint32_t const b          = (uOpcode >> 17) & 0x00000001;
        uint32_t const a          = (uOpcode >> 18) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MOVI_asimdimm_L_sl Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__MOVI_asimdimm_L_sl
            IEM_INSTR_IMPL_A64__MOVI_asimdimm_L_sl(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
            RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff8ec00/0f00c400: MOVI  <Vd>.<T>, #<imm8>, MSL #<amount>
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MOVI_asimdimm_M_sm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbff8ec00)) == UINT32_C(0x0f00c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const h          = (uOpcode >>  5) & 0x00000001;
        uint32_t const g          = (uOpcode >>  6) & 0x00000001;
        uint32_t const f          = (uOpcode >>  7) & 0x00000001;
        uint32_t const e          = (uOpcode >>  8) & 0x00000001;
        uint32_t const d          = (uOpcode >>  9) & 0x00000001;
        uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
        uint32_t const c          = (uOpcode >> 16) & 0x00000001;
        uint32_t const b          = (uOpcode >> 17) & 0x00000001;
        uint32_t const a          = (uOpcode >> 18) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MOVI_asimdimm_M_sm Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__MOVI_asimdimm_M_sm
            IEM_INSTR_IMPL_A64__MOVI_asimdimm_M_sm(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
            RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff8fc00/0f00e400: MOVI  <Vd>.<T>, #<imm8>{, LSL #0}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MOVI_asimdimm_N_b, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: MOVI_asimdimm_N_b Rd=%#x h=%u g=%u f=%u e=%u d=%u c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__MOVI_asimdimm_N_b
        IEM_INSTR_IMPL_A64__MOVI_asimdimm_N_b(Rd, h, g, f, e, d, c, b, a, Q);
#else
        RT_NOREF(Rd, h, g, f, e, d, c, b, a, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/72800000: MOVK  <Wd>, #<imm>{, LSL #<shift>}
   Instruction Set: A64  Groups: movewide, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_MOVK_32_movewide, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    uint32_t const hw         = (uOpcode >> 21) & 0x00000003;
    LogFlow(("%018x/%010x: MOVK_32_movewide Rd=%#x imm16=%#x hw=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm16, hw));
#ifdef IEM_INSTR_IMPL_A64__MOVK_32_movewide
    IEM_INSTR_IMPL_A64__MOVK_32_movewide(Rd, imm16, hw);
#else
    RT_NOREF(Rd, imm16, hw, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/f2800000: MOVK  <Xd>, #<imm>{, LSL #<shift>}
   Instruction Set: A64  Groups: movewide, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_MOVK_64_movewide, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    uint32_t const hw         = (uOpcode >> 21) & 0x00000003;
    LogFlow(("%018x/%010x: MOVK_64_movewide Rd=%#x imm16=%#x hw=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm16, hw));
#ifdef IEM_INSTR_IMPL_A64__MOVK_64_movewide
    IEM_INSTR_IMPL_A64__MOVK_64_movewide(Rd, imm16, hw);
#else
    RT_NOREF(Rd, imm16, hw, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/12800000: MOVN  <Wd>, #<imm>{, LSL #<shift>}
   Instruction Set: A64  Groups: movewide, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_MOVN_32_movewide, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    uint32_t const hw         = (uOpcode >> 21) & 0x00000003;
    LogFlow(("%018x/%010x: MOVN_32_movewide Rd=%#x imm16=%#x hw=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm16, hw));
#ifdef IEM_INSTR_IMPL_A64__MOVN_32_movewide
    IEM_INSTR_IMPL_A64__MOVN_32_movewide(Rd, imm16, hw);
#else
    RT_NOREF(Rd, imm16, hw, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/92800000: MOVN  <Xd>, #<imm>{, LSL #<shift>}
   Instruction Set: A64  Groups: movewide, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_MOVN_64_movewide, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    uint32_t const hw         = (uOpcode >> 21) & 0x00000003;
    LogFlow(("%018x/%010x: MOVN_64_movewide Rd=%#x imm16=%#x hw=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm16, hw));
#ifdef IEM_INSTR_IMPL_A64__MOVN_64_movewide
    IEM_INSTR_IMPL_A64__MOVN_64_movewide(Rd, imm16, hw);
#else
    RT_NOREF(Rd, imm16, hw, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/52800000: MOVZ  <Wd>, #<imm>{, LSL #<shift>}
   Instruction Set: A64  Groups: movewide, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_MOVZ_32_movewide, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    uint32_t const hw         = (uOpcode >> 21) & 0x00000003;
    LogFlow(("%018x/%010x: MOVZ_32_movewide Rd=%#x imm16=%#x hw=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm16, hw));
#ifdef IEM_INSTR_IMPL_A64__MOVZ_32_movewide
    IEM_INSTR_IMPL_A64__MOVZ_32_movewide(Rd, imm16, hw);
#else
    RT_NOREF(Rd, imm16, hw, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/d2800000: MOVZ  <Xd>, #<imm>{, LSL #<shift>}
   Instruction Set: A64  Groups: movewide, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_MOVZ_64_movewide, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    uint32_t const hw         = (uOpcode >> 21) & 0x00000003;
    LogFlow(("%018x/%010x: MOVZ_64_movewide Rd=%#x imm16=%#x hw=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm16, hw));
#ifdef IEM_INSTR_IMPL_A64__MOVZ_64_movewide
    IEM_INSTR_IMPL_A64__MOVZ_64_movewide(Rd, imm16, hw);
#else
    RT_NOREF(Rd, imm16, hw, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fff00000/d5700000: MRRS  <Xt>, <Xt+1>, {<systemreg> | S<op0>_<op1>_<Cn>_<Cm>_<op2>}
   Instruction Set: A64  Groups: systemmovepr, control */
FNIEMOP_DEF_1(iemDecodeA64_MRRS_RS_systemmovepr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5700000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
        uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
        uint32_t const CRn        = (uOpcode >> 12) & 0x0000000f;
        uint32_t const op1        = (uOpcode >> 16) & 0x00000007;
        uint32_t const o0         = (uOpcode >> 19) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSysReg128 /*FEAT_SYSREG128*/)
        {
            LogFlow(("%018x/%010x: MRRS_RS_systemmovepr Rt=%#x op2=%u CRm=%#x CRn=%#x op1=%u o0=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, op2, CRm, CRn, op1, o0));
#ifdef IEM_INSTR_IMPL_A64__MRRS_RS_systemmovepr
            IEM_INSTR_IMPL_A64__MRRS_RS_systemmovepr(Rt, op2, CRm, CRn, op1, o0);
#else
            RT_NOREF(Rt, op2, CRm, CRn, op1, o0, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff00000/d5300000: MRS  <Xt>, {<systemreg> | S<op0>_<op1>_<Cn>_<Cm>_<op2>}
   Instruction Set: A64  Groups: systemmove, control */
FNIEMOP_DEF_1(iemDecodeA64_MRS_RS_systemmove, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    uint32_t const CRn        = (uOpcode >> 12) & 0x0000000f;
    uint32_t const op1        = (uOpcode >> 16) & 0x00000007;
    uint32_t const o0         = (uOpcode >> 19) & 0x00000001;
    LogFlow(("%018x/%010x: MRS_RS_systemmove Rt=%#x op2=%u CRm=%#x CRn=%#x op1=%u o0=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, op2, CRm, CRn, op1, o0));
#ifdef IEM_INSTR_IMPL_A64__MRS_RS_systemmove
    IEM_INSTR_IMPL_A64__MRS_RS_systemmove(Rt, op2, CRm, CRn, op1, o0);
#else
    RT_NOREF(Rt, op2, CRm, CRn, op1, o0, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fff00000/d5500000: MSRR  {<systemreg> | S<op0>_<op1>_<Cn>_<Cm>_<op2>}, <Xt>, <Xt+1>
   Instruction Set: A64  Groups: systemmovepr, control */
FNIEMOP_DEF_1(iemDecodeA64_MSRR_SR_systemmovepr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    uint32_t const CRn        = (uOpcode >> 12) & 0x0000000f;
    uint32_t const op1        = (uOpcode >> 16) & 0x00000007;
    uint32_t const o0         = (uOpcode >> 19) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSysReg128 /*FEAT_SYSREG128*/)
    {
        LogFlow(("%018x/%010x: MSRR_SR_systemmovepr Rt=%#x op2=%u CRm=%#x CRn=%#x op1=%u o0=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, op2, CRm, CRn, op1, o0));
#ifdef IEM_INSTR_IMPL_A64__MSRR_SR_systemmovepr
        IEM_INSTR_IMPL_A64__MSRR_SR_systemmovepr(Rt, op2, CRm, CRn, op1, o0);
#else
        RT_NOREF(Rt, op2, CRm, CRn, op1, o0, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff8f01f/d500401f: MSR  <pstatefield>, #<imm>
   Instruction Set: A64  Groups: pstate, control */
FNIEMOP_DEF_1(iemDecodeA64_MSR_SI_pstate, uint32_t, uOpcode)
{
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    uint32_t const op1        = (uOpcode >> 16) & 0x00000007;
    if (!((op1 == 0) && (((op2 & 6) == 0 || op2 == 2))))
    {
        LogFlow(("%018x/%010x: MSR_SI_pstate op2=%u CRm=%#x op1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, op2, CRm, op1));
#ifdef IEM_INSTR_IMPL_A64__MSR_SI_pstate
        IEM_INSTR_IMPL_A64__MSR_SI_pstate(op2, CRm, op1);
#else
        RT_NOREF(op2, CRm, op1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff00000/d5100000: MSR  {<systemreg> | S<op0>_<op1>_<Cn>_<Cm>_<op2>}, <Xt>
   Instruction Set: A64  Groups: systemmove, control */
FNIEMOP_DEF_1(iemDecodeA64_MSR_SR_systemmove, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    uint32_t const CRn        = (uOpcode >> 12) & 0x0000000f;
    uint32_t const op1        = (uOpcode >> 16) & 0x00000007;
    uint32_t const o0         = (uOpcode >> 19) & 0x00000001;
    LogFlow(("%018x/%010x: MSR_SR_systemmove Rt=%#x op2=%u CRm=%#x CRn=%#x op1=%u o0=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, op2, CRm, CRn, op1, o0));
#ifdef IEM_INSTR_IMPL_A64__MSR_SR_systemmove
    IEM_INSTR_IMPL_A64__MSR_SR_systemmove(Rt, op2, CRm, CRn, op1, o0);
#else
    RT_NOREF(Rt, op2, CRm, CRn, op1, o0, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe08000/9b608000: MSUBPT  <Xd>, <Xn>, <Xm>, <Xa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_MSUBPT_64A_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
    {
        LogFlow(("%018x/%010x: MSUBPT_64A_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__MSUBPT_64A_dp_3src
        IEM_INSTR_IMPL_A64__MSUBPT_64A_dp_3src(Rd, Rn, Ra, Rm);
#else
        RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/1b008000: MSUB  <Wd>, <Wn>, <Wm>, <Wa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_MSUB_32A_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: MSUB_32A_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__MSUB_32A_dp_3src
    IEM_INSTR_IMPL_A64__MSUB_32A_dp_3src(Rd, Rn, Ra, Rm);
#else
    RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe08000/9b008000: MSUB  <Xd>, <Xn>, <Xm>, <Xa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_MSUB_64A_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: MSUB_64A_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__MSUB_64A_dp_3src
    IEM_INSTR_IMPL_A64__MSUB_64A_dp_3src(Rd, Rn, Ra, Rm);
#else
    RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf00f400/0f008000: MUL  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MUL_asimdelem_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f008000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MUL_asimdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__MUL_asimdelem_R
            IEM_INSTR_IMPL_A64__MUL_asimdelem_R(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e209c00: MUL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MUL_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e209c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MUL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__MUL_asimdsame_only
            IEM_INSTR_IMPL_A64__MUL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff8dc00/2f008400: MVNI  <Vd>.<T>, #<imm8>{, LSL #<amount>}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MVNI_asimdimm_L_hl, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: MVNI_asimdimm_L_hl Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__MVNI_asimdimm_L_hl
        IEM_INSTR_IMPL_A64__MVNI_asimdimm_L_hl(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
        RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff89c00/2f000400: MVNI  <Vd>.<T>, #<imm8>{, LSL #<amount>}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MVNI_asimdimm_L_sl, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: MVNI_asimdimm_L_sl Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__MVNI_asimdimm_L_sl
        IEM_INSTR_IMPL_A64__MVNI_asimdimm_L_sl(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
        RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff8ec00/2f00c400: MVNI  <Vd>.<T>, #<imm8>, MSL #<amount>
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_MVNI_asimdimm_M_sm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbff8ec00)) == UINT32_C(0x2f00c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const h          = (uOpcode >>  5) & 0x00000001;
        uint32_t const g          = (uOpcode >>  6) & 0x00000001;
        uint32_t const f          = (uOpcode >>  7) & 0x00000001;
        uint32_t const e          = (uOpcode >>  8) & 0x00000001;
        uint32_t const d          = (uOpcode >>  9) & 0x00000001;
        uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
        uint32_t const c          = (uOpcode >> 16) & 0x00000001;
        uint32_t const b          = (uOpcode >> 17) & 0x00000001;
        uint32_t const a          = (uOpcode >> 18) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: MVNI_asimdimm_M_sm Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__MVNI_asimdimm_M_sm
            IEM_INSTR_IMPL_A64__MVNI_asimdimm_M_sm(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
            RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e20b800: NEG  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_NEG_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e20b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: NEG_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__NEG_asimdmisc_R
            IEM_INSTR_IMPL_A64__NEG_asimdmisc_R(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7ee0b800: NEG  D<d>, D<n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_NEG_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7ee0b800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: NEG_asisdmisc_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__NEG_asisdmisc_R
            IEM_INSTR_IMPL_A64__NEG_asisdmisc_R(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503201f: NOP
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_NOP_HI_hints, uint32_t, uOpcode)
{
    LogFlow(("%018x/%010x: NOP_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__NOP_HI_hints
    IEM_INSTR_IMPL_A64__NOP_HI_hints();
#else
    RT_NOREF(pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bffffc00/2e205800: NOT  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_NOT_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e205800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: NOT_asimdmisc_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__NOT_asimdmisc_R
            IEM_INSTR_IMPL_A64__NOT_asimdmisc_R(Rd, Rn, Q);
#else
            RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff200000/2a200000: ORN  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ORN_32_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: ORN_32_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ORN_32_log_shift
    IEM_INSTR_IMPL_A64__ORN_32_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/aa200000: ORN  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ORN_64_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: ORN_64_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ORN_64_log_shift
    IEM_INSTR_IMPL_A64__ORN_64_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bfe0fc00/0ee01c00: ORN  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ORN_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0ee01c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ORN_asimdsame_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ORN_asimdsame_only
            IEM_INSTR_IMPL_A64__ORN_asimdsame_only(Rd, Rn, Rm, Q);
#else
            RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/32000000: ORR  <Wd|WSP>, <Wn>, #<imm>
   Instruction Set: A64  Groups: log_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ORR_32_log_imm, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x32000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
        LogFlow(("%018x/%010x: ORR_32_log_imm Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__ORR_32_log_imm
        IEM_INSTR_IMPL_A64__ORR_32_log_imm(Rd, Rn, imms, immr);
#else
        RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff200000/2a000000: ORR  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ORR_32_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: ORR_32_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ORR_32_log_shift
    IEM_INSTR_IMPL_A64__ORR_32_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/b2000000: ORR  <Xd|SP>, <Xn>, #<imm>
   Instruction Set: A64  Groups: log_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_ORR_64_log_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    uint32_t const N          = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: ORR_64_log_imm Rd=%#x Rn=%#x imms=%#x immr=%#x N=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr, N));
#ifdef IEM_INSTR_IMPL_A64__ORR_64_log_imm
    IEM_INSTR_IMPL_A64__ORR_64_log_imm(Rd, Rn, imms, immr, N);
#else
    RT_NOREF(Rd, Rn, imms, immr, N, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/aa000000: ORR  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: log_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_ORR_64_log_shift, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
    LogFlow(("%018x/%010x: ORR_64_log_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__ORR_64_log_shift
    IEM_INSTR_IMPL_A64__ORR_64_log_shift(Rd, Rn, imm6, Rm, shift);
#else
    RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bff8dc00/0f009400: ORR  <Vd>.<T>, #<imm8>{, LSL #<amount>}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ORR_asimdimm_L_hl, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbff8dc00)) == UINT32_C(0x0f009400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const h          = (uOpcode >>  5) & 0x00000001;
        uint32_t const g          = (uOpcode >>  6) & 0x00000001;
        uint32_t const f          = (uOpcode >>  7) & 0x00000001;
        uint32_t const e          = (uOpcode >>  8) & 0x00000001;
        uint32_t const d          = (uOpcode >>  9) & 0x00000001;
        uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
        uint32_t const c          = (uOpcode >> 16) & 0x00000001;
        uint32_t const b          = (uOpcode >> 17) & 0x00000001;
        uint32_t const a          = (uOpcode >> 18) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ORR_asimdimm_L_hl Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__ORR_asimdimm_L_hl
            IEM_INSTR_IMPL_A64__ORR_asimdimm_L_hl(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
            RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bff89c00/0f001400: ORR  <Vd>.<T>, #<imm8>{, LSL #<amount>}
   Instruction Set: A64  Groups: asimdimm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ORR_asimdimm_L_sl, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const h          = (uOpcode >>  5) & 0x00000001;
    uint32_t const g          = (uOpcode >>  6) & 0x00000001;
    uint32_t const f          = (uOpcode >>  7) & 0x00000001;
    uint32_t const e          = (uOpcode >>  8) & 0x00000001;
    uint32_t const d          = (uOpcode >>  9) & 0x00000001;
    uint32_t const cmode      = (uOpcode >> 12) & 0x0000000f;
    uint32_t const c          = (uOpcode >> 16) & 0x00000001;
    uint32_t const b          = (uOpcode >> 17) & 0x00000001;
    uint32_t const a          = (uOpcode >> 18) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ORR_asimdimm_L_sl Rd=%#x h=%u g=%u f=%u e=%u d=%u cmode=%#x c=%u b=%u a=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, h, g, f, e, d, cmode, c, b, a, Q));
#ifdef IEM_INSTR_IMPL_A64__ORR_asimdimm_L_sl
        IEM_INSTR_IMPL_A64__ORR_asimdimm_L_sl(Rd, h, g, f, e, d, cmode, c, b, a, Q);
#else
        RT_NOREF(Rd, h, g, f, e, d, cmode, c, b, a, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0ea01c00: ORR  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ORR_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ORR_asimdsame_only Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ORR_asimdsame_only
        IEM_INSTR_IMPL_A64__ORR_asimdsame_only(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac10800: PACDA  <Xd>, <Xn|SP>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACDA_64P_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACDA_64P_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__PACDA_64P_dp_1src
        IEM_INSTR_IMPL_A64__PACDA_64P_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac10c00: PACDB  <Xd>, <Xn|SP>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACDB_64P_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACDB_64P_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__PACDB_64P_dp_1src
        IEM_INSTR_IMPL_A64__PACDB_64P_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac12be0: PACDZA  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACDZA_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac12be0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: PACDZA_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__PACDZA_64Z_dp_1src
            IEM_INSTR_IMPL_A64__PACDZA_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac12fe0: PACDZB  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACDZB_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac12fe0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: PACDZB_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__PACDZB_64Z_dp_1src
            IEM_INSTR_IMPL_A64__PACDZB_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac03000: PACGA  <Xd>, <Xn>, <Xm|SP>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACGA_64P_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACGA_64P_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__PACGA_64P_dp_2src
        IEM_INSTR_IMPL_A64__PACGA_64P_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/dac18bfe: PACIA171615
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACIA171615_64LR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xdac18bfe))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: PACIA171615_64LR_dp_1src\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIA171615_64LR_dp_1src
            IEM_INSTR_IMPL_A64__PACIA171615_64LR_dp_1src();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503211f: PACIA1716
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_PACIA1716_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIA1716_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIA1716_HI_hints
        IEM_INSTR_IMPL_A64__PACIA1716_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/dac1a3fe: PACIASPPC
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACIASPPC_64LR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xdac1a3fe))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: PACIASPPC_64LR_dp_1src\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIASPPC_64LR_dp_1src
            IEM_INSTR_IMPL_A64__PACIASPPC_64LR_dp_1src();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503233f: PACIASP
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_PACIASP_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIASP_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIASP_HI_hints
        IEM_INSTR_IMPL_A64__PACIASP_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503231f: PACIAZ
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_PACIAZ_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIAZ_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIAZ_HI_hints
        IEM_INSTR_IMPL_A64__PACIAZ_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac10000: PACIA  <Xd>, <Xn|SP>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACIA_64P_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIA_64P_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__PACIA_64P_dp_1src
        IEM_INSTR_IMPL_A64__PACIA_64P_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/dac18ffe: PACIB171615
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACIB171615_64LR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xdac18ffe))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: PACIB171615_64LR_dp_1src\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIB171615_64LR_dp_1src
            IEM_INSTR_IMPL_A64__PACIB171615_64LR_dp_1src();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503215f: PACIB1716
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_PACIB1716_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIB1716_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIB1716_HI_hints
        IEM_INSTR_IMPL_A64__PACIB1716_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/dac1a7fe: PACIBSPPC
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACIBSPPC_64LR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xdac1a7fe))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: PACIBSPPC_64LR_dp_1src\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIBSPPC_64LR_dp_1src
            IEM_INSTR_IMPL_A64__PACIBSPPC_64LR_dp_1src();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503237f: PACIBSP
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_PACIBSP_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIBSP_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIBSP_HI_hints
        IEM_INSTR_IMPL_A64__PACIBSP_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503235f: PACIBZ
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_PACIBZ_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIBZ_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACIBZ_HI_hints
        IEM_INSTR_IMPL_A64__PACIBZ_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac10400: PACIB  <Xd>, <Xn|SP>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACIB_64P_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIB_64P_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__PACIB_64P_dp_1src
        IEM_INSTR_IMPL_A64__PACIB_64P_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac123e0: PACIZA  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACIZA_64Z_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: PACIZA_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__PACIZA_64Z_dp_1src
        IEM_INSTR_IMPL_A64__PACIZA_64Z_dp_1src(Rd);
#else
        RT_NOREF(Rd, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac127e0: PACIZB  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACIZB_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac127e0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: PACIZB_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__PACIZB_64Z_dp_1src
            IEM_INSTR_IMPL_A64__PACIZB_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d50324ff: PACM
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_PACM_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
    {
        LogFlow(("%018x/%010x: PACM_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACM_HI_hints
        IEM_INSTR_IMPL_A64__PACM_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/dac183fe: PACNBIASPPC
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACNBIASPPC_64LR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xdac183fe))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: PACNBIASPPC_64LR_dp_1src\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACNBIASPPC_64LR_dp_1src
            IEM_INSTR_IMPL_A64__PACNBIASPPC_64LR_dp_1src();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/dac187fe: PACNBIBSPPC
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_PACNBIBSPPC_64LR_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xdac187fe))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: PACNBIBSPPC_64LR_dp_1src\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PACNBIBSPPC_64LR_dp_1src
            IEM_INSTR_IMPL_A64__PACNBIBSPPC_64LR_dp_1src();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e20e000: PMULL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_PMULL_asimddiff_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: PMULL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__PMULL_asimddiff_L
        IEM_INSTR_IMPL_A64__PMULL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e209c00: PMUL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_PMUL_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e209c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: PMUL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__PMUL_asimdsame_only
            IEM_INSTR_IMPL_A64__PMUL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/f9800000: PRFM  {<prfop> | #<imm5>}, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_PRFM_P_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: PRFM_P_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__PRFM_P_ldst_pos
    IEM_INSTR_IMPL_A64__PRFM_P_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8a00800: PRFM  {<prfop> | #<imm5>}, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_PRFM_P_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (!((Rt & 0x18) == 0x18) && ((option & 2) == 2))
    {
        LogFlow(("%018x/%010x: PRFM_P_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__PRFM_P_ldst_regoff
        IEM_INSTR_IMPL_A64__PRFM_P_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff000000/d8000000: PRFM  {<prfop> | #<imm5>}, <label>
   Instruction Set: A64  Groups: loadlit, ldst */
FNIEMOP_DEF_1(iemDecodeA64_PRFM_P_loadlit, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm19      = (uOpcode >>  5) & 0x0007ffff;
    LogFlow(("%018x/%010x: PRFM_P_loadlit Rt=%#x imm19=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm19));
#ifdef IEM_INSTR_IMPL_A64__PRFM_P_loadlit
    IEM_INSTR_IMPL_A64__PRFM_P_loadlit(Rt, imm19);
#else
    RT_NOREF(Rt, imm19, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8800000: PRFUM  {<prfop> | #<imm5>}, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_PRFUM_P_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: PRFUM_P_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__PRFUM_P_ldst_unscaled
    IEM_INSTR_IMPL_A64__PRFUM_P_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffffffff/d503223f: PSB  CSYNC
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_PSB_HC_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSpe /*FEAT_SPE*/)
    {
        LogFlow(("%018x/%010x: PSB_HC_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__PSB_HC_hints
        IEM_INSTR_IMPL_A64__PSB_HC_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e204000: RADDHN2  <Vd>.<Tb>, <Vn>.<Ta>, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_RADDHN_asimddiff_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: RADDHN_asimddiff_N Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__RADDHN_asimddiff_N
        IEM_INSTR_IMPL_A64__RADDHN_asimddiff_N(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/ce608c00: RAX1  <Vd>.2D, <Vn>.2D, <Vm>.2D
   Instruction Set: A64  Groups: cryptosha512_3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_RAX1_VVV2_cryptosha512_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce608c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha3 /*FEAT_SHA3*/)
        {
            LogFlow(("%018x/%010x: RAX1_VVV2_cryptosha512_3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__RAX1_VVV2_cryptosha512_3
            IEM_INSTR_IMPL_A64__RAX1_VVV2_cryptosha512_3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ac00000: RBIT  <Wd>, <Wn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_RBIT_32_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ac00000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: RBIT_32_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__RBIT_32_dp_1src
        IEM_INSTR_IMPL_A64__RBIT_32_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac00000: RBIT  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_RBIT_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    LogFlow(("%018x/%010x: RBIT_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__RBIT_64_dp_1src
    IEM_INSTR_IMPL_A64__RBIT_64_dp_1src(Rd, Rn);
#else
    RT_NOREF(Rd, Rn, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bffffc00/2e605800: RBIT  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_RBIT_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e605800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: RBIT_asimdmisc_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__RBIT_asimdmisc_R
            IEM_INSTR_IMPL_A64__RBIT_asimdmisc_R(Rd, Rn, Q);
#else
            RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e00800: RCWCASAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCASAL_C64_rcwcomswap, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e00800))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWCASAL_C64_rcwcomswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCASAL_C64_rcwcomswap
            IEM_INSTR_IMPL_A64__RCWCASAL_C64_rcwcomswap(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a00800: RCWCASA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCASA_C64_rcwcomswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCASA_C64_rcwcomswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCASA_C64_rcwcomswap
        IEM_INSTR_IMPL_A64__RCWCASA_C64_rcwcomswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19600800: RCWCASL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCASL_C64_rcwcomswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCASL_C64_rcwcomswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCASL_C64_rcwcomswap
        IEM_INSTR_IMPL_A64__RCWCASL_C64_rcwcomswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e00c00: RCWCASPAL  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCASPAL_C64_rcwcomswappr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e00c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWCASPAL_C64_rcwcomswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCASPAL_C64_rcwcomswappr
            IEM_INSTR_IMPL_A64__RCWCASPAL_C64_rcwcomswappr(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a00c00: RCWCASPA  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCASPA_C64_rcwcomswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCASPA_C64_rcwcomswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCASPA_C64_rcwcomswappr
        IEM_INSTR_IMPL_A64__RCWCASPA_C64_rcwcomswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19600c00: RCWCASPL  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCASPL_C64_rcwcomswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCASPL_C64_rcwcomswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCASPL_C64_rcwcomswappr
        IEM_INSTR_IMPL_A64__RCWCASPL_C64_rcwcomswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19200c00: RCWCASP  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCASP_C64_rcwcomswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCASP_C64_rcwcomswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCASP_C64_rcwcomswappr
        IEM_INSTR_IMPL_A64__RCWCASP_C64_rcwcomswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19200800: RCWCAS  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCAS_C64_rcwcomswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCAS_C64_rcwcomswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCAS_C64_rcwcomswap
        IEM_INSTR_IMPL_A64__RCWCAS_C64_rcwcomswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e09000: RCWCLRAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCLRAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCLRAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCLRAL_64_memop
        IEM_INSTR_IMPL_A64__RCWCLRAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a09000: RCWCLRA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCLRA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCLRA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCLRA_64_memop
        IEM_INSTR_IMPL_A64__RCWCLRA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38609000: RCWCLRL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCLRL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCLRL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCLRL_64_memop
        IEM_INSTR_IMPL_A64__RCWCLRL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e09000: RCWCLRPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCLRPAL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCLRPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWCLRPAL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWCLRPAL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a09000: RCWCLRPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCLRPA_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCLRPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWCLRPA_128_memop_128
        IEM_INSTR_IMPL_A64__RCWCLRPA_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19609000: RCWCLRPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCLRPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCLRPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWCLRPL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWCLRPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19209000: RCWCLRP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCLRP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCLRP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWCLRP_128_memop_128
        IEM_INSTR_IMPL_A64__RCWCLRP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38209000: RCWCLR  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWCLR_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWCLR_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWCLR_64_memop
        IEM_INSTR_IMPL_A64__RCWCLR_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e00800: RCWSCASAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCASAL_C64_rcwcomswap, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59e00800))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWSCASAL_C64_rcwcomswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCASAL_C64_rcwcomswap
            IEM_INSTR_IMPL_A64__RCWSCASAL_C64_rcwcomswap(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a00800: RCWSCASA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCASA_C64_rcwcomswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCASA_C64_rcwcomswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCASA_C64_rcwcomswap
        IEM_INSTR_IMPL_A64__RCWSCASA_C64_rcwcomswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59600800: RCWSCASL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCASL_C64_rcwcomswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCASL_C64_rcwcomswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCASL_C64_rcwcomswap
        IEM_INSTR_IMPL_A64__RCWSCASL_C64_rcwcomswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e00c00: RCWSCASPAL  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCASPAL_C64_rcwcomswappr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59e00c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWSCASPAL_C64_rcwcomswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCASPAL_C64_rcwcomswappr
            IEM_INSTR_IMPL_A64__RCWSCASPAL_C64_rcwcomswappr(Rt, Rn, Rs);
#else
            RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a00c00: RCWSCASPA  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCASPA_C64_rcwcomswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCASPA_C64_rcwcomswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCASPA_C64_rcwcomswappr
        IEM_INSTR_IMPL_A64__RCWSCASPA_C64_rcwcomswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59600c00: RCWSCASPL  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCASPL_C64_rcwcomswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCASPL_C64_rcwcomswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCASPL_C64_rcwcomswappr
        IEM_INSTR_IMPL_A64__RCWSCASPL_C64_rcwcomswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59200c00: RCWSCASP  <Xs>, <X(s+1)>, <Xt>, <X(t+1)>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswappr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCASP_C64_rcwcomswappr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCASP_C64_rcwcomswappr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCASP_C64_rcwcomswappr
        IEM_INSTR_IMPL_A64__RCWSCASP_C64_rcwcomswappr(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59200800: RCWSCAS  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: rcwcomswap, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCAS_C64_rcwcomswap, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCAS_C64_rcwcomswap Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCAS_C64_rcwcomswap
        IEM_INSTR_IMPL_A64__RCWSCAS_C64_rcwcomswap(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e09000: RCWSCLRAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCLRAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCLRAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCLRAL_64_memop
        IEM_INSTR_IMPL_A64__RCWSCLRAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a09000: RCWSCLRA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCLRA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCLRA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCLRA_64_memop
        IEM_INSTR_IMPL_A64__RCWSCLRA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78609000: RCWSCLRL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCLRL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCLRL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCLRL_64_memop
        IEM_INSTR_IMPL_A64__RCWSCLRL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e09000: RCWSCLRPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCLRPAL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCLRPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSCLRPAL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSCLRPAL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a09000: RCWSCLRPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCLRPA_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCLRPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSCLRPA_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSCLRPA_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59609000: RCWSCLRPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCLRPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCLRPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSCLRPL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSCLRPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59209000: RCWSCLRP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCLRP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCLRP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSCLRP_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSCLRP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78209000: RCWSCLR  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSCLR_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSCLR_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSCLR_64_memop
        IEM_INSTR_IMPL_A64__RCWSCLR_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e0b000: RCWSETAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSETAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSETAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSETAL_64_memop
        IEM_INSTR_IMPL_A64__RCWSETAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a0b000: RCWSETA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSETA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSETA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSETA_64_memop
        IEM_INSTR_IMPL_A64__RCWSETA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3860b000: RCWSETL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSETL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSETL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSETL_64_memop
        IEM_INSTR_IMPL_A64__RCWSETL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e0b000: RCWSETPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSETPAL_128_memop_128, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e0b000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWSETPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSETPAL_128_memop_128
            IEM_INSTR_IMPL_A64__RCWSETPAL_128_memop_128(Rt, Rn, Rt2);
#else
            RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a0b000: RCWSETPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSETPA_128_memop_128, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19a0b000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWSETPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSETPA_128_memop_128
            IEM_INSTR_IMPL_A64__RCWSETPA_128_memop_128(Rt, Rn, Rt2);
#else
            RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1960b000: RCWSETPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSETPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSETPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSETPL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSETPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1920b000: RCWSETP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSETP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSETP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSETP_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSETP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3820b000: RCWSET  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSET_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSET_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSET_64_memop
        IEM_INSTR_IMPL_A64__RCWSET_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e0b000: RCWSSETAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSETAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSETAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSSETAL_64_memop
        IEM_INSTR_IMPL_A64__RCWSSETAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a0b000: RCWSSETA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSETA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSETA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSSETA_64_memop
        IEM_INSTR_IMPL_A64__RCWSSETA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7860b000: RCWSSETL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSETL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSETL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSSETL_64_memop
        IEM_INSTR_IMPL_A64__RCWSSETL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e0b000: RCWSSETPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSETPAL_128_memop_128, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59e0b000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWSSETPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSSETPAL_128_memop_128
            IEM_INSTR_IMPL_A64__RCWSSETPAL_128_memop_128(Rt, Rn, Rt2);
#else
            RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a0b000: RCWSSETPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSETPA_128_memop_128, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59a0b000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWSSETPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSSETPA_128_memop_128
            IEM_INSTR_IMPL_A64__RCWSSETPA_128_memop_128(Rt, Rn, Rt2);
#else
            RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5960b000: RCWSSETPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSETPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSETPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSSETPL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSSETPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5920b000: RCWSSETP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSETP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSETP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSSETP_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSSETP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7820b000: RCWSSET  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSET_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSET_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSSET_64_memop
        IEM_INSTR_IMPL_A64__RCWSSET_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e0a000: RCWSSWPAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSWPAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSWPAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSSWPAL_64_memop
        IEM_INSTR_IMPL_A64__RCWSSWPAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a0a000: RCWSSWPA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSWPA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSWPA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSSWPA_64_memop
        IEM_INSTR_IMPL_A64__RCWSSWPA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7860a000: RCWSSWPL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSWPL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSWPL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSSWPL_64_memop
        IEM_INSTR_IMPL_A64__RCWSSWPL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e0a000: RCWSSWPPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSWPPAL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSWPPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSSWPPAL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSSWPPAL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a0a000: RCWSSWPPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSWPPA_128_memop_128, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59a0a000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWSSWPPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSSWPPA_128_memop_128
            IEM_INSTR_IMPL_A64__RCWSSWPPA_128_memop_128(Rt, Rn, Rt2);
#else
            RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5960a000: RCWSSWPPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSWPPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSWPPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSSWPPL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSSWPPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5920a000: RCWSSWPP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSWPP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSWPP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSSWPP_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSSWPP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7820a000: RCWSSWP  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSSWP_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSSWP_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSSWP_64_memop
        IEM_INSTR_IMPL_A64__RCWSSWP_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e0a000: RCWSWPAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSWPAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSWPAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSWPAL_64_memop
        IEM_INSTR_IMPL_A64__RCWSWPAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38a0a000: RCWSWPA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSWPA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSWPA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSWPA_64_memop
        IEM_INSTR_IMPL_A64__RCWSWPA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3860a000: RCWSWPL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSWPL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSWPL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSWPL_64_memop
        IEM_INSTR_IMPL_A64__RCWSWPL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e0a000: RCWSWPPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSWPPAL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSWPPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSWPPAL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSWPPAL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a0a000: RCWSWPPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSWPPA_128_memop_128, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19a0a000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
        {
            LogFlow(("%018x/%010x: RCWSWPPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSWPPA_128_memop_128
            IEM_INSTR_IMPL_A64__RCWSWPPA_128_memop_128(Rt, Rn, Rt2);
#else
            RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1960a000: RCWSWPPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSWPPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSWPPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSWPPL_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSWPPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1920a000: RCWSWPP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSWPP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fD128 /*FEAT_D128*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSWPP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__RCWSWPP_128_memop_128
        IEM_INSTR_IMPL_A64__RCWSWPP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/3820a000: RCWSWP  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RCWSWP_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fThe /*FEAT_THE*/)
    {
        LogFlow(("%018x/%010x: RCWSWP_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__RCWSWP_64_memop
        IEM_INSTR_IMPL_A64__RCWSWP_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/d65f0be0: RETAASPPCR  <Xm>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_RETAASPPCR_64M_branch_reg, uint32_t, uOpcode)
{
    uint32_t const Rm         = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: RETAASPPCR_64M_branch_reg Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rm));
#ifdef IEM_INSTR_IMPL_A64__RETAASPPCR_64M_branch_reg
        IEM_INSTR_IMPL_A64__RETAASPPCR_64M_branch_reg(Rm);
#else
        RT_NOREF(Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/5500001f: RETAASPPC  <label>
   Instruction Set: A64  Groups: miscbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_RETAASPPC_only_miscbranch, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0x5500001f))
    {
        uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: RETAASPPC_only_miscbranch imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__RETAASPPC_only_miscbranch
            IEM_INSTR_IMPL_A64__RETAASPPC_only_miscbranch(imm16);
#else
            RT_NOREF(imm16, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d65f0bff: RETAA
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_RETAA_64E_branch_reg, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: RETAA_64E_branch_reg\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__RETAA_64E_branch_reg
        IEM_INSTR_IMPL_A64__RETAA_64E_branch_reg();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/d65f0fe0: RETABSPPCR  <Xm>
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_RETABSPPCR_64M_branch_reg, uint32_t, uOpcode)
{
    uint32_t const Rm         = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: RETABSPPCR_64M_branch_reg Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rm));
#ifdef IEM_INSTR_IMPL_A64__RETABSPPCR_64M_branch_reg
        IEM_INSTR_IMPL_A64__RETABSPPCR_64M_branch_reg(Rm);
#else
        RT_NOREF(Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/5520001f: RETABSPPC  <label>
   Instruction Set: A64  Groups: miscbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_RETABSPPC_only_miscbranch, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0x5520001f))
    {
        uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuthLR /*FEAT_PAuth_LR*/)
        {
            LogFlow(("%018x/%010x: RETABSPPC_only_miscbranch imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__RETABSPPC_only_miscbranch
            IEM_INSTR_IMPL_A64__RETABSPPC_only_miscbranch(imm16);
#else
            RT_NOREF(imm16, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d65f0fff: RETAB
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_RETAB_64E_branch_reg, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: RETAB_64E_branch_reg\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__RETAB_64E_branch_reg
        IEM_INSTR_IMPL_A64__RETAB_64E_branch_reg();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/d65f0000: RET{  <Xn>}
   Instruction Set: A64  Groups: branch_reg, control */
FNIEMOP_DEF_1(iemDecodeA64_RET_64R_branch_reg, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    LogFlow(("%018x/%010x: RET_64R_branch_reg Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__RET_64R_branch_reg
    IEM_INSTR_IMPL_A64__RET_64R_branch_reg(Rn);
#else
    RT_NOREF(Rn, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fffffc00/5ac00400: REV16  <Wd>, <Wn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_REV16_32_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ac00400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: REV16_32_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__REV16_32_dp_1src
        IEM_INSTR_IMPL_A64__REV16_32_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac00400: REV16  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_REV16_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    LogFlow(("%018x/%010x: REV16_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__REV16_64_dp_1src
    IEM_INSTR_IMPL_A64__REV16_64_dp_1src(Rd, Rn);
#else
    RT_NOREF(Rd, Rn, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf3ffc00/0e201800: REV16  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_REV16_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e201800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: REV16_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__REV16_asimdmisc_R
            IEM_INSTR_IMPL_A64__REV16_asimdmisc_R(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac00800: REV32  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_REV32_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    LogFlow(("%018x/%010x: REV32_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__REV32_64_dp_1src
    IEM_INSTR_IMPL_A64__REV32_64_dp_1src(Rd, Rn);
#else
    RT_NOREF(Rd, Rn, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf3ffc00/2e200800: REV32  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_REV32_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e200800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: REV32_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__REV32_asimdmisc_R
            IEM_INSTR_IMPL_A64__REV32_asimdmisc_R(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e200800: REV64  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_REV64_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e200800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: REV64_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__REV64_asimdmisc_R
            IEM_INSTR_IMPL_A64__REV64_asimdmisc_R(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5ac00800: REV  <Wd>, <Wn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_REV_32_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ac00800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: REV_32_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__REV_32_dp_1src
        IEM_INSTR_IMPL_A64__REV_32_dp_1src(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/dac00c00: REV  <Xd>, <Xn>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_REV_64_dp_1src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    LogFlow(("%018x/%010x: REV_64_dp_1src Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__REV_64_dp_1src
    IEM_INSTR_IMPL_A64__REV_64_dp_1src(Rd, Rn);
#else
    RT_NOREF(Rd, Rn, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe07c10/ba000400: RMIF  <Xn>, #<shift>, #<mask>
   Instruction Set: A64  Groups: rmif, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_RMIF_only_rmif, uint32_t, uOpcode)
{
    uint32_t const mask       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 15) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFlagM /*FEAT_FlagM*/)
    {
        LogFlow(("%018x/%010x: RMIF_only_rmif mask=%#x Rn=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, mask, Rn, imm6));
#ifdef IEM_INSTR_IMPL_A64__RMIF_only_rmif
        IEM_INSTR_IMPL_A64__RMIF_only_rmif(mask, Rn, imm6);
#else
        RT_NOREF(mask, Rn, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac02c00: RORV  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_RORV_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: RORV_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__RORV_32_dp_2src
    IEM_INSTR_IMPL_A64__RORV_32_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9ac02c00: RORV  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_RORV_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: RORV_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__RORV_64_dp_2src
    IEM_INSTR_IMPL_A64__RORV_64_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8a00800: RPRFM  {<rprfop> | #<imm6>}, <Xm>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_RPRFM_R_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRprfm /*FEAT_RPRFM*/ && ((option & 2) == 2) && ((Rt & 0x18) == 0x18))
    {
        LogFlow(("%018x/%010x: RPRFM_R_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__RPRFM_R_ldst_regoff
        IEM_INSTR_IMPL_A64__RPRFM_R_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f008c00: RSHRN2  <Vd>.<Tb>, <Vn>.<Ta>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_RSHRN_asimdshf_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f008c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
        {
            LogFlow(("%018x/%010x: RSHRN_asimdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__RSHRN_asimdshf_N
            IEM_INSTR_IMPL_A64__RSHRN_asimdshf_N(Rd, Rn, immb, immh, Q);
#else
            RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e206000: RSUBHN2  <Vd>.<Tb>, <Vn>.<Ta>, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_RSUBHN_asimddiff_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: RSUBHN_asimddiff_N Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__RSUBHN_asimddiff_N
        IEM_INSTR_IMPL_A64__RSUBHN_asimddiff_N(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e205000: SABAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SABAL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e205000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SABAL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SABAL_asimddiff_L
            IEM_INSTR_IMPL_A64__SABAL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e207c00: SABA  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SABA_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e207c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SABA_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SABA_asimdsame_only
            IEM_INSTR_IMPL_A64__SABA_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e207000: SABDL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SABDL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e207000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SABDL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SABDL_asimddiff_L
            IEM_INSTR_IMPL_A64__SABDL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e207400: SABD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SABD_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e207400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SABD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SABD_asimdsame_only
            IEM_INSTR_IMPL_A64__SABD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e206800: SADALP  <Vd>.<Ta>, <Vn>.<Tb>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SADALP_asimdmisc_P, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e206800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SADALP_asimdmisc_P Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SADALP_asimdmisc_P
            IEM_INSTR_IMPL_A64__SADALP_asimdmisc_P(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e202800: SADDLP  <Vd>.<Ta>, <Vn>.<Tb>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SADDLP_asimdmisc_P, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SADDLP_asimdmisc_P Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SADDLP_asimdmisc_P
        IEM_INSTR_IMPL_A64__SADDLP_asimdmisc_P(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e303800: SADDLV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SADDLV_asimdall_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SADDLV_asimdall_only Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SADDLV_asimdall_only
        IEM_INSTR_IMPL_A64__SADDLV_asimdall_only(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e200000: SADDL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SADDL_asimddiff_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SADDL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SADDL_asimddiff_L
        IEM_INSTR_IMPL_A64__SADDL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e201000: SADDW2  <Vd>.<Ta>, <Vn>.<Ta>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SADDW_asimddiff_W, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e201000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SADDW_asimddiff_W Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SADDW_asimddiff_W
            IEM_INSTR_IMPL_A64__SADDW_asimddiff_W(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7a000000: SBCS  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: addsub_carry, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SBCS_32_addsub_carry, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SBCS_32_addsub_carry Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SBCS_32_addsub_carry
    IEM_INSTR_IMPL_A64__SBCS_32_addsub_carry(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/fa000000: SBCS  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: addsub_carry, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SBCS_64_addsub_carry, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SBCS_64_addsub_carry Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SBCS_64_addsub_carry
    IEM_INSTR_IMPL_A64__SBCS_64_addsub_carry(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/5a000000: SBC  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: addsub_carry, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SBC_32_addsub_carry, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SBC_32_addsub_carry Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SBC_32_addsub_carry
    IEM_INSTR_IMPL_A64__SBC_32_addsub_carry(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/da000000: SBC  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: addsub_carry, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SBC_64_addsub_carry, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SBC_64_addsub_carry Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SBC_64_addsub_carry
    IEM_INSTR_IMPL_A64__SBC_64_addsub_carry(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/13000000: SBFM  <Wd>, <Wn>, #<immr>, #<imms>
   Instruction Set: A64  Groups: bitfield, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SBFM_32M_bitfield, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    LogFlow(("%018x/%010x: SBFM_32M_bitfield Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__SBFM_32M_bitfield
    IEM_INSTR_IMPL_A64__SBFM_32M_bitfield(Rd, Rn, imms, immr);
#else
    RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/93400000: SBFM  <Xd>, <Xn>, #<immr>, #<imms>
   Instruction Set: A64  Groups: bitfield, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SBFM_64M_bitfield, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    LogFlow(("%018x/%010x: SBFM_64M_bitfield Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__SBFM_64M_bitfield
    IEM_INSTR_IMPL_A64__SBFM_64M_bitfield(Rd, Rn, imms, immr);
#else
    RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffffffff/d50330ff: SB
   Instruction Set: A64  Groups: barriers, control */
FNIEMOP_DEF_1(iemDecodeA64_SB_only_barriers, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50330ff))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSb /*FEAT_SB*/)
        {
            LogFlow(("%018x/%010x: SB_only_barriers\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__SB_only_barriers
            IEM_INSTR_IMPL_A64__SB_only_barriers();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1e420000: SCVTF  <Dd>, <Wn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_D32_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: SCVTF_D32_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_D32_float2fix
        IEM_INSTR_IMPL_A64__SCVTF_D32_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e620000: SCVTF  <Dd>, <Wn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_D32_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: SCVTF_D32_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_D32_float2int
        IEM_INSTR_IMPL_A64__SCVTF_D32_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9e420000: SCVTF  <Dd>, <Xn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_D64_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: SCVTF_D64_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_D64_float2fix
        IEM_INSTR_IMPL_A64__SCVTF_D64_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e620000: SCVTF  <Dd>, <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_D64_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: SCVTF_D64_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_D64_float2int
        IEM_INSTR_IMPL_A64__SCVTF_D64_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1ec20000: SCVTF  <Hd>, <Wn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_H32_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: SCVTF_H32_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_H32_float2fix
        IEM_INSTR_IMPL_A64__SCVTF_H32_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee20000: SCVTF  <Hd>, <Wn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_H32_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: SCVTF_H32_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_H32_float2int
        IEM_INSTR_IMPL_A64__SCVTF_H32_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9ec20000: SCVTF  <Hd>, <Xn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_H64_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: SCVTF_H64_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_H64_float2fix
        IEM_INSTR_IMPL_A64__SCVTF_H64_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee20000: SCVTF  <Hd>, <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_H64_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: SCVTF_H64_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_H64_float2int
        IEM_INSTR_IMPL_A64__SCVTF_H64_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1e020000: SCVTF  <Sd>, <Wn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_S32_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: SCVTF_S32_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_S32_float2fix
        IEM_INSTR_IMPL_A64__SCVTF_S32_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e220000: SCVTF  <Sd>, <Wn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_S32_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: SCVTF_S32_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_S32_float2int
        IEM_INSTR_IMPL_A64__SCVTF_S32_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9e020000: SCVTF  <Sd>, <Xn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_S64_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: SCVTF_S64_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_S64_float2fix
        IEM_INSTR_IMPL_A64__SCVTF_S64_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e220000: SCVTF  <Sd>, <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_S64_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: SCVTF_S64_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_S64_float2int
        IEM_INSTR_IMPL_A64__SCVTF_S64_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0e21d800: SCVTF  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SCVTF_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_asimdmisc_R
        IEM_INSTR_IMPL_A64__SCVTF_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0e79d800: SCVTF  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: SCVTF_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__SCVTF_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f00e400: SCVTF  <Vd>.<T>, <Vn>.<T>, #<fbits>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_asimdshf_C, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SCVTF_asimdshf_C Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_asimdshf_C
        IEM_INSTR_IMPL_A64__SCVTF_asimdshf_C(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/5e21d800: SCVTF  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SCVTF_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_asisdmisc_R
        IEM_INSTR_IMPL_A64__SCVTF_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e79d800: SCVTF  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: SCVTF_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__SCVTF_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f00e400: SCVTF  <V><d>, <V><n>, #<fbits>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_asisdshf_C, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
    {
        LogFlow(("%018x/%010x: SCVTF_asisdshf_C Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_asisdshf_C
        IEM_INSTR_IMPL_A64__SCVTF_asisdshf_C(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e7c0000: SCVTF  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: SCVTF_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_sisd_32D
        IEM_INSTR_IMPL_A64__SCVTF_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1efc0000: SCVTF  <Hd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: SCVTF_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_sisd_32H
        IEM_INSTR_IMPL_A64__SCVTF_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9efc0000: SCVTF  <Hd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: SCVTF_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_sisd_64H
        IEM_INSTR_IMPL_A64__SCVTF_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e3c0000: SCVTF  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SCVTF_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: SCVTF_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SCVTF_sisd_64S
        IEM_INSTR_IMPL_A64__SCVTF_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac00c00: SDIV  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SDIV_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SDIV_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SDIV_32_dp_2src
    IEM_INSTR_IMPL_A64__SDIV_32_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9ac00c00: SDIV  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SDIV_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SDIV_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SDIV_64_dp_2src
    IEM_INSTR_IMPL_A64__SDIV_64_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf00f400/0f00e000: SDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.4B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SDOT_asimdelem_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f00e000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fDotProd /*FEAT_DotProd*/)
        {
            LogFlow(("%018x/%010x: SDOT_asimdelem_D Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SDOT_asimdelem_D
            IEM_INSTR_IMPL_A64__SDOT_asimdelem_D(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e009400: SDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SDOT_asimdsame2_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e009400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fDotProd /*FEAT_DotProd*/)
        {
            LogFlow(("%018x/%010x: SDOT_asimdsame2_D Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SDOT_asimdsame2_D
            IEM_INSTR_IMPL_A64__SDOT_asimdsame2_D(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c0a400: SETEN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETEN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETEN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETEN_SET_memcms
        IEM_INSTR_IMPL_A64__SETEN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c0b400: SETETN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETETN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETETN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETETN_SET_memcms
        IEM_INSTR_IMPL_A64__SETETN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c09400: SETET  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETET_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETET_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETET_SET_memcms
        IEM_INSTR_IMPL_A64__SETET_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c08400: SETE  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETE_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETE_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETE_SET_memcms
        IEM_INSTR_IMPL_A64__SETE_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/3a00480d: SETF16  <Wn>
   Instruction Set: A64  Groups: setf, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SETF16_only_setf, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFlagM /*FEAT_FlagM*/)
    {
        LogFlow(("%018x/%010x: SETF16_only_setf Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__SETF16_only_setf
        IEM_INSTR_IMPL_A64__SETF16_only_setf(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/3a00080d: SETF8  <Wn>
   Instruction Set: A64  Groups: setf, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SETF8_only_setf, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFlagM /*FEAT_FlagM*/)
    {
        LogFlow(("%018x/%010x: SETF8_only_setf Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__SETF8_only_setf
        IEM_INSTR_IMPL_A64__SETF8_only_setf(Rn);
#else
        RT_NOREF(Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc0a400: SETGEN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGEN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGEN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGEN_SET_memcms
        IEM_INSTR_IMPL_A64__SETGEN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc0b400: SETGETN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGETN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGETN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGETN_SET_memcms
        IEM_INSTR_IMPL_A64__SETGETN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc09400: SETGET  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGET_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGET_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGET_SET_memcms
        IEM_INSTR_IMPL_A64__SETGET_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc08400: SETGE  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGE_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGE_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGE_SET_memcms
        IEM_INSTR_IMPL_A64__SETGE_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc06400: SETGMN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGMN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGMN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGMN_SET_memcms
        IEM_INSTR_IMPL_A64__SETGMN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc07400: SETGMTN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGMTN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGMTN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGMTN_SET_memcms
        IEM_INSTR_IMPL_A64__SETGMTN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc05400: SETGMT  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGMT_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGMT_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGMT_SET_memcms
        IEM_INSTR_IMPL_A64__SETGMT_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc04400: SETGM  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGM_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGM_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGM_SET_memcms
        IEM_INSTR_IMPL_A64__SETGM_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc02400: SETGPN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGPN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGPN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGPN_SET_memcms
        IEM_INSTR_IMPL_A64__SETGPN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc03400: SETGPTN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGPTN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGPTN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGPTN_SET_memcms
        IEM_INSTR_IMPL_A64__SETGPTN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc01400: SETGPT  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGPT_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGPT_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGPT_SET_memcms
        IEM_INSTR_IMPL_A64__SETGPT_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/1dc00400: SETGP  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETGP_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SETGP_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETGP_SET_memcms
        IEM_INSTR_IMPL_A64__SETGP_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c06400: SETMN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETMN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETMN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETMN_SET_memcms
        IEM_INSTR_IMPL_A64__SETMN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c07400: SETMTN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETMTN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETMTN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETMTN_SET_memcms
        IEM_INSTR_IMPL_A64__SETMTN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c05400: SETMT  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETMT_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETMT_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETMT_SET_memcms
        IEM_INSTR_IMPL_A64__SETMT_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c04400: SETM  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETM_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETM_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETM_SET_memcms
        IEM_INSTR_IMPL_A64__SETM_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c02400: SETPN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETPN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETPN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETPN_SET_memcms
        IEM_INSTR_IMPL_A64__SETPN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c03400: SETPTN  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETPTN_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETPTN_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETPTN_SET_memcms
        IEM_INSTR_IMPL_A64__SETPTN_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c01400: SETPT  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETPT_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETPT_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETPT_SET_memcms
        IEM_INSTR_IMPL_A64__SETPT_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 3fe0fc00/19c00400: SETP  [<Xd>]!, <Xn>!, <Xs>
   Instruction Set: A64  Groups: memcms, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SETP_SET_memcms, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 30) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMops /*FEAT_MOPS*/)
    {
        LogFlow(("%018x/%010x: SETP_SET_memcms Rd=%#x Rn=%#x Rs=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rs, sz));
#ifdef IEM_INSTR_IMPL_A64__SETP_SET_memcms
        IEM_INSTR_IMPL_A64__SETP_SET_memcms(Rd, Rn, Rs, sz);
#else
        RT_NOREF(Rd, Rn, Rs, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d50320bf: SEVL
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_SEVL_HI_hints, uint32_t, uOpcode)
{
    LogFlow(("%018x/%010x: SEVL_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__SEVL_HI_hints
    IEM_INSTR_IMPL_A64__SEVL_HI_hints();
#else
    RT_NOREF(pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffffffff/d503209f: SEV
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_SEV_HI_hints, uint32_t, uOpcode)
{
    LogFlow(("%018x/%010x: SEV_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__SEV_HI_hints
    IEM_INSTR_IMPL_A64__SEV_HI_hints();
#else
    RT_NOREF(pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/5e000000: SHA1C  <Qd>, <Sn>, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA1C_QSV_cryptosha3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha1 /*FEAT_SHA1*/)
        {
            LogFlow(("%018x/%010x: SHA1C_QSV_cryptosha3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA1C_QSV_cryptosha3
            IEM_INSTR_IMPL_A64__SHA1C_QSV_cryptosha3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e280800: SHA1H  <Sd>, <Sn>
   Instruction Set: A64  Groups: cryptosha2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA1H_SS_cryptosha2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e280800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha1 /*FEAT_SHA1*/)
        {
            LogFlow(("%018x/%010x: SHA1H_SS_cryptosha2 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SHA1H_SS_cryptosha2
            IEM_INSTR_IMPL_A64__SHA1H_SS_cryptosha2(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e002000: SHA1M  <Qd>, <Sn>, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA1M_QSV_cryptosha3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e002000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha1 /*FEAT_SHA1*/)
        {
            LogFlow(("%018x/%010x: SHA1M_QSV_cryptosha3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA1M_QSV_cryptosha3
            IEM_INSTR_IMPL_A64__SHA1M_QSV_cryptosha3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e001000: SHA1P  <Qd>, <Sn>, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA1P_QSV_cryptosha3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e001000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha1 /*FEAT_SHA1*/)
        {
            LogFlow(("%018x/%010x: SHA1P_QSV_cryptosha3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA1P_QSV_cryptosha3
            IEM_INSTR_IMPL_A64__SHA1P_QSV_cryptosha3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e003000: SHA1SU0  <Vd>.4S, <Vn>.4S, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA1SU0_VVV_cryptosha3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e003000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha1 /*FEAT_SHA1*/)
        {
            LogFlow(("%018x/%010x: SHA1SU0_VVV_cryptosha3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA1SU0_VVV_cryptosha3
            IEM_INSTR_IMPL_A64__SHA1SU0_VVV_cryptosha3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e281800: SHA1SU1  <Vd>.4S, <Vn>.4S
   Instruction Set: A64  Groups: cryptosha2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA1SU1_VV_cryptosha2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha1 /*FEAT_SHA1*/)
    {
        LogFlow(("%018x/%010x: SHA1SU1_VV_cryptosha2 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SHA1SU1_VV_cryptosha2
        IEM_INSTR_IMPL_A64__SHA1SU1_VV_cryptosha2(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e005000: SHA256H2  <Qd>, <Qn>, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA256H2_QQV_cryptosha3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e005000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha256 /*FEAT_SHA256*/)
        {
            LogFlow(("%018x/%010x: SHA256H2_QQV_cryptosha3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA256H2_QQV_cryptosha3
            IEM_INSTR_IMPL_A64__SHA256H2_QQV_cryptosha3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e004000: SHA256H  <Qd>, <Qn>, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA256H_QQV_cryptosha3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e004000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha256 /*FEAT_SHA256*/)
        {
            LogFlow(("%018x/%010x: SHA256H_QQV_cryptosha3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA256H_QQV_cryptosha3
            IEM_INSTR_IMPL_A64__SHA256H_QQV_cryptosha3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/5e282800: SHA256SU0  <Vd>.4S, <Vn>.4S
   Instruction Set: A64  Groups: cryptosha2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA256SU0_VV_cryptosha2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e282800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha256 /*FEAT_SHA256*/)
        {
            LogFlow(("%018x/%010x: SHA256SU0_VV_cryptosha2 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SHA256SU0_VV_cryptosha2
            IEM_INSTR_IMPL_A64__SHA256SU0_VV_cryptosha2(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5e006000: SHA256SU1  <Vd>.4S, <Vn>.4S, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA256SU1_VVV_cryptosha3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e006000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha256 /*FEAT_SHA256*/)
        {
            LogFlow(("%018x/%010x: SHA256SU1_VVV_cryptosha3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA256SU1_VVV_cryptosha3
            IEM_INSTR_IMPL_A64__SHA256SU1_VVV_cryptosha3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/ce608400: SHA512H2  <Qd>, <Qn>, <Vm>.2D
   Instruction Set: A64  Groups: cryptosha512_3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA512H2_QQV_cryptosha512_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce608400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha512 /*FEAT_SHA512*/)
        {
            LogFlow(("%018x/%010x: SHA512H2_QQV_cryptosha512_3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA512H2_QQV_cryptosha512_3
            IEM_INSTR_IMPL_A64__SHA512H2_QQV_cryptosha512_3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/ce608000: SHA512H  <Qd>, <Qn>, <Vm>.2D
   Instruction Set: A64  Groups: cryptosha512_3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA512H_QQV_cryptosha512_3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha512 /*FEAT_SHA512*/)
    {
        LogFlow(("%018x/%010x: SHA512H_QQV_cryptosha512_3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA512H_QQV_cryptosha512_3
        IEM_INSTR_IMPL_A64__SHA512H_QQV_cryptosha512_3(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/cec08000: SHA512SU0  <Vd>.2D, <Vn>.2D
   Instruction Set: A64  Groups: cryptosha512_2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA512SU0_VV2_cryptosha512_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xcec08000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha512 /*FEAT_SHA512*/)
        {
            LogFlow(("%018x/%010x: SHA512SU0_VV2_cryptosha512_2 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SHA512SU0_VV2_cryptosha512_2
            IEM_INSTR_IMPL_A64__SHA512SU0_VV2_cryptosha512_2(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/ce608800: SHA512SU1  <Vd>.2D, <Vn>.2D, <Vm>.2D
   Instruction Set: A64  Groups: cryptosha512_3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHA512SU1_VVV2_cryptosha512_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce608800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha512 /*FEAT_SHA512*/)
        {
            LogFlow(("%018x/%010x: SHA512SU1_VVV2_cryptosha512_3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SHA512SU1_VVV2_cryptosha512_3
            IEM_INSTR_IMPL_A64__SHA512SU1_VVV2_cryptosha512_3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e200400: SHADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHADD_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e200400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SHADD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SHADD_asimdsame_only
            IEM_INSTR_IMPL_A64__SHADD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e213800: SHLL2  <Vd>.<Ta>, <Vn>.<Tb>, #<shift>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHLL_asimdmisc_S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SHLL_asimdmisc_S Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SHLL_asimdmisc_S
        IEM_INSTR_IMPL_A64__SHLL_asimdmisc_S(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f005400: SHL  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHL_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SHL_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SHL_asimdshf_R
        IEM_INSTR_IMPL_A64__SHL_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f005400: SHL  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHL_asisdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
    {
        LogFlow(("%018x/%010x: SHL_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SHL_asisdshf_R
        IEM_INSTR_IMPL_A64__SHL_asisdshf_R(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f008400: SHRN2  <Vd>.<Tb>, <Vn>.<Ta>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHRN_asimdshf_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f008400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
        {
            LogFlow(("%018x/%010x: SHRN_asimdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SHRN_asimdshf_N
            IEM_INSTR_IMPL_A64__SHRN_asimdshf_N(Rd, Rn, immb, immh, Q);
#else
            RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e202400: SHSUB  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SHSUB_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e202400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SHSUB_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SHSUB_asimdsame_only
            IEM_INSTR_IMPL_A64__SHSUB_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f005400: SLI  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SLI_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SLI_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SLI_asimdshf_R
        IEM_INSTR_IMPL_A64__SLI_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f005400: SLI  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SLI_asisdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f005400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
        {
            LogFlow(("%018x/%010x: SLI_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SLI_asisdshf_R
            IEM_INSTR_IMPL_A64__SLI_asisdshf_R(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/ce60c000: SM3PARTW1  <Vd>.4S, <Vn>.4S, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha512_3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM3PARTW1_VVV4_cryptosha512_3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm3 /*FEAT_SM3*/)
    {
        LogFlow(("%018x/%010x: SM3PARTW1_VVV4_cryptosha512_3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SM3PARTW1_VVV4_cryptosha512_3
        IEM_INSTR_IMPL_A64__SM3PARTW1_VVV4_cryptosha512_3(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/ce60c400: SM3PARTW2  <Vd>.4S, <Vn>.4S, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha512_3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM3PARTW2_VVV4_cryptosha512_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce60c400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm3 /*FEAT_SM3*/)
        {
            LogFlow(("%018x/%010x: SM3PARTW2_VVV4_cryptosha512_3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SM3PARTW2_VVV4_cryptosha512_3
            IEM_INSTR_IMPL_A64__SM3PARTW2_VVV4_cryptosha512_3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/ce400000: SM3SS1  <Vd>.4S, <Vn>.4S, <Vm>.4S, <Va>.4S
   Instruction Set: A64  Groups: crypto4, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM3SS1_VVV4_crypto4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm3 /*FEAT_SM3*/)
        {
            LogFlow(("%018x/%010x: SM3SS1_VVV4_crypto4 Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__SM3SS1_VVV4_crypto4
            IEM_INSTR_IMPL_A64__SM3SS1_VVV4_crypto4(Rd, Rn, Ra, Rm);
#else
            RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0cc00/ce408000: SM3TT1A  <Vd>.4S, <Vn>.4S, <Vm>.S[<imm2>]
   Instruction Set: A64  Groups: crypto3_imm2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM3TT1A_VVV4_crypto3_imm2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0cc00)) == UINT32_C(0xce408000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm2       = (uOpcode >> 12) & 0x00000003;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm3 /*FEAT_SM3*/)
        {
            LogFlow(("%018x/%010x: SM3TT1A_VVV4_crypto3_imm2 Rd=%#x Rn=%#x imm2=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm2, Rm));
#ifdef IEM_INSTR_IMPL_A64__SM3TT1A_VVV4_crypto3_imm2
            IEM_INSTR_IMPL_A64__SM3TT1A_VVV4_crypto3_imm2(Rd, Rn, imm2, Rm);
#else
            RT_NOREF(Rd, Rn, imm2, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0cc00/ce408400: SM3TT1B  <Vd>.4S, <Vn>.4S, <Vm>.S[<imm2>]
   Instruction Set: A64  Groups: crypto3_imm2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM3TT1B_VVV4_crypto3_imm2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0cc00)) == UINT32_C(0xce408400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm2       = (uOpcode >> 12) & 0x00000003;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm3 /*FEAT_SM3*/)
        {
            LogFlow(("%018x/%010x: SM3TT1B_VVV4_crypto3_imm2 Rd=%#x Rn=%#x imm2=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm2, Rm));
#ifdef IEM_INSTR_IMPL_A64__SM3TT1B_VVV4_crypto3_imm2
            IEM_INSTR_IMPL_A64__SM3TT1B_VVV4_crypto3_imm2(Rd, Rn, imm2, Rm);
#else
            RT_NOREF(Rd, Rn, imm2, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0cc00/ce408800: SM3TT2A  <Vd>.4S, <Vn>.4S, <Vm>.S[<imm2>]
   Instruction Set: A64  Groups: crypto3_imm2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM3TT2A_VVV4_crypto3_imm2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0cc00)) == UINT32_C(0xce408800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm2       = (uOpcode >> 12) & 0x00000003;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm3 /*FEAT_SM3*/)
        {
            LogFlow(("%018x/%010x: SM3TT2A_VVV4_crypto3_imm2 Rd=%#x Rn=%#x imm2=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm2, Rm));
#ifdef IEM_INSTR_IMPL_A64__SM3TT2A_VVV4_crypto3_imm2
            IEM_INSTR_IMPL_A64__SM3TT2A_VVV4_crypto3_imm2(Rd, Rn, imm2, Rm);
#else
            RT_NOREF(Rd, Rn, imm2, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0cc00/ce408c00: SM3TT2B  <Vd>.4S, <Vn>.4S, <Vm>.S[<imm2>]
   Instruction Set: A64  Groups: crypto3_imm2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM3TT2B_VVV_crypto3_imm2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0cc00)) == UINT32_C(0xce408c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm2       = (uOpcode >> 12) & 0x00000003;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm3 /*FEAT_SM3*/)
        {
            LogFlow(("%018x/%010x: SM3TT2B_VVV_crypto3_imm2 Rd=%#x Rn=%#x imm2=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm2, Rm));
#ifdef IEM_INSTR_IMPL_A64__SM3TT2B_VVV_crypto3_imm2
            IEM_INSTR_IMPL_A64__SM3TT2B_VVV_crypto3_imm2(Rd, Rn, imm2, Rm);
#else
            RT_NOREF(Rd, Rn, imm2, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/ce60c800: SM4EKEY  <Vd>.4S, <Vn>.4S, <Vm>.4S
   Instruction Set: A64  Groups: cryptosha512_3, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce60c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm4 /*FEAT_SM4*/)
        {
            LogFlow(("%018x/%010x: SM4EKEY_VVV4_cryptosha512_3 Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SM4EKEY_VVV4_cryptosha512_3
            IEM_INSTR_IMPL_A64__SM4EKEY_VVV4_cryptosha512_3(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/cec08400: SM4E  <Vd>.4S, <Vn>.4S
   Instruction Set: A64  Groups: cryptosha512_2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SM4E_VV4_cryptosha512_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xcec08400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSm4 /*FEAT_SM4*/)
        {
            LogFlow(("%018x/%010x: SM4E_VV4_cryptosha512_2 Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__SM4E_VV4_cryptosha512_2
            IEM_INSTR_IMPL_A64__SM4E_VV4_cryptosha512_2(Rd, Rn);
#else
            RT_NOREF(Rd, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/9b200000: SMADDL  <Xd>, <Wn>, <Wm>, <Xa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SMADDL_64WA_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SMADDL_64WA_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__SMADDL_64WA_dp_3src
    IEM_INSTR_IMPL_A64__SMADDL_64WA_dp_3src(Rd, Rn, Ra, Rm);
#else
    RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf20fc00/0e20a400: SMAXP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMAXP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20a400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMAXP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMAXP_asimdsame_only
            IEM_INSTR_IMPL_A64__SMAXP_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e30a800: SMAXV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMAXV_asimdall_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SMAXV_asimdall_only Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMAXV_asimdall_only
        IEM_INSTR_IMPL_A64__SMAXV_asimdall_only(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac06000: SMAX  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SMAX_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: SMAX_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SMAX_32_dp_2src
        IEM_INSTR_IMPL_A64__SMAX_32_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/11c00000: SMAX  <Wd>, <Wn>, #<simm>
   Instruction Set: A64  Groups: minmax_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SMAX_32_minmax_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 10) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: SMAX_32_minmax_imm Rd=%#x Rn=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm8));
#ifdef IEM_INSTR_IMPL_A64__SMAX_32_minmax_imm
        IEM_INSTR_IMPL_A64__SMAX_32_minmax_imm(Rd, Rn, imm8);
#else
        RT_NOREF(Rd, Rn, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac06000: SMAX  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SMAX_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: SMAX_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SMAX_64_dp_2src
        IEM_INSTR_IMPL_A64__SMAX_64_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/91c00000: SMAX  <Xd>, <Xn>, #<simm>
   Instruction Set: A64  Groups: minmax_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SMAX_64_minmax_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 10) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: SMAX_64_minmax_imm Rd=%#x Rn=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm8));
#ifdef IEM_INSTR_IMPL_A64__SMAX_64_minmax_imm
        IEM_INSTR_IMPL_A64__SMAX_64_minmax_imm(Rd, Rn, imm8);
#else
        RT_NOREF(Rd, Rn, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e206400: SMAX  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMAX_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e206400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMAX_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMAX_asimdsame_only
            IEM_INSTR_IMPL_A64__SMAX_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/d4000003: SMC  #<imm>
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_SMC_EX_exception, uint32_t, uOpcode)
{
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    LogFlow(("%018x/%010x: SMC_EX_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__SMC_EX_exception
    IEM_INSTR_IMPL_A64__SMC_EX_exception(imm16);
#else
    RT_NOREF(imm16, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf20fc00/0e20ac00: SMINP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMINP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20ac00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMINP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMINP_asimdsame_only
            IEM_INSTR_IMPL_A64__SMINP_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e31a800: SMINV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMINV_asimdall_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SMINV_asimdall_only Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMINV_asimdall_only
        IEM_INSTR_IMPL_A64__SMINV_asimdall_only(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac06800: SMIN  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SMIN_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: SMIN_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SMIN_32_dp_2src
        IEM_INSTR_IMPL_A64__SMIN_32_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/11c80000: SMIN  <Wd>, <Wn>, #<simm>
   Instruction Set: A64  Groups: minmax_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SMIN_32_minmax_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 10) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: SMIN_32_minmax_imm Rd=%#x Rn=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm8));
#ifdef IEM_INSTR_IMPL_A64__SMIN_32_minmax_imm
        IEM_INSTR_IMPL_A64__SMIN_32_minmax_imm(Rd, Rn, imm8);
#else
        RT_NOREF(Rd, Rn, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac06800: SMIN  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SMIN_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: SMIN_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SMIN_64_dp_2src
        IEM_INSTR_IMPL_A64__SMIN_64_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/91c80000: SMIN  <Xd>, <Xn>, #<simm>
   Instruction Set: A64  Groups: minmax_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SMIN_64_minmax_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 10) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: SMIN_64_minmax_imm Rd=%#x Rn=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm8));
#ifdef IEM_INSTR_IMPL_A64__SMIN_64_minmax_imm
        IEM_INSTR_IMPL_A64__SMIN_64_minmax_imm(Rd, Rn, imm8);
#else
        RT_NOREF(Rd, Rn, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e206c00: SMIN  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMIN_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e206c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMIN_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMIN_asimdsame_only
            IEM_INSTR_IMPL_A64__SMIN_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e208000: SMLAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMLAL_asimddiff_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SMLAL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMLAL_asimddiff_L
        IEM_INSTR_IMPL_A64__SMLAL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/0f002000: SMLAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMLAL_asimdelem_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f002000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMLAL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMLAL_asimdelem_L
            IEM_INSTR_IMPL_A64__SMLAL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e20a000: SMLSL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMLSL_asimddiff_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SMLSL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMLSL_asimddiff_L
        IEM_INSTR_IMPL_A64__SMLSL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/0f006000: SMLSL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMLSL_asimdelem_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f006000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMLSL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMLSL_asimdelem_L
            IEM_INSTR_IMPL_A64__SMLSL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4e80a400: SMMLA  <Vd>.4S, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMMLA_asimdsame2_G, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4e80a400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
        {
            LogFlow(("%018x/%010x: SMMLA_asimdsame2_G Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SMMLA_asimdsame2_G
            IEM_INSTR_IMPL_A64__SMMLA_asimdsame2_G(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/0e002c00: SMOV  <Wd>, <Vn>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdins, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMOV_asimdins_W_w, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0e002c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMOV_asimdins_W_w Rd=%#x Rn=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm5));
#ifdef IEM_INSTR_IMPL_A64__SMOV_asimdins_W_w
            IEM_INSTR_IMPL_A64__SMOV_asimdins_W_w(Rd, Rn, imm5);
#else
            RT_NOREF(Rd, Rn, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4e002c00: SMOV  <Xd>, <Vn>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdins, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMOV_asimdins_X_x, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SMOV_asimdins_X_x Rd=%#x Rn=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm5));
#ifdef IEM_INSTR_IMPL_A64__SMOV_asimdins_X_x
        IEM_INSTR_IMPL_A64__SMOV_asimdins_X_x(Rd, Rn, imm5);
#else
        RT_NOREF(Rd, Rn, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/9b208000: SMSUBL  <Xd>, <Wn>, <Wm>, <Xa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SMSUBL_64WA_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SMSUBL_64WA_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__SMSUBL_64WA_dp_3src
    IEM_INSTR_IMPL_A64__SMSUBL_64WA_dp_3src(Rd, Rn, Ra, Rm);
#else
    RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9b407c00: SMULH  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SMULH_64_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SMULH_64_dp_3src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SMULH_64_dp_3src
    IEM_INSTR_IMPL_A64__SMULH_64_dp_3src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf20fc00/0e20c000: SMULL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMULL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMULL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMULL_asimddiff_L
            IEM_INSTR_IMPL_A64__SMULL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/0f00a000: SMULL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SMULL_asimdelem_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f00a000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SMULL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SMULL_asimdelem_L
            IEM_INSTR_IMPL_A64__SMULL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e207800: SQABS  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQABS_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e207800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQABS_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQABS_asimdmisc_R
            IEM_INSTR_IMPL_A64__SQABS_asimdmisc_R(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/5e207800: SQABS  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQABS_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x5e207800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQABS_asisdmisc_R Rd=%#x Rn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size));
#ifdef IEM_INSTR_IMPL_A64__SQABS_asisdmisc_R
            IEM_INSTR_IMPL_A64__SQABS_asisdmisc_R(Rd, Rn, size);
#else
            RT_NOREF(Rd, Rn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e200c00: SQADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQADD_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQADD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQADD_asimdsame_only
        IEM_INSTR_IMPL_A64__SQADD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/5e200c00: SQADD  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQADD_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQADD_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQADD_asisdsame_only
        IEM_INSTR_IMPL_A64__SQADD_asisdsame_only(Rd, Rn, Rm, size);
#else
        RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e209000: SQDMLAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMLAL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e209000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMLAL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQDMLAL_asimddiff_L
            IEM_INSTR_IMPL_A64__SQDMLAL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/0f003000: SQDMLAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMLAL_asimdelem_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQDMLAL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQDMLAL_asimdelem_L
        IEM_INSTR_IMPL_A64__SQDMLAL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/5e209000: SQDMLAL  <Va><d>, <Vb><n>, <Vb><m>
   Instruction Set: A64  Groups: asisddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMLAL_asisddiff_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e209000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMLAL_asisddiff_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQDMLAL_asisddiff_only
            IEM_INSTR_IMPL_A64__SQDMLAL_asisddiff_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff00f400/5f003000: SQDMLAL  <Va><d>, <Vb><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMLAL_asisdelem_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQDMLAL_asisdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size));
#ifdef IEM_INSTR_IMPL_A64__SQDMLAL_asisdelem_L
        IEM_INSTR_IMPL_A64__SQDMLAL_asisdelem_L(Rd, Rn, H, Rm, M, L, size);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e20b000: SQDMLSL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMLSL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20b000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMLSL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQDMLSL_asimddiff_L
            IEM_INSTR_IMPL_A64__SQDMLSL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/0f007000: SQDMLSL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMLSL_asimdelem_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQDMLSL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQDMLSL_asimdelem_L
        IEM_INSTR_IMPL_A64__SQDMLSL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/5e20b000: SQDMLSL  <Va><d>, <Vb><n>, <Vb><m>
   Instruction Set: A64  Groups: asisddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMLSL_asisddiff_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e20b000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMLSL_asisddiff_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQDMLSL_asisddiff_only
            IEM_INSTR_IMPL_A64__SQDMLSL_asisddiff_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff00f400/5f007000: SQDMLSL  <Va><d>, <Vb><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMLSL_asisdelem_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQDMLSL_asisdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size));
#ifdef IEM_INSTR_IMPL_A64__SQDMLSL_asisdelem_L
        IEM_INSTR_IMPL_A64__SQDMLSL_asisdelem_L(Rd, Rn, H, Rm, M, L, size);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/0f00c000: SQDMULH  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMULH_asimdelem_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f00c000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMULH_asimdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQDMULH_asimdelem_R
            IEM_INSTR_IMPL_A64__SQDMULH_asimdelem_R(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e20b400: SQDMULH  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMULH_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQDMULH_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQDMULH_asimdsame_only
        IEM_INSTR_IMPL_A64__SQDMULH_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff00f400/5f00c000: SQDMULH  <V><d>, <V><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMULH_asisdelem_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f00c000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMULH_asisdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size));
#ifdef IEM_INSTR_IMPL_A64__SQDMULH_asisdelem_R
            IEM_INSTR_IMPL_A64__SQDMULH_asisdelem_R(Rd, Rn, H, Rm, M, L, size);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/5e20b400: SQDMULH  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMULH_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQDMULH_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQDMULH_asisdsame_only
        IEM_INSTR_IMPL_A64__SQDMULH_asisdsame_only(Rd, Rn, Rm, size);
#else
        RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e20d000: SQDMULL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMULL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20d000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMULL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQDMULL_asimddiff_L
            IEM_INSTR_IMPL_A64__SQDMULL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/0f00b000: SQDMULL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMULL_asimdelem_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f00b000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMULL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQDMULL_asimdelem_L
            IEM_INSTR_IMPL_A64__SQDMULL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/5e20d000: SQDMULL  <Va><d>, <Vb><n>, <Vb><m>
   Instruction Set: A64  Groups: asisddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMULL_asisddiff_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e20d000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMULL_asisddiff_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQDMULL_asisddiff_only
            IEM_INSTR_IMPL_A64__SQDMULL_asisddiff_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff00f400/5f00b000: SQDMULL  <Va><d>, <Vb><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQDMULL_asisdelem_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f00b000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQDMULL_asisdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size));
#ifdef IEM_INSTR_IMPL_A64__SQDMULL_asisdelem_L
            IEM_INSTR_IMPL_A64__SQDMULL_asisdelem_L(Rd, Rn, H, Rm, M, L, size);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e207800: SQNEG  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQNEG_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQNEG_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQNEG_asimdmisc_R
        IEM_INSTR_IMPL_A64__SQNEG_asimdmisc_R(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/7e207800: SQNEG  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQNEG_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x7e207800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQNEG_asisdmisc_R Rd=%#x Rn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size));
#ifdef IEM_INSTR_IMPL_A64__SQNEG_asisdmisc_R
            IEM_INSTR_IMPL_A64__SQNEG_asisdmisc_R(Rd, Rn, size);
#else
            RT_NOREF(Rd, Rn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/2f00d000: SQRDMLAH  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMLAH_asimdelem_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRdm /*FEAT_RDM*/)
    {
        LogFlow(("%018x/%010x: SQRDMLAH_asimdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRDMLAH_asimdelem_R
        IEM_INSTR_IMPL_A64__SQRDMLAH_asimdelem_R(Rd, Rn, H, Rm, M, L, size, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e008400: SQRDMLAH  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMLAH_asimdsame2_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRdm /*FEAT_RDM*/)
    {
        LogFlow(("%018x/%010x: SQRDMLAH_asimdsame2_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRDMLAH_asimdsame2_only
        IEM_INSTR_IMPL_A64__SQRDMLAH_asimdsame2_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff00f400/7f00d000: SQRDMLAH  <V><d>, <V><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMLAH_asisdelem_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x7f00d000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRdm /*FEAT_RDM*/)
        {
            LogFlow(("%018x/%010x: SQRDMLAH_asisdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size));
#ifdef IEM_INSTR_IMPL_A64__SQRDMLAH_asisdelem_R
            IEM_INSTR_IMPL_A64__SQRDMLAH_asisdelem_R(Rd, Rn, H, Rm, M, L, size);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/7e008400: SQRDMLAH  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMLAH_asisdsame2_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x7e008400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRdm /*FEAT_RDM*/)
        {
            LogFlow(("%018x/%010x: SQRDMLAH_asisdsame2_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQRDMLAH_asisdsame2_only
            IEM_INSTR_IMPL_A64__SQRDMLAH_asisdsame2_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/2f00f000: SQRDMLSH  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMLSH_asimdelem_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x2f00f000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRdm /*FEAT_RDM*/)
        {
            LogFlow(("%018x/%010x: SQRDMLSH_asimdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRDMLSH_asimdelem_R
            IEM_INSTR_IMPL_A64__SQRDMLSH_asimdelem_R(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e008c00: SQRDMLSH  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMLSH_asimdsame2_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e008c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRdm /*FEAT_RDM*/)
        {
            LogFlow(("%018x/%010x: SQRDMLSH_asimdsame2_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRDMLSH_asimdsame2_only
            IEM_INSTR_IMPL_A64__SQRDMLSH_asimdsame2_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff00f400/7f00f000: SQRDMLSH  <V><d>, <V><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMLSH_asisdelem_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x7f00f000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRdm /*FEAT_RDM*/)
        {
            LogFlow(("%018x/%010x: SQRDMLSH_asisdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size));
#ifdef IEM_INSTR_IMPL_A64__SQRDMLSH_asisdelem_R
            IEM_INSTR_IMPL_A64__SQRDMLSH_asisdelem_R(Rd, Rn, H, Rm, M, L, size);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/7e008c00: SQRDMLSH  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMLSH_asisdsame2_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x7e008c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fRdm /*FEAT_RDM*/)
        {
            LogFlow(("%018x/%010x: SQRDMLSH_asisdsame2_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQRDMLSH_asisdsame2_only
            IEM_INSTR_IMPL_A64__SQRDMLSH_asisdsame2_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/0f00d000: SQRDMULH  <Vd>.<T>, <Vn>.<T>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMULH_asimdelem_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQRDMULH_asimdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRDMULH_asimdelem_R
        IEM_INSTR_IMPL_A64__SQRDMULH_asimdelem_R(Rd, Rn, H, Rm, M, L, size, Q);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e20b400: SQRDMULH  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMULH_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQRDMULH_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRDMULH_asimdsame_only
        IEM_INSTR_IMPL_A64__SQRDMULH_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff00f400/5f00d000: SQRDMULH  <V><d>, <V><n>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asisdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMULH_asisdelem_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const H          = (uOpcode >> 11) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const M          = (uOpcode >> 20) & 0x00000001;
    uint32_t const L          = (uOpcode >> 21) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQRDMULH_asisdelem_R Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size));
#ifdef IEM_INSTR_IMPL_A64__SQRDMULH_asisdelem_R
        IEM_INSTR_IMPL_A64__SQRDMULH_asisdelem_R(Rd, Rn, H, Rm, M, L, size);
#else
        RT_NOREF(Rd, Rn, H, Rm, M, L, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/7e20b400: SQRDMULH  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRDMULH_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQRDMULH_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQRDMULH_asisdsame_only
        IEM_INSTR_IMPL_A64__SQRDMULH_asisdsame_only(Rd, Rn, Rm, size);
#else
        RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e205c00: SQRSHL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRSHL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQRSHL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRSHL_asimdsame_only
        IEM_INSTR_IMPL_A64__SQRSHL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/5e205c00: SQRSHL  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRSHL_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQRSHL_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQRSHL_asisdsame_only
        IEM_INSTR_IMPL_A64__SQRSHL_asisdsame_only(Rd, Rn, Rm, size);
#else
        RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f009c00: SQRSHRN2  <Vd>.<Tb>, <Vn>.<Ta>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRSHRN_asimdshf_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SQRSHRN_asimdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRSHRN_asimdshf_N
        IEM_INSTR_IMPL_A64__SQRSHRN_asimdshf_N(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f009c00: SQRSHRN  <Vb><d>, <Va><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRSHRN_asisdshf_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
    {
        LogFlow(("%018x/%010x: SQRSHRN_asisdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SQRSHRN_asisdshf_N
        IEM_INSTR_IMPL_A64__SQRSHRN_asisdshf_N(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f008c00: SQRSHRUN2  <Vd>.<Tb>, <Vn>.<Ta>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRSHRUN_asimdshf_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f008c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
        {
            LogFlow(("%018x/%010x: SQRSHRUN_asimdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SQRSHRUN_asimdshf_N
            IEM_INSTR_IMPL_A64__SQRSHRUN_asimdshf_N(Rd, Rn, immb, immh, Q);
#else
            RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f008c00: SQRSHRUN  <Vb><d>, <Va><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQRSHRUN_asisdshf_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f008c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
        {
            LogFlow(("%018x/%010x: SQRSHRUN_asisdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SQRSHRUN_asisdshf_N
            IEM_INSTR_IMPL_A64__SQRSHRUN_asisdshf_N(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f006400: SQSHLU  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHLU_asimdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f006400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
        {
            LogFlow(("%018x/%010x: SQSHLU_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SQSHLU_asimdshf_R
            IEM_INSTR_IMPL_A64__SQSHLU_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
            RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f006400: SQSHLU  <V><d>, <V><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHLU_asisdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f006400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
        {
            LogFlow(("%018x/%010x: SQSHLU_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SQSHLU_asisdshf_R
            IEM_INSTR_IMPL_A64__SQSHLU_asisdshf_R(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e204c00: SQSHL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQSHL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQSHL_asimdsame_only
        IEM_INSTR_IMPL_A64__SQSHL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f007400: SQSHL  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHL_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SQSHL_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SQSHL_asimdshf_R
        IEM_INSTR_IMPL_A64__SQSHL_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/5e204c00: SQSHL  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHL_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQSHL_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQSHL_asisdsame_only
        IEM_INSTR_IMPL_A64__SQSHL_asisdsame_only(Rd, Rn, Rm, size);
#else
        RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f007400: SQSHL  <V><d>, <V><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHL_asisdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
    {
        LogFlow(("%018x/%010x: SQSHL_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SQSHL_asisdshf_R
        IEM_INSTR_IMPL_A64__SQSHL_asisdshf_R(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f009400: SQSHRN2  <Vd>.<Tb>, <Vn>.<Ta>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHRN_asimdshf_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SQSHRN_asimdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SQSHRN_asimdshf_N
        IEM_INSTR_IMPL_A64__SQSHRN_asimdshf_N(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f009400: SQSHRN  <Vb><d>, <Va><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHRN_asisdshf_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
    {
        LogFlow(("%018x/%010x: SQSHRN_asisdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SQSHRN_asisdshf_N
        IEM_INSTR_IMPL_A64__SQSHRN_asisdshf_N(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f008400: SQSHRUN2  <Vd>.<Tb>, <Vn>.<Ta>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHRUN_asimdshf_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f008400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
        {
            LogFlow(("%018x/%010x: SQSHRUN_asimdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SQSHRUN_asimdshf_N
            IEM_INSTR_IMPL_A64__SQSHRUN_asimdshf_N(Rd, Rn, immb, immh, Q);
#else
            RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f008400: SQSHRUN  <Vb><d>, <Va><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSHRUN_asisdshf_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f008400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
        {
            LogFlow(("%018x/%010x: SQSHRUN_asisdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SQSHRUN_asisdshf_N
            IEM_INSTR_IMPL_A64__SQSHRUN_asisdshf_N(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e202c00: SQSUB  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSUB_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQSUB_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQSUB_asimdsame_only
        IEM_INSTR_IMPL_A64__SQSUB_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/5e202c00: SQSUB  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQSUB_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQSUB_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__SQSUB_asisdsame_only
        IEM_INSTR_IMPL_A64__SQSUB_asisdsame_only(Rd, Rn, Rm, size);
#else
        RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e214800: SQXTN2  <Vd>.<Tb>, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQXTN_asimdmisc_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQXTN_asimdmisc_N Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQXTN_asimdmisc_N
        IEM_INSTR_IMPL_A64__SQXTN_asimdmisc_N(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/5e214800: SQXTN  <Vb><d>, <Va><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQXTN_asisdmisc_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x5e214800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQXTN_asisdmisc_N Rd=%#x Rn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size));
#ifdef IEM_INSTR_IMPL_A64__SQXTN_asisdmisc_N
            IEM_INSTR_IMPL_A64__SQXTN_asisdmisc_N(Rd, Rn, size);
#else
            RT_NOREF(Rd, Rn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e212800: SQXTUN2  <Vd>.<Tb>, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQXTUN_asimdmisc_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SQXTUN_asimdmisc_N Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SQXTUN_asimdmisc_N
        IEM_INSTR_IMPL_A64__SQXTUN_asimdmisc_N(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/7e212800: SQXTUN  <Vb><d>, <Va><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SQXTUN_asisdmisc_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x7e212800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SQXTUN_asisdmisc_N Rd=%#x Rn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size));
#ifdef IEM_INSTR_IMPL_A64__SQXTUN_asisdmisc_N
            IEM_INSTR_IMPL_A64__SQXTUN_asisdmisc_N(Rd, Rn, size);
#else
            RT_NOREF(Rd, Rn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e201400: SRHADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRHADD_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e201400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SRHADD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SRHADD_asimdsame_only
            IEM_INSTR_IMPL_A64__SRHADD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f004400: SRI  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRI_asimdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f004400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
        {
            LogFlow(("%018x/%010x: SRI_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SRI_asimdshf_R
            IEM_INSTR_IMPL_A64__SRI_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
            RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f004400: SRI  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRI_asisdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f004400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
        {
            LogFlow(("%018x/%010x: SRI_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SRI_asisdshf_R
            IEM_INSTR_IMPL_A64__SRI_asisdshf_R(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e205400: SRSHL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRSHL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SRSHL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SRSHL_asimdsame_only
        IEM_INSTR_IMPL_A64__SRSHL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5ee05400: SRSHL  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRSHL_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SRSHL_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SRSHL_asisdsame_only
        IEM_INSTR_IMPL_A64__SRSHL_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f002400: SRSHR  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRSHR_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SRSHR_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SRSHR_asimdshf_R
        IEM_INSTR_IMPL_A64__SRSHR_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f002400: SRSHR  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRSHR_asisdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
    {
        LogFlow(("%018x/%010x: SRSHR_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SRSHR_asisdshf_R
        IEM_INSTR_IMPL_A64__SRSHR_asisdshf_R(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f003400: SRSRA  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRSRA_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SRSRA_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SRSRA_asimdshf_R
        IEM_INSTR_IMPL_A64__SRSRA_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f003400: SRSRA  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SRSRA_asisdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
    {
        LogFlow(("%018x/%010x: SRSRA_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SRSRA_asisdshf_R
        IEM_INSTR_IMPL_A64__SRSRA_asisdshf_R(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f00a400: SSHLL2  <Vd>.<Ta>, <Vn>.<Tb>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSHLL_asimdshf_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f00a400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
        {
            LogFlow(("%018x/%010x: SSHLL_asimdshf_L Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SSHLL_asimdshf_L
            IEM_INSTR_IMPL_A64__SSHLL_asimdshf_L(Rd, Rn, immb, immh, Q);
#else
            RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e204400: SSHL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSHL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SSHL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SSHL_asimdsame_only
        IEM_INSTR_IMPL_A64__SSHL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/5ee04400: SSHL  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSHL_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SSHL_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SSHL_asisdsame_only
        IEM_INSTR_IMPL_A64__SSHL_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f000400: SSHR  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSHR_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SSHR_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SSHR_asimdshf_R
        IEM_INSTR_IMPL_A64__SSHR_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f000400: SSHR  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSHR_asisdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
    {
        LogFlow(("%018x/%010x: SSHR_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SSHR_asisdshf_R
        IEM_INSTR_IMPL_A64__SSHR_asisdshf_R(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/0f001400: SSRA  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSRA_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: SSRA_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__SSRA_asimdshf_R
        IEM_INSTR_IMPL_A64__SSRA_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/5f001400: SSRA  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSRA_asisdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
    {
        LogFlow(("%018x/%010x: SSRA_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__SSRA_asisdshf_R
        IEM_INSTR_IMPL_A64__SSRA_asisdshf_R(Rd, Rn, immb, immh);
#else
        RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e202000: SSUBL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSUBL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e202000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SSUBL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SSUBL_asimddiff_L
            IEM_INSTR_IMPL_A64__SSUBL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e203000: SSUBW2  <Vd>.<Ta>, <Vn>.<Ta>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SSUBW_asimddiff_W, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e203000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SSUBW_asimddiff_W Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SSUBW_asimddiff_W
            IEM_INSTR_IMPL_A64__SSUBW_asimddiff_W(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c007000: ST1  { <Vt>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlse_R1_1v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c007000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST1_asisdlse_R1_1v Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlse_R1_1v
            IEM_INSTR_IMPL_A64__ST1_asisdlse_R1_1v(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c00a000: ST1  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlse_R2_2v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c00a000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST1_asisdlse_R2_2v Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlse_R2_2v
            IEM_INSTR_IMPL_A64__ST1_asisdlse_R2_2v(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c006000: ST1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlse_R3_3v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c006000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST1_asisdlse_R3_3v Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlse_R3_3v
            IEM_INSTR_IMPL_A64__ST1_asisdlse_R3_3v(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c002000: ST1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlse_R4_4v, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c002000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST1_asisdlse_R4_4v Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlse_R4_4v
            IEM_INSTR_IMPL_A64__ST1_asisdlse_R4_4v(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c9f7000: ST1  { <Vt>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsep_I1_i1, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlsep_I1_i1 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsep_I1_i1
        IEM_INSTR_IMPL_A64__ST1_asisdlsep_I1_i1(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c9fa000: ST1  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsep_I2_i2, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlsep_I2_i2 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsep_I2_i2
        IEM_INSTR_IMPL_A64__ST1_asisdlsep_I2_i2(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c9f6000: ST1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsep_I3_i3, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlsep_I3_i3 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsep_I3_i3
        IEM_INSTR_IMPL_A64__ST1_asisdlsep_I3_i3(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c9f2000: ST1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsep_I4_i4, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlsep_I4_i4 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsep_I4_i4
        IEM_INSTR_IMPL_A64__ST1_asisdlsep_I4_i4(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0c807000: ST1  { <Vt>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsep_R1_r1, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST1_asisdlsep_R1_r1 Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsep_R1_r1
        IEM_INSTR_IMPL_A64__ST1_asisdlsep_R1_r1(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0c80a000: ST1  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsep_R2_r2, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST1_asisdlsep_R2_r2 Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsep_R2_r2
        IEM_INSTR_IMPL_A64__ST1_asisdlsep_R2_r2(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0c806000: ST1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsep_R3_r3, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST1_asisdlsep_R3_r3 Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsep_R3_r3
        IEM_INSTR_IMPL_A64__ST1_asisdlsep_R3_r3(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0c802000: ST1  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsep_R4_r4, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST1_asisdlsep_R4_r4 Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsep_R4_r4
        IEM_INSTR_IMPL_A64__ST1_asisdlsep_R4_r4(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d000000: ST1  { <Vt>.B }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlso_B1_1b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d000000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST1_asisdlso_B1_1b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlso_B1_1b
            IEM_INSTR_IMPL_A64__ST1_asisdlso_B1_1b(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d008400: ST1  { <Vt>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlso_D1_1d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlso_D1_1d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlso_D1_1d
        IEM_INSTR_IMPL_A64__ST1_asisdlso_D1_1d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d004000: ST1  { <Vt>.H }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlso_H1_1h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d004000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST1_asisdlso_H1_1h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlso_H1_1h
            IEM_INSTR_IMPL_A64__ST1_asisdlso_H1_1h(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d008000: ST1  { <Vt>.S }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlso_S1_1s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d008000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST1_asisdlso_S1_1s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlso_S1_1s
            IEM_INSTR_IMPL_A64__ST1_asisdlso_S1_1s(Rt, Rn, S, Q);
#else
            RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d9f0000: ST1  { <Vt>.B }[<index>], [<Xn|SP>], #1
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsop_B1_i1b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlsop_B1_i1b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsop_B1_i1b
        IEM_INSTR_IMPL_A64__ST1_asisdlsop_B1_i1b(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e000/0d800000: ST1  { <Vt>.B }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsop_BX1_r1b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST1_asisdlsop_BX1_r1b Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsop_BX1_r1b
        IEM_INSTR_IMPL_A64__ST1_asisdlsop_BX1_r1b(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d9f8400: ST1  { <Vt>.D }[<index>], [<Xn|SP>], #8
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsop_D1_i1d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlsop_D1_i1d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsop_D1_i1d
        IEM_INSTR_IMPL_A64__ST1_asisdlsop_D1_i1d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0d808400: ST1  { <Vt>.D }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsop_DX1_r1d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST1_asisdlsop_DX1_r1d Rt=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsop_DX1_r1d
        IEM_INSTR_IMPL_A64__ST1_asisdlsop_DX1_r1d(Rt, Rn, Rm, Q);
#else
        RT_NOREF(Rt, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d9f4000: ST1  { <Vt>.H }[<index>], [<Xn|SP>], #2
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsop_H1_i1h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlsop_H1_i1h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsop_H1_i1h
        IEM_INSTR_IMPL_A64__ST1_asisdlsop_H1_i1h(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e400/0d804000: ST1  { <Vt>.H }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsop_HX1_r1h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST1_asisdlsop_HX1_r1h Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsop_HX1_r1h
        IEM_INSTR_IMPL_A64__ST1_asisdlsop_HX1_r1h(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d9f8000: ST1  { <Vt>.S }[<index>], [<Xn|SP>], #4
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsop_S1_i1s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST1_asisdlsop_S1_i1s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsop_S1_i1s
        IEM_INSTR_IMPL_A64__ST1_asisdlsop_S1_i1s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0ec00/0d808000: ST1  { <Vt>.S }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST1_asisdlsop_SX1_r1s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST1_asisdlsop_SX1_r1s Rt=%#x Rn=%#x S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST1_asisdlsop_SX1_r1s
        IEM_INSTR_IMPL_A64__ST1_asisdlsop_SX1_r1s(Rt, Rn, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9a00800: ST2G  <Xt|SP>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2G_64Soffset_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: ST2G_64Soffset_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__ST2G_64Soffset_ldsttags
        IEM_INSTR_IMPL_A64__ST2G_64Soffset_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9a00400: ST2G  <Xt|SP>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2G_64Spost_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: ST2G_64Spost_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__ST2G_64Spost_ldsttags
        IEM_INSTR_IMPL_A64__ST2G_64Spost_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9a00c00: ST2G  <Xt|SP>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2G_64Spre_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: ST2G_64Spre_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__ST2G_64Spre_ldsttags
        IEM_INSTR_IMPL_A64__ST2G_64Spre_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c008000: ST2  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlse_R2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c008000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST2_asisdlse_R2 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlse_R2
            IEM_INSTR_IMPL_A64__ST2_asisdlse_R2(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c9f8000: ST2  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsep_I2_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST2_asisdlsep_I2_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsep_I2_i
        IEM_INSTR_IMPL_A64__ST2_asisdlsep_I2_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0c808000: ST2  { <Vt>.<T>, <Vt2>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsep_R2_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST2_asisdlsep_R2_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsep_R2_r
        IEM_INSTR_IMPL_A64__ST2_asisdlsep_R2_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d200000: ST2  { <Vt>.B, <Vt2>.B }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlso_B2_2b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d200000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST2_asisdlso_B2_2b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlso_B2_2b
            IEM_INSTR_IMPL_A64__ST2_asisdlso_B2_2b(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d208400: ST2  { <Vt>.D, <Vt2>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlso_D2_2d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d208400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST2_asisdlso_D2_2d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlso_D2_2d
            IEM_INSTR_IMPL_A64__ST2_asisdlso_D2_2d(Rt, Rn, Q);
#else
            RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d204000: ST2  { <Vt>.H, <Vt2>.H }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlso_H2_2h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d204000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST2_asisdlso_H2_2h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlso_H2_2h
            IEM_INSTR_IMPL_A64__ST2_asisdlso_H2_2h(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d208000: ST2  { <Vt>.S, <Vt2>.S }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlso_S2_2s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d208000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST2_asisdlso_S2_2s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlso_S2_2s
            IEM_INSTR_IMPL_A64__ST2_asisdlso_S2_2s(Rt, Rn, S, Q);
#else
            RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0dbf0000: ST2  { <Vt>.B, <Vt2>.B }[<index>], [<Xn|SP>], #2
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsop_B2_i2b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST2_asisdlsop_B2_i2b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsop_B2_i2b
        IEM_INSTR_IMPL_A64__ST2_asisdlsop_B2_i2b(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e000/0da00000: ST2  { <Vt>.B, <Vt2>.B }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsop_BX2_r2b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST2_asisdlsop_BX2_r2b Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsop_BX2_r2b
        IEM_INSTR_IMPL_A64__ST2_asisdlsop_BX2_r2b(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0dbf8400: ST2  { <Vt>.D, <Vt2>.D }[<index>], [<Xn|SP>], #16
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsop_D2_i2d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST2_asisdlsop_D2_i2d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsop_D2_i2d
        IEM_INSTR_IMPL_A64__ST2_asisdlsop_D2_i2d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0da08400: ST2  { <Vt>.D, <Vt2>.D }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsop_DX2_r2d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST2_asisdlsop_DX2_r2d Rt=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsop_DX2_r2d
        IEM_INSTR_IMPL_A64__ST2_asisdlsop_DX2_r2d(Rt, Rn, Rm, Q);
#else
        RT_NOREF(Rt, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0dbf4000: ST2  { <Vt>.H, <Vt2>.H }[<index>], [<Xn|SP>], #4
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsop_H2_i2h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST2_asisdlsop_H2_i2h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsop_H2_i2h
        IEM_INSTR_IMPL_A64__ST2_asisdlsop_H2_i2h(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e400/0da04000: ST2  { <Vt>.H, <Vt2>.H }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsop_HX2_r2h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST2_asisdlsop_HX2_r2h Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsop_HX2_r2h
        IEM_INSTR_IMPL_A64__ST2_asisdlsop_HX2_r2h(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0dbf8000: ST2  { <Vt>.S, <Vt2>.S }[<index>], [<Xn|SP>], #8
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsop_S2_i2s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST2_asisdlsop_S2_i2s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsop_S2_i2s
        IEM_INSTR_IMPL_A64__ST2_asisdlsop_S2_i2s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0ec00/0da08000: ST2  { <Vt>.S, <Vt2>.S }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST2_asisdlsop_SX2_r2s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST2_asisdlsop_SX2_r2s Rt=%#x Rn=%#x S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST2_asisdlsop_SX2_r2s
        IEM_INSTR_IMPL_A64__ST2_asisdlsop_SX2_r2s(Rt, Rn, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c004000: ST3  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlse_R3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c004000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST3_asisdlse_R3 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlse_R3
            IEM_INSTR_IMPL_A64__ST3_asisdlse_R3(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c9f4000: ST3  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsep_I3_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST3_asisdlsep_I3_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsep_I3_i
        IEM_INSTR_IMPL_A64__ST3_asisdlsep_I3_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0c804000: ST3  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsep_R3_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST3_asisdlsep_R3_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsep_R3_r
        IEM_INSTR_IMPL_A64__ST3_asisdlsep_R3_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d002000: ST3  { <Vt>.B, <Vt2>.B, <Vt3>.B }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlso_B3_3b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d002000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST3_asisdlso_B3_3b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlso_B3_3b
            IEM_INSTR_IMPL_A64__ST3_asisdlso_B3_3b(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d00a400: ST3  { <Vt>.D, <Vt2>.D, <Vt3>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlso_D3_3d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d00a400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST3_asisdlso_D3_3d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlso_D3_3d
            IEM_INSTR_IMPL_A64__ST3_asisdlso_D3_3d(Rt, Rn, Q);
#else
            RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d006000: ST3  { <Vt>.H, <Vt2>.H, <Vt3>.H }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlso_H3_3h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d006000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST3_asisdlso_H3_3h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlso_H3_3h
            IEM_INSTR_IMPL_A64__ST3_asisdlso_H3_3h(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d00a000: ST3  { <Vt>.S, <Vt2>.S, <Vt3>.S }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlso_S3_3s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d00a000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST3_asisdlso_S3_3s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlso_S3_3s
            IEM_INSTR_IMPL_A64__ST3_asisdlso_S3_3s(Rt, Rn, S, Q);
#else
            RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d9f2000: ST3  { <Vt>.B, <Vt2>.B, <Vt3>.B }[<index>], [<Xn|SP>], #3
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsop_B3_i3b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST3_asisdlsop_B3_i3b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsop_B3_i3b
        IEM_INSTR_IMPL_A64__ST3_asisdlsop_B3_i3b(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e000/0d802000: ST3  { <Vt>.B, <Vt2>.B, <Vt3>.B }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsop_BX3_r3b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST3_asisdlsop_BX3_r3b Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsop_BX3_r3b
        IEM_INSTR_IMPL_A64__ST3_asisdlsop_BX3_r3b(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d9fa400: ST3  { <Vt>.D, <Vt2>.D, <Vt3>.D }[<index>], [<Xn|SP>], #24
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsop_D3_i3d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST3_asisdlsop_D3_i3d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsop_D3_i3d
        IEM_INSTR_IMPL_A64__ST3_asisdlsop_D3_i3d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0d80a400: ST3  { <Vt>.D, <Vt2>.D, <Vt3>.D }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsop_DX3_r3d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST3_asisdlsop_DX3_r3d Rt=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsop_DX3_r3d
        IEM_INSTR_IMPL_A64__ST3_asisdlsop_DX3_r3d(Rt, Rn, Rm, Q);
#else
        RT_NOREF(Rt, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d9f6000: ST3  { <Vt>.H, <Vt2>.H, <Vt3>.H }[<index>], [<Xn|SP>], #6
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsop_H3_i3h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST3_asisdlsop_H3_i3h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsop_H3_i3h
        IEM_INSTR_IMPL_A64__ST3_asisdlsop_H3_i3h(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e400/0d806000: ST3  { <Vt>.H, <Vt2>.H, <Vt3>.H }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsop_HX3_r3h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST3_asisdlsop_HX3_r3h Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsop_HX3_r3h
        IEM_INSTR_IMPL_A64__ST3_asisdlsop_HX3_r3h(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d9fa000: ST3  { <Vt>.S, <Vt2>.S, <Vt3>.S }[<index>], [<Xn|SP>], #12
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsop_S3_i3s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST3_asisdlsop_S3_i3s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsop_S3_i3s
        IEM_INSTR_IMPL_A64__ST3_asisdlsop_S3_i3s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0ec00/0d80a000: ST3  { <Vt>.S, <Vt2>.S, <Vt3>.S }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST3_asisdlsop_SX3_r3s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST3_asisdlsop_SX3_r3s Rt=%#x Rn=%#x S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST3_asisdlsop_SX3_r3s
        IEM_INSTR_IMPL_A64__ST3_asisdlsop_SX3_r3s(Rt, Rn, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c000000: ST4  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlse, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlse_R4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c000000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST4_asisdlse_R4 Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlse_R4
            IEM_INSTR_IMPL_A64__ST4_asisdlse_R4(Rt, Rn, size, Q);
#else
            RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffff000/0c9f0000: ST4  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <imm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsep_I4_i, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST4_asisdlsep_I4_i Rt=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsep_I4_i
        IEM_INSTR_IMPL_A64__ST4_asisdlsep_I4_i(Rt, Rn, size, Q);
#else
        RT_NOREF(Rt, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0f000/0c800000: ST4  { <Vt>.<T>, <Vt2>.<T>, <Vt3>.<T>, <Vt4>.<T> }, [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsep, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsep_R4_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST4_asisdlsep_R4_r Rt=%#x Rn=%#x size=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsep_R4_r
        IEM_INSTR_IMPL_A64__ST4_asisdlsep_R4_r(Rt, Rn, size, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0d202000: ST4  { <Vt>.B, <Vt2>.B, <Vt3>.B, <Vt4>.B }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlso_B4_4b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d202000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST4_asisdlso_B4_4b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlso_B4_4b
            IEM_INSTR_IMPL_A64__ST4_asisdlso_B4_4b(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d20a400: ST4  { <Vt>.D, <Vt2>.D, <Vt3>.D, <Vt4>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlso_D4_4d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d20a400))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST4_asisdlso_D4_4d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlso_D4_4d
            IEM_INSTR_IMPL_A64__ST4_asisdlso_D4_4d(Rt, Rn, Q);
#else
            RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0d206000: ST4  { <Vt>.H, <Vt2>.H, <Vt3>.H, <Vt4>.H }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlso_H4_4h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d206000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 10) & 0x00000003;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST4_asisdlso_H4_4h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlso_H4_4h
            IEM_INSTR_IMPL_A64__ST4_asisdlso_H4_4h(Rt, Rn, size, S, Q);
#else
            RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0d20a000: ST4  { <Vt>.S, <Vt2>.S, <Vt3>.S, <Vt4>.S }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlso_S4_4s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d20a000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const S          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ST4_asisdlso_S4_4s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlso_S4_4s
            IEM_INSTR_IMPL_A64__ST4_asisdlso_S4_4s(Rt, Rn, S, Q);
#else
            RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe000/0dbf2000: ST4  { <Vt>.B, <Vt2>.B, <Vt3>.B, <Vt4>.B }[<index>], [<Xn|SP>], #4
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsop_B4_i4b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST4_asisdlsop_B4_i4b Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsop_B4_i4b
        IEM_INSTR_IMPL_A64__ST4_asisdlsop_B4_i4b(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e000/0da02000: ST4  { <Vt>.B, <Vt2>.B, <Vt3>.B, <Vt4>.B }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsop_BX4_r4b, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST4_asisdlsop_BX4_r4b Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsop_BX4_r4b
        IEM_INSTR_IMPL_A64__ST4_asisdlsop_BX4_r4b(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0dbfa400: ST4  { <Vt>.D, <Vt2>.D, <Vt3>.D, <Vt4>.D }[<index>], [<Xn|SP>], #32
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsop_D4_i4d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST4_asisdlsop_D4_i4d Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsop_D4_i4d
        IEM_INSTR_IMPL_A64__ST4_asisdlsop_D4_i4d(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0da0a400: ST4  { <Vt>.D, <Vt2>.D, <Vt3>.D, <Vt4>.D }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsop_DX4_r4d, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST4_asisdlsop_DX4_r4d Rt=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsop_DX4_r4d
        IEM_INSTR_IMPL_A64__ST4_asisdlsop_DX4_r4d(Rt, Rn, Rm, Q);
#else
        RT_NOREF(Rt, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffe400/0dbf6000: ST4  { <Vt>.H, <Vt2>.H, <Vt3>.H, <Vt4>.H }[<index>], [<Xn|SP>], #8
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsop_H4_i4h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST4_asisdlsop_H4_i4h Rt=%#x Rn=%#x size=%u S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsop_H4_i4h
        IEM_INSTR_IMPL_A64__ST4_asisdlsop_H4_i4h(Rt, Rn, size, S, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0e400/0da06000: ST4  { <Vt>.H, <Vt2>.H, <Vt3>.H, <Vt4>.H }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsop_HX4_r4h, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 10) & 0x00000003;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST4_asisdlsop_HX4_r4h Rt=%#x Rn=%#x size=%u S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, size, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsop_HX4_r4h
        IEM_INSTR_IMPL_A64__ST4_asisdlsop_HX4_r4h(Rt, Rn, size, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, size, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfffec00/0dbfa000: ST4  { <Vt>.S, <Vt2>.S, <Vt3>.S, <Vt4>.S }[<index>], [<Xn|SP>], #16
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsop_S4_i4s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: ST4_asisdlsop_S4_i4s Rt=%#x Rn=%#x S=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsop_S4_i4s
        IEM_INSTR_IMPL_A64__ST4_asisdlsop_S4_i4s(Rt, Rn, S, Q);
#else
        RT_NOREF(Rt, Rn, S, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0ec00/0da0a000: ST4  { <Vt>.S, <Vt2>.S, <Vt3>.S, <Vt4>.S }[<index>], [<Xn|SP>], <Xm>
   Instruction Set: A64  Groups: asisdlsop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST4_asisdlsop_SX4_r4s, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (Rm != 0x1f))
    {
        LogFlow(("%018x/%010x: ST4_asisdlsop_SX4_r4s Rt=%#x Rn=%#x S=%u Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__ST4_asisdlsop_SX4_r4s
        IEM_INSTR_IMPL_A64__ST4_asisdlsop_SX4_r4s(Rt, Rn, S, Rm, Q);
#else
        RT_NOREF(Rt, Rn, S, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f820a000: ST64BV0  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST64BV0_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLs64Accdata /*FEAT_LS64_ACCDATA*/)
    {
        LogFlow(("%018x/%010x: ST64BV0_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__ST64BV0_64_memop
        IEM_INSTR_IMPL_A64__ST64BV0_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f820b000: ST64BV  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST64BV_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLs64V /*FEAT_LS64_V*/)
    {
        LogFlow(("%018x/%010x: ST64BV_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__ST64BV_64_memop
        IEM_INSTR_IMPL_A64__ST64BV_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/f83f9000: ST64B  <Xt>, [<Xn|SP>{ , #0}]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_ST64B_64L_memop, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xf83f9000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLs64 /*FEAT_LS64*/)
        {
            LogFlow(("%018x/%010x: ST64B_64L_memop Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__ST64B_64L_memop
            IEM_INSTR_IMPL_A64__ST64B_64L_memop(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c60801f: STBFADDL  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFADDL_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c60801f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFADDL_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFADDL_16
            IEM_INSTR_IMPL_A64__STBFADDL_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c20801f: STBFADD  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFADD_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c20801f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFADD_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFADD_16
            IEM_INSTR_IMPL_A64__STBFADD_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c60c01f: STBFMAXL  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFMAXL_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c60c01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFMAXL_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFMAXL_16
            IEM_INSTR_IMPL_A64__STBFMAXL_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c60e01f: STBFMAXNML  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFMAXNML_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c60e01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFMAXNML_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFMAXNML_16
            IEM_INSTR_IMPL_A64__STBFMAXNML_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c20e01f: STBFMAXNM  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFMAXNM_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c20e01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFMAXNM_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFMAXNM_16
            IEM_INSTR_IMPL_A64__STBFMAXNM_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c20c01f: STBFMAX  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFMAX_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c20c01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFMAX_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFMAX_16
            IEM_INSTR_IMPL_A64__STBFMAX_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c60d01f: STBFMINL  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFMINL_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c60d01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFMINL_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFMINL_16
            IEM_INSTR_IMPL_A64__STBFMINL_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c60f01f: STBFMINNML  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFMINNML_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c60f01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFMINNML_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFMINNML_16
            IEM_INSTR_IMPL_A64__STBFMINNML_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c20f01f: STBFMINNM  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFMINNM_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c20f01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFMINNM_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFMINNM_16
            IEM_INSTR_IMPL_A64__STBFMINNM_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/3c20d01f: STBFMIN  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STBFMIN_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x3c20d01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STBFMIN_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STBFMIN_16
            IEM_INSTR_IMPL_A64__STBFMIN_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c60801f: STFADDL  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFADDL_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c60801f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFADDL_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFADDL_16
            IEM_INSTR_IMPL_A64__STFADDL_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc60801f: STFADDL  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFADDL_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc60801f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFADDL_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFADDL_32
            IEM_INSTR_IMPL_A64__STFADDL_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc60801f: STFADDL  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFADDL_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc60801f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFADDL_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFADDL_64
            IEM_INSTR_IMPL_A64__STFADDL_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c20801f: STFADD  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFADD_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c20801f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFADD_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFADD_16
            IEM_INSTR_IMPL_A64__STFADD_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc20801f: STFADD  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFADD_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc20801f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFADD_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFADD_32
            IEM_INSTR_IMPL_A64__STFADD_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc20801f: STFADD  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFADD_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc20801f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFADD_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFADD_64
            IEM_INSTR_IMPL_A64__STFADD_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c60c01f: STFMAXL  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXL_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c60c01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXL_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXL_16
            IEM_INSTR_IMPL_A64__STFMAXL_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc60c01f: STFMAXL  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXL_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc60c01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXL_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXL_32
            IEM_INSTR_IMPL_A64__STFMAXL_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc60c01f: STFMAXL  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXL_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc60c01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXL_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXL_64
            IEM_INSTR_IMPL_A64__STFMAXL_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c60e01f: STFMAXNML  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXNML_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c60e01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXNML_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXNML_16
            IEM_INSTR_IMPL_A64__STFMAXNML_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc60e01f: STFMAXNML  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXNML_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc60e01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXNML_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXNML_32
            IEM_INSTR_IMPL_A64__STFMAXNML_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc60e01f: STFMAXNML  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXNML_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc60e01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXNML_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXNML_64
            IEM_INSTR_IMPL_A64__STFMAXNML_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c20e01f: STFMAXNM  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXNM_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c20e01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXNM_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXNM_16
            IEM_INSTR_IMPL_A64__STFMAXNM_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc20e01f: STFMAXNM  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXNM_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc20e01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXNM_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXNM_32
            IEM_INSTR_IMPL_A64__STFMAXNM_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc20e01f: STFMAXNM  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAXNM_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc20e01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAXNM_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAXNM_64
            IEM_INSTR_IMPL_A64__STFMAXNM_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c20c01f: STFMAX  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAX_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c20c01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAX_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAX_16
            IEM_INSTR_IMPL_A64__STFMAX_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc20c01f: STFMAX  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAX_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc20c01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAX_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAX_32
            IEM_INSTR_IMPL_A64__STFMAX_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc20c01f: STFMAX  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMAX_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc20c01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMAX_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMAX_64
            IEM_INSTR_IMPL_A64__STFMAX_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c60d01f: STFMINL  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINL_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c60d01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINL_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINL_16
            IEM_INSTR_IMPL_A64__STFMINL_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc60d01f: STFMINL  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINL_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc60d01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINL_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINL_32
            IEM_INSTR_IMPL_A64__STFMINL_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc60d01f: STFMINL  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINL_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc60d01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINL_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINL_64
            IEM_INSTR_IMPL_A64__STFMINL_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c60f01f: STFMINNML  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINNML_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c60f01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINNML_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINNML_16
            IEM_INSTR_IMPL_A64__STFMINNML_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc60f01f: STFMINNML  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINNML_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc60f01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINNML_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINNML_32
            IEM_INSTR_IMPL_A64__STFMINNML_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc60f01f: STFMINNML  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINNML_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc60f01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINNML_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINNML_64
            IEM_INSTR_IMPL_A64__STFMINNML_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c20f01f: STFMINNM  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINNM_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c20f01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINNM_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINNM_16
            IEM_INSTR_IMPL_A64__STFMINNM_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc20f01f: STFMINNM  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINNM_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc20f01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINNM_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINNM_32
            IEM_INSTR_IMPL_A64__STFMINNM_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc20f01f: STFMINNM  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMINNM_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc20f01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMINNM_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMINNM_64
            IEM_INSTR_IMPL_A64__STFMINNM_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/7c20d01f: STFMIN  <Hs>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMIN_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x7c20d01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMIN_16 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMIN_16
            IEM_INSTR_IMPL_A64__STFMIN_16(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/bc20d01f: STFMIN  <Ss>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMIN_32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xbc20d01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMIN_32 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMIN_32
            IEM_INSTR_IMPL_A64__STFMIN_32(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc1f/fc20d01f: STFMIN  <Ds>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STFMIN_64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0xfc20d01f))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsfe /*FEAT_LSFE*/)
        {
            LogFlow(("%018x/%010x: STFMIN_64 Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STFMIN_64
            IEM_INSTR_IMPL_A64__STFMIN_64(Rn, Rs);
#else
            RT_NOREF(Rn, Rs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d9a00000: STGM  <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STGM_64bulk_ldsttags, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd9a00000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte2 /*FEAT_MTE2*/)
        {
            LogFlow(("%018x/%010x: STGM_64bulk_ldsttags Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STGM_64bulk_ldsttags
            IEM_INSTR_IMPL_A64__STGM_64bulk_ldsttags(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/69000000: STGP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STGP_64_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const simm7      = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STGP_64_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x simm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, simm7));
#ifdef IEM_INSTR_IMPL_A64__STGP_64_ldstpair_off
        IEM_INSTR_IMPL_A64__STGP_64_ldstpair_off(Rt, Rn, Rt2, simm7);
#else
        RT_NOREF(Rt, Rn, Rt2, simm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/68800000: STGP  <Xt1>, <Xt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STGP_64_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const simm7      = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STGP_64_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x simm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, simm7));
#ifdef IEM_INSTR_IMPL_A64__STGP_64_ldstpair_post
        IEM_INSTR_IMPL_A64__STGP_64_ldstpair_post(Rt, Rn, Rt2, simm7);
#else
        RT_NOREF(Rt, Rn, Rt2, simm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/69800000: STGP  <Xt1>, <Xt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STGP_64_ldstpair_pre, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x69800000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
        uint32_t const simm7      = (uOpcode >> 15) & 0x0000007f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
        {
            LogFlow(("%018x/%010x: STGP_64_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x simm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, simm7));
#ifdef IEM_INSTR_IMPL_A64__STGP_64_ldstpair_pre
            IEM_INSTR_IMPL_A64__STGP_64_ldstpair_pre(Rt, Rn, Rt2, simm7);
#else
            RT_NOREF(Rt, Rn, Rt2, simm7, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9200800: STG  <Xt|SP>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STG_64Soffset_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STG_64Soffset_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STG_64Soffset_ldsttags
        IEM_INSTR_IMPL_A64__STG_64Soffset_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9200400: STG  <Xt|SP>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STG_64Spost_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STG_64Spost_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STG_64Spost_ldsttags
        IEM_INSTR_IMPL_A64__STG_64Spost_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9200c00: STG  <Xt|SP>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STG_64Spre_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STG_64Spre_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STG_64Spre_ldsttags
        IEM_INSTR_IMPL_A64__STG_64Spre_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/99000800: STILP  <Wt1>, <Wt2>, [<Xn|SP>, #-8]!
   Instruction Set: A64  Groups: ldiappstilp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STILP_32SE_ldiappstilp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STILP_32SE_ldiappstilp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__STILP_32SE_ldiappstilp
        IEM_INSTR_IMPL_A64__STILP_32SE_ldiappstilp(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/99001800: STILP  <Wt1>, <Wt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldiappstilp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STILP_32S_ldiappstilp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STILP_32S_ldiappstilp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__STILP_32S_ldiappstilp
        IEM_INSTR_IMPL_A64__STILP_32S_ldiappstilp(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/d9000800: STILP  <Xt1>, <Xt2>, [<Xn|SP>, #-16]!
   Instruction Set: A64  Groups: ldiappstilp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STILP_64SS_ldiappstilp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STILP_64SS_ldiappstilp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__STILP_64SS_ldiappstilp
        IEM_INSTR_IMPL_A64__STILP_64SS_ldiappstilp(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/d9001800: STILP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldiappstilp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STILP_64S_ldiappstilp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STILP_64S_ldiappstilp Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__STILP_64S_ldiappstilp
        IEM_INSTR_IMPL_A64__STILP_64S_ldiappstilp(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/0d018400: STL1  { <Vt>.D }[<index>], [<Xn|SP>]
   Instruction Set: A64  Groups: asisdlso, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STL1_asisdlso_D1, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STL1_asisdlso_D1 Rt=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__STL1_asisdlso_D1
        IEM_INSTR_IMPL_A64__STL1_asisdlso_D1(Rt, Rn, Q);
#else
        RT_NOREF(Rt, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/089f7c00: STLLRB  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLLRB_SL32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x089f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLor /*FEAT_LOR*/)
        {
            LogFlow(("%018x/%010x: STLLRB_SL32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLLRB_SL32_ldstord
            IEM_INSTR_IMPL_A64__STLLRB_SL32_ldstord(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/489f7c00: STLLRH  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLLRH_SL32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x489f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLor /*FEAT_LOR*/)
        {
            LogFlow(("%018x/%010x: STLLRH_SL32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLLRH_SL32_ldstord
            IEM_INSTR_IMPL_A64__STLLRH_SL32_ldstord(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/889f7c00: STLLR  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLLR_SL32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x889f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLor /*FEAT_LOR*/)
        {
            LogFlow(("%018x/%010x: STLLR_SL32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLLR_SL32_ldstord
            IEM_INSTR_IMPL_A64__STLLR_SL32_ldstord(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/c89f7c00: STLLR  <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLLR_SL64_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xc89f7c00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLor /*FEAT_LOR*/)
        {
            LogFlow(("%018x/%010x: STLLR_SL64_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLLR_SL64_ldstord
            IEM_INSTR_IMPL_A64__STLLR_SL64_ldstord(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/089ffc00: STLRB  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLRB_SL32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x089ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: STLRB_SL32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLRB_SL32_ldstord
        IEM_INSTR_IMPL_A64__STLRB_SL32_ldstord(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/489ffc00: STLRH  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLRH_SL32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x489ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: STLRH_SL32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLRH_SL32_ldstord
        IEM_INSTR_IMPL_A64__STLRH_SL32_ldstord(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/99800800: STLR  <Wt>, [<Xn|SP>, #-4]!
   Instruction Set: A64  Groups: ldapstl_writeback, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLR_32S_ldapstl_writeback, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x99800800))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
        {
            LogFlow(("%018x/%010x: STLR_32S_ldapstl_writeback Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLR_32S_ldapstl_writeback
            IEM_INSTR_IMPL_A64__STLR_32S_ldapstl_writeback(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d9800800: STLR  <Xt>, [<Xn|SP>, #-8]!
   Instruction Set: A64  Groups: ldapstl_writeback, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLR_64S_ldapstl_writeback, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd9800800))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
        {
            LogFlow(("%018x/%010x: STLR_64S_ldapstl_writeback Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLR_64S_ldapstl_writeback
            IEM_INSTR_IMPL_A64__STLR_64S_ldapstl_writeback(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/889ffc00: STLR  <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLR_SL32_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x889ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: STLR_SL32_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLR_SL32_ldstord
        IEM_INSTR_IMPL_A64__STLR_SL32_ldstord(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/c89ffc00: STLR  <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstord, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLR_SL64_ldstord, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xc89ffc00))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        LogFlow(("%018x/%010x: STLR_SL64_ldstord Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STLR_SL64_ldstord
        IEM_INSTR_IMPL_A64__STLR_SL64_ldstord(Rt, Rn);
#else
        RT_NOREF(Rt, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/8900fc00: STLTXR  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLTXR_SR32_ldstexclr_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STLTXR_SR32_ldstexclr_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STLTXR_SR32_ldstexclr_unpriv
        IEM_INSTR_IMPL_A64__STLTXR_SR32_ldstexclr_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c900fc00: STLTXR  <Ws>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLTXR_SR64_ldstexclr_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STLTXR_SR64_ldstexclr_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STLTXR_SR64_ldstexclr_unpriv
        IEM_INSTR_IMPL_A64__STLTXR_SR64_ldstexclr_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/19000000: STLURB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLURB_32_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: STLURB_32_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLURB_32_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__STLURB_32_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/59000000: STLURH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLURH_32_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: STLURH_32_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLURH_32_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__STLURH_32_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/99000000: STLUR  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLUR_32_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: STLUR_32_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLUR_32_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__STLUR_32_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9000000: STLUR  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLUR_64_ldapstl_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc2 /*FEAT_LRCPC2*/)
    {
        LogFlow(("%018x/%010x: STLUR_64_ldapstl_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLUR_64_ldapstl_unscaled
        IEM_INSTR_IMPL_A64__STLUR_64_ldapstl_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/1d000800: STLUR  <Bt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLUR_B_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STLUR_B_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLUR_B_ldapstl_simd
        IEM_INSTR_IMPL_A64__STLUR_B_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/dd000800: STLUR  <Dt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLUR_D_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STLUR_D_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLUR_D_ldapstl_simd
        IEM_INSTR_IMPL_A64__STLUR_D_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/5d000800: STLUR  <Ht>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLUR_H_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STLUR_H_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLUR_H_ldapstl_simd
        IEM_INSTR_IMPL_A64__STLUR_H_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/1d800800: STLUR  <Qt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLUR_Q_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STLUR_Q_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLUR_Q_ldapstl_simd
        IEM_INSTR_IMPL_A64__STLUR_Q_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/9d000800: STLUR  <St>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldapstl_simd, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLUR_S_ldapstl_simd, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLrcpc3 /*FEAT_LRCPC3*/)
    {
        LogFlow(("%018x/%010x: STLUR_S_ldapstl_simd Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STLUR_S_ldapstl_simd
        IEM_INSTR_IMPL_A64__STLUR_S_ldapstl_simd(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/88208000: STLXP  <Ws>, <Wt1>, <Wt2>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLXP_SP32_ldstexclp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STLXP_SP32_ldstexclp Rt=%#x Rn=%#x Rt2=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, Rs));
#ifdef IEM_INSTR_IMPL_A64__STLXP_SP32_ldstexclp
    IEM_INSTR_IMPL_A64__STLXP_SP32_ldstexclp(Rt, Rn, Rt2, Rs);
#else
    RT_NOREF(Rt, Rn, Rt2, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe08000/c8208000: STLXP  <Ws>, <Xt1>, <Xt2>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLXP_SP64_ldstexclp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STLXP_SP64_ldstexclp Rt=%#x Rn=%#x Rt2=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, Rs));
#ifdef IEM_INSTR_IMPL_A64__STLXP_SP64_ldstexclp
    IEM_INSTR_IMPL_A64__STLXP_SP64_ldstexclp(Rt, Rn, Rt2, Rs);
#else
    RT_NOREF(Rt, Rn, Rt2, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/0800fc00: STLXRB  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLXRB_SR32_ldstexclr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STLXRB_SR32_ldstexclr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STLXRB_SR32_ldstexclr
    IEM_INSTR_IMPL_A64__STLXRB_SR32_ldstexclr(Rt, Rn, Rs);
#else
    RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/4800fc00: STLXRH  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLXRH_SR32_ldstexclr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STLXRH_SR32_ldstexclr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STLXRH_SR32_ldstexclr
    IEM_INSTR_IMPL_A64__STLXRH_SR32_ldstexclr(Rt, Rn, Rs);
#else
    RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/8800fc00: STLXR  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLXR_SR32_ldstexclr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STLXR_SR32_ldstexclr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STLXR_SR32_ldstexclr
    IEM_INSTR_IMPL_A64__STLXR_SR32_ldstexclr(Rt, Rn, Rs);
#else
    RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/c800fc00: STLXR  <Ws>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STLXR_SR64_ldstexclr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STLXR_SR64_ldstexclr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STLXR_SR64_ldstexclr
    IEM_INSTR_IMPL_A64__STLXR_SR64_ldstexclr(Rt, Rn, Rs);
#else
    RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/28000000: STNP  <Wt1>, <Wt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STNP_32_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: STNP_32_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STNP_32_ldstnapair_offs
    IEM_INSTR_IMPL_A64__STNP_32_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/a8000000: STNP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STNP_64_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: STNP_64_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STNP_64_ldstnapair_offs
    IEM_INSTR_IMPL_A64__STNP_64_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/6c000000: STNP  <Dt1>, <Dt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STNP_D_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STNP_D_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STNP_D_ldstnapair_offs
        IEM_INSTR_IMPL_A64__STNP_D_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ac000000: STNP  <Qt1>, <Qt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STNP_Q_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STNP_Q_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STNP_Q_ldstnapair_offs
        IEM_INSTR_IMPL_A64__STNP_Q_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/2c000000: STNP  <St1>, <St2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STNP_S_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STNP_S_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STNP_S_ldstnapair_offs
        IEM_INSTR_IMPL_A64__STNP_S_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/29000000: STP  <Wt1>, <Wt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_32_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: STP_32_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_32_ldstpair_off
    IEM_INSTR_IMPL_A64__STP_32_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/28800000: STP  <Wt1>, <Wt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_32_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: STP_32_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_32_ldstpair_post
    IEM_INSTR_IMPL_A64__STP_32_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/29800000: STP  <Wt1>, <Wt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_32_ldstpair_pre, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x29800000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
        uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
        LogFlow(("%018x/%010x: STP_32_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_32_ldstpair_pre
        IEM_INSTR_IMPL_A64__STP_32_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/a9000000: STP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_64_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: STP_64_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_64_ldstpair_off
    IEM_INSTR_IMPL_A64__STP_64_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/a8800000: STP  <Xt1>, <Xt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_64_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    LogFlow(("%018x/%010x: STP_64_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_64_ldstpair_post
    IEM_INSTR_IMPL_A64__STP_64_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
    RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/a9800000: STP  <Xt1>, <Xt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_64_ldstpair_pre, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9800000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
        uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
        LogFlow(("%018x/%010x: STP_64_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_64_ldstpair_pre
        IEM_INSTR_IMPL_A64__STP_64_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/6d000000: STP  <Dt1>, <Dt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_D_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_D_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_D_ldstpair_off
        IEM_INSTR_IMPL_A64__STP_D_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/6c800000: STP  <Dt1>, <Dt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_D_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_D_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_D_ldstpair_post
        IEM_INSTR_IMPL_A64__STP_D_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/6d800000: STP  <Dt1>, <Dt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_D_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_D_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_D_ldstpair_pre
        IEM_INSTR_IMPL_A64__STP_D_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ad000000: STP  <Qt1>, <Qt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_Q_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_Q_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_Q_ldstpair_off
        IEM_INSTR_IMPL_A64__STP_Q_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ac800000: STP  <Qt1>, <Qt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_Q_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_Q_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_Q_ldstpair_post
        IEM_INSTR_IMPL_A64__STP_Q_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ad800000: STP  <Qt1>, <Qt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_Q_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_Q_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_Q_ldstpair_pre
        IEM_INSTR_IMPL_A64__STP_Q_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/2d000000: STP  <St1>, <St2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_S_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_S_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_S_ldstpair_off
        IEM_INSTR_IMPL_A64__STP_S_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/2c800000: STP  <St1>, <St2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_S_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_S_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_S_ldstpair_post
        IEM_INSTR_IMPL_A64__STP_S_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/2d800000: STP  <St1>, <St2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STP_S_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STP_S_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STP_S_ldstpair_pre
        IEM_INSTR_IMPL_A64__STP_S_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0ec00/38206800: STRB  <Wt>, [<Xn|SP>, <Xm>{, LSL <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRB_32BL_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STRB_32BL_ldst_regoff Rt=%#x Rn=%#x S=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm));
#ifdef IEM_INSTR_IMPL_A64__STRB_32BL_ldst_regoff
    IEM_INSTR_IMPL_A64__STRB_32BL_ldst_regoff(Rt, Rn, S, Rm);
#else
    RT_NOREF(Rt, Rn, S, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38200800: STRB  <Wt>, [<Xn|SP>, {<Wm> | <Xm>}, <extend>{ <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRB_32B_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (option != 3)
    {
        LogFlow(("%018x/%010x: STRB_32B_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STRB_32B_ldst_regoff
        IEM_INSTR_IMPL_A64__STRB_32B_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/38000400: STRB  <Wt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRB_32_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STRB_32_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STRB_32_ldst_immpost
    IEM_INSTR_IMPL_A64__STRB_32_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/38000c00: STRB  <Wt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRB_32_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STRB_32_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STRB_32_ldst_immpre
    IEM_INSTR_IMPL_A64__STRB_32_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/39000000: STRB  <Wt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRB_32_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: STRB_32_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STRB_32_ldst_pos
    IEM_INSTR_IMPL_A64__STRB_32_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78000400: STRH  <Wt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRH_32_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STRH_32_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STRH_32_ldst_immpost
    IEM_INSTR_IMPL_A64__STRH_32_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78000c00: STRH  <Wt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRH_32_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STRH_32_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STRH_32_ldst_immpre
    IEM_INSTR_IMPL_A64__STRH_32_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/79000000: STRH  <Wt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRH_32_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: STRH_32_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STRH_32_ldst_pos
    IEM_INSTR_IMPL_A64__STRH_32_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78200800: STRH  <Wt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STRH_32_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STRH_32_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STRH_32_ldst_regoff
    IEM_INSTR_IMPL_A64__STRH_32_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8000400: STR  <Wt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_32_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STR_32_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_32_ldst_immpost
    IEM_INSTR_IMPL_A64__STR_32_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8000c00: STR  <Wt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_32_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STR_32_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_32_ldst_immpre
    IEM_INSTR_IMPL_A64__STR_32_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/b9000000: STR  <Wt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_32_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: STR_32_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STR_32_ldst_pos
    IEM_INSTR_IMPL_A64__STR_32_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8200800: STR  <Wt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_32_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STR_32_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STR_32_ldst_regoff
    IEM_INSTR_IMPL_A64__STR_32_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8000400: STR  <Xt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_64_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STR_64_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_64_ldst_immpost
    IEM_INSTR_IMPL_A64__STR_64_ldst_immpost(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8000c00: STR  <Xt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_64_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STR_64_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_64_ldst_immpre
    IEM_INSTR_IMPL_A64__STR_64_ldst_immpre(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/f9000000: STR  <Xt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_64_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    LogFlow(("%018x/%010x: STR_64_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STR_64_ldst_pos
    IEM_INSTR_IMPL_A64__STR_64_ldst_pos(Rt, Rn, imm12);
#else
    RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8200800: STR  <Xt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_64_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STR_64_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STR_64_ldst_regoff
    IEM_INSTR_IMPL_A64__STR_64_ldst_regoff(Rt, Rn, S, option, Rm);
#else
    RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0ec00/3c206800: STR  <Bt>, [<Xn|SP>, <Xm>{, LSL <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_BL_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_BL_ldst_regoff Rt=%#x Rn=%#x S=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, Rm));
#ifdef IEM_INSTR_IMPL_A64__STR_BL_ldst_regoff
        IEM_INSTR_IMPL_A64__STR_BL_ldst_regoff(Rt, Rn, S, Rm);
#else
        RT_NOREF(Rt, Rn, S, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c000400: STR  <Bt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_B_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_B_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_B_ldst_immpost
        IEM_INSTR_IMPL_A64__STR_B_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c000c00: STR  <Bt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_B_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_B_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_B_ldst_immpre
        IEM_INSTR_IMPL_A64__STR_B_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/3d000000: STR  <Bt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_B_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_B_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STR_B_ldst_pos
        IEM_INSTR_IMPL_A64__STR_B_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c200800: STR  <Bt>, [<Xn|SP>, {<Wm> | <Xm>}, <extend>{ <amount>}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_B_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && (option != 3))
    {
        LogFlow(("%018x/%010x: STR_B_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STR_B_ldst_regoff
        IEM_INSTR_IMPL_A64__STR_B_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/fc000400: STR  <Dt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_D_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_D_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_D_ldst_immpost
        IEM_INSTR_IMPL_A64__STR_D_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/fc000c00: STR  <Dt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_D_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_D_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_D_ldst_immpre
        IEM_INSTR_IMPL_A64__STR_D_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/fd000000: STR  <Dt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_D_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_D_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STR_D_ldst_pos
        IEM_INSTR_IMPL_A64__STR_D_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/fc200800: STR  <Dt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_D_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_D_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STR_D_ldst_regoff
        IEM_INSTR_IMPL_A64__STR_D_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/7c000400: STR  <Ht>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_H_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_H_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_H_ldst_immpost
        IEM_INSTR_IMPL_A64__STR_H_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/7c000c00: STR  <Ht>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_H_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_H_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_H_ldst_immpre
        IEM_INSTR_IMPL_A64__STR_H_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/7d000000: STR  <Ht>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_H_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_H_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STR_H_ldst_pos
        IEM_INSTR_IMPL_A64__STR_H_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/7c200800: STR  <Ht>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_H_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_H_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STR_H_ldst_regoff
        IEM_INSTR_IMPL_A64__STR_H_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c800400: STR  <Qt>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_Q_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_Q_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_Q_ldst_immpost
        IEM_INSTR_IMPL_A64__STR_Q_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c800c00: STR  <Qt>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_Q_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_Q_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_Q_ldst_immpre
        IEM_INSTR_IMPL_A64__STR_Q_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/3d800000: STR  <Qt>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_Q_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_Q_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STR_Q_ldst_pos
        IEM_INSTR_IMPL_A64__STR_Q_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3ca00800: STR  <Qt>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_Q_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_Q_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STR_Q_ldst_regoff
        IEM_INSTR_IMPL_A64__STR_Q_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/bc000400: STR  <St>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldst_immpost, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_S_ldst_immpost, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_S_ldst_immpost Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_S_ldst_immpost
        IEM_INSTR_IMPL_A64__STR_S_ldst_immpost(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/bc000c00: STR  <St>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldst_immpre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_S_ldst_immpre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_S_ldst_immpre Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STR_S_ldst_immpre
        IEM_INSTR_IMPL_A64__STR_S_ldst_immpre(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/bd000000: STR  <St>, [<Xn|SP>{, #<pimm>}]
   Instruction Set: A64  Groups: ldst_pos, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_S_ldst_pos, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_S_ldst_pos Rt=%#x Rn=%#x imm12=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm12));
#ifdef IEM_INSTR_IMPL_A64__STR_S_ldst_pos
        IEM_INSTR_IMPL_A64__STR_S_ldst_pos(Rt, Rn, imm12);
#else
        RT_NOREF(Rt, Rn, imm12, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/bc200800: STR  <St>, [<Xn|SP>, {<Wm> | <Xm>}{, <extend>{ <amount>}}]
   Instruction Set: A64  Groups: ldst_regoff, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STR_S_ldst_regoff, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const S          = (uOpcode >> 12) & 0x00000001;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STR_S_ldst_regoff Rt=%#x Rn=%#x S=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, S, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__STR_S_ldst_regoff
        IEM_INSTR_IMPL_A64__STR_S_ldst_regoff(Rt, Rn, S, option, Rm);
#else
        RT_NOREF(Rt, Rn, S, option, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffff1f/d503261f: STSHH  <policy>
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_STSHH_HI_hints, uint32_t, uOpcode)
{
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPCDPHint /*FEAT_PCDPHINT*/ && ((op2 & 6) == 0))
    {
        LogFlow(("%018x/%010x: STSHH_HI_hints op2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, op2));
#ifdef IEM_INSTR_IMPL_A64__STSHH_HI_hints
        IEM_INSTR_IMPL_A64__STSHH_HI_hints(op2);
#else
        RT_NOREF(op2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/e8000000: STTNP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTNP_64_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTNP_64_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STTNP_64_ldstnapair_offs
        IEM_INSTR_IMPL_A64__STTNP_64_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ec000000: STTNP  <Qt1>, <Qt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstnapair_offs, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTNP_Q_ldstnapair_offs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTNP_Q_ldstnapair_offs Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STTNP_Q_ldstnapair_offs
        IEM_INSTR_IMPL_A64__STTNP_Q_ldstnapair_offs(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/e9000000: STTP  <Xt1>, <Xt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTP_64_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTP_64_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STTP_64_ldstpair_off
        IEM_INSTR_IMPL_A64__STTP_64_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/e8800000: STTP  <Xt1>, <Xt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTP_64_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTP_64_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STTP_64_ldstpair_post
        IEM_INSTR_IMPL_A64__STTP_64_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/e9800000: STTP  <Xt1>, <Xt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTP_64_ldstpair_pre, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9800000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
        uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
        {
            LogFlow(("%018x/%010x: STTP_64_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STTP_64_ldstpair_pre
            IEM_INSTR_IMPL_A64__STTP_64_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
            RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ed000000: STTP  <Qt1>, <Qt2>, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: ldstpair_off, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTP_Q_ldstpair_off, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTP_Q_ldstpair_off Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STTP_Q_ldstpair_off
        IEM_INSTR_IMPL_A64__STTP_Q_ldstpair_off(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ec800000: STTP  <Qt1>, <Qt2>, [<Xn|SP>], #<imm>
   Instruction Set: A64  Groups: ldstpair_post, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTP_Q_ldstpair_post, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTP_Q_ldstpair_post Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STTP_Q_ldstpair_post
        IEM_INSTR_IMPL_A64__STTP_Q_ldstpair_post(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/ed800000: STTP  <Qt1>, <Qt2>, [<Xn|SP>, #<imm>]!
   Instruction Set: A64  Groups: ldstpair_pre, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTP_Q_ldstpair_pre, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const imm7       = (uOpcode >> 15) & 0x0000007f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTP_Q_ldstpair_pre Rt=%#x Rn=%#x Rt2=%#x imm7=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, imm7));
#ifdef IEM_INSTR_IMPL_A64__STTP_Q_ldstpair_pre
        IEM_INSTR_IMPL_A64__STTP_Q_ldstpair_pre(Rt, Rn, Rt2, imm7);
#else
        RT_NOREF(Rt, Rn, Rt2, imm7, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/38000800: STTRB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTRB_32_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STTRB_32_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STTRB_32_ldst_unpriv
    IEM_INSTR_IMPL_A64__STTRB_32_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78000800: STTRH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTRH_32_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STTRH_32_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STTRH_32_ldst_unpriv
    IEM_INSTR_IMPL_A64__STTRH_32_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8000800: STTR  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTR_32_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STTR_32_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STTR_32_ldst_unpriv
    IEM_INSTR_IMPL_A64__STTR_32_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8000800: STTR  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTR_64_ldst_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STTR_64_ldst_unpriv Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STTR_64_ldst_unpriv
    IEM_INSTR_IMPL_A64__STTR_64_ldst_unpriv(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/89007c00: STTXR  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTXR_SR32_ldstexclr_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTXR_SR32_ldstexclr_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STTXR_SR32_ldstexclr_unpriv
        IEM_INSTR_IMPL_A64__STTXR_SR32_ldstexclr_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/c9007c00: STTXR  <Ws>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STTXR_SR64_ldstexclr_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: STTXR_SR64_ldstexclr_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STTXR_SR64_ldstexclr_unpriv
        IEM_INSTR_IMPL_A64__STTXR_SR64_ldstexclr_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/38000000: STURB  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STURB_32_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STURB_32_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STURB_32_ldst_unscaled
    IEM_INSTR_IMPL_A64__STURB_32_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/78000000: STURH  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STURH_32_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STURH_32_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STURH_32_ldst_unscaled
    IEM_INSTR_IMPL_A64__STURH_32_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/b8000000: STUR  <Wt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STUR_32_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STUR_32_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STUR_32_ldst_unscaled
    IEM_INSTR_IMPL_A64__STUR_32_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/f8000000: STUR  <Xt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STUR_64_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    LogFlow(("%018x/%010x: STUR_64_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STUR_64_ldst_unscaled
    IEM_INSTR_IMPL_A64__STUR_64_ldst_unscaled(Rt, Rn, imm9);
#else
    RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/3c000000: STUR  <Bt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STUR_B_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STUR_B_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STUR_B_ldst_unscaled
        IEM_INSTR_IMPL_A64__STUR_B_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/fc000000: STUR  <Dt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STUR_D_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STUR_D_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STUR_D_ldst_unscaled
        IEM_INSTR_IMPL_A64__STUR_D_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/7c000000: STUR  <Ht>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STUR_H_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STUR_H_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STUR_H_ldst_unscaled
        IEM_INSTR_IMPL_A64__STUR_H_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/3c800000: STUR  <Qt>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STUR_Q_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STUR_Q_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STUR_Q_ldst_unscaled
        IEM_INSTR_IMPL_A64__STUR_Q_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/bc000000: STUR  <St>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldst_unscaled, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STUR_S_ldst_unscaled, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: STUR_S_ldst_unscaled Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STUR_S_ldst_unscaled
        IEM_INSTR_IMPL_A64__STUR_S_ldst_unscaled(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/88200000: STXP  <Ws>, <Wt1>, <Wt2>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STXP_SP32_ldstexclp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STXP_SP32_ldstexclp Rt=%#x Rn=%#x Rt2=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, Rs));
#ifdef IEM_INSTR_IMPL_A64__STXP_SP32_ldstexclp
    IEM_INSTR_IMPL_A64__STXP_SP32_ldstexclp(Rt, Rn, Rt2, Rs);
#else
    RT_NOREF(Rt, Rn, Rt2, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe08000/c8200000: STXP  <Ws>, <Xt1>, <Xt2>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclp, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STXP_SP64_ldstexclp, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STXP_SP64_ldstexclp Rt=%#x Rn=%#x Rt2=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2, Rs));
#ifdef IEM_INSTR_IMPL_A64__STXP_SP64_ldstexclp
    IEM_INSTR_IMPL_A64__STXP_SP64_ldstexclp(Rt, Rn, Rt2, Rs);
#else
    RT_NOREF(Rt, Rn, Rt2, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/08007c00: STXRB  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STXRB_SR32_ldstexclr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STXRB_SR32_ldstexclr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STXRB_SR32_ldstexclr
    IEM_INSTR_IMPL_A64__STXRB_SR32_ldstexclr(Rt, Rn, Rs);
#else
    RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/48007c00: STXRH  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STXRH_SR32_ldstexclr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STXRH_SR32_ldstexclr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STXRH_SR32_ldstexclr
    IEM_INSTR_IMPL_A64__STXRH_SR32_ldstexclr(Rt, Rn, Rs);
#else
    RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/88007c00: STXR  <Ws>, <Wt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STXR_SR32_ldstexclr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STXR_SR32_ldstexclr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STXR_SR32_ldstexclr
    IEM_INSTR_IMPL_A64__STXR_SR32_ldstexclr(Rt, Rn, Rs);
#else
    RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/c8007c00: STXR  <Ws>, <Xt>, [<Xn|SP>{, #0}]
   Instruction Set: A64  Groups: ldstexclr, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STXR_SR64_ldstexclr, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: STXR_SR64_ldstexclr Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__STXR_SR64_ldstexclr
    IEM_INSTR_IMPL_A64__STXR_SR64_ldstexclr(Rt, Rn, Rs);
#else
    RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe00c00/d9e00800: STZ2G  <Xt|SP>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STZ2G_64Soffset_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STZ2G_64Soffset_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STZ2G_64Soffset_ldsttags
        IEM_INSTR_IMPL_A64__STZ2G_64Soffset_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9e00400: STZ2G  <Xt|SP>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STZ2G_64Spost_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STZ2G_64Spost_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STZ2G_64Spost_ldsttags
        IEM_INSTR_IMPL_A64__STZ2G_64Spost_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9e00c00: STZ2G  <Xt|SP>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STZ2G_64Spre_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STZ2G_64Spre_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STZ2G_64Spre_ldsttags
        IEM_INSTR_IMPL_A64__STZ2G_64Spre_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/d9200000: STZGM  <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STZGM_64bulk_ldsttags, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xd9200000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte2 /*FEAT_MTE2*/)
        {
            LogFlow(("%018x/%010x: STZGM_64bulk_ldsttags Rt=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn));
#ifdef IEM_INSTR_IMPL_A64__STZGM_64bulk_ldsttags
            IEM_INSTR_IMPL_A64__STZGM_64bulk_ldsttags(Rt, Rn);
#else
            RT_NOREF(Rt, Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9600800: STZG  <Xt|SP>, [<Xn|SP>{, #<simm>}]
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STZG_64Soffset_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STZG_64Soffset_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STZG_64Soffset_ldsttags
        IEM_INSTR_IMPL_A64__STZG_64Soffset_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9600400: STZG  <Xt|SP>, [<Xn|SP>], #<simm>
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STZG_64Spost_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STZG_64Spost_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STZG_64Spost_ldsttags
        IEM_INSTR_IMPL_A64__STZG_64Spost_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00c00/d9600c00: STZG  <Xt|SP>, [<Xn|SP>, #<simm>]!
   Instruction Set: A64  Groups: ldsttags, ldst */
FNIEMOP_DEF_1(iemDecodeA64_STZG_64Spre_ldsttags, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9       = (uOpcode >> 12) & 0x000001ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: STZG_64Spre_ldsttags Rt=%#x Rn=%#x imm9=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, imm9));
#ifdef IEM_INSTR_IMPL_A64__STZG_64Spre_ldsttags
        IEM_INSTR_IMPL_A64__STZG_64Spre_ldsttags(Rt, Rn, imm9);
#else
        RT_NOREF(Rt, Rn, imm9, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0c000/d1800000: SUBG  <Xd|SP>, <Xn|SP>, #<uimm6>, #<uimm4>
   Instruction Set: A64  Groups: addsub_immtags, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SUBG_64_addsub_immtags, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 10) & 0x0000000f;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SUBG_64_addsub_immtags Rd=%#x Rn=%#x imm4=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm4, imm6));
#ifdef IEM_INSTR_IMPL_A64__SUBG_64_addsub_immtags
        IEM_INSTR_IMPL_A64__SUBG_64_addsub_immtags(Rd, Rn, imm4, imm6);
#else
        RT_NOREF(Rd, Rn, imm4, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e206000: SUBHN2  <Vd>.<Tb>, <Vn>.<Ta>, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SUBHN_asimddiff_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SUBHN_asimddiff_N Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SUBHN_asimddiff_N
        IEM_INSTR_IMPL_A64__SUBHN_asimddiff_N(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/bac00000: SUBPS  <Xd>, <Xn|SP>, <Xm|SP>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUBPS_64S_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SUBPS_64S_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SUBPS_64S_dp_2src
        IEM_INSTR_IMPL_A64__SUBPS_64S_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/da002000: SUBPT  <Xd|SP>, <Xn|SP>, <Xm>{, LSL #<amount>}
   Instruction Set: A64  Groups: addsub_pt, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUBPT_64_addsub_pt, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
    {
        LogFlow(("%018x/%010x: SUBPT_64_addsub_pt Rd=%#x Rn=%#x imm3=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, Rm));
#ifdef IEM_INSTR_IMPL_A64__SUBPT_64_addsub_pt
        IEM_INSTR_IMPL_A64__SUBPT_64_addsub_pt(Rd, Rn, imm3, Rm);
#else
        RT_NOREF(Rd, Rn, imm3, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac00000: SUBP  <Xd>, <Xn|SP>, <Xm|SP>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUBP_64S_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fMte /*FEAT_MTE*/)
    {
        LogFlow(("%018x/%010x: SUBP_64S_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SUBP_64S_dp_2src
        IEM_INSTR_IMPL_A64__SUBP_64S_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/6b200000: SUBS  <Wd>, <Wn|WSP>, <Wm>{, <extend>{ #<amount>}}
   Instruction Set: A64  Groups: addsub_ext, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUBS_32S_addsub_ext, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SUBS_32S_addsub_ext Rd=%#x Rn=%#x imm3=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__SUBS_32S_addsub_ext
    IEM_INSTR_IMPL_A64__SUBS_32S_addsub_ext(Rd, Rn, imm3, option, Rm);
#else
    RT_NOREF(Rd, Rn, imm3, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/71000000: SUBS  <Wd>, <Wn|WSP>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: addsub_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SUBS_32S_addsub_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    uint32_t const sh         = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: SUBS_32S_addsub_imm Rd=%#x Rn=%#x imm12=%#x sh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm12, sh));
#ifdef IEM_INSTR_IMPL_A64__SUBS_32S_addsub_imm
    IEM_INSTR_IMPL_A64__SUBS_32S_addsub_imm(Rd, Rn, imm12, sh);
#else
    RT_NOREF(Rd, Rn, imm12, sh, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/6b000000: SUBS  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: addsub_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUBS_32_addsub_shift, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff200000)) == UINT32_C(0x6b000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
        LogFlow(("%018x/%010x: SUBS_32_addsub_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__SUBS_32_addsub_shift
        IEM_INSTR_IMPL_A64__SUBS_32_addsub_shift(Rd, Rn, imm6, Rm, shift);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/eb200000: SUBS  <Xd>, <Xn|SP>, <R><m>{, <extend>{ #<amount>}}
   Instruction Set: A64  Groups: addsub_ext, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUBS_64S_addsub_ext, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SUBS_64S_addsub_ext Rd=%#x Rn=%#x imm3=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__SUBS_64S_addsub_ext
    IEM_INSTR_IMPL_A64__SUBS_64S_addsub_ext(Rd, Rn, imm3, option, Rm);
#else
    RT_NOREF(Rd, Rn, imm3, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/f1000000: SUBS  <Xd>, <Xn|SP>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: addsub_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SUBS_64S_addsub_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    uint32_t const sh         = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: SUBS_64S_addsub_imm Rd=%#x Rn=%#x imm12=%#x sh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm12, sh));
#ifdef IEM_INSTR_IMPL_A64__SUBS_64S_addsub_imm
    IEM_INSTR_IMPL_A64__SUBS_64S_addsub_imm(Rd, Rn, imm12, sh);
#else
    RT_NOREF(Rd, Rn, imm12, sh, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/eb000000: SUBS  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: addsub_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUBS_64_addsub_shift, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff200000)) == UINT32_C(0xeb000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
        LogFlow(("%018x/%010x: SUBS_64_addsub_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__SUBS_64_addsub_shift
        IEM_INSTR_IMPL_A64__SUBS_64_addsub_shift(Rd, Rn, imm6, Rm, shift);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/4b200000: SUB  <Wd|WSP>, <Wn|WSP>, <Wm>{, <extend>{ #<amount>}}
   Instruction Set: A64  Groups: addsub_ext, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUB_32_addsub_ext, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SUB_32_addsub_ext Rd=%#x Rn=%#x imm3=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__SUB_32_addsub_ext
    IEM_INSTR_IMPL_A64__SUB_32_addsub_ext(Rd, Rn, imm3, option, Rm);
#else
    RT_NOREF(Rd, Rn, imm3, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/51000000: SUB  <Wd|WSP>, <Wn|WSP>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: addsub_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SUB_32_addsub_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    uint32_t const sh         = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: SUB_32_addsub_imm Rd=%#x Rn=%#x imm12=%#x sh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm12, sh));
#ifdef IEM_INSTR_IMPL_A64__SUB_32_addsub_imm
    IEM_INSTR_IMPL_A64__SUB_32_addsub_imm(Rd, Rn, imm12, sh);
#else
    RT_NOREF(Rd, Rn, imm12, sh, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/4b000000: SUB  <Wd>, <Wn>, <Wm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: addsub_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUB_32_addsub_shift, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff200000)) == UINT32_C(0x4b000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
        LogFlow(("%018x/%010x: SUB_32_addsub_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__SUB_32_addsub_shift
        IEM_INSTR_IMPL_A64__SUB_32_addsub_shift(Rd, Rn, imm6, Rm, shift);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/cb200000: SUB  <Xd|SP>, <Xn|SP>, <R><m>{, <extend>{ #<amount>}}
   Instruction Set: A64  Groups: addsub_ext, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUB_64_addsub_ext, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 10) & 0x00000007;
    uint32_t const option     = (uOpcode >> 13) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: SUB_64_addsub_ext Rd=%#x Rn=%#x imm3=%u option=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm3, option, Rm));
#ifdef IEM_INSTR_IMPL_A64__SUB_64_addsub_ext
    IEM_INSTR_IMPL_A64__SUB_64_addsub_ext(Rd, Rn, imm3, option, Rm);
#else
    RT_NOREF(Rd, Rn, imm3, option, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff800000/d1000000: SUB  <Xd|SP>, <Xn|SP>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: addsub_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_SUB_64_addsub_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm12      = (uOpcode >> 10) & 0x00000fff;
    uint32_t const sh         = (uOpcode >> 22) & 0x00000001;
    LogFlow(("%018x/%010x: SUB_64_addsub_imm Rd=%#x Rn=%#x imm12=%#x sh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm12, sh));
#ifdef IEM_INSTR_IMPL_A64__SUB_64_addsub_imm
    IEM_INSTR_IMPL_A64__SUB_64_addsub_imm(Rd, Rn, imm12, sh);
#else
    RT_NOREF(Rd, Rn, imm12, sh, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ff200000/cb000000: SUB  <Xd>, <Xn>, <Xm>{, <shift> #<amount>}
   Instruction Set: A64  Groups: addsub_shift, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_SUB_64_addsub_shift, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff200000)) == UINT32_C(0xcb000000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const shift      = (uOpcode >> 22) & 0x00000003;
        LogFlow(("%018x/%010x: SUB_64_addsub_shift Rd=%#x Rn=%#x imm6=%#x Rm=%#x shift=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm, shift));
#ifdef IEM_INSTR_IMPL_A64__SUB_64_addsub_shift
        IEM_INSTR_IMPL_A64__SUB_64_addsub_shift(Rd, Rn, imm6, Rm, shift);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, shift, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e208400: SUB  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SUB_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SUB_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SUB_asimdsame_only
        IEM_INSTR_IMPL_A64__SUB_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ee08400: SUB  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SUB_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SUB_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__SUB_asisdsame_only
        IEM_INSTR_IMPL_A64__SUB_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f00f000: SUDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.4B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SUDOT_asimdelem_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f00f000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
        {
            LogFlow(("%018x/%010x: SUDOT_asimdelem_D Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__SUDOT_asimdelem_D
            IEM_INSTR_IMPL_A64__SUDOT_asimdelem_D(Rd, Rn, H, Rm, M, L, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e203800: SUQADD  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SUQADD_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: SUQADD_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__SUQADD_asimdmisc_R
        IEM_INSTR_IMPL_A64__SUQADD_asimdmisc_R(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/5e203800: SUQADD  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_SUQADD_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x5e203800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: SUQADD_asisdmisc_R Rd=%#x Rn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size));
#ifdef IEM_INSTR_IMPL_A64__SUQADD_asisdmisc_R
            IEM_INSTR_IMPL_A64__SUQADD_asisdmisc_R(Rd, Rn, size);
#else
            RT_NOREF(Rd, Rn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/d4000001: SVC  #<imm>
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_SVC_EX_exception, uint32_t, uOpcode)
{
    uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
    LogFlow(("%018x/%010x: SVC_EX_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__SVC_EX_exception
    IEM_INSTR_IMPL_A64__SVC_EX_exception(imm16);
#else
    RT_NOREF(imm16, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/38a08000: SWPAB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPAB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPAB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPAB_32_memop
        IEM_INSTR_IMPL_A64__SWPAB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78a08000: SWPAH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPAH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPAH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPAH_32_memop
        IEM_INSTR_IMPL_A64__SWPAH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38e08000: SWPALB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPALB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPALB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPALB_32_memop
        IEM_INSTR_IMPL_A64__SWPALB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78e08000: SWPALH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPALH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPALH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPALH_32_memop
        IEM_INSTR_IMPL_A64__SWPALH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8e08000: SWPAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPAL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPAL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPAL_32_memop
        IEM_INSTR_IMPL_A64__SWPAL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8e08000: SWPAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPAL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPAL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPAL_64_memop
        IEM_INSTR_IMPL_A64__SWPAL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8a08000: SWPA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPA_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPA_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPA_32_memop
        IEM_INSTR_IMPL_A64__SWPA_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8a08000: SWPA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPA_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPA_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPA_64_memop
        IEM_INSTR_IMPL_A64__SWPA_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38208000: SWPB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPB_32_memop
        IEM_INSTR_IMPL_A64__SWPB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78208000: SWPH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPH_32_memop
        IEM_INSTR_IMPL_A64__SWPH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/38608000: SWPLB  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPLB_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPLB_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPLB_32_memop
        IEM_INSTR_IMPL_A64__SWPLB_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/78608000: SWPLH  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPLH_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPLH_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPLH_32_memop
        IEM_INSTR_IMPL_A64__SWPLH_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8608000: SWPL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPL_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPL_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPL_32_memop
        IEM_INSTR_IMPL_A64__SWPL_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8608000: SWPL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPL_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWPL_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPL_64_memop
        IEM_INSTR_IMPL_A64__SWPL_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e08000: SWPPAL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPPAL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: SWPPAL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__SWPPAL_128_memop_128
        IEM_INSTR_IMPL_A64__SWPPAL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a08000: SWPPA  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPPA_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: SWPPA_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__SWPPA_128_memop_128
        IEM_INSTR_IMPL_A64__SWPPA_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19608000: SWPPL  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPPL_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: SWPPL_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__SWPPL_128_memop_128
        IEM_INSTR_IMPL_A64__SWPPL_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19208000: SWPP  <Xt1>, <Xt2>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_128, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPP_128_memop_128, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rt2        = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse128 /*FEAT_LSE128*/)
    {
        LogFlow(("%018x/%010x: SWPP_128_memop_128 Rt=%#x Rn=%#x Rt2=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rt2));
#ifdef IEM_INSTR_IMPL_A64__SWPP_128_memop_128
        IEM_INSTR_IMPL_A64__SWPP_128_memop_128(Rt, Rn, Rt2);
#else
        RT_NOREF(Rt, Rn, Rt2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19e08400: SWPTAL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPTAL_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: SWPTAL_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPTAL_32_memop_unpriv
        IEM_INSTR_IMPL_A64__SWPTAL_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59e08400: SWPTAL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPTAL_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: SWPTAL_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPTAL_64_memop_unpriv
        IEM_INSTR_IMPL_A64__SWPTAL_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19a08400: SWPTA  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPTA_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: SWPTA_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPTA_32_memop_unpriv
        IEM_INSTR_IMPL_A64__SWPTA_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59a08400: SWPTA  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPTA_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: SWPTA_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPTA_64_memop_unpriv
        IEM_INSTR_IMPL_A64__SWPTA_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19608400: SWPTL  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPTL_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: SWPTL_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPTL_32_memop_unpriv
        IEM_INSTR_IMPL_A64__SWPTL_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59608400: SWPTL  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPTL_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: SWPTL_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPTL_64_memop_unpriv
        IEM_INSTR_IMPL_A64__SWPTL_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/19208400: SWPT  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPT_32_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: SWPT_32_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPT_32_memop_unpriv
        IEM_INSTR_IMPL_A64__SWPT_32_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/59208400: SWPT  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop_unpriv, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWPT_64_memop_unpriv, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLsui /*FEAT_LSUI*/)
    {
        LogFlow(("%018x/%010x: SWPT_64_memop_unpriv Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWPT_64_memop_unpriv
        IEM_INSTR_IMPL_A64__SWPT_64_memop_unpriv(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/b8208000: SWP  <Ws>, <Wt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWP_32_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWP_32_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWP_32_memop
        IEM_INSTR_IMPL_A64__SWP_32_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/f8208000: SWP  <Xs>, <Xt>, [<Xn|SP>]
   Instruction Set: A64  Groups: memop, ldst */
FNIEMOP_DEF_1(iemDecodeA64_SWP_64_memop, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rs         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLse /*FEAT_LSE*/)
    {
        LogFlow(("%018x/%010x: SWP_64_memop Rt=%#x Rn=%#x Rs=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, Rn, Rs));
#ifdef IEM_INSTR_IMPL_A64__SWP_64_memop
        IEM_INSTR_IMPL_A64__SWP_64_memop(Rt, Rn, Rs);
#else
        RT_NOREF(Rt, Rn, Rs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff80000/d5280000: SYSL  <Xt>, #<op1>, <Cn>, <Cm>, #<op2>
   Instruction Set: A64  Groups: systeminstrs, control */
FNIEMOP_DEF_1(iemDecodeA64_SYSL_RC_systeminstrs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    uint32_t const CRn        = (uOpcode >> 12) & 0x0000000f;
    uint32_t const op1        = (uOpcode >> 16) & 0x00000007;
    LogFlow(("%018x/%010x: SYSL_RC_systeminstrs Rt=%#x op2=%u CRm=%#x CRn=%#x op1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, op2, CRm, CRn, op1));
#ifdef IEM_INSTR_IMPL_A64__SYSL_RC_systeminstrs
    IEM_INSTR_IMPL_A64__SYSL_RC_systeminstrs(Rt, op2, CRm, CRn, op1);
#else
    RT_NOREF(Rt, op2, CRm, CRn, op1, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* fff80000/d5480000: SYSP  #<op1>, <Cn>, <Cm>, #<op2>{, <Xt1>, <Xt2>}
   Instruction Set: A64  Groups: syspairinstrs, control */
FNIEMOP_DEF_1(iemDecodeA64_SYSP_CR_syspairinstrs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    uint32_t const CRn        = (uOpcode >> 12) & 0x0000000f;
    uint32_t const op1        = (uOpcode >> 16) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSysInstr128 /*FEAT_SYSINSTR128*/)
    {
        LogFlow(("%018x/%010x: SYSP_CR_syspairinstrs Rt=%#x op2=%u CRm=%#x CRn=%#x op1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, op2, CRm, CRn, op1));
#ifdef IEM_INSTR_IMPL_A64__SYSP_CR_syspairinstrs
        IEM_INSTR_IMPL_A64__SYSP_CR_syspairinstrs(Rt, op2, CRm, CRn, op1);
#else
        RT_NOREF(Rt, op2, CRm, CRn, op1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff80000/d5080000: SYS  #<op1>, <Cn>, <Cm>, #<op2>{, <Xt>}
   Instruction Set: A64  Groups: systeminstrs, control */
FNIEMOP_DEF_1(iemDecodeA64_SYS_CR_systeminstrs, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const op2        = (uOpcode >>  5) & 0x00000007;
    uint32_t const CRm        = (uOpcode >>  8) & 0x0000000f;
    uint32_t const CRn        = (uOpcode >> 12) & 0x0000000f;
    uint32_t const op1        = (uOpcode >> 16) & 0x00000007;
    LogFlow(("%018x/%010x: SYS_CR_systeminstrs Rt=%#x op2=%u CRm=%#x CRn=%#x op1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, op2, CRm, CRn, op1));
#ifdef IEM_INSTR_IMPL_A64__SYS_CR_systeminstrs
    IEM_INSTR_IMPL_A64__SYS_CR_systeminstrs(Rt, op2, CRm, CRn, op1);
#else
    RT_NOREF(Rt, op2, CRm, CRn, op1, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bfe0fc00/0e000000: TBL  <Vd>.<Ta>, { <Vn>.16B }, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TBL_asimdtbl_L1_1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: TBL_asimdtbl_L1_1 Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__TBL_asimdtbl_L1_1
        IEM_INSTR_IMPL_A64__TBL_asimdtbl_L1_1(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e002000: TBL  <Vd>.<Ta>, { <Vn>.16B, <Vn+1>.16B }, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TBL_asimdtbl_L2_2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: TBL_asimdtbl_L2_2 Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__TBL_asimdtbl_L2_2
        IEM_INSTR_IMPL_A64__TBL_asimdtbl_L2_2(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e004000: TBL  <Vd>.<Ta>, { <Vn>.16B, <Vn+1>.16B, <Vn+2>.16B }, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TBL_asimdtbl_L3_3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: TBL_asimdtbl_L3_3 Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__TBL_asimdtbl_L3_3
        IEM_INSTR_IMPL_A64__TBL_asimdtbl_L3_3(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e006000: TBL  <Vd>.<Ta>, { <Vn>.16B, <Vn+1>.16B, <Vn+2>.16B, <Vn+3>.16B }, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TBL_asimdtbl_L4_4, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: TBL_asimdtbl_L4_4 Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__TBL_asimdtbl_L4_4
        IEM_INSTR_IMPL_A64__TBL_asimdtbl_L4_4(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 7f000000/37000000: TBNZ  <R><t>, #<imm>, <label>
   Instruction Set: A64  Groups: testbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_TBNZ_only_testbranch, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm14      = (uOpcode >>  5) & 0x00003fff;
    uint32_t const b40        = (uOpcode >> 19) & 0x0000001f;
    uint32_t const b5         = (uOpcode >> 31) & 0x00000001;
    LogFlow(("%018x/%010x: TBNZ_only_testbranch Rt=%#x imm14=%#x b40=%#x b5=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm14, b40, b5));
#ifdef IEM_INSTR_IMPL_A64__TBNZ_only_testbranch
    IEM_INSTR_IMPL_A64__TBNZ_only_testbranch(Rt, imm14, b40, b5);
#else
    RT_NOREF(Rt, imm14, b40, b5, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bfe0fc00/0e001000: TBX  <Vd>.<Ta>, { <Vn>.16B }, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TBX_asimdtbl_L1_1, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: TBX_asimdtbl_L1_1 Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__TBX_asimdtbl_L1_1
        IEM_INSTR_IMPL_A64__TBX_asimdtbl_L1_1(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e003000: TBX  <Vd>.<Ta>, { <Vn>.16B, <Vn+1>.16B }, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TBX_asimdtbl_L2_2, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: TBX_asimdtbl_L2_2 Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__TBX_asimdtbl_L2_2
        IEM_INSTR_IMPL_A64__TBX_asimdtbl_L2_2(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e005000: TBX  <Vd>.<Ta>, { <Vn>.16B, <Vn+1>.16B, <Vn+2>.16B }, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TBX_asimdtbl_L3_3, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: TBX_asimdtbl_L3_3 Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__TBX_asimdtbl_L3_3
        IEM_INSTR_IMPL_A64__TBX_asimdtbl_L3_3(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e007000: TBX  <Vd>.<Ta>, { <Vn>.16B, <Vn+1>.16B, <Vn+2>.16B, <Vn+3>.16B }, <Vm>.<Ta>
   Instruction Set: A64  Groups: asimdtbl, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TBX_asimdtbl_L4_4, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: TBX_asimdtbl_L4_4 Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__TBX_asimdtbl_L4_4
        IEM_INSTR_IMPL_A64__TBX_asimdtbl_L4_4(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* 7f000000/36000000: TBZ  <R><t>, #<imm>, <label>
   Instruction Set: A64  Groups: testbranch, control */
FNIEMOP_DEF_1(iemDecodeA64_TBZ_only_testbranch, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
    {
        uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm14      = (uOpcode >>  5) & 0x00003fff;
        uint32_t const b40        = (uOpcode >> 19) & 0x0000001f;
        uint32_t const b5         = (uOpcode >> 31) & 0x00000001;
        LogFlow(("%018x/%010x: TBZ_only_testbranch Rt=%#x imm14=%#x b40=%#x b5=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, imm14, b40, b5));
#ifdef IEM_INSTR_IMPL_A64__TBZ_only_testbranch
        IEM_INSTR_IMPL_A64__TBZ_only_testbranch(Rt, imm14, b40, b5);
#else
        RT_NOREF(Rt, imm14, b40, b5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001f/d4600000: TCANCEL  #<imm>
   Instruction Set: A64  Groups: exception, control */
FNIEMOP_DEF_1(iemDecodeA64_TCANCEL_EX_exception, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4600000))
    {
        uint32_t const imm16      = (uOpcode >>  5) & 0x0000ffff;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fTme /*FEAT_TME*/)
        {
            LogFlow(("%018x/%010x: TCANCEL_EX_exception imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__TCANCEL_EX_exception
            IEM_INSTR_IMPL_A64__TCANCEL_EX_exception(imm16);
#else
            RT_NOREF(imm16, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503307f: TCOMMIT
   Instruction Set: A64  Groups: barriers, control */
FNIEMOP_DEF_1(iemDecodeA64_TCOMMIT_only_barriers, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503307f))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fTme /*FEAT_TME*/)
        {
            LogFlow(("%018x/%010x: TCOMMIT_only_barriers\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__TCOMMIT_only_barriers
            IEM_INSTR_IMPL_A64__TCOMMIT_only_barriers();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e002800: TRN1  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdperm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TRN1_asimdperm_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e002800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: TRN1_asimdperm_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__TRN1_asimdperm_only
            IEM_INSTR_IMPL_A64__TRN1_asimdperm_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e006800: TRN2  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdperm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_TRN2_asimdperm_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e006800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: TRN2_asimdperm_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__TRN2_asimdperm_only
            IEM_INSTR_IMPL_A64__TRN2_asimdperm_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503225f: TSB  CSYNC
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_TSB_HC_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fTrf /*FEAT_TRF*/)
    {
        LogFlow(("%018x/%010x: TSB_HC_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__TSB_HC_hints
        IEM_INSTR_IMPL_A64__TSB_HC_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/d5233060: TSTART  <Xt>
   Instruction Set: A64  Groups: systemresult, control */
FNIEMOP_DEF_1(iemDecodeA64_TSTART_BR_systemresult, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fTme /*FEAT_TME*/)
    {
        LogFlow(("%018x/%010x: TSTART_BR_systemresult Rt=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt));
#ifdef IEM_INSTR_IMPL_A64__TSTART_BR_systemresult
        IEM_INSTR_IMPL_A64__TSTART_BR_systemresult(Rt);
#else
        RT_NOREF(Rt, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/d5233160: TTEST  <Xt>
   Instruction Set: A64  Groups: systemresult, control */
FNIEMOP_DEF_1(iemDecodeA64_TTEST_BR_systemresult, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fTme /*FEAT_TME*/)
    {
        LogFlow(("%018x/%010x: TTEST_BR_systemresult Rt=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt));
#ifdef IEM_INSTR_IMPL_A64__TTEST_BR_systemresult
        IEM_INSTR_IMPL_A64__TTEST_BR_systemresult(Rt);
#else
        RT_NOREF(Rt, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e205000: UABAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UABAL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e205000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UABAL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UABAL_asimddiff_L
            IEM_INSTR_IMPL_A64__UABAL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e207c00: UABA  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UABA_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e207c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UABA_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UABA_asimdsame_only
            IEM_INSTR_IMPL_A64__UABA_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e207000: UABDL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UABDL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e207000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UABDL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UABDL_asimddiff_L
            IEM_INSTR_IMPL_A64__UABDL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e207400: UABD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UABD_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e207400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UABD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UABD_asimdsame_only
            IEM_INSTR_IMPL_A64__UABD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e206800: UADALP  <Vd>.<Ta>, <Vn>.<Tb>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UADALP_asimdmisc_P, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e206800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UADALP_asimdmisc_P Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UADALP_asimdmisc_P
            IEM_INSTR_IMPL_A64__UADALP_asimdmisc_P(Rd, Rn, size, Q);
#else
            RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e202800: UADDLP  <Vd>.<Ta>, <Vn>.<Tb>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UADDLP_asimdmisc_P, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UADDLP_asimdmisc_P Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UADDLP_asimdmisc_P
        IEM_INSTR_IMPL_A64__UADDLP_asimdmisc_P(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e303800: UADDLV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UADDLV_asimdall_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UADDLV_asimdall_only Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UADDLV_asimdall_only
        IEM_INSTR_IMPL_A64__UADDLV_asimdall_only(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e200000: UADDL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UADDL_asimddiff_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UADDL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UADDL_asimddiff_L
        IEM_INSTR_IMPL_A64__UADDL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e201000: UADDW2  <Vd>.<Ta>, <Vn>.<Ta>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UADDW_asimddiff_W, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e201000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UADDW_asimddiff_W Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UADDW_asimddiff_W
            IEM_INSTR_IMPL_A64__UADDW_asimddiff_W(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc00000/53000000: UBFM  <Wd>, <Wn>, #<immr>, #<imms>
   Instruction Set: A64  Groups: bitfield, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_UBFM_32M_bitfield, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    LogFlow(("%018x/%010x: UBFM_32M_bitfield Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__UBFM_32M_bitfield
    IEM_INSTR_IMPL_A64__UBFM_32M_bitfield(Rd, Rn, imms, immr);
#else
    RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffc00000/d3400000: UBFM  <Xd>, <Xn>, #<immr>, #<imms>
   Instruction Set: A64  Groups: bitfield, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_UBFM_64M_bitfield, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imms       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const immr       = (uOpcode >> 16) & 0x0000003f;
    LogFlow(("%018x/%010x: UBFM_64M_bitfield Rd=%#x Rn=%#x imms=%#x immr=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imms, immr));
#ifdef IEM_INSTR_IMPL_A64__UBFM_64M_bitfield
    IEM_INSTR_IMPL_A64__UBFM_64M_bitfield(Rd, Rn, imms, immr);
#else
    RT_NOREF(Rd, Rn, imms, immr, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffff0000/1e430000: UCVTF  <Dd>, <Wn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_D32_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: UCVTF_D32_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_D32_float2fix
        IEM_INSTR_IMPL_A64__UCVTF_D32_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e630000: UCVTF  <Dd>, <Wn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_D32_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: UCVTF_D32_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_D32_float2int
        IEM_INSTR_IMPL_A64__UCVTF_D32_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9e430000: UCVTF  <Dd>, <Xn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_D64_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: UCVTF_D64_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_D64_float2fix
        IEM_INSTR_IMPL_A64__UCVTF_D64_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e630000: UCVTF  <Dd>, <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_D64_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: UCVTF_D64_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_D64_float2int
        IEM_INSTR_IMPL_A64__UCVTF_D64_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1ec30000: UCVTF  <Hd>, <Wn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_H32_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: UCVTF_H32_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_H32_float2fix
        IEM_INSTR_IMPL_A64__UCVTF_H32_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1ee30000: UCVTF  <Hd>, <Wn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_H32_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: UCVTF_H32_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_H32_float2int
        IEM_INSTR_IMPL_A64__UCVTF_H32_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9ec30000: UCVTF  <Hd>, <Xn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_H64_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: UCVTF_H64_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_H64_float2fix
        IEM_INSTR_IMPL_A64__UCVTF_H64_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9ee30000: UCVTF  <Hd>, <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_H64_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: UCVTF_H64_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_H64_float2int
        IEM_INSTR_IMPL_A64__UCVTF_H64_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/1e030000: UCVTF  <Sd>, <Wn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_S32_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: UCVTF_S32_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_S32_float2fix
        IEM_INSTR_IMPL_A64__UCVTF_S32_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e230000: UCVTF  <Sd>, <Wn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_S32_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: UCVTF_S32_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_S32_float2int
        IEM_INSTR_IMPL_A64__UCVTF_S32_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/9e030000: UCVTF  <Sd>, <Xn>, #<fbits>
   Instruction Set: A64  Groups: float2fix, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_S64_float2fix, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const scale      = (uOpcode >> 10) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: UCVTF_S64_float2fix Rd=%#x Rn=%#x scale=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, scale));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_S64_float2fix
        IEM_INSTR_IMPL_A64__UCVTF_S64_float2fix(Rd, Rn, scale);
#else
        RT_NOREF(Rd, Rn, scale, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e230000: UCVTF  <Sd>, <Xn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_S64_float2int, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp /*FEAT_FP*/)
    {
        LogFlow(("%018x/%010x: UCVTF_S64_float2int Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_S64_float2int
        IEM_INSTR_IMPL_A64__UCVTF_S64_float2int(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2e21d800: UCVTF  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UCVTF_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_asimdmisc_R
        IEM_INSTR_IMPL_A64__UCVTF_asimdmisc_R(Rd, Rn, sz, Q);
#else
        RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bffffc00/2e79d800: UCVTF  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_asimdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: UCVTF_asimdmiscfp16_R Rd=%#x Rn=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Q));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_asimdmiscfp16_R
        IEM_INSTR_IMPL_A64__UCVTF_asimdmiscfp16_R(Rd, Rn, Q);
#else
        RT_NOREF(Rd, Rn, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f00e400: UCVTF  <Vd>.<T>, <Vn>.<T>, #<fbits>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_asimdshf_C, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: UCVTF_asimdshf_C Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_asimdshf_C
        IEM_INSTR_IMPL_A64__UCVTF_asimdshf_C(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbffc00/7e21d800: UCVTF  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_asisdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UCVTF_asisdmisc_R Rd=%#x Rn=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_asisdmisc_R
        IEM_INSTR_IMPL_A64__UCVTF_asisdmisc_R(Rd, Rn, sz);
#else
        RT_NOREF(Rd, Rn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/7e79d800: UCVTF  <Hd>, <Hn>
   Instruction Set: A64  Groups: asisdmiscfp16, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_asisdmiscfp16_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp16 /*FEAT_FP16*/)
    {
        LogFlow(("%018x/%010x: UCVTF_asisdmiscfp16_R Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_asisdmiscfp16_R
        IEM_INSTR_IMPL_A64__UCVTF_asisdmiscfp16_R(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f00e400: UCVTF  <V><d>, <V><n>, #<fbits>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_asisdshf_C, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f00e400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
        {
            LogFlow(("%018x/%010x: UCVTF_asisdshf_C Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_asisdshf_C
            IEM_INSTR_IMPL_A64__UCVTF_asisdshf_C(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1e7d0000: UCVTF  <Dd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_sisd_32D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: UCVTF_sisd_32D Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_sisd_32D
        IEM_INSTR_IMPL_A64__UCVTF_sisd_32D(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/1efd0000: UCVTF  <Hd>, <Sn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_sisd_32H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: UCVTF_sisd_32H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_sisd_32H
        IEM_INSTR_IMPL_A64__UCVTF_sisd_32H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9efd0000: UCVTF  <Hd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_sisd_64H, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: UCVTF_sisd_64H Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_sisd_64H
        IEM_INSTR_IMPL_A64__UCVTF_sisd_64H(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/9e3d0000: UCVTF  <Sd>, <Dn>
   Instruction Set: A64  Groups: float2int, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UCVTF_sisd_64S, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFpRcvt /*FEAT_FPRCVT*/)
    {
        LogFlow(("%018x/%010x: UCVTF_sisd_64S Rd=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn));
#ifdef IEM_INSTR_IMPL_A64__UCVTF_sisd_64S
        IEM_INSTR_IMPL_A64__UCVTF_sisd_64S(Rd, Rn);
#else
        RT_NOREF(Rd, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0000/00000000: UDF  #<imm>
   Instruction Set: A64  Groups: perm_undef, reserved */
FNIEMOP_DEF_1(iemDecodeA64_UDF_only_perm_undef, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x00000000))
    {
        uint32_t const imm16      = (uOpcode >>  0) & 0x0000ffff;
        LogFlow(("%018x/%010x: UDF_only_perm_undef imm16=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm16));
#ifdef IEM_INSTR_IMPL_A64__UDF_only_perm_undef
        IEM_INSTR_IMPL_A64__UDF_only_perm_undef(imm16);
#else
        RT_NOREF(imm16, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac00800: UDIV  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UDIV_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: UDIV_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__UDIV_32_dp_2src
    IEM_INSTR_IMPL_A64__UDIV_32_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9ac00800: UDIV  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UDIV_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: UDIV_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__UDIV_64_dp_2src
    IEM_INSTR_IMPL_A64__UDIV_64_dp_2src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf00f400/2f00e000: UDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.4B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UDOT_asimdelem_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x2f00e000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fDotProd /*FEAT_DotProd*/)
        {
            LogFlow(("%018x/%010x: UDOT_asimdelem_D Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UDOT_asimdelem_D
            IEM_INSTR_IMPL_A64__UDOT_asimdelem_D(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e009400: UDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UDOT_asimdsame2_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e009400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fDotProd /*FEAT_DotProd*/)
        {
            LogFlow(("%018x/%010x: UDOT_asimdsame2_D Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UDOT_asimdsame2_D
            IEM_INSTR_IMPL_A64__UDOT_asimdsame2_D(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e200400: UHADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UHADD_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e200400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UHADD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UHADD_asimdsame_only
            IEM_INSTR_IMPL_A64__UHADD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e202400: UHSUB  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UHSUB_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e202400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UHSUB_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UHSUB_asimdsame_only
            IEM_INSTR_IMPL_A64__UHSUB_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/9ba00000: UMADDL  <Xd>, <Wn>, <Wm>, <Xa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UMADDL_64WA_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: UMADDL_64WA_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__UMADDL_64WA_dp_3src
    IEM_INSTR_IMPL_A64__UMADDL_64WA_dp_3src(Rd, Rn, Ra, Rm);
#else
    RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf20fc00/2e20a400: UMAXP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMAXP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20a400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMAXP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMAXP_asimdsame_only
            IEM_INSTR_IMPL_A64__UMAXP_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e30a800: UMAXV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMAXV_asimdall_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UMAXV_asimdall_only Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMAXV_asimdall_only
        IEM_INSTR_IMPL_A64__UMAXV_asimdall_only(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/11c40000: UMAX  <Wd>, <Wn>, #<uimm>
   Instruction Set: A64  Groups: minmax_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_UMAX_32U_minmax_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 10) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: UMAX_32U_minmax_imm Rd=%#x Rn=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm8));
#ifdef IEM_INSTR_IMPL_A64__UMAX_32U_minmax_imm
        IEM_INSTR_IMPL_A64__UMAX_32U_minmax_imm(Rd, Rn, imm8);
#else
        RT_NOREF(Rd, Rn, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac06400: UMAX  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UMAX_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: UMAX_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__UMAX_32_dp_2src
        IEM_INSTR_IMPL_A64__UMAX_32_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/91c40000: UMAX  <Xd>, <Xn>, #<uimm>
   Instruction Set: A64  Groups: minmax_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_UMAX_64U_minmax_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 10) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: UMAX_64U_minmax_imm Rd=%#x Rn=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm8));
#ifdef IEM_INSTR_IMPL_A64__UMAX_64U_minmax_imm
        IEM_INSTR_IMPL_A64__UMAX_64U_minmax_imm(Rd, Rn, imm8);
#else
        RT_NOREF(Rd, Rn, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac06400: UMAX  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UMAX_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: UMAX_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__UMAX_64_dp_2src
        IEM_INSTR_IMPL_A64__UMAX_64_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e206400: UMAX  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMAX_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e206400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMAX_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMAX_asimdsame_only
            IEM_INSTR_IMPL_A64__UMAX_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e20ac00: UMINP  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMINP_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20ac00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMINP_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMINP_asimdsame_only
            IEM_INSTR_IMPL_A64__UMINP_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e31a800: UMINV  <V><d>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdall, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMINV_asimdall_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UMINV_asimdall_only Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMINV_asimdall_only
        IEM_INSTR_IMPL_A64__UMINV_asimdall_only(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/11cc0000: UMIN  <Wd>, <Wn>, #<uimm>
   Instruction Set: A64  Groups: minmax_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_UMIN_32U_minmax_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 10) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: UMIN_32U_minmax_imm Rd=%#x Rn=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm8));
#ifdef IEM_INSTR_IMPL_A64__UMIN_32U_minmax_imm
        IEM_INSTR_IMPL_A64__UMIN_32U_minmax_imm(Rd, Rn, imm8);
#else
        RT_NOREF(Rd, Rn, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/1ac06c00: UMIN  <Wd>, <Wn>, <Wm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UMIN_32_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: UMIN_32_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__UMIN_32_dp_2src
        IEM_INSTR_IMPL_A64__UMIN_32_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/91cc0000: UMIN  <Xd>, <Xn>, #<uimm>
   Instruction Set: A64  Groups: minmax_imm, dpimm */
FNIEMOP_DEF_1(iemDecodeA64_UMIN_64U_minmax_imm, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >> 10) & 0x000000ff;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: UMIN_64U_minmax_imm Rd=%#x Rn=%#x imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm8));
#ifdef IEM_INSTR_IMPL_A64__UMIN_64U_minmax_imm
        IEM_INSTR_IMPL_A64__UMIN_64U_minmax_imm(Rd, Rn, imm8);
#else
        RT_NOREF(Rd, Rn, imm8, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/9ac06c00: UMIN  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_2src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UMIN_64_dp_2src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCssc /*FEAT_CSSC*/)
    {
        LogFlow(("%018x/%010x: UMIN_64_dp_2src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__UMIN_64_dp_2src
        IEM_INSTR_IMPL_A64__UMIN_64_dp_2src(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e206c00: UMIN  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMIN_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e206c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMIN_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMIN_asimdsame_only
            IEM_INSTR_IMPL_A64__UMIN_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e208000: UMLAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMLAL_asimddiff_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UMLAL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMLAL_asimddiff_L
        IEM_INSTR_IMPL_A64__UMLAL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/2f002000: UMLAL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMLAL_asimdelem_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x2f002000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMLAL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMLAL_asimdelem_L
            IEM_INSTR_IMPL_A64__UMLAL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e20a000: UMLSL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMLSL_asimddiff_L, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UMLSL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMLSL_asimddiff_L
        IEM_INSTR_IMPL_A64__UMLSL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/2f006000: UMLSL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMLSL_asimdelem_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x2f006000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMLSL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMLSL_asimdelem_L
            IEM_INSTR_IMPL_A64__UMLSL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6e80a400: UMMLA  <Vd>.4S, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMMLA_asimdsame2_G, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x6e80a400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
        {
            LogFlow(("%018x/%010x: UMMLA_asimdsame2_G Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__UMMLA_asimdsame2_G
            IEM_INSTR_IMPL_A64__UMMLA_asimdsame2_G(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/0e003c00: UMOV  <Wd>, <Vn>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdins, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMOV_asimdins_W_w, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0e003c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMOV_asimdins_W_w Rd=%#x Rn=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm5));
#ifdef IEM_INSTR_IMPL_A64__UMOV_asimdins_W_w
            IEM_INSTR_IMPL_A64__UMOV_asimdins_W_w(Rd, Rn, imm5);
#else
            RT_NOREF(Rd, Rn, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffeffc00/4e083c00: UMOV  <Xd>, <Vn>.D[<index>]
   Instruction Set: A64  Groups: asimdins, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMOV_asimdins_X_x, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffeffc00)) == UINT32_C(0x4e083c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMOV_asimdins_X_x Rd=%#x Rn=%#x imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm5));
#ifdef IEM_INSTR_IMPL_A64__UMOV_asimdins_X_x
            IEM_INSTR_IMPL_A64__UMOV_asimdins_X_x(Rd, Rn, imm5);
#else
            RT_NOREF(Rd, Rn, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe08000/9ba08000: UMSUBL  <Xd>, <Wn>, <Wm>, <Xa>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UMSUBL_64WA_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Ra         = (uOpcode >> 10) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: UMSUBL_64WA_dp_3src Rd=%#x Rn=%#x Ra=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Ra, Rm));
#ifdef IEM_INSTR_IMPL_A64__UMSUBL_64WA_dp_3src
    IEM_INSTR_IMPL_A64__UMSUBL_64WA_dp_3src(Rd, Rn, Ra, Rm);
#else
    RT_NOREF(Rd, Rn, Ra, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffe0fc00/9bc07c00: UMULH  <Xd>, <Xn>, <Xm>
   Instruction Set: A64  Groups: dp_3src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_UMULH_64_dp_3src, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    LogFlow(("%018x/%010x: UMULH_64_dp_3src Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__UMULH_64_dp_3src
    IEM_INSTR_IMPL_A64__UMULH_64_dp_3src(Rd, Rn, Rm);
#else
    RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf20fc00/2e20c000: UMULL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMULL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMULL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMULL_asimddiff_L
            IEM_INSTR_IMPL_A64__UMULL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf00f400/2f00a000: UMULL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Ts>[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UMULL_asimdelem_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x2f00a000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UMULL_asimdelem_L Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UMULL_asimdelem_L
            IEM_INSTR_IMPL_A64__UMULL_asimdelem_L(Rd, Rn, H, Rm, M, L, size, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e200c00: UQADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQADD_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UQADD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UQADD_asimdsame_only
        IEM_INSTR_IMPL_A64__UQADD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/7e200c00: UQADD  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQADD_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x7e200c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UQADD_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__UQADD_asisdsame_only
            IEM_INSTR_IMPL_A64__UQADD_asisdsame_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e205c00: UQRSHL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQRSHL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UQRSHL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UQRSHL_asimdsame_only
        IEM_INSTR_IMPL_A64__UQRSHL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/7e205c00: UQRSHL  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQRSHL_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x7e205c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UQRSHL_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__UQRSHL_asisdsame_only
            IEM_INSTR_IMPL_A64__UQRSHL_asisdsame_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f009c00: UQRSHRN2  <Vd>.<Tb>, <Vn>.<Ta>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQRSHRN_asimdshf_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: UQRSHRN_asimdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__UQRSHRN_asimdshf_N
        IEM_INSTR_IMPL_A64__UQRSHRN_asimdshf_N(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f009c00: UQRSHRN  <Vb><d>, <Va><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQRSHRN_asisdshf_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f009c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
        {
            LogFlow(("%018x/%010x: UQRSHRN_asisdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__UQRSHRN_asisdshf_N
            IEM_INSTR_IMPL_A64__UQRSHRN_asisdshf_N(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e204c00: UQSHL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQSHL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UQSHL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UQSHL_asimdsame_only
        IEM_INSTR_IMPL_A64__UQSHL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f007400: UQSHL  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQSHL_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: UQSHL_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__UQSHL_asimdshf_R
        IEM_INSTR_IMPL_A64__UQSHL_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/7e204c00: UQSHL  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQSHL_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x7e204c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UQSHL_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__UQSHL_asisdsame_only
            IEM_INSTR_IMPL_A64__UQSHL_asisdsame_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f007400: UQSHL  <V><d>, <V><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQSHL_asisdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f007400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
        {
            LogFlow(("%018x/%010x: UQSHL_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__UQSHL_asisdshf_R
            IEM_INSTR_IMPL_A64__UQSHL_asisdshf_R(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f009400: UQSHRN2  <Vd>.<Tb>, <Vn>.<Ta>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQSHRN_asimdshf_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: UQSHRN_asimdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__UQSHRN_asimdshf_N
        IEM_INSTR_IMPL_A64__UQSHRN_asimdshf_N(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f009400: UQSHRN  <Vb><d>, <Va><n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQSHRN_asisdshf_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f009400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0))
        {
            LogFlow(("%018x/%010x: UQSHRN_asisdshf_N Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__UQSHRN_asisdshf_N
            IEM_INSTR_IMPL_A64__UQSHRN_asisdshf_N(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e202c00: UQSUB  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQSUB_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UQSUB_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UQSUB_asimdsame_only
        IEM_INSTR_IMPL_A64__UQSUB_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/7e202c00: UQSUB  <V><d>, <V><n>, <V><m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQSUB_asisdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x7e202c00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UQSUB_asisdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__UQSUB_asisdsame_only
            IEM_INSTR_IMPL_A64__UQSUB_asisdsame_only(Rd, Rn, Rm, size);
#else
            RT_NOREF(Rd, Rn, Rm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e214800: UQXTN2  <Vd>.<Tb>, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQXTN_asimdmisc_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: UQXTN_asimdmisc_N Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UQXTN_asimdmisc_N
        IEM_INSTR_IMPL_A64__UQXTN_asimdmisc_N(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/7e214800: UQXTN  <Vb><d>, <Va><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UQXTN_asisdmisc_N, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x7e214800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UQXTN_asisdmisc_N Rd=%#x Rn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size));
#ifdef IEM_INSTR_IMPL_A64__UQXTN_asisdmisc_N
            IEM_INSTR_IMPL_A64__UQXTN_asisdmisc_N(Rd, Rn, size);
#else
            RT_NOREF(Rd, Rn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/0ea1c800: URECPE  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URECPE_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea1c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: URECPE_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__URECPE_asimdmisc_R
            IEM_INSTR_IMPL_A64__URECPE_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e201400: URHADD  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URHADD_asimdsame_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e201400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: URHADD_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__URHADD_asimdsame_only
            IEM_INSTR_IMPL_A64__URHADD_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e205400: URSHL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URSHL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: URSHL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__URSHL_asimdsame_only
        IEM_INSTR_IMPL_A64__URSHL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ee05400: URSHL  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URSHL_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: URSHL_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__URSHL_asisdsame_only
        IEM_INSTR_IMPL_A64__URSHL_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f002400: URSHR  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URSHR_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: URSHR_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__URSHR_asimdshf_R
        IEM_INSTR_IMPL_A64__URSHR_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f002400: URSHR  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URSHR_asisdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f002400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
        {
            LogFlow(("%018x/%010x: URSHR_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__URSHR_asisdshf_R
            IEM_INSTR_IMPL_A64__URSHR_asisdshf_R(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfbffc00/2ea1c800: URSQRTE  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URSQRTE_asimdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1c800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: URSQRTE_asimdmisc_R Rd=%#x Rn=%#x sz=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, sz, Q));
#ifdef IEM_INSTR_IMPL_A64__URSQRTE_asimdmisc_R
            IEM_INSTR_IMPL_A64__URSQRTE_asimdmisc_R(Rd, Rn, sz, Q);
#else
            RT_NOREF(Rd, Rn, sz, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f003400: URSRA  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URSRA_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: URSRA_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__URSRA_asimdshf_R
        IEM_INSTR_IMPL_A64__URSRA_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f003400: URSRA  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_URSRA_asisdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f003400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
        {
            LogFlow(("%018x/%010x: URSRA_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__URSRA_asisdshf_R
            IEM_INSTR_IMPL_A64__URSRA_asisdshf_R(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfc0f400/0f80f000: USDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.4B[<index>]
   Instruction Set: A64  Groups: asimdelem, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USDOT_asimdelem_D, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f80f000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const H          = (uOpcode >> 11) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const M          = (uOpcode >> 20) & 0x00000001;
        uint32_t const L          = (uOpcode >> 21) & 0x00000001;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
        {
            LogFlow(("%018x/%010x: USDOT_asimdelem_D Rd=%#x Rn=%#x H=%u Rm=%#x M=%u L=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, H, Rm, M, L, Q));
#ifdef IEM_INSTR_IMPL_A64__USDOT_asimdelem_D
            IEM_INSTR_IMPL_A64__USDOT_asimdelem_D(Rd, Rn, H, Rm, M, L, Q);
#else
            RT_NOREF(Rd, Rn, H, Rm, M, L, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bfe0fc00/0e809c00: USDOT  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USDOT_asimdsame2_D, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
    {
        LogFlow(("%018x/%010x: USDOT_asimdsame2_D Rd=%#x Rn=%#x Rm=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, Q));
#ifdef IEM_INSTR_IMPL_A64__USDOT_asimdsame2_D
        IEM_INSTR_IMPL_A64__USDOT_asimdsame2_D(Rd, Rn, Rm, Q);
#else
        RT_NOREF(Rd, Rn, Rm, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f00a400: USHLL2  <Vd>.<Ta>, <Vn>.<Tb>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USHLL_asimdshf_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f00a400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
        {
            LogFlow(("%018x/%010x: USHLL_asimdshf_L Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__USHLL_asimdshf_L
            IEM_INSTR_IMPL_A64__USHLL_asimdshf_L(Rd, Rn, immb, immh, Q);
#else
            RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e204400: USHL  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USHL_asimdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: USHL_asimdsame_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__USHL_asimdsame_only
        IEM_INSTR_IMPL_A64__USHL_asimdsame_only(Rd, Rn, Rm, size, Q);
#else
        RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/7ee04400: USHL  D<d>, D<n>, D<m>
   Instruction Set: A64  Groups: asisdsame, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USHL_asisdsame_only, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: USHL_asisdsame_only Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__USHL_asisdsame_only
        IEM_INSTR_IMPL_A64__USHL_asisdsame_only(Rd, Rn, Rm);
#else
        RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f000400: USHR  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USHR_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: USHR_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__USHR_asimdshf_R
        IEM_INSTR_IMPL_A64__USHR_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f000400: USHR  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USHR_asisdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f000400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
        {
            LogFlow(("%018x/%010x: USHR_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__USHR_asisdshf_R
            IEM_INSTR_IMPL_A64__USHR_asisdshf_R(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4e80ac00: USMMLA  <Vd>.4S, <Vn>.16B, <Vm>.16B
   Instruction Set: A64  Groups: asimdsame2, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USMMLA_asimdsame2_G, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4e80ac00))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
        {
            LogFlow(("%018x/%010x: USMMLA_asimdsame2_G Rd=%#x Rn=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm));
#ifdef IEM_INSTR_IMPL_A64__USMMLA_asimdsame2_G
            IEM_INSTR_IMPL_A64__USMMLA_asimdsame2_G(Rd, Rn, Rm);
#else
            RT_NOREF(Rd, Rn, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/2e203800: USQADD  <Vd>.<T>, <Vn>.<T>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USQADD_asimdmisc_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: USQADD_asimdmisc_R Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__USQADD_asimdmisc_R
        IEM_INSTR_IMPL_A64__USQADD_asimdmisc_R(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/7e203800: USQADD  <V><d>, <V><n>
   Instruction Set: A64  Groups: asisdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USQADD_asisdmisc_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x7e203800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: USQADD_asisdmisc_R Rd=%#x Rn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size));
#ifdef IEM_INSTR_IMPL_A64__USQADD_asisdmisc_R
            IEM_INSTR_IMPL_A64__USQADD_asisdmisc_R(Rd, Rn, size);
#else
            RT_NOREF(Rd, Rn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf80fc00/2f001400: USRA  <Vd>.<T>, <Vn>.<T>, #<shift>
   Instruction Set: A64  Groups: asimdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USRA_asimdshf_R, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
    uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && (immh != 0) && (immh != 0))
    {
        LogFlow(("%018x/%010x: USRA_asimdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh, Q));
#ifdef IEM_INSTR_IMPL_A64__USRA_asimdshf_R
        IEM_INSTR_IMPL_A64__USRA_asimdshf_R(Rd, Rn, immb, immh, Q);
#else
        RT_NOREF(Rd, Rn, immb, immh, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80fc00/7f001400: USRA  D<d>, D<n>, #<shift>
   Instruction Set: A64  Groups: asisdshf, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USRA_asisdshf_R, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x7f001400))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const immb       = (uOpcode >> 16) & 0x00000007;
        uint32_t const immh       = (uOpcode >> 19) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/ && ((immh & 8) == 8))
        {
            LogFlow(("%018x/%010x: USRA_asisdshf_R Rd=%#x Rn=%#x immb=%u immh=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, immb, immh));
#ifdef IEM_INSTR_IMPL_A64__USRA_asisdshf_R
            IEM_INSTR_IMPL_A64__USRA_asisdshf_R(Rd, Rn, immb, immh);
#else
            RT_NOREF(Rd, Rn, immb, immh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e202000: USUBL2  <Vd>.<Ta>, <Vn>.<Tb>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USUBL_asimddiff_L, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e202000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: USUBL_asimddiff_L Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__USUBL_asimddiff_L
            IEM_INSTR_IMPL_A64__USUBL_asimddiff_L(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/2e203000: USUBW2  <Vd>.<Ta>, <Vn>.<Ta>, <Vm>.<Tb>
   Instruction Set: A64  Groups: asimddiff, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_USUBW_asimddiff_W, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e203000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: USUBW_asimddiff_W Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__USUBW_asimddiff_W
            IEM_INSTR_IMPL_A64__USUBW_asimddiff_W(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e001800: UZP1  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdperm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UZP1_asimdperm_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e001800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UZP1_asimdperm_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UZP1_asimdperm_only
            IEM_INSTR_IMPL_A64__UZP1_asimdperm_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e005800: UZP2  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdperm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_UZP2_asimdperm_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e005800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: UZP2_asimdperm_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__UZP2_asimdperm_only
            IEM_INSTR_IMPL_A64__UZP2_asimdperm_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/d5031000: WFET  <Xt>
   Instruction Set: A64  Groups: systeminstrswithreg, control */
FNIEMOP_DEF_1(iemDecodeA64_WFET_only_systeminstrswithreg, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fWfxt /*FEAT_WFxT*/)
    {
        LogFlow(("%018x/%010x: WFET_only_systeminstrswithreg Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__WFET_only_systeminstrswithreg
        IEM_INSTR_IMPL_A64__WFET_only_systeminstrswithreg(Rd);
#else
        RT_NOREF(Rd, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503205f: WFE
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_WFE_HI_hints, uint32_t, uOpcode)
{
    LogFlow(("%018x/%010x: WFE_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__WFE_HI_hints
    IEM_INSTR_IMPL_A64__WFE_HI_hints();
#else
    RT_NOREF(pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffffffe0/d5031020: WFIT  <Xt>
   Instruction Set: A64  Groups: systeminstrswithreg, control */
FNIEMOP_DEF_1(iemDecodeA64_WFIT_only_systeminstrswithreg, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fWfxt /*FEAT_WFxT*/)
    {
        LogFlow(("%018x/%010x: WFIT_only_systeminstrswithreg Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__WFIT_only_systeminstrswithreg
        IEM_INSTR_IMPL_A64__WFIT_only_systeminstrswithreg(Rd);
#else
        RT_NOREF(Rd, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503207f: WFI
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_WFI_HI_hints, uint32_t, uOpcode)
{
    LogFlow(("%018x/%010x: WFI_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__WFI_HI_hints
    IEM_INSTR_IMPL_A64__WFI_HI_hints();
#else
    RT_NOREF(pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* ffffffff/d500403f: XAFLAG
   Instruction Set: A64  Groups: pstate, control */
FNIEMOP_DEF_1(iemDecodeA64_XAFLAG_M_pstate, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFlagM2 /*FEAT_FlagM2*/)
    {
        LogFlow(("%018x/%010x: XAFLAG_M_pstate\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__XAFLAG_M_pstate
        IEM_INSTR_IMPL_A64__XAFLAG_M_pstate();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00000/ce800000: XAR  <Vd>.2D, <Vn>.2D, <Vm>.2D, #<imm6>
   Instruction Set: A64  Groups: crypto3_imm6, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_XAR_VVV2_crypto3_imm6, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >> 10) & 0x0000003f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSha3 /*FEAT_SHA3*/)
    {
        LogFlow(("%018x/%010x: XAR_VVV2_crypto3_imm6 Rd=%#x Rn=%#x imm6=%#x Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, imm6, Rm));
#ifdef IEM_INSTR_IMPL_A64__XAR_VVV2_crypto3_imm6
        IEM_INSTR_IMPL_A64__XAR_VVV2_crypto3_imm6(Rd, Rn, imm6, Rm);
#else
        RT_NOREF(Rd, Rn, imm6, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac147e0: XPACD  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_XPACD_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac147e0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: XPACD_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__XPACD_64Z_dp_1src
            IEM_INSTR_IMPL_A64__XPACD_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/dac143e0: XPACI  <Xd>
   Instruction Set: A64  Groups: dp_1src, dpreg */
FNIEMOP_DEF_1(iemDecodeA64_XPACI_64Z_dp_1src, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac143e0))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
        {
            LogFlow(("%018x/%010x: XPACI_64Z_dp_1src Rd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd));
#ifdef IEM_INSTR_IMPL_A64__XPACI_64Z_dp_1src
            IEM_INSTR_IMPL_A64__XPACI_64Z_dp_1src(Rd);
#else
            RT_NOREF(Rd, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d50320ff: XPACLRI
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_XPACLRI_HI_hints, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fPAuth /*FEAT_PAuth*/)
    {
        LogFlow(("%018x/%010x: XPACLRI_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__XPACLRI_HI_hints
        IEM_INSTR_IMPL_A64__XPACLRI_HI_hints();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf3ffc00/0e212800: XTN2  <Vd>.<Tb>, <Vn>.<Ta>
   Instruction Set: A64  Groups: asimdmisc, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_XTN_asimdmisc_N, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
    {
        LogFlow(("%018x/%010x: XTN_asimdmisc_N Rd=%#x Rn=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, size, Q));
#ifdef IEM_INSTR_IMPL_A64__XTN_asimdmisc_N
        IEM_INSTR_IMPL_A64__XTN_asimdmisc_N(Rd, Rn, size, Q);
#else
        RT_NOREF(Rd, Rn, size, Q, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/d503203f: YIELD
   Instruction Set: A64  Groups: hints, control */
FNIEMOP_DEF_1(iemDecodeA64_YIELD_HI_hints, uint32_t, uOpcode)
{
    LogFlow(("%018x/%010x: YIELD_HI_hints\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__YIELD_HI_hints
    IEM_INSTR_IMPL_A64__YIELD_HI_hints();
#else
    RT_NOREF(pVCpu, uOpcode);
    return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
}

/* bf20fc00/0e003800: ZIP1  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdperm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ZIP1_asimdperm_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e003800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ZIP1_asimdperm_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ZIP1_asimdperm_only
            IEM_INSTR_IMPL_A64__ZIP1_asimdperm_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* bf20fc00/0e007800: ZIP2  <Vd>.<T>, <Vn>.<T>, <Vm>.<T>
   Instruction Set: A64  Groups: asimdperm, simd_dp */
FNIEMOP_DEF_1(iemDecodeA64_ZIP2_asimdperm_only, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e007800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        uint32_t const Q          = (uOpcode >> 30) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fAdvSimd /*FEAT_AdvSIMD*/)
        {
            LogFlow(("%018x/%010x: ZIP2_asimdperm_only Rd=%#x Rn=%#x Rm=%#x size=%u Q=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Rn, Rm, size, Q));
#ifdef IEM_INSTR_IMPL_A64__ZIP2_asimdperm_only
            IEM_INSTR_IMPL_A64__ZIP2_asimdperm_only(Rd, Rn, Rm, size, Q);
#else
            RT_NOREF(Rd, Rn, Rm, size, Q, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0416a000: ABS  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_abs_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: abs_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__abs_z_p_z_m
        IEM_INSTR_IMPL_A64__abs_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0406a000: ABS  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_abs_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: abs_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__abs_z_p_z_z
        IEM_INSTR_IMPL_A64__abs_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4500d000: ADCLB  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_adc_long, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_adclb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: adclb_z_zzz Zda=%#x Zn=%#x Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__adclb_z_zzz
        IEM_INSTR_IMPL_A64__adclb_z_zzz(Zda, Zn, Zm, sz);
#else
        RT_NOREF(Zda, Zn, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4500d400: ADCLT  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_adc_long, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_adclt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: adclt_z_zzz Zda=%#x Zn=%#x Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__adclt_z_zzz
        IEM_INSTR_IMPL_A64__adclt_z_zzz(Zda, Zn, Zm, sz);
#else
        RT_NOREF(Zda, Zn, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a300: ADD  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_add_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_add_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a300))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: add_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__add_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__add_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120ab00: ADD  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_add_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_add_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120ab00))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: add_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__add_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__add_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04000000: ADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_0, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_add_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04000000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: add_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__add_z_p_zz
            IEM_INSTR_IMPL_A64__add_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc000/2520c000: ADD  <Zdn>.<T>, <Zdn>.<T>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_arith_imm0, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_add_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc000)) == UINT32_C(0x2520c000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
        uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: add_z_zi Zdn=%#x imm8=%#x sh=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, sh, size));
#ifdef IEM_INSTR_IMPL_A64__add_z_zi
            IEM_INSTR_IMPL_A64__add_z_zi(Zdn, imm8, sh, size);
#else
            RT_NOREF(Zdn, imm8, sh, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04200000: ADD  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_cons_arit_0, sve_int_unpred_arit, sve */
FNIEMOP_DEF_1(iemDecodeA64_add_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: add_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__add_z_zz
        IEM_INSTR_IMPL_A64__add_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbf9c38/c1a01c10: ADD  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_int_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_add_za_zw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbf9c38)) == UINT32_C(0xc1a01c10))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: add_za_zw_2x2 off3=%u Zm=%#x Rv=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv, sz));
#ifdef IEM_INSTR_IMPL_A64__add_za_zw_2x2
            IEM_INSTR_IMPL_A64__add_za_zw_2x2(off3, Zm, Rv, sz);
#else
            RT_NOREF(off3, Zm, Rv, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbf9c78/c1a11c10: ADD  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_int_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_add_za_zw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbf9c78)) == UINT32_C(0xc1a11c10))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: add_za_zw_4x4 off3=%u Zm=%u Rv=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv, sz));
#ifdef IEM_INSTR_IMPL_A64__add_za_zw_4x4
            IEM_INSTR_IMPL_A64__add_za_zw_4x4(off3, Zm, Rv, sz);
#else
            RT_NOREF(off3, Zm, Rv, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1201810: ADD  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<T>-<Zn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_int_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_add_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: add_za_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__add_za_zzv_2x1
        IEM_INSTR_IMPL_A64__add_za_zzv_2x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1301810: ADD  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<T>-<Zn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_int_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_add_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: add_za_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__add_za_zzv_4x1
        IEM_INSTR_IMPL_A64__add_za_zzv_4x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c38/c1a01810: ADD  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<T>-<Zn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_int_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_add_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c38)) == UINT32_C(0xc1a01810))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: add_za_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__add_za_zzw_2x2
            IEM_INSTR_IMPL_A64__add_za_zzw_2x2(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c78/c1a11810: ADD  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<T>-<Zn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_int_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_add_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c78)) == UINT32_C(0xc1a11810))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: add_za_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__add_za_zzw_4x4
            IEM_INSTR_IMPL_A64__add_za_zzw_4x4(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff001c/c0900000: ADDHA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.S
   Instruction Set: A64  Groups: mortlach_addhv, mortlach_hvadd, sme */
FNIEMOP_DEF_1(iemDecodeA64_addha_za_pp_z_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addha_za_pp_z_32 ZAda=%u Zn=%#x Pn=%u Pm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm));
#ifdef IEM_INSTR_IMPL_A64__addha_za_pp_z_32
        IEM_INSTR_IMPL_A64__addha_za_pp_z_32(ZAda, Zn, Pn, Pm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0018/c0d00000: ADDHA  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.D
   Instruction Set: A64  Groups: mortlach_addhv, mortlach_hvadd, sme */
FNIEMOP_DEF_1(iemDecodeA64_addha_za_pp_z_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: addha_za_pp_z_64 ZAda=%u Zn=%#x Pn=%u Pm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm));
#ifdef IEM_INSTR_IMPL_A64__addha_za_pp_z_64
        IEM_INSTR_IMPL_A64__addha_za_pp_z_64(ZAda, Zn, Pn, Pm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45206000: ADDHNB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_arith_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_addhnb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addhnb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__addhnb_z_zz
        IEM_INSTR_IMPL_A64__addhnb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45206400: ADDHNT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_arith_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_addhnt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addhnt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__addhnt_z_zz
        IEM_INSTR_IMPL_A64__addhnt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4411a000: ADDP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_arith_binary_pairs, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_addp_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__addp_z_p_zz
        IEM_INSTR_IMPL_A64__addp_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f800/04605000: ADDPL  <Xd|SP>, <Xn|SP>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_vl, sve_alloca, sve */
FNIEMOP_DEF_1(iemDecodeA64_addpl_r_ri, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >>  5) & 0x0000003f;
    uint32_t const Rn         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addpl_r_ri Rd=%#x imm6=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm6, Rn));
#ifdef IEM_INSTR_IMPL_A64__addpl_r_ri
        IEM_INSTR_IMPL_A64__addpl_r_ri(Rd, imm6, Rn);
#else
        RT_NOREF(Rd, imm6, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/04c40000: ADDPT  <Zdn>.D, <Pg>/M, <Zdn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_0, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_addpt_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x04c40000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
        {
            LogFlow(("%018x/%010x: addpt_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__addpt_z_p_zz
            IEM_INSTR_IMPL_A64__addpt_z_p_zz(Zdn, Zm, Pg);
#else
            RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04e00800: ADDPT  <Zd>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_arit_0, sve_int_unpred_arit, sve */
FNIEMOP_DEF_1(iemDecodeA64_addpt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
    {
        LogFlow(("%018x/%010x: addpt_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__addpt_z_zz
        IEM_INSTR_IMPL_A64__addpt_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04052000: ADDQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_reduce_0q, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_addqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: addqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__addqv_z_p_z
        IEM_INSTR_IMPL_A64__addqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f800/04605800: ADDSPL  <Xd|SP>, <Xn|SP>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_svl, sve_alloca, sve */
FNIEMOP_DEF_1(iemDecodeA64_addspl_r_ri, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >>  5) & 0x0000003f;
    uint32_t const Rn         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addspl_r_ri Rd=%#x imm6=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm6, Rn));
#ifdef IEM_INSTR_IMPL_A64__addspl_r_ri
        IEM_INSTR_IMPL_A64__addspl_r_ri(Rd, imm6, Rn);
#else
        RT_NOREF(Rd, imm6, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f800/04205800: ADDSVL  <Xd|SP>, <Xn|SP>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_svl, sve_alloca, sve */
FNIEMOP_DEF_1(iemDecodeA64_addsvl_r_ri, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >>  5) & 0x0000003f;
    uint32_t const Rn         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addsvl_r_ri Rd=%#x imm6=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm6, Rn));
#ifdef IEM_INSTR_IMPL_A64__addsvl_r_ri
        IEM_INSTR_IMPL_A64__addsvl_r_ri(Rd, imm6, Rn);
#else
        RT_NOREF(Rd, imm6, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff001c/c0910000: ADDVA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.S
   Instruction Set: A64  Groups: mortlach_addhv, mortlach_hvadd, sme */
FNIEMOP_DEF_1(iemDecodeA64_addva_za_pp_z_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addva_za_pp_z_32 ZAda=%u Zn=%#x Pn=%u Pm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm));
#ifdef IEM_INSTR_IMPL_A64__addva_za_pp_z_32
        IEM_INSTR_IMPL_A64__addva_za_pp_z_32(ZAda, Zn, Pn, Pm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0018/c0d10000: ADDVA  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.D
   Instruction Set: A64  Groups: mortlach_addhv, mortlach_hvadd, sme */
FNIEMOP_DEF_1(iemDecodeA64_addva_za_pp_z_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: addva_za_pp_z_64 ZAda=%u Zn=%#x Pn=%u Pm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm));
#ifdef IEM_INSTR_IMPL_A64__addva_za_pp_z_64
        IEM_INSTR_IMPL_A64__addva_za_pp_z_64(ZAda, Zn, Pn, Pm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f800/04205000: ADDVL  <Xd|SP>, <Xn|SP>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_vl, sve_alloca, sve */
FNIEMOP_DEF_1(iemDecodeA64_addvl_r_ri, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm6       = (uOpcode >>  5) & 0x0000003f;
    uint32_t const Rn         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: addvl_r_ri Rd=%#x imm6=%#x Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm6, Rn));
#ifdef IEM_INSTR_IMPL_A64__addvl_r_ri
        IEM_INSTR_IMPL_A64__addvl_r_ri(Rd, imm6, Rn);
#else
        RT_NOREF(Rd, imm6, Rn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/0420a000: ADR  <Zd>.D, [<Zn>.D, <Zm>.D, SXTW<amount>]
   Instruction Set: A64  Groups: sve_int_bin_cons_misc_0_a, sve_int_adr, sve */
FNIEMOP_DEF_1(iemDecodeA64_adr_z_az_d_s32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const msz        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: adr_z_az_d_s32_scaled Zd=%#x Zn=%#x msz=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, msz, Zm));
#ifdef IEM_INSTR_IMPL_A64__adr_z_az_d_s32_scaled
        IEM_INSTR_IMPL_A64__adr_z_az_d_s32_scaled(Zd, Zn, msz, Zm);
#else
        RT_NOREF(Zd, Zn, msz, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/0460a000: ADR  <Zd>.D, [<Zn>.D, <Zm>.D, UXTW<amount>]
   Instruction Set: A64  Groups: sve_int_bin_cons_misc_0_a, sve_int_adr, sve */
FNIEMOP_DEF_1(iemDecodeA64_adr_z_az_d_u32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const msz        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: adr_z_az_d_u32_scaled Zd=%#x Zn=%#x msz=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, msz, Zm));
#ifdef IEM_INSTR_IMPL_A64__adr_z_az_d_u32_scaled
        IEM_INSTR_IMPL_A64__adr_z_az_d_u32_scaled(Zd, Zn, msz, Zm);
#else
        RT_NOREF(Zd, Zn, msz, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0f000/04a0a000: ADR  <Zd>.<T>, [<Zn>.<T>, <Zm>.<T>{, <mod> <amount>}]
   Instruction Set: A64  Groups: sve_int_bin_cons_misc_0_a, sve_int_adr, sve */
FNIEMOP_DEF_1(iemDecodeA64_adr_z_az_sd_same_scaled, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const msz        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: adr_z_az_sd_same_scaled Zd=%#x Zn=%#x msz=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, msz, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__adr_z_az_sd_same_scaled
        IEM_INSTR_IMPL_A64__adr_z_az_sd_same_scaled(Zd, Zn, msz, Zm, sz);
#else
        RT_NOREF(Zd, Zn, msz, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe7fc01/4522ec00: AESD  { <Zdn1>.B-<Zdn2>.B }, { <Zdn1>.B-<Zdn2>.B }, <Zm>.Q[<index>]
   Instruction Set: A64  Groups: sve_crypto_binary_multi2, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesd_mz_zzi_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
    {
        LogFlow(("%018x/%010x: aesd_mz_zzi_2x1 Zdn=%#x Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__aesd_mz_zzi_2x1
        IEM_INSTR_IMPL_A64__aesd_mz_zzi_2x1(Zdn, Zm, i2);
#else
        RT_NOREF(Zdn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe7fc03/4526ec00: AESD  { <Zdn1>.B-<Zdn4>.B }, { <Zdn1>.B-<Zdn4>.B }, <Zm>.Q[<index>]
   Instruction Set: A64  Groups: sve_crypto_binary_multi4, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesd_mz_zzi_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
    {
        LogFlow(("%018x/%010x: aesd_mz_zzi_4x1 Zdn=%u Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__aesd_mz_zzi_4x1
        IEM_INSTR_IMPL_A64__aesd_mz_zzi_4x1(Zdn, Zm, i2);
#else
        RT_NOREF(Zdn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/4522e400: AESD  <Zdn>.B, <Zdn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_crypto_binary_dest, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesd_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes /*FEAT_SVE_AES*/)
    {
        LogFlow(("%018x/%010x: aesd_z_zz Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__aesd_z_zz
        IEM_INSTR_IMPL_A64__aesd_z_zz(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe7fc01/4523ec00: AESDIMC  { <Zdn1>.B-<Zdn2>.B }, { <Zdn1>.B-<Zdn2>.B }, <Zm>.Q[<index>]
   Instruction Set: A64  Groups: sve_crypto_binary_multi2, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesdimc_mz_zzi_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
    {
        LogFlow(("%018x/%010x: aesdimc_mz_zzi_2x1 Zdn=%#x Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__aesdimc_mz_zzi_2x1
        IEM_INSTR_IMPL_A64__aesdimc_mz_zzi_2x1(Zdn, Zm, i2);
#else
        RT_NOREF(Zdn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe7fc03/4527ec00: AESDIMC  { <Zdn1>.B-<Zdn4>.B }, { <Zdn1>.B-<Zdn4>.B }, <Zm>.Q[<index>]
   Instruction Set: A64  Groups: sve_crypto_binary_multi4, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesdimc_mz_zzi_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
    {
        LogFlow(("%018x/%010x: aesdimc_mz_zzi_4x1 Zdn=%u Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__aesdimc_mz_zzi_4x1
        IEM_INSTR_IMPL_A64__aesdimc_mz_zzi_4x1(Zdn, Zm, i2);
#else
        RT_NOREF(Zdn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe7fc01/4522e800: AESE  { <Zdn1>.B-<Zdn2>.B }, { <Zdn1>.B-<Zdn2>.B }, <Zm>.Q[<index>]
   Instruction Set: A64  Groups: sve_crypto_binary_multi2, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aese_mz_zzi_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
    {
        LogFlow(("%018x/%010x: aese_mz_zzi_2x1 Zdn=%#x Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__aese_mz_zzi_2x1
        IEM_INSTR_IMPL_A64__aese_mz_zzi_2x1(Zdn, Zm, i2);
#else
        RT_NOREF(Zdn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe7fc03/4526e800: AESE  { <Zdn1>.B-<Zdn4>.B }, { <Zdn1>.B-<Zdn4>.B }, <Zm>.Q[<index>]
   Instruction Set: A64  Groups: sve_crypto_binary_multi4, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aese_mz_zzi_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
    {
        LogFlow(("%018x/%010x: aese_mz_zzi_4x1 Zdn=%u Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__aese_mz_zzi_4x1
        IEM_INSTR_IMPL_A64__aese_mz_zzi_4x1(Zdn, Zm, i2);
#else
        RT_NOREF(Zdn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/4522e000: AESE  <Zdn>.B, <Zdn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_crypto_binary_dest, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aese_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes /*FEAT_SVE_AES*/)
    {
        LogFlow(("%018x/%010x: aese_z_zz Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__aese_z_zz
        IEM_INSTR_IMPL_A64__aese_z_zz(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe7fc01/4523e800: AESEMC  { <Zdn1>.B-<Zdn2>.B }, { <Zdn1>.B-<Zdn2>.B }, <Zm>.Q[<index>]
   Instruction Set: A64  Groups: sve_crypto_binary_multi2, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesemc_mz_zzi_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
    {
        LogFlow(("%018x/%010x: aesemc_mz_zzi_2x1 Zdn=%#x Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__aesemc_mz_zzi_2x1
        IEM_INSTR_IMPL_A64__aesemc_mz_zzi_2x1(Zdn, Zm, i2);
#else
        RT_NOREF(Zdn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe7fc03/4527e800: AESEMC  { <Zdn1>.B-<Zdn4>.B }, { <Zdn1>.B-<Zdn4>.B }, <Zm>.Q[<index>]
   Instruction Set: A64  Groups: sve_crypto_binary_multi4, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesemc_mz_zzi_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
    {
        LogFlow(("%018x/%010x: aesemc_mz_zzi_4x1 Zdn=%u Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__aesemc_mz_zzi_4x1
        IEM_INSTR_IMPL_A64__aesemc_mz_zzi_4x1(Zdn, Zm, i2);
#else
        RT_NOREF(Zdn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/4520e400: AESIMC  <Zdn>.B, <Zdn>.B
   Instruction Set: A64  Groups: sve_crypto_unary, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesimc_z_z, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes /*FEAT_SVE_AES*/)
    {
        LogFlow(("%018x/%010x: aesimc_z_z Zdn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn));
#ifdef IEM_INSTR_IMPL_A64__aesimc_z_z
        IEM_INSTR_IMPL_A64__aesimc_z_z(Zdn);
#else
        RT_NOREF(Zdn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffe0/4520e000: AESMC  <Zdn>.B, <Zdn>.B
   Instruction Set: A64  Groups: sve_crypto_unary, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_aesmc_z_z, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes /*FEAT_SVE_AES*/)
    {
        LogFlow(("%018x/%010x: aesmc_z_z Zdn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn));
#ifdef IEM_INSTR_IMPL_A64__aesmc_z_z
        IEM_INSTR_IMPL_A64__aesmc_z_z(Zdn);
#else
        RT_NOREF(Zdn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25004000: AND  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_and_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: and_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__and_p_p_pp_z
        IEM_INSTR_IMPL_A64__and_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041a0000: AND  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_log, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_and_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x041a0000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: and_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__and_z_p_zz
            IEM_INSTR_IMPL_A64__and_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/05800000: AND  <Zdn>.<T>, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_log_imm, sve_maskimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_and_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05800000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm13      = (uOpcode >>  5) & 0x00001fff;
        if ((0x2 /*opc@22*/ != 3) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: and_z_zi Zdn=%#x imm13=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm13));
#ifdef IEM_INSTR_IMPL_A64__and_z_zi
            IEM_INSTR_IMPL_A64__and_z_zi(Zdn, imm13);
#else
            RT_NOREF(Zdn, imm13, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04203000: AND  <Zd>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_and_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: and_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__and_z_zz
        IEM_INSTR_IMPL_A64__and_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041e2000: ANDQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_reduce_2q, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_andqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: andqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__andqv_z_p_z
        IEM_INSTR_IMPL_A64__andqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25404000: ANDS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_ands_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ands_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__ands_p_p_pp_z
        IEM_INSTR_IMPL_A64__ands_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041a2000: ANDV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_2, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_andv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: andv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__andv_r_p_z
        IEM_INSTR_IMPL_A64__andv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04008000: ASR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_asr_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: asr_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__asr_z_p_zi
        IEM_INSTR_IMPL_A64__asr_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04188000: ASR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_2, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_asr_z_p_zw, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: asr_z_p_zw Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__asr_z_p_zw
        IEM_INSTR_IMPL_A64__asr_z_p_zw(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04108000: ASR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_1, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_asr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: asr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__asr_z_p_zz
        IEM_INSTR_IMPL_A64__asr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04209000: ASR  <Zd>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_cons_shift_b, sve_int_unpred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_asr_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: asr_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__asr_z_zi
        IEM_INSTR_IMPL_A64__asr_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04208000: ASR  <Zd>.<T>, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_shift_a, sve_int_unpred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_asr_z_zw, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: asr_z_zw Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__asr_z_zw
        IEM_INSTR_IMPL_A64__asr_z_zw(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04048000: ASRD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_asrd_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: asrd_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__asrd_z_p_zi
        IEM_INSTR_IMPL_A64__asrd_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04148000: ASRR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_1, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_asrr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: asrr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__asrr_z_p_zz
        IEM_INSTR_IMPL_A64__asrr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04603800: BCAX  <Zdn>.D, <Zdn>.D, <Zm>.D, <Zk>.D
   Instruction Set: A64  Groups: sve_int_tern_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_bcax_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zk         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bcax_z_zzz Zdn=%#x Zk=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zk, Zm));
#ifdef IEM_INSTR_IMPL_A64__bcax_z_zzz
        IEM_INSTR_IMPL_A64__bcax_z_zzz(Zdn, Zk, Zm);
#else
        RT_NOREF(Zdn, Zk, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500b400: BDEP  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_perm_bit, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_bdep_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBitPerm /*FEAT_SVE_BitPerm*/)
    {
        LogFlow(("%018x/%010x: bdep_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__bdep_z_zz
        IEM_INSTR_IMPL_A64__bdep_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500b000: BEXT  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_perm_bit, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_bext_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBitPerm /*FEAT_SVE_BitPerm*/)
    {
        LogFlow(("%018x/%010x: bext_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__bext_z_zz
        IEM_INSTR_IMPL_A64__bext_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c166e000: BF1CVT  { <Zd1>.H-<Zd2>.H }, <Zn>.B
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bf1cvt_mz2_z8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc166e000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: bf1cvt_mz2_z8 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bf1cvt_mz2_z8
            IEM_INSTR_IMPL_A64__bf1cvt_mz2_z8(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/65083800: BF1CVT  <Zd>.H, <Zn>.B
   Instruction Set: A64  Groups: sve_fp8_fcvt_wide, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bf1cvt_z_z8_b2bf, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: bf1cvt_z_z8_b2bf Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bf1cvt_z_z8_b2bf
        IEM_INSTR_IMPL_A64__bf1cvt_z_z8_b2bf(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c166e001: BF1CVTL  { <Zd1>.H-<Zd2>.H }, <Zn>.B
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bf1cvtl_mz2_z8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc166e001))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: bf1cvtl_mz2_z8 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bf1cvtl_mz2_z8
            IEM_INSTR_IMPL_A64__bf1cvtl_mz2_z8(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/65093800: BF1CVTLT  <Zd>.H, <Zn>.B
   Instruction Set: A64  Groups: sve_fp8_fcvt_wide, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bf1cvtlt_z_z8_b2bf, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: bf1cvtlt_z_z8_b2bf Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bf1cvtlt_z_z8_b2bf
        IEM_INSTR_IMPL_A64__bf1cvtlt_z_z8_b2bf(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c1e6e000: BF2CVT  { <Zd1>.H-<Zd2>.H }, <Zn>.B
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bf2cvt_mz2_z8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc1e6e000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: bf2cvt_mz2_z8 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bf2cvt_mz2_z8
            IEM_INSTR_IMPL_A64__bf2cvt_mz2_z8(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/65083c00: BF2CVT  <Zd>.H, <Zn>.B
   Instruction Set: A64  Groups: sve_fp8_fcvt_wide, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bf2cvt_z_z8_b2bf, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: bf2cvt_z_z8_b2bf Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bf2cvt_z_z8_b2bf
        IEM_INSTR_IMPL_A64__bf2cvt_z_z8_b2bf(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c1e6e001: BF2CVTL  { <Zd1>.H-<Zd2>.H }, <Zn>.B
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bf2cvtl_mz2_z8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc1e6e001))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: bf2cvtl_mz2_z8 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bf2cvtl_mz2_z8
            IEM_INSTR_IMPL_A64__bf2cvtl_mz2_z8(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/65093c00: BF2CVTLT  <Zd>.H, <Zn>.B
   Instruction Set: A64  Groups: sve_fp8_fcvt_wide, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bf2cvtlt_z_z8_b2bf, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: bf2cvtlt_z_z8_b2bf Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bf2cvtlt_z_z8_b2bf
        IEM_INSTR_IMPL_A64__bf2cvtlt_z_z8_b2bf(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65008000: BFADD  <Zdn>.H, <Pg>/M, <Zdn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfadd_z_p_zz
        IEM_INSTR_IMPL_A64__bfadd_z_p_zz(Zdn, Zm, Pg);
#else
        RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/65000000: BFADD  <Zd>.H, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfadd_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfadd_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfadd_z_zz
        IEM_INSTR_IMPL_A64__bfadd_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c38/c1e41c00: BFADD  ZA.H[<Wv>, <offs>{, VGx2}], { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_f16_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfadd_za_zw_2x2_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c38)) == UINT32_C(0xc1e41c00))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
        {
            LogFlow(("%018x/%010x: bfadd_za_zw_2x2_16 off3=%u Zm=%#x Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv));
#ifdef IEM_INSTR_IMPL_A64__bfadd_za_zw_2x2_16
            IEM_INSTR_IMPL_A64__bfadd_za_zw_2x2_16(off3, Zm, Rv);
#else
            RT_NOREF(off3, Zm, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c78/c1e51c00: BFADD  ZA.H[<Wv>, <offs>{, VGx4}], { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_f16_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfadd_za_zw_4x4_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c78)) == UINT32_C(0xc1e51c00))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
        {
            LogFlow(("%018x/%010x: bfadd_za_zw_4x4_16 off3=%u Zm=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv));
#ifdef IEM_INSTR_IMPL_A64__bfadd_za_zw_4x4_16
            IEM_INSTR_IMPL_A64__bfadd_za_zw_4x4_16(off3, Zm, Rv);
#else
            RT_NOREF(off3, Zm, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc01/c120c000: BFCLAMP  { <Zd1>.H-<Zd2>.H }, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_fclamp, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfclamp_mz_zz_2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfclamp_mz_zz_2 Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfclamp_mz_zz_2
        IEM_INSTR_IMPL_A64__bfclamp_mz_zz_2(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc03/c120c800: BFCLAMP  { <Zd1>.H-<Zd4>.H }, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_fclamp, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfclamp_mz_zz_4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfclamp_mz_zz_4 Zd=%u Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfclamp_mz_zz_4
        IEM_INSTR_IMPL_A64__bfclamp_mz_zz_4(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64202400: BFCLAMP  <Zd>.H, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_clamp_lvl2, sve_fp_clamp, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfclamp_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfclamp_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfclamp_z_zz
        IEM_INSTR_IMPL_A64__bfclamp_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c164e000: BFCVT  <Zd>.B, { <Zn1>.H-<Zn2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfcvt_z8_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc164e000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: bfcvt_z8_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bfcvt_z8_mz2
            IEM_INSTR_IMPL_A64__bfcvt_z8_mz2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c160e000: BFCVT  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_fp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfcvt_z_mz2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfcvt_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bfcvt_z_mz2
        IEM_INSTR_IMPL_A64__bfcvt_z_mz2(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/658aa000: BFCVT  <Zd>.H, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_0, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfcvt_z_p_z_s2bf, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfcvt_z_p_z_s2bf Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfcvt_z_p_z_s2bf
        IEM_INSTR_IMPL_A64__bfcvt_z_p_z_s2bf(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/649ac000: BFCVT  <Zd>.H, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_0, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfcvt_z_p_z_s2bfz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: bfcvt_z_p_z_s2bfz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfcvt_z_p_z_s2bfz
        IEM_INSTR_IMPL_A64__bfcvt_z_p_z_s2bfz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/650a3800: BFCVTN  <Zd>.B, { <Zn1>.H-<Zn2>.H }
   Instruction Set: A64  Groups: sve_fp8_fcvt_narrow, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfcvtn_z8_mz2_bf2b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0x650a3800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: bfcvtn_z8_mz2_bf2b Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bfcvtn_z8_mz2_bf2b
            IEM_INSTR_IMPL_A64__bfcvtn_z8_mz2_bf2b(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c160e020: BFCVTN  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_fp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfcvtn_z_mz2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfcvtn_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__bfcvtn_z_mz2
        IEM_INSTR_IMPL_A64__bfcvtn_z_mz2(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/648aa000: BFCVTNT  <Zd>.H, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_fcvt2_lvl2, sve_fp_fcvt2, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfcvtnt_z_p_z_s2bf, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfcvtnt_z_p_z_s2bf Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfcvtnt_z_p_z_s2bf
        IEM_INSTR_IMPL_A64__bfcvtnt_z_p_z_s2bf(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6482a000: BFCVTNT  <Zd>.H, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_fcvt2z_lvl2, sve_fp_fcvt2z, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfcvtnt_z_p_z_s2bfz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: bfcvtnt_z_p_z_s2bfz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfcvtnt_z_p_z_s2bfz
        IEM_INSTR_IMPL_A64__bfcvtnt_z_p_z_s2bfz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64608000: BFDOT  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fdot, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfdot_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfdot_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfdot_z_zzz
        IEM_INSTR_IMPL_A64__bfdot_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64604000: BFDOT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fdot_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfdot_z_zzzi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfdot_z_zzzi Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__bfdot_z_zzzi
        IEM_INSTR_IMPL_A64__bfdot_z_zzzi(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1501018: BFDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfdot_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfdot_za_zzi_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfdot_za_zzi_2xi
        IEM_INSTR_IMPL_A64__bfdot_za_zzi_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1509018: BFDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfdot_za_zzi_4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfdot_za_zzi_4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfdot_za_zzi_4xi
        IEM_INSTR_IMPL_A64__bfdot_za_zzi_4xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1201010: BFDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_za_fpdot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfdot_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfdot_za_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfdot_za_zzv_2x1
        IEM_INSTR_IMPL_A64__bfdot_za_zzv_2x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1301010: BFDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_za_fpdot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfdot_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfdot_za_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfdot_za_zzv_4x1
        IEM_INSTR_IMPL_A64__bfdot_za_zzv_4x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1a01010: BFDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_fpdot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfdot_za_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfdot_za_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfdot_za_zzw_2x2
        IEM_INSTR_IMPL_A64__bfdot_za_zzw_2x2(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1a11010: BFDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_fpdot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfdot_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1a11010))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: bfdot_za_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfdot_za_zzw_4x4
            IEM_INSTR_IMPL_A64__bfdot_za_zzw_4x4(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe1/c120a100: BFMAX  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmax_mz_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmax_mz_zzv_2x1 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmax_mz_zzv_2x1
        IEM_INSTR_IMPL_A64__bfmax_mz_zzv_2x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe3/c120a900: BFMAX  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmax_mz_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmax_mz_zzv_4x1 Zdn=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmax_mz_zzv_4x1
        IEM_INSTR_IMPL_A64__bfmax_mz_zzv_4x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe1ffe1/c120b100: BFMAX  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmax_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmax_mz_zzw_2x2 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmax_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__bfmax_mz_zzw_2x2(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe3ffe3/c120b900: BFMAX  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmax_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmax_mz_zzw_4x4 Zdn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmax_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__bfmax_mz_zzw_4x4(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65068000: BFMAX  <Zdn>.H, <Pg>/M, <Zdn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmax_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmax_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfmax_z_p_zz
        IEM_INSTR_IMPL_A64__bfmax_z_p_zz(Zdn, Zm, Pg);
#else
        RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe1/c120a120: BFMAXNM  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmaxnm_mz_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmaxnm_mz_zzv_2x1 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmaxnm_mz_zzv_2x1
        IEM_INSTR_IMPL_A64__bfmaxnm_mz_zzv_2x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe3/c120a920: BFMAXNM  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmaxnm_mz_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmaxnm_mz_zzv_4x1 Zdn=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmaxnm_mz_zzv_4x1
        IEM_INSTR_IMPL_A64__bfmaxnm_mz_zzv_4x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe1ffe1/c120b120: BFMAXNM  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmaxnm_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmaxnm_mz_zzw_2x2 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmaxnm_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__bfmaxnm_mz_zzw_2x2(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe3ffe3/c120b920: BFMAXNM  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmaxnm_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmaxnm_mz_zzw_4x4 Zdn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmaxnm_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__bfmaxnm_mz_zzw_4x4(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65048000: BFMAXNM  <Zdn>.H, <Pg>/M, <Zdn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmaxnm_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmaxnm_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfmaxnm_z_p_zz
        IEM_INSTR_IMPL_A64__bfmaxnm_z_p_zz(Zdn, Zm, Pg);
#else
        RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe1/c120a101: BFMIN  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmin_mz_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmin_mz_zzv_2x1 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmin_mz_zzv_2x1
        IEM_INSTR_IMPL_A64__bfmin_mz_zzv_2x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe3/c120a901: BFMIN  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmin_mz_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmin_mz_zzv_4x1 Zdn=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmin_mz_zzv_4x1
        IEM_INSTR_IMPL_A64__bfmin_mz_zzv_4x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe1ffe1/c120b101: BFMIN  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmin_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmin_mz_zzw_2x2 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmin_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__bfmin_mz_zzw_2x2(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe3ffe3/c120b901: BFMIN  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmin_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmin_mz_zzw_4x4 Zdn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmin_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__bfmin_mz_zzw_4x4(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65078000: BFMIN  <Zdn>.H, <Pg>/M, <Zdn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmin_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmin_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfmin_z_p_zz
        IEM_INSTR_IMPL_A64__bfmin_z_p_zz(Zdn, Zm, Pg);
#else
        RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe1/c120a121: BFMINNM  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfminnm_mz_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfminnm_mz_zzv_2x1 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfminnm_mz_zzv_2x1
        IEM_INSTR_IMPL_A64__bfminnm_mz_zzv_2x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe3/c120a921: BFMINNM  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfminnm_mz_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfminnm_mz_zzv_4x1 Zdn=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfminnm_mz_zzv_4x1
        IEM_INSTR_IMPL_A64__bfminnm_mz_zzv_4x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe1ffe1/c120b121: BFMINNM  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfminnm_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfminnm_mz_zzw_2x2 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfminnm_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__bfminnm_mz_zzw_2x2(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe3ffe3/c120b921: BFMINNM  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfminnm_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfminnm_mz_zzw_4x4 Zdn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfminnm_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__bfminnm_mz_zzw_4x4(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65058000: BFMINNM  <Zdn>.H, <Pg>/M, <Zdn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfminnm_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfminnm_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfminnm_z_p_zz
        IEM_INSTR_IMPL_A64__bfminnm_z_p_zz(Zdn, Zm, Pg);
#else
        RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/65200000: BFMLA  <Zda>.H, <Pg>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_a, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmla_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmla_z_p_zzz Zda=%#x Zn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmla_z_p_zzz
        IEM_INSTR_IMPL_A64__bfmla_z_p_zzz(Zda, Zn, Pg, Zm);
#else
        RT_NOREF(Zda, Zn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/64200800: BFMLA  <Zda>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_by_indexed_elem_lvl2, sve_fp_fma_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmla_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmla_z_zzzi_h Zda=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__bfmla_z_zzzi_h
        IEM_INSTR_IMPL_A64__bfmla_z_zzzi_h(Zda, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zda, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09030/c1101020: BFMLA  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_h, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmla_za_zzi_h2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmla_za_zzi_h2xi off3=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmla_za_zzi_h2xi
        IEM_INSTR_IMPL_A64__bfmla_za_zzi_h2xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09070/c1109020: BFMLA  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_h, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmla_za_zzi_h4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmla_za_zzi_h4xi off3=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmla_za_zzi_h4xi
        IEM_INSTR_IMPL_A64__bfmla_za_zzi_h4xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1601c00: BFMLA  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_f16_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmla_za_zzv_2x1_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmla_za_zzv_2x1_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmla_za_zzv_2x1_16
        IEM_INSTR_IMPL_A64__bfmla_za_zzv_2x1_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1701c00: BFMLA  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_f16_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmla_za_zzv_4x1_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmla_za_zzv_4x1_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmla_za_zzv_4x1_16
        IEM_INSTR_IMPL_A64__bfmla_za_zzv_4x1_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1e01008: BFMLA  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_f16_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmla_za_zzw_2x2_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmla_za_zzw_2x2_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmla_za_zzw_2x2_16
        IEM_INSTR_IMPL_A64__bfmla_za_zzw_2x2_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1e11008: BFMLA  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_f16_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmla_za_zzw_4x4_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmla_za_zzw_4x4_16 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmla_za_zzw_4x4_16
        IEM_INSTR_IMPL_A64__bfmla_za_zzw_4x4_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01018/c1801010: BFMLAL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_fma_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlal_za_zzi_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlal_za_zzi_1 off3=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlal_za_zzi_1
        IEM_INSTR_IMPL_A64__bfmlal_za_zzi_1(off3, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off3, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1901010: BFMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fma_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlal_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlal_za_zzi_2xi off2=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlal_za_zzi_2xi
        IEM_INSTR_IMPL_A64__bfmlal_za_zzi_2xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1909010: BFMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_fma_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlal_za_zzi_4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1909010))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: bfmlal_za_zzi_4xi off2=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlal_za_zzi_4xi
            IEM_INSTR_IMPL_A64__bfmlal_za_zzi_4xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1200c10: BFMLAL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlal_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlal_za_zzv_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlal_za_zzv_1
        IEM_INSTR_IMPL_A64__bfmlal_za_zzv_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1200810: BFMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlal_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlal_za_zzv_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlal_za_zzv_2x1
        IEM_INSTR_IMPL_A64__bfmlal_za_zzv_2x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1300810: BFMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlal_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlal_za_zzv_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlal_za_zzv_4x1
        IEM_INSTR_IMPL_A64__bfmlal_za_zzv_4x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1a00810: BFMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlal_za_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlal_za_zzw_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlal_za_zzw_2x2
        IEM_INSTR_IMPL_A64__bfmlal_za_zzw_2x2(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1a10810: BFMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlal_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1a10810))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: bfmlal_za_zzw_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlal_za_zzw_4x4
            IEM_INSTR_IMPL_A64__bfmlal_za_zzw_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64e08000: BFMLALB  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fma_long, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmlalb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfmlalb_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlalb_z_zzz
        IEM_INSTR_IMPL_A64__bfmlalb_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64e04000: BFMLALB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_long_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmlalb_z_zzzi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfmlalb_z_zzzi Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__bfmlalb_z_zzzi
        IEM_INSTR_IMPL_A64__bfmlalb_z_zzzi(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64e08400: BFMLALT  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fma_long, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmlalt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfmlalt_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlalt_z_zzz
        IEM_INSTR_IMPL_A64__bfmlalt_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64e04400: BFMLALT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_long_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmlalt_z_zzzi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfmlalt_z_zzzi Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__bfmlalt_z_zzzi
        IEM_INSTR_IMPL_A64__bfmlalt_z_zzzi(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/65202000: BFMLS  <Zda>.H, <Pg>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_a, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmls_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmls_z_p_zzz Zda=%#x Zn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmls_z_p_zzz
        IEM_INSTR_IMPL_A64__bfmls_z_p_zzz(Zda, Zn, Pg, Zm);
#else
        RT_NOREF(Zda, Zn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/64200c00: BFMLS  <Zda>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_by_indexed_elem_lvl2, sve_fp_fma_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmls_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmls_z_zzzi_h Zda=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__bfmls_z_zzzi_h
        IEM_INSTR_IMPL_A64__bfmls_z_zzzi_h(Zda, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zda, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09030/c1101030: BFMLS  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_h, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmls_za_zzi_h2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmls_za_zzi_h2xi off3=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmls_za_zzi_h2xi
        IEM_INSTR_IMPL_A64__bfmls_za_zzi_h2xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09070/c1109030: BFMLS  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_h, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmls_za_zzi_h4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmls_za_zzi_h4xi off3=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmls_za_zzi_h4xi
        IEM_INSTR_IMPL_A64__bfmls_za_zzi_h4xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1601c08: BFMLS  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_f16_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmls_za_zzv_2x1_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmls_za_zzv_2x1_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmls_za_zzv_2x1_16
        IEM_INSTR_IMPL_A64__bfmls_za_zzv_2x1_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1701c08: BFMLS  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_f16_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmls_za_zzv_4x1_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmls_za_zzv_4x1_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmls_za_zzv_4x1_16
        IEM_INSTR_IMPL_A64__bfmls_za_zzv_4x1_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1e01018: BFMLS  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_f16_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmls_za_zzw_2x2_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmls_za_zzw_2x2_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmls_za_zzw_2x2_16
        IEM_INSTR_IMPL_A64__bfmls_za_zzw_2x2_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1e11018: BFMLS  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_f16_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmls_za_zzw_4x4_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmls_za_zzw_4x4_16 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmls_za_zzw_4x4_16
        IEM_INSTR_IMPL_A64__bfmls_za_zzw_4x4_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01018/c1801018: BFMLSL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_fma_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlsl_za_zzi_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlsl_za_zzi_1 off3=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlsl_za_zzi_1
        IEM_INSTR_IMPL_A64__bfmlsl_za_zzi_1(off3, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off3, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1901018: BFMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fma_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlsl_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlsl_za_zzi_2xi off2=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlsl_za_zzi_2xi
        IEM_INSTR_IMPL_A64__bfmlsl_za_zzi_2xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1909018: BFMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_fma_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlsl_za_zzi_4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1909018))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: bfmlsl_za_zzi_4xi off2=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlsl_za_zzi_4xi
            IEM_INSTR_IMPL_A64__bfmlsl_za_zzi_4xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1200c18: BFMLSL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlsl_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlsl_za_zzv_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlsl_za_zzv_1
        IEM_INSTR_IMPL_A64__bfmlsl_za_zzv_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1200818: BFMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlsl_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlsl_za_zzv_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlsl_za_zzv_2x1
        IEM_INSTR_IMPL_A64__bfmlsl_za_zzv_2x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1300818: BFMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlsl_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlsl_za_zzv_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlsl_za_zzv_4x1
        IEM_INSTR_IMPL_A64__bfmlsl_za_zzv_4x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1a00818: BFMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlsl_za_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfmlsl_za_zzw_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlsl_za_zzw_2x2
        IEM_INSTR_IMPL_A64__bfmlsl_za_zzw_2x2(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1a10818: BFMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmlsl_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1a10818))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: bfmlsl_za_zzw_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlsl_za_zzw_4x4
            IEM_INSTR_IMPL_A64__bfmlsl_za_zzw_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64e0a000: BFMLSLB  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fma_long, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmlslb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: bfmlslb_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlslb_z_zzz
        IEM_INSTR_IMPL_A64__bfmlslb_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64e06000: BFMLSLB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_long_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmlslb_z_zzzi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: bfmlslb_z_zzzi Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__bfmlslb_z_zzzi
        IEM_INSTR_IMPL_A64__bfmlslb_z_zzzi(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64e0a400: BFMLSLT  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fma_long, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmlslt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: bfmlslt_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmlslt_z_zzz
        IEM_INSTR_IMPL_A64__bfmlslt_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64e06400: BFMLSLT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_long_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmlslt_z_zzzi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: bfmlslt_z_zzzi Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__bfmlslt_z_zzzi
        IEM_INSTR_IMPL_A64__bfmlslt_z_zzzi(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6460e400: BFMMLA  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fmmla_lvl2, sve_fp_fmmla, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmmla_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fBf16 /*FEAT_BF16*/)
    {
        LogFlow(("%018x/%010x: bfmmla_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmmla_z_zzz
        IEM_INSTR_IMPL_A64__bfmmla_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81000000: BFMOP4A  <ZAda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4a_za32_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81000000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4a_za32_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4a_za32_zz_h1x1
            IEM_INSTR_IMPL_A64__bfmop4a_za32_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81100000: BFMOP4A  <ZAda>.S, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_b16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4a_za32_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81100000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4a_za32_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4a_za32_zz_h1x2
            IEM_INSTR_IMPL_A64__bfmop4a_za32_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81000200: BFMOP4A  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4a_za32_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81000200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4a_za32_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4a_za32_zz_h2x1
            IEM_INSTR_IMPL_A64__bfmop4a_za32_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81100200: BFMOP4A  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_b16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4a_za32_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81100200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4a_za32_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4a_za32_zz_h2x2
            IEM_INSTR_IMPL_A64__bfmop4a_za32_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81200008: BFMOP4A  <ZAda>.H, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16b16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4a_za_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81200008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4a_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4a_za_zz_h1x1
            IEM_INSTR_IMPL_A64__bfmop4a_za_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81300008: BFMOP4A  <ZAda>.H, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_b16b16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4a_za_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81300008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4a_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4a_za_zz_h1x2
            IEM_INSTR_IMPL_A64__bfmop4a_za_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81200208: BFMOP4A  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16b16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4a_za_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81200208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4a_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4a_za_zz_h2x1
            IEM_INSTR_IMPL_A64__bfmop4a_za_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81300208: BFMOP4A  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_b16b16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4a_za_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81300208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4a_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4a_za_zz_h2x2
            IEM_INSTR_IMPL_A64__bfmop4a_za_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81000010: BFMOP4S  <ZAda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4s_za32_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81000010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4s_za32_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4s_za32_zz_h1x1
            IEM_INSTR_IMPL_A64__bfmop4s_za32_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81100010: BFMOP4S  <ZAda>.S, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_b16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4s_za32_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81100010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4s_za32_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4s_za32_zz_h1x2
            IEM_INSTR_IMPL_A64__bfmop4s_za32_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81000210: BFMOP4S  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4s_za32_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81000210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4s_za32_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4s_za32_zz_h2x1
            IEM_INSTR_IMPL_A64__bfmop4s_za32_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81100210: BFMOP4S  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_b16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4s_za32_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81100210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4s_za32_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4s_za32_zz_h2x2
            IEM_INSTR_IMPL_A64__bfmop4s_za32_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81200018: BFMOP4S  <ZAda>.H, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16b16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4s_za_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81200018))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4s_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4s_za_zz_h1x1
            IEM_INSTR_IMPL_A64__bfmop4s_za_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81300018: BFMOP4S  <ZAda>.H, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_b16b16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4s_za_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81300018))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4s_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4s_za_zz_h1x2
            IEM_INSTR_IMPL_A64__bfmop4s_za_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81200218: BFMOP4S  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16b16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4s_za_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81200218))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4s_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4s_za_zz_h2x1
            IEM_INSTR_IMPL_A64__bfmop4s_za_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81300218: BFMOP4S  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_b16b16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmop4s_za_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81300218))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: bfmop4s_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmop4s_za_zz_h2x2
            IEM_INSTR_IMPL_A64__bfmop4s_za_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/81800000: BFMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16f32_prod, mortlach_32bit_fp_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmopa_za32_pp_zz, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bfmopa_za32_pp_zz ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmopa_za32_pp_zz
        IEM_INSTR_IMPL_A64__bfmopa_za32_pp_zz(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001e/81a00008: BFMOPA  <ZAda>.H, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16b16_prod, mortlach2_misc_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmopa_za_pp_zz_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001e)) == UINT32_C(0x81a00008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
        {
            LogFlow(("%018x/%010x: bfmopa_za_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmopa_za_pp_zz_16
            IEM_INSTR_IMPL_A64__bfmopa_za_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
            RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/81800010: BFMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16f32_prod, mortlach_32bit_fp_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmops_za32_pp_zz, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bfmops_za32_pp_zz ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmops_za32_pp_zz
        IEM_INSTR_IMPL_A64__bfmops_za32_pp_zz(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001e/81a00018: BFMOPS  <ZAda>.H, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_b16b16_prod, mortlach2_misc_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmops_za_pp_zz_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001e)) == UINT32_C(0x81a00018))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
        {
            LogFlow(("%018x/%010x: bfmops_za_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmops_za_pp_zz_16
            IEM_INSTR_IMPL_A64__bfmops_za_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
            RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe1fc21/c120e800: BFMUL  { <Zd1>.H-<Zd2>.H }, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_fmul_sm, mortlach_multi_sve_5b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmul_mz_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/)
    {
        LogFlow(("%018x/%010x: bfmul_mz_zzv_2x1 Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmul_mz_zzv_2x1
        IEM_INSTR_IMPL_A64__bfmul_mz_zzv_2x1(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe1fc63/c121e800: BFMUL  { <Zd1>.H-<Zd4>.H }, { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_fmul_sm, mortlach_multi_sve_5b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmul_mz_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/)
    {
        LogFlow(("%018x/%010x: bfmul_mz_zzv_4x1 Zd=%u Zn=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmul_mz_zzv_4x1
        IEM_INSTR_IMPL_A64__bfmul_mz_zzv_4x1(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe1fc21/c120e400: BFMUL  { <Zd1>.H-<Zd2>.H }, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_fmul_mm, mortlach_multi_sve_5a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmul_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/)
    {
        LogFlow(("%018x/%010x: bfmul_mz_zzw_2x2 Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmul_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__bfmul_mz_zzw_2x2(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe3fc63/c121e400: BFMUL  { <Zd1>.H-<Zd4>.H }, { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_fmul_mm, mortlach_multi_sve_5a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfmul_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/)
    {
        LogFlow(("%018x/%010x: bfmul_mz_zzw_4x4 Zd=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmul_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__bfmul_mz_zzw_4x4(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65028000: BFMUL  <Zdn>.H, <Pg>/M, <Zdn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmul_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmul_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfmul_z_p_zz
        IEM_INSTR_IMPL_A64__bfmul_z_p_zz(Zdn, Zm, Pg);
#else
        RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/65000800: BFMUL  <Zd>.H, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmul_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmul_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfmul_z_zz
        IEM_INSTR_IMPL_A64__bfmul_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/64202800: BFMUL  <Zd>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fmul_by_indexed_elem_lvl2, sve_fp_fmul_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfmul_z_zzi_h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfmul_z_zzi_h Zd=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__bfmul_z_zzi_h
        IEM_INSTR_IMPL_A64__bfmul_z_zzi_h(Zd, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zd, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe1/c120a180: BFSCALE  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fscale_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfscale_mz_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfscale_mz_zzv_2x1 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfscale_mz_zzv_2x1
        IEM_INSTR_IMPL_A64__bfscale_mz_zzv_2x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0ffe3/c120a980: BFSCALE  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fscale_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfscale_mz_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfscale_mz_zzv_4x1 Zdn=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfscale_mz_zzv_4x1
        IEM_INSTR_IMPL_A64__bfscale_mz_zzv_4x1(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe1ffe1/c120b180: BFSCALE  { <Zdn1>.H-<Zdn2>.H }, { <Zdn1>.H-<Zdn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fscale_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfscale_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfscale_mz_zzw_2x2 Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfscale_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__bfscale_mz_zzw_2x2(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe3ffe3/c120b980: BFSCALE  { <Zdn1>.H-<Zdn4>.H }, { <Zdn1>.H-<Zdn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fscale_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfscale_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfscale_mz_zzw_4x4 Zdn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfscale_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__bfscale_mz_zzw_4x4(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65098000: BFSCALE  <Zdn>.H, <Pg>/M, <Zdn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfscale_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBfscale /*FEAT_SVE_BFSCALE*/)
    {
        LogFlow(("%018x/%010x: bfscale_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfscale_z_p_zz
        IEM_INSTR_IMPL_A64__bfscale_z_p_zz(Zdn, Zm, Pg);
#else
        RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65018000: BFSUB  <Zdn>.H, <Pg>/M, <Zdn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfsub_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfsub_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__bfsub_z_p_zz
        IEM_INSTR_IMPL_A64__bfsub_z_p_zz(Zdn, Zm, Pg);
#else
        RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/65000400: BFSUB  <Zd>.H, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_bfsub_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveB16B16 /*FEAT_SVE_B16B16*/)
    {
        LogFlow(("%018x/%010x: bfsub_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfsub_z_zz
        IEM_INSTR_IMPL_A64__bfsub_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c38/c1e41c08: BFSUB  ZA.H[<Wv>, <offs>{, VGx2}], { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_f16_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfsub_za_zw_2x2_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c38)) == UINT32_C(0xc1e41c08))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
        {
            LogFlow(("%018x/%010x: bfsub_za_zw_2x2_16 off3=%u Zm=%#x Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv));
#ifdef IEM_INSTR_IMPL_A64__bfsub_za_zw_2x2_16
            IEM_INSTR_IMPL_A64__bfsub_za_zw_2x2_16(off3, Zm, Rv);
#else
            RT_NOREF(off3, Zm, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c78/c1e51c08: BFSUB  ZA.H[<Wv>, <offs>{, VGx4}], { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_f16_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfsub_za_zw_4x4_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c78)) == UINT32_C(0xc1e51c08))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/)
        {
            LogFlow(("%018x/%010x: bfsub_za_zw_4x4_16 off3=%u Zm=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv));
#ifdef IEM_INSTR_IMPL_A64__bfsub_za_zw_4x4_16
            IEM_INSTR_IMPL_A64__bfsub_za_zw_4x4_16(off3, Zm, Rv);
#else
            RT_NOREF(off3, Zm, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/81400000: BFTMOPA  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_b16f32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_bftmopa_za32_zzzi_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: bftmopa_za32_zzzi_h2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__bftmopa_za32_zzzi_h2x1
        IEM_INSTR_IMPL_A64__bftmopa_za32_zzzi_h2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00e/81600008: BFTMOPA  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, <Zm>.H, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_b16b16_1in2ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_bftmopa_za_zzzi_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeB16B16 /*FEAT_SME_B16B16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: bftmopa_za_zzzi_h2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__bftmopa_za_zzzi_h2x1
        IEM_INSTR_IMPL_A64__bftmopa_za_zzzi_h2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1500018: BFVDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_bfvdot_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bfvdot_za_zzi_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__bfvdot_za_zzi_2xi
        IEM_INSTR_IMPL_A64__bfvdot_za_zzi_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500b800: BGRP  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_perm_bit, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_bgrp_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveBitPerm /*FEAT_SVE_BitPerm*/)
    {
        LogFlow(("%018x/%010x: bgrp_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__bgrp_z_zz
        IEM_INSTR_IMPL_A64__bgrp_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25004010: BIC  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_bic_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bic_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__bic_p_p_pp_z
        IEM_INSTR_IMPL_A64__bic_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041b0000: BIC  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_log, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_bic_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x041b0000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: bic_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__bic_z_p_zz
            IEM_INSTR_IMPL_A64__bic_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04e03000: BIC  <Zd>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_bic_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bic_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__bic_z_zz
        IEM_INSTR_IMPL_A64__bic_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25404010: BICS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_bics_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bics_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__bics_p_p_pp_z
        IEM_INSTR_IMPL_A64__bics_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/80800008: BMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.S, <Zm>.S
   Instruction Set: A64  Groups: mortlach_bini32_prod, mortlach2_misc_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_bmopa_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bmopa_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__bmopa_za_pp_zz_32
        IEM_INSTR_IMPL_A64__bmopa_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/80800018: BMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.S, <Zm>.S
   Instruction Set: A64  Groups: mortlach_bini32_prod, mortlach2_misc_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_bmops_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: bmops_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__bmops_za_pp_zz_32
        IEM_INSTR_IMPL_A64__bmops_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffc200/25104000: BRKA  <Pd>.B, <Pg>/<ZM>, <Pn>.B
   Instruction Set: A64  Groups: sve_int_break, sve_pred_gen_c, sve */
FNIEMOP_DEF_1(iemDecodeA64_brka_p_p_p, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffc200)) == UINT32_C(0x25104000))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const M          = (uOpcode >>  4) & 0x00000001;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: brka_p_p_p Pd=%#x M=%u Pn=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, M, Pn, Pg));
#ifdef IEM_INSTR_IMPL_A64__brka_p_p_p
            IEM_INSTR_IMPL_A64__brka_p_p_p(Pd, M, Pn, Pg);
#else
            RT_NOREF(Pd, M, Pn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffc210/25504000: BRKAS  <Pd>.B, <Pg>/Z, <Pn>.B
   Instruction Set: A64  Groups: sve_int_break, sve_pred_gen_c, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkas_p_p_p_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: brkas_p_p_p_z Pd=%#x Pn=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg));
#ifdef IEM_INSTR_IMPL_A64__brkas_p_p_p_z
        IEM_INSTR_IMPL_A64__brkas_p_p_p_z(Pd, Pn, Pg);
#else
        RT_NOREF(Pd, Pn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffc200/25904000: BRKB  <Pd>.B, <Pg>/<ZM>, <Pn>.B
   Instruction Set: A64  Groups: sve_int_break, sve_pred_gen_c, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkb_p_p_p, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffc200)) == UINT32_C(0x25904000))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const M          = (uOpcode >>  4) & 0x00000001;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: brkb_p_p_p Pd=%#x M=%u Pn=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, M, Pn, Pg));
#ifdef IEM_INSTR_IMPL_A64__brkb_p_p_p
            IEM_INSTR_IMPL_A64__brkb_p_p_p(Pd, M, Pn, Pg);
#else
            RT_NOREF(Pd, M, Pn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffc210/25d04000: BRKBS  <Pd>.B, <Pg>/Z, <Pn>.B
   Instruction Set: A64  Groups: sve_int_break, sve_pred_gen_c, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkbs_p_p_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffc210)) == UINT32_C(0x25d04000))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: brkbs_p_p_p_z Pd=%#x Pn=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg));
#ifdef IEM_INSTR_IMPL_A64__brkbs_p_p_p_z
            IEM_INSTR_IMPL_A64__brkbs_p_p_p_z(Pd, Pn, Pg);
#else
            RT_NOREF(Pd, Pn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffc210/25184000: BRKN  <Pdm>.B, <Pg>/Z, <Pn>.B, <Pdm>.B
   Instruction Set: A64  Groups: sve_int_brkn, sve_pred_gen_c, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkn_p_p_pp, uint32_t, uOpcode)
{
    uint32_t const Pdm        = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: brkn_p_p_pp Pdm=%#x Pn=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pdm, Pn, Pg));
#ifdef IEM_INSTR_IMPL_A64__brkn_p_p_pp
        IEM_INSTR_IMPL_A64__brkn_p_p_pp(Pdm, Pn, Pg);
#else
        RT_NOREF(Pdm, Pn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffc210/25584000: BRKNS  <Pdm>.B, <Pg>/Z, <Pn>.B, <Pdm>.B
   Instruction Set: A64  Groups: sve_int_brkn, sve_pred_gen_c, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkns_p_p_pp, uint32_t, uOpcode)
{
    uint32_t const Pdm        = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: brkns_p_p_pp Pdm=%#x Pn=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pdm, Pn, Pg));
#ifdef IEM_INSTR_IMPL_A64__brkns_p_p_pp
        IEM_INSTR_IMPL_A64__brkns_p_p_pp(Pdm, Pn, Pg);
#else
        RT_NOREF(Pdm, Pn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/2500c000: BRKPA  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_brkp, sve_pred_gen_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkpa_p_p_pp, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: brkpa_p_p_pp Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__brkpa_p_p_pp
        IEM_INSTR_IMPL_A64__brkpa_p_p_pp(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/2540c000: BRKPAS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_brkp, sve_pred_gen_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkpas_p_p_pp, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: brkpas_p_p_pp Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__brkpas_p_p_pp
        IEM_INSTR_IMPL_A64__brkpas_p_p_pp(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/2500c010: BRKPB  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_brkp, sve_pred_gen_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkpb_p_p_pp, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: brkpb_p_p_pp Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__brkpb_p_p_pp
        IEM_INSTR_IMPL_A64__brkpb_p_p_pp(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/2540c010: BRKPBS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_brkp, sve_pred_gen_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_brkpbs_p_p_pp, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: brkpbs_p_p_pp Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__brkpbs_p_p_pp
        IEM_INSTR_IMPL_A64__brkpbs_p_p_pp(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04603c00: BSL1N  <Zdn>.D, <Zdn>.D, <Zm>.D, <Zk>.D
   Instruction Set: A64  Groups: sve_int_tern_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_bsl1n_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zk         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bsl1n_z_zzz Zdn=%#x Zk=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zk, Zm));
#ifdef IEM_INSTR_IMPL_A64__bsl1n_z_zzz
        IEM_INSTR_IMPL_A64__bsl1n_z_zzz(Zdn, Zk, Zm);
#else
        RT_NOREF(Zdn, Zk, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04a03c00: BSL2N  <Zdn>.D, <Zdn>.D, <Zm>.D, <Zk>.D
   Instruction Set: A64  Groups: sve_int_tern_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_bsl2n_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zk         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bsl2n_z_zzz Zdn=%#x Zk=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zk, Zm));
#ifdef IEM_INSTR_IMPL_A64__bsl2n_z_zzz
        IEM_INSTR_IMPL_A64__bsl2n_z_zzz(Zdn, Zk, Zm);
#else
        RT_NOREF(Zdn, Zk, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04203c00: BSL  <Zdn>.D, <Zdn>.D, <Zm>.D, <Zk>.D
   Instruction Set: A64  Groups: sve_int_tern_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_bsl_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zk         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: bsl_z_zzz Zdn=%#x Zk=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zk, Zm));
#ifdef IEM_INSTR_IMPL_A64__bsl_z_zzz
        IEM_INSTR_IMPL_A64__bsl_z_zzz(Zdn, Zk, Zm);
#else
        RT_NOREF(Zdn, Zk, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ff800/4500d800: CADD  <Zdn>.<T>, <Zdn>.<T>, <Zm>.<T>, <const>
   Instruction Set: A64  Groups: sve_intx_cadd, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_cadd_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cadd_z_zz Zdn=%#x Zm=%#x rot=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, rot, size));
#ifdef IEM_INSTR_IMPL_A64__cadd_z_zz
        IEM_INSTR_IMPL_A64__cadd_z_zz(Zdn, Zm, rot, size);
#else
        RT_NOREF(Zdn, Zm, rot, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20f000/44001000: CDOT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>, <const>
   Instruction Set: A64  Groups: sve_intx_cdot, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_cdot_z_zzz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20f000)) == UINT32_C(0x44001000))
    {
        uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: cdot_z_zzz Zda=%#x Zn=%#x rot=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cdot_z_zzz
            IEM_INSTR_IMPL_A64__cdot_z_zzz(Zda, Zn, rot, Zm, size);
#else
            RT_NOREF(Zda, Zn, rot, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/44e04000: CDOT  <Zda>.D, <Zn>.H, <Zm>.H[<imm>], <const>
   Instruction Set: A64  Groups: sve_intx_cdot_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_cdot_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cdot_z_zzzi_d Zda=%#x Zn=%#x rot=%u Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__cdot_z_zzzi_d
        IEM_INSTR_IMPL_A64__cdot_z_zzzi_d(Zda, Zn, rot, Zm, i1);
#else
        RT_NOREF(Zda, Zn, rot, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/44a04000: CDOT  <Zda>.S, <Zn>.B, <Zm>.B[<imm>], <const>
   Instruction Set: A64  Groups: sve_intx_cdot_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_cdot_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cdot_z_zzzi_s Zda=%#x Zn=%#x rot=%u Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__cdot_z_zzzi_s
        IEM_INSTR_IMPL_A64__cdot_z_zzzi_s(Zda, Zn, rot, Zm, i2);
#else
        RT_NOREF(Zda, Zn, rot, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0530a000: CLASTA  <R><dn>, <Pg>, <R><dn>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_clast_rz, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_clasta_r_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0530a000))
    {
        uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: clasta_r_p_z Rdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__clasta_r_p_z
            IEM_INSTR_IMPL_A64__clasta_r_p_z(Rdn, Zm, Pg, size);
#else
            RT_NOREF(Rdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/052a8000: CLASTA  <V><dn>, <Pg>, <V><dn>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_clast_vz, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_clasta_v_p_z, uint32_t, uOpcode)
{
    uint32_t const Vdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: clasta_v_p_z Vdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__clasta_v_p_z
        IEM_INSTR_IMPL_A64__clasta_v_p_z(Vdn, Zm, Pg, size);
#else
        RT_NOREF(Vdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05288000: CLASTA  <Zdn>.<T>, <Pg>, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_clast_zz, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_clasta_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: clasta_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__clasta_z_p_zz
        IEM_INSTR_IMPL_A64__clasta_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0531a000: CLASTB  <R><dn>, <Pg>, <R><dn>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_clast_rz, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_clastb_r_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0531a000))
    {
        uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: clastb_r_p_z Rdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__clastb_r_p_z
            IEM_INSTR_IMPL_A64__clastb_r_p_z(Rdn, Zm, Pg, size);
#else
            RT_NOREF(Rdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/052b8000: CLASTB  <V><dn>, <Pg>, <V><dn>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_clast_vz, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_clastb_v_p_z, uint32_t, uOpcode)
{
    uint32_t const Vdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: clastb_v_p_z Vdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__clastb_v_p_z
        IEM_INSTR_IMPL_A64__clastb_v_p_z(Vdn, Zm, Pg, size);
#else
        RT_NOREF(Vdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05298000: CLASTB  <Zdn>.<T>, <Pg>, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_clast_zz, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_clastb_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: clastb_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__clastb_z_p_zz
        IEM_INSTR_IMPL_A64__clastb_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0418a000: CLS  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_cls_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cls_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cls_z_p_z_m
        IEM_INSTR_IMPL_A64__cls_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0408a000: CLS  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_cls_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: cls_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cls_z_p_z_z
        IEM_INSTR_IMPL_A64__cls_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0419a000: CLZ  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_clz_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: clz_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__clz_z_p_z_m
        IEM_INSTR_IMPL_A64__clz_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0409a000: CLZ  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_clz_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: clz_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__clz_z_p_z_z
        IEM_INSTR_IMPL_A64__clz_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20f000/44002000: CMLA  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>, <const>
   Instruction Set: A64  Groups: sve_intx_cmla, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmla_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmla_z_zzz Zda=%#x Zn=%#x rot=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmla_z_zzz
        IEM_INSTR_IMPL_A64__cmla_z_zzz(Zda, Zn, rot, Zm, size);
#else
        RT_NOREF(Zda, Zn, rot, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/44a06000: CMLA  <Zda>.H, <Zn>.H, <Zm>.H[<imm>], <const>
   Instruction Set: A64  Groups: sve_intx_cmla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmla_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmla_z_zzzi_h Zda=%#x Zn=%#x rot=%u Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__cmla_z_zzzi_h
        IEM_INSTR_IMPL_A64__cmla_z_zzzi_h(Zda, Zn, rot, Zm, i2);
#else
        RT_NOREF(Zda, Zn, rot, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/44e06000: CMLA  <Zda>.S, <Zn>.S, <Zm>.S[<imm>], <const>
   Instruction Set: A64  Groups: sve_intx_cmla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmla_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmla_z_zzzi_s Zda=%#x Zn=%#x rot=%u Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__cmla_z_zzzi_s
        IEM_INSTR_IMPL_A64__cmla_z_zzzi_s(Zda, Zn, rot, Zm, i1);
#else
        RT_NOREF(Zda, Zn, rot, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/25008000: CMPEQ  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_scmp_vi, sve_cmpsimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpeq_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpeq_p_p_zi Pd=%#x Zn=%#x Pg=%u imm5=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm5, size));
#ifdef IEM_INSTR_IMPL_A64__cmpeq_p_p_zi
        IEM_INSTR_IMPL_A64__cmpeq_p_p_zi(Pd, Zn, Pg, imm5, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm5, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24002000: CMPEQ  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_0, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpeq_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpeq_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpeq_p_p_zw
        IEM_INSTR_IMPL_A64__cmpeq_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/2400a000: CMPEQ  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_cmp_0, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpeq_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpeq_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpeq_p_p_zz
        IEM_INSTR_IMPL_A64__cmpeq_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/25000000: CMPGE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_scmp_vi, sve_cmpsimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpge_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpge_p_p_zi Pd=%#x Zn=%#x Pg=%u imm5=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm5, size));
#ifdef IEM_INSTR_IMPL_A64__cmpge_p_p_zi
        IEM_INSTR_IMPL_A64__cmpge_p_p_zi(Pd, Zn, Pg, imm5, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm5, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24004000: CMPGE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_1, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpge_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpge_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpge_p_p_zw
        IEM_INSTR_IMPL_A64__cmpge_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24008000: CMPGE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_cmp_0, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpge_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpge_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpge_p_p_zz
        IEM_INSTR_IMPL_A64__cmpge_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/25000010: CMPGT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_scmp_vi, sve_cmpsimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpgt_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpgt_p_p_zi Pd=%#x Zn=%#x Pg=%u imm5=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm5, size));
#ifdef IEM_INSTR_IMPL_A64__cmpgt_p_p_zi
        IEM_INSTR_IMPL_A64__cmpgt_p_p_zi(Pd, Zn, Pg, imm5, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm5, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24004010: CMPGT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_1, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpgt_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpgt_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpgt_p_p_zw
        IEM_INSTR_IMPL_A64__cmpgt_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24008010: CMPGT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_cmp_0, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpgt_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpgt_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpgt_p_p_zz
        IEM_INSTR_IMPL_A64__cmpgt_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff202010/24200010: CMPHI  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_ucmp_vi, sve_cmpuimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmphi_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm7       = (uOpcode >> 14) & 0x0000007f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmphi_p_p_zi Pd=%#x Zn=%#x Pg=%u imm7=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm7, size));
#ifdef IEM_INSTR_IMPL_A64__cmphi_p_p_zi
        IEM_INSTR_IMPL_A64__cmphi_p_p_zi(Pd, Zn, Pg, imm7, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm7, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/2400c010: CMPHI  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_1, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmphi_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmphi_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmphi_p_p_zw
        IEM_INSTR_IMPL_A64__cmphi_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24000010: CMPHI  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_cmp_0, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmphi_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmphi_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmphi_p_p_zz
        IEM_INSTR_IMPL_A64__cmphi_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff202010/24200000: CMPHS  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_ucmp_vi, sve_cmpuimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmphs_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm7       = (uOpcode >> 14) & 0x0000007f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmphs_p_p_zi Pd=%#x Zn=%#x Pg=%u imm7=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm7, size));
#ifdef IEM_INSTR_IMPL_A64__cmphs_p_p_zi
        IEM_INSTR_IMPL_A64__cmphs_p_p_zi(Pd, Zn, Pg, imm7, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm7, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/2400c000: CMPHS  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_1, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmphs_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmphs_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmphs_p_p_zw
        IEM_INSTR_IMPL_A64__cmphs_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24000000: CMPHS  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_cmp_0, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmphs_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmphs_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmphs_p_p_zz
        IEM_INSTR_IMPL_A64__cmphs_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/25002010: CMPLE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_scmp_vi, sve_cmpsimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmple_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmple_p_p_zi Pd=%#x Zn=%#x Pg=%u imm5=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm5, size));
#ifdef IEM_INSTR_IMPL_A64__cmple_p_p_zi
        IEM_INSTR_IMPL_A64__cmple_p_p_zi(Pd, Zn, Pg, imm5, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm5, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24006010: CMPLE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_1, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmple_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmple_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmple_p_p_zw
        IEM_INSTR_IMPL_A64__cmple_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff202010/24202000: CMPLO  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_ucmp_vi, sve_cmpuimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmplo_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm7       = (uOpcode >> 14) & 0x0000007f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmplo_p_p_zi Pd=%#x Zn=%#x Pg=%u imm7=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm7, size));
#ifdef IEM_INSTR_IMPL_A64__cmplo_p_p_zi
        IEM_INSTR_IMPL_A64__cmplo_p_p_zi(Pd, Zn, Pg, imm7, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm7, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/2400e000: CMPLO  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_1, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmplo_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmplo_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmplo_p_p_zw
        IEM_INSTR_IMPL_A64__cmplo_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff202010/24202010: CMPLS  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_ucmp_vi, sve_cmpuimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpls_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm7       = (uOpcode >> 14) & 0x0000007f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpls_p_p_zi Pd=%#x Zn=%#x Pg=%u imm7=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm7, size));
#ifdef IEM_INSTR_IMPL_A64__cmpls_p_p_zi
        IEM_INSTR_IMPL_A64__cmpls_p_p_zi(Pd, Zn, Pg, imm7, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm7, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/2400e010: CMPLS  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_1, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpls_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpls_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpls_p_p_zw
        IEM_INSTR_IMPL_A64__cmpls_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/25002000: CMPLT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_scmp_vi, sve_cmpsimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmplt_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmplt_p_p_zi Pd=%#x Zn=%#x Pg=%u imm5=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm5, size));
#ifdef IEM_INSTR_IMPL_A64__cmplt_p_p_zi
        IEM_INSTR_IMPL_A64__cmplt_p_p_zi(Pd, Zn, Pg, imm5, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm5, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24006000: CMPLT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_1, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmplt_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmplt_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmplt_p_p_zw
        IEM_INSTR_IMPL_A64__cmplt_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/25008010: CMPNE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_scmp_vi, sve_cmpsimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpne_p_p_zi, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpne_p_p_zi Pd=%#x Zn=%#x Pg=%u imm5=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, imm5, size));
#ifdef IEM_INSTR_IMPL_A64__cmpne_p_p_zi
        IEM_INSTR_IMPL_A64__cmpne_p_p_zi(Pd, Zn, Pg, imm5, size);
#else
        RT_NOREF(Pd, Zn, Pg, imm5, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/24002010: CMPNE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_cmp_0, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpne_p_p_zw, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpne_p_p_zw Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpne_p_p_zw
        IEM_INSTR_IMPL_A64__cmpne_p_p_zw(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/2400a010: CMPNE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_cmp_0, sve_cmpvec, sve */
FNIEMOP_DEF_1(iemDecodeA64_cmpne_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cmpne_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__cmpne_p_p_zz
        IEM_INSTR_IMPL_A64__cmpne_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041ba000: CNOT  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_cnot_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cnot_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cnot_z_p_z_m
        IEM_INSTR_IMPL_A64__cnot_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040ba000: CNOT  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_cnot_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: cnot_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cnot_z_p_z_z
        IEM_INSTR_IMPL_A64__cnot_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041aa000: CNT  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_cnt_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cnt_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cnt_z_p_z_m
        IEM_INSTR_IMPL_A64__cnt_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040aa000: CNT  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_cnt_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: cnt_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cnt_z_p_z_z
        IEM_INSTR_IMPL_A64__cnt_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0420e000: CNTB  <Xd>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_count, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_cntb_r_s, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cntb_r_s Rd=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__cntb_r_s
        IEM_INSTR_IMPL_A64__cntb_r_s(Rd, pattern, imm4);
#else
        RT_NOREF(Rd, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0e000: CNTD  <Xd>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_count, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_cntd_r_s, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cntd_r_s Rd=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__cntd_r_s
        IEM_INSTR_IMPL_A64__cntd_r_s(Rd, pattern, imm4);
#else
        RT_NOREF(Rd, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460e000: CNTH  <Xd>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_count, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_cnth_r_s, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cnth_r_s Rd=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__cnth_r_s
        IEM_INSTR_IMPL_A64__cnth_r_s(Rd, pattern, imm4);
#else
        RT_NOREF(Rd, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc200/25208000: CNTP  <Xd>, <Pg>, <Pn>.<T>
   Instruction Set: A64  Groups: sve_int_pcount_pred, sve_pred_count_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_cntp_r_p_p, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cntp_r_p_p Rd=%#x Pn=%#x Pg=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Pn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cntp_r_p_p
        IEM_INSTR_IMPL_A64__cntp_r_p_p(Rd, Pn, Pg, size);
#else
        RT_NOREF(Rd, Pn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffa00/25208200: CNTP  <Xd>, <PNn>.<T>, <vl>
   Instruction Set: A64  Groups: sve_int_pcount_pn, sve_pred_count_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_cntp_r_pn, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const PNn        = (uOpcode >>  5) & 0x0000000f;
    uint32_t const vl         = (uOpcode >> 10) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: cntp_r_pn Rd=%#x PNn=%#x vl=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, PNn, vl, size));
#ifdef IEM_INSTR_IMPL_A64__cntp_r_pn
        IEM_INSTR_IMPL_A64__cntp_r_pn(Rd, PNn, vl, size);
#else
        RT_NOREF(Rd, PNn, vl, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0e000: CNTW  <Xd>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_count, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_cntw_r_s, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cntw_r_s Rd=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__cntw_r_s
        IEM_INSTR_IMPL_A64__cntw_r_s(Rd, pattern, imm4);
#else
        RT_NOREF(Rd, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbfe000/05a18000: COMPACT  <Zd>.<T>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_compact, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_compact_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: compact_z_p_z Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__compact_z_p_z
        IEM_INSTR_IMPL_A64__compact_z_p_z(Zd, Zn, Pg, sz);
#else
        RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbfe000/05218000: COMPACT  <Zd>.<T>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_compact, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_compact_z_p_z_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: compact_z_p_z_s Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__compact_z_p_z_s
        IEM_INSTR_IMPL_A64__compact_z_p_z_s(Zd, Zn, Pg, sz);
#else
        RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30c000/05100000: CPY  <Zd>.<T>, <Pg>/Z, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_dup_imm_pred, sve_wideimm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_cpy_z_o_i, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Pg         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cpy_z_o_i Zd=%#x imm8=%#x sh=%u Pg=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, imm8, sh, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cpy_z_o_i
        IEM_INSTR_IMPL_A64__cpy_z_o_i(Zd, imm8, sh, Pg, size);
#else
        RT_NOREF(Zd, imm8, sh, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30c000/05104000: CPY  <Zd>.<T>, <Pg>/M, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_dup_imm_pred, sve_wideimm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_cpy_z_p_i, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Pg         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cpy_z_p_i Zd=%#x imm8=%#x sh=%u Pg=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, imm8, sh, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cpy_z_p_i
        IEM_INSTR_IMPL_A64__cpy_z_p_i(Zd, imm8, sh, Pg, size);
#else
        RT_NOREF(Zd, imm8, sh, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0528a000: CPY  <Zd>.<T>, <Pg>/M, <R><n|SP>
   Instruction Set: A64  Groups: sve_int_perm_cpy_r, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_cpy_z_p_r, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cpy_z_p_r Zd=%#x Rn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Rn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cpy_z_p_r
        IEM_INSTR_IMPL_A64__cpy_z_p_r(Zd, Rn, Pg, size);
#else
        RT_NOREF(Zd, Rn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05208000: CPY  <Zd>.<T>, <Pg>/M, <V><n>
   Instruction Set: A64  Groups: sve_int_perm_cpy_v, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_cpy_z_p_v, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Vn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: cpy_z_p_v Zd=%#x Vn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Vn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__cpy_z_p_v
        IEM_INSTR_IMPL_A64__cpy_z_p_v(Zd, Vn, Pg, size);
#else
        RT_NOREF(Zd, Vn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc1f/25a02000: CTERMEQ  <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_cterm, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_ctermeq_rr, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ctermeq_rr Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__ctermeq_rr
        IEM_INSTR_IMPL_A64__ctermeq_rr(Rn, Rm, sz);
#else
        RT_NOREF(Rn, Rm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc1f/25a02010: CTERMNE  <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_cterm, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_ctermne_rr, uint32_t, uOpcode)
{
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ctermne_rr Rn=%#x Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__ctermne_rr
        IEM_INSTR_IMPL_A64__ctermne_rr(Rn, Rm, sz);
#else
        RT_NOREF(Rn, Rm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0430e400: DECB  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_a, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_decb_r_rs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0430e400))
    {
        uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: decb_r_rs Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__decb_r_rs
            IEM_INSTR_IMPL_A64__decb_r_rs(Rdn, pattern, imm4);
#else
            RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04f0e400: DECD  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_a, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_decd_r_rs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04f0e400))
    {
        uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: decd_r_rs Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__decd_r_rs
            IEM_INSTR_IMPL_A64__decd_r_rs(Rdn, pattern, imm4);
#else
            RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04f0c400: DECD  <Zdn>.D{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv1, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_decd_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: decd_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__decd_z_zs
        IEM_INSTR_IMPL_A64__decd_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0470e400: DECH  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_a, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_dech_r_rs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0470e400))
    {
        uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: dech_r_rs Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__dech_r_rs
            IEM_INSTR_IMPL_A64__dech_r_rs(Rdn, pattern, imm4);
#else
            RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0470c400: DECH  <Zdn>.H{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv1, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_dech_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: dech_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__dech_z_zs
        IEM_INSTR_IMPL_A64__dech_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252d8800: DECP  <Xdn>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_r, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_decp_r_p_r, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: decp_r_p_r Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__decp_r_p_r
        IEM_INSTR_IMPL_A64__decp_r_p_r(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252d8000: DECP  <Zdn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_v, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_decp_z_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252d8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: decp_z_p_z Zdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__decp_z_p_z
            IEM_INSTR_IMPL_A64__decp_z_p_z(Zdn, Pm, size);
#else
            RT_NOREF(Zdn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04b0e400: DECW  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_a, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_decw_r_rs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04b0e400))
    {
        uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: decw_r_rs Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__decw_r_rs
            IEM_INSTR_IMPL_A64__decw_r_rs(Rdn, pattern, imm4);
#else
            RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04b0c400: DECW  <Zdn>.S{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv1, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_decw_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: decw_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__decw_z_zs
        IEM_INSTR_IMPL_A64__decw_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc000/2538c000: DUP  <Zd>.<T>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_dup_imm, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_dup_z_i, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc000)) == UINT32_C(0x2538c000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
        uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: dup_z_i Zd=%#x imm8=%#x sh=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, imm8, sh, size));
#ifdef IEM_INSTR_IMPL_A64__dup_z_i
            IEM_INSTR_IMPL_A64__dup_z_i(Zd, imm8, sh, size);
#else
            RT_NOREF(Zd, imm8, sh, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/05203800: DUP  <Zd>.<T>, <R><n|SP>
   Instruction Set: A64  Groups: sve_int_perm_dup_r, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_dup_z_r, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: dup_z_r Zd=%#x Rn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Rn, size));
#ifdef IEM_INSTR_IMPL_A64__dup_z_r
        IEM_INSTR_IMPL_A64__dup_z_r(Zd, Rn, size);
#else
        RT_NOREF(Zd, Rn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05202000: DUP  <Zd>.<T>, <Zn>.<T>[<imm>]
   Instruction Set: A64  Groups: sve_int_perm_dup_i, sve_perm_unpred_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_dup_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const tsz        = (uOpcode >> 16) & 0x0000001f;
    uint32_t const imm2       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: dup_z_zi Zd=%#x Zn=%#x tsz=%#x imm2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, tsz, imm2));
#ifdef IEM_INSTR_IMPL_A64__dup_z_zi
        IEM_INSTR_IMPL_A64__dup_z_zi(Zd, Zn, tsz, imm2);
#else
        RT_NOREF(Zd, Zn, tsz, imm2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/05c00000: DUPM  <Zd>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_dup_mask_imm, sve_maskimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_dupm_z_i, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05c00000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm13      = (uOpcode >>  5) & 0x00001fff;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: dupm_z_i Zd=%#x imm13=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, imm13));
#ifdef IEM_INSTR_IMPL_A64__dupm_z_i
            IEM_INSTR_IMPL_A64__dupm_z_i(Zd, imm13);
#else
            RT_NOREF(Zd, imm13, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/05202400: DUPQ  <Zd>.<T>, <Zn>.<T>[<imm>]
   Instruction Set: A64  Groups: sve_int_perm_dupq_i, sve_perm_quads_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_dupq_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const tsz        = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: dupq_z_zi Zd=%#x Zn=%#x tsz=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, tsz, i1));
#ifdef IEM_INSTR_IMPL_A64__dupq_z_zi
        IEM_INSTR_IMPL_A64__dupq_z_zi(Zd, Zn, tsz, i1);
#else
        RT_NOREF(Zd, Zn, tsz, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04203800: EOR3  <Zdn>.D, <Zdn>.D, <Zm>.D, <Zk>.D
   Instruction Set: A64  Groups: sve_int_tern_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_eor3_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zk         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: eor3_z_zzz Zdn=%#x Zk=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zk, Zm));
#ifdef IEM_INSTR_IMPL_A64__eor3_z_zzz
        IEM_INSTR_IMPL_A64__eor3_z_zzz(Zdn, Zk, Zm);
#else
        RT_NOREF(Zdn, Zk, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25004200: EOR  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_eor_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: eor_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__eor_p_p_pp_z
        IEM_INSTR_IMPL_A64__eor_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04190000: EOR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_log, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_eor_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04190000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: eor_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__eor_z_p_zz
            IEM_INSTR_IMPL_A64__eor_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/05400000: EOR  <Zdn>.<T>, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_log_imm, sve_maskimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_eor_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05400000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm13      = (uOpcode >>  5) & 0x00001fff;
        if ((0x1 /*opc@22*/ != 3) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: eor_z_zi Zdn=%#x imm13=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm13));
#ifdef IEM_INSTR_IMPL_A64__eor_z_zi
            IEM_INSTR_IMPL_A64__eor_z_zi(Zdn, imm13);
#else
            RT_NOREF(Zdn, imm13, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04a03000: EOR  <Zd>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_eor_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: eor_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__eor_z_zz
        IEM_INSTR_IMPL_A64__eor_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45009000: EORBT  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_eorx, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_eorbt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: eorbt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__eorbt_z_zz
        IEM_INSTR_IMPL_A64__eorbt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041d2000: EORQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_reduce_2q, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_eorqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: eorqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__eorqv_z_p_z
        IEM_INSTR_IMPL_A64__eorqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25404200: EORS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_eors_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: eors_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__eors_p_p_pp_z
        IEM_INSTR_IMPL_A64__eors_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45009400: EORTB  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_eorx, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_eortb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: eortb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__eortb_z_zz
        IEM_INSTR_IMPL_A64__eortb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04192000: EORV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_2, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_eorv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: eorv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__eorv_r_p_z
        IEM_INSTR_IMPL_A64__eorv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05318000: EXPAND  <Zd>.<T>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_expand, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_expand_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: expand_z_p_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__expand_z_p_z
        IEM_INSTR_IMPL_A64__expand_z_p_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/05600000: EXT  <Zd>.B, { <Zn1>.B, <Zn2>.B }, #<imm>
   Instruction Set: A64  Groups: sve_intx_perm_extract_i, sve_perm_extract, sve */
FNIEMOP_DEF_1(iemDecodeA64_ext_z_zi_con, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8l      = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm8h      = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ext_z_zi_con Zd=%#x Zn=%#x imm8l=%u imm8h=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm8l, imm8h));
#ifdef IEM_INSTR_IMPL_A64__ext_z_zi_con
        IEM_INSTR_IMPL_A64__ext_z_zi_con(Zd, Zn, imm8l, imm8h);
#else
        RT_NOREF(Zd, Zn, imm8l, imm8h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/05200000: EXT  <Zdn>.B, <Zdn>.B, <Zm>.B, #<imm>
   Instruction Set: A64  Groups: sve_int_perm_extract_i, sve_perm_extract, sve */
FNIEMOP_DEF_1(iemDecodeA64_ext_z_zi_des, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm8l      = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm8h      = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ext_z_zi_des Zdn=%#x Zm=%#x imm8l=%u imm8h=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, imm8l, imm8h));
#ifdef IEM_INSTR_IMPL_A64__ext_z_zi_des
        IEM_INSTR_IMPL_A64__ext_z_zi_des(Zdn, Zm, imm8l, imm8h);
#else
        RT_NOREF(Zdn, Zm, imm8l, imm8h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/05602400: EXTQ  <Zdn>.B, <Zdn>.B, <Zm>.B, #<imm>
   Instruction Set: A64  Groups: sve_int_perm_extq, sve_perm_quads_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_extq_z_zi_des, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x05602400))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: extq_z_zi_des Zdn=%#x Zm=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, imm4));
#ifdef IEM_INSTR_IMPL_A64__extq_z_zi_des
            IEM_INSTR_IMPL_A64__extq_z_zi_des(Zdn, Zm, imm4);
#else
            RT_NOREF(Zdn, Zm, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c126e000: F1CVT  { <Zd1>.H-<Zd2>.H }, <Zn>.B
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_f1cvt_mz2_z8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc126e000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: f1cvt_mz2_z8 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__f1cvt_mz2_z8
            IEM_INSTR_IMPL_A64__f1cvt_mz2_z8(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/65083000: F1CVT  <Zd>.H, <Zn>.B
   Instruction Set: A64  Groups: sve_fp8_fcvt_wide, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_f1cvt_z_z8_b2h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: f1cvt_z_z8_b2h Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__f1cvt_z_z8_b2h
        IEM_INSTR_IMPL_A64__f1cvt_z_z8_b2h(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c126e001: F1CVTL  { <Zd1>.H-<Zd2>.H }, <Zn>.B
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_f1cvtl_mz2_z8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc126e001))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: f1cvtl_mz2_z8 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__f1cvtl_mz2_z8
            IEM_INSTR_IMPL_A64__f1cvtl_mz2_z8(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/65093000: F1CVTLT  <Zd>.H, <Zn>.B
   Instruction Set: A64  Groups: sve_fp8_fcvt_wide, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_f1cvtlt_z_z8_b2h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: f1cvtlt_z_z8_b2h Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__f1cvtlt_z_z8_b2h
        IEM_INSTR_IMPL_A64__f1cvtlt_z_z8_b2h(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c1a6e000: F2CVT  { <Zd1>.H-<Zd2>.H }, <Zn>.B
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_f2cvt_mz2_z8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc1a6e000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: f2cvt_mz2_z8 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__f2cvt_mz2_z8
            IEM_INSTR_IMPL_A64__f2cvt_mz2_z8(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/65083400: F2CVT  <Zd>.H, <Zn>.B
   Instruction Set: A64  Groups: sve_fp8_fcvt_wide, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_f2cvt_z_z8_b2h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: f2cvt_z_z8_b2h Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__f2cvt_z_z8_b2h
        IEM_INSTR_IMPL_A64__f2cvt_z_z8_b2h(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c1a6e001: F2CVTL  { <Zd1>.H-<Zd2>.H }, <Zn>.B
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_f2cvtl_mz2_z8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc1a6e001))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: f2cvtl_mz2_z8 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__f2cvtl_mz2_z8
            IEM_INSTR_IMPL_A64__f2cvtl_mz2_z8(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/65093400: F2CVTLT  <Zd>.H, <Zn>.B
   Instruction Set: A64  Groups: sve_fp8_fcvt_wide, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_f2cvtlt_z_z8_b2h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
    {
        LogFlow(("%018x/%010x: f2cvtlt_z_z8_b2h Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__f2cvtlt_z_z8_b2h
        IEM_INSTR_IMPL_A64__f2cvtlt_z_z8_b2h(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65088000: FABD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fabd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fabd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fabd_z_p_zz
        IEM_INSTR_IMPL_A64__fabd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041ca000: FABS  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_fabs_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fabs_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fabs_z_p_z_m
        IEM_INSTR_IMPL_A64__fabs_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040ca000: FABS  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_fabs_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fabs_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fabs_z_p_z_z
        IEM_INSTR_IMPL_A64__fabs_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/6500c010: FACGE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_pd, sve_fp_cmpvev, sve */
FNIEMOP_DEF_1(iemDecodeA64_facge_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: facge_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__facge_p_p_zz
        IEM_INSTR_IMPL_A64__facge_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/6500e010: FACGT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_pd, sve_fp_cmpvev, sve */
FNIEMOP_DEF_1(iemDecodeA64_facgt_p_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x6500e010))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: facgt_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__facgt_p_p_zz
            IEM_INSTR_IMPL_A64__facgt_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
            RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe3c0/65188000: FADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_2op_i_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fadd_z_p_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65188000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const i1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fadd_z_p_zs Zdn=%#x i1=%u Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, i1, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fadd_z_p_zs
            IEM_INSTR_IMPL_A64__fadd_z_p_zs(Zdn, i1, Pg, size);
#else
            RT_NOREF(Zdn, i1, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65008000: FADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fadd_z_p_zz
        IEM_INSTR_IMPL_A64__fadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/65000000: FADD  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fadd_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fadd_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fadd_z_zz
        IEM_INSTR_IMPL_A64__fadd_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbf9c38/c1a01c00: FADD  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_float_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fadd_za_zw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbf9c38)) == UINT32_C(0xc1a01c00))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fadd_za_zw_2x2 off3=%u Zm=%#x Rv=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv, sz));
#ifdef IEM_INSTR_IMPL_A64__fadd_za_zw_2x2
            IEM_INSTR_IMPL_A64__fadd_za_zw_2x2(off3, Zm, Rv, sz);
#else
            RT_NOREF(off3, Zm, Rv, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c38/c1a41c00: FADD  ZA.H[<Wv>, <offs>{, VGx2}], { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_f16_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fadd_za_zw_2x2_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c38)) == UINT32_C(0xc1a41c00))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
        {
            LogFlow(("%018x/%010x: fadd_za_zw_2x2_16 off3=%u Zm=%#x Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv));
#ifdef IEM_INSTR_IMPL_A64__fadd_za_zw_2x2_16
            IEM_INSTR_IMPL_A64__fadd_za_zw_2x2_16(off3, Zm, Rv);
#else
            RT_NOREF(off3, Zm, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbf9c78/c1a11c00: FADD  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_float_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fadd_za_zw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbf9c78)) == UINT32_C(0xc1a11c00))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fadd_za_zw_4x4 off3=%u Zm=%u Rv=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv, sz));
#ifdef IEM_INSTR_IMPL_A64__fadd_za_zw_4x4
            IEM_INSTR_IMPL_A64__fadd_za_zw_4x4(off3, Zm, Rv, sz);
#else
            RT_NOREF(off3, Zm, Rv, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c78/c1a51c00: FADD  ZA.H[<Wv>, <offs>{, VGx4}], { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_f16_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fadd_za_zw_4x4_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c78)) == UINT32_C(0xc1a51c00))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
        {
            LogFlow(("%018x/%010x: fadd_za_zw_4x4_16 off3=%u Zm=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv));
#ifdef IEM_INSTR_IMPL_A64__fadd_za_zw_4x4_16
            IEM_INSTR_IMPL_A64__fadd_za_zw_4x4_16(off3, Zm, Rv);
#else
            RT_NOREF(off3, Zm, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65182000: FADDA  <V><dn>, <Pg>, <V><dn>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_vd, sve_fp_slowreduce, sve */
FNIEMOP_DEF_1(iemDecodeA64_fadda_v_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65182000))
    {
        uint32_t const Vdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: fadda_v_p_z Vdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fadda_v_p_z
            IEM_INSTR_IMPL_A64__fadda_v_p_z(Vdn, Zm, Pg, size);
#else
            RT_NOREF(Vdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/64108000: FADDP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_pairwise_lvl2, sve_fp_pairwise, sve */
FNIEMOP_DEF_1(iemDecodeA64_faddp_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: faddp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__faddp_z_p_zz
        IEM_INSTR_IMPL_A64__faddp_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6410a000: FADDQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_fp_fast_redq, sve_fp_fastreduceq, sve */
FNIEMOP_DEF_1(iemDecodeA64_faddqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: faddqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__faddqv_z_p_z
        IEM_INSTR_IMPL_A64__faddqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65002000: FADDV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_fast_red, sve_fp_fastreduce, sve */
FNIEMOP_DEF_1(iemDecodeA64_faddv_v_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: faddv_v_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__faddv_v_p_z
        IEM_INSTR_IMPL_A64__faddv_v_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b140: FAMAX  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_famax_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b140))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: famax_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__famax_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__famax_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b940: FAMAX  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_famax_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b940))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: famax_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__famax_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__famax_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/650e8000: FAMAX  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_famax_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/)
    {
        LogFlow(("%018x/%010x: famax_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__famax_z_p_zz
        IEM_INSTR_IMPL_A64__famax_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b141: FAMIN  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_famin_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b141))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: famin_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__famin_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__famin_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b941: FAMIN  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_famin_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b941))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: famin_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__famin_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__famin_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/650f8000: FAMIN  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_famin_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFaMinMax /*FEAT_FAMINMAX*/)
    {
        LogFlow(("%018x/%010x: famin_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__famin_z_p_zz
        IEM_INSTR_IMPL_A64__famin_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ee000/64008000: FCADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_fcadd_lvl2, sve_fp_fcadd, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const rot        = (uOpcode >> 16) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u rot=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, rot, size));
#ifdef IEM_INSTR_IMPL_A64__fcadd_z_p_zz
        IEM_INSTR_IMPL_A64__fcadd_z_p_zz(Zdn, Zm, Pg, rot, size);
#else
        RT_NOREF(Zdn, Zm, Pg, rot, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc01/c120c000: FCLAMP  { <Zd1>.<T>-<Zd2>.<T> }, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_fclamp, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fclamp_mz_zz_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120c000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fclamp_mz_zz_2 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fclamp_mz_zz_2
            IEM_INSTR_IMPL_A64__fclamp_mz_zz_2(Zd, Zn, Zm, size);
#else
            RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc03/c120c800: FCLAMP  { <Zd1>.<T>-<Zd4>.<T> }, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_fclamp, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fclamp_mz_zz_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc03)) == UINT32_C(0xc120c800))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fclamp_mz_zz_4 Zd=%u Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fclamp_mz_zz_4
            IEM_INSTR_IMPL_A64__fclamp_mz_zz_4(Zd, Zn, Zm, size);
#else
            RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/64202400: FCLAMP  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_clamp_lvl2, sve_fp_clamp, sve */
FNIEMOP_DEF_1(iemDecodeA64_fclamp_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fclamp_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fclamp_z_zz
        IEM_INSTR_IMPL_A64__fclamp_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe010/65122000: FCMEQ  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #0.0
   Instruction Set: A64  Groups: sve_fp_2op_p_pd, sve_fp_cmpzero, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmeq_p_p_z0, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65122000))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fcmeq_p_p_z0 Pd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fcmeq_p_p_z0
            IEM_INSTR_IMPL_A64__fcmeq_p_p_z0(Pd, Zn, Pg, size);
#else
            RT_NOREF(Pd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/65006000: FCMEQ  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_pd, sve_fp_cmpvev, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmeq_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmeq_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fcmeq_p_p_zz
        IEM_INSTR_IMPL_A64__fcmeq_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe010/65102000: FCMGE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #0.0
   Instruction Set: A64  Groups: sve_fp_2op_p_pd, sve_fp_cmpzero, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmge_p_p_z0, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmge_p_p_z0 Pd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fcmge_p_p_z0
        IEM_INSTR_IMPL_A64__fcmge_p_p_z0(Pd, Zn, Pg, size);
#else
        RT_NOREF(Pd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/65004000: FCMGE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_pd, sve_fp_cmpvev, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmge_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmge_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fcmge_p_p_zz
        IEM_INSTR_IMPL_A64__fcmge_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe010/65102010: FCMGT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #0.0
   Instruction Set: A64  Groups: sve_fp_2op_p_pd, sve_fp_cmpzero, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmgt_p_p_z0, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmgt_p_p_z0 Pd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fcmgt_p_p_z0
        IEM_INSTR_IMPL_A64__fcmgt_p_p_z0(Pd, Zn, Pg, size);
#else
        RT_NOREF(Pd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/65004010: FCMGT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_pd, sve_fp_cmpvev, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmgt_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmgt_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fcmgt_p_p_zz
        IEM_INSTR_IMPL_A64__fcmgt_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff208000/64000000: FCMLA  <Zda>.<T>, <Pg>/M, <Zn>.<T>, <Zm>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_fcmla_lvl2, sve_fp_fcmla, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmla_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const rot        = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmla_z_p_zzz Zda=%#x Zn=%#x Pg=%u rot=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, rot, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fcmla_z_p_zzz
        IEM_INSTR_IMPL_A64__fcmla_z_p_zzz(Zda, Zn, Pg, rot, Zm, size);
#else
        RT_NOREF(Zda, Zn, Pg, rot, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/64a01000: FCMLA  <Zda>.H, <Zn>.H, <Zm>.H[<imm>], <const>
   Instruction Set: A64  Groups: sve_fp_fcmla_by_indexed_elem_lvl2, sve_fp_fcmla_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmla_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmla_z_zzzi_h Zda=%#x Zn=%#x rot=%u Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__fcmla_z_zzzi_h
        IEM_INSTR_IMPL_A64__fcmla_z_zzzi_h(Zda, Zn, rot, Zm, i2);
#else
        RT_NOREF(Zda, Zn, rot, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/64e01000: FCMLA  <Zda>.S, <Zn>.S, <Zm>.S[<imm>], <const>
   Instruction Set: A64  Groups: sve_fp_fcmla_by_indexed_elem_lvl2, sve_fp_fcmla_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmla_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmla_z_zzzi_s Zda=%#x Zn=%#x rot=%u Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__fcmla_z_zzzi_s
        IEM_INSTR_IMPL_A64__fcmla_z_zzzi_s(Zda, Zn, rot, Zm, i1);
#else
        RT_NOREF(Zda, Zn, rot, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe010/65112010: FCMLE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #0.0
   Instruction Set: A64  Groups: sve_fp_2op_p_pd, sve_fp_cmpzero, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmle_p_p_z0, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmle_p_p_z0 Pd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fcmle_p_p_z0
        IEM_INSTR_IMPL_A64__fcmle_p_p_z0(Pd, Zn, Pg, size);
#else
        RT_NOREF(Pd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe010/65112000: FCMLT  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #0.0
   Instruction Set: A64  Groups: sve_fp_2op_p_pd, sve_fp_cmpzero, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmlt_p_p_z0, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmlt_p_p_z0 Pd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fcmlt_p_p_z0
        IEM_INSTR_IMPL_A64__fcmlt_p_p_z0(Pd, Zn, Pg, size);
#else
        RT_NOREF(Pd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe010/65132000: FCMNE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, #0.0
   Instruction Set: A64  Groups: sve_fp_2op_p_pd, sve_fp_cmpzero, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmne_p_p_z0, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65132000))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fcmne_p_p_z0 Pd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fcmne_p_p_z0
            IEM_INSTR_IMPL_A64__fcmne_p_p_z0(Pd, Zn, Pg, size);
#else
            RT_NOREF(Pd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/65006010: FCMNE  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_pd, sve_fp_cmpvev, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmne_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmne_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fcmne_p_p_zz
        IEM_INSTR_IMPL_A64__fcmne_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/6500c000: FCMUO  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_pd, sve_fp_cmpvev, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcmuo_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcmuo_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fcmuo_p_p_zz
        IEM_INSTR_IMPL_A64__fcmuo_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30e000/0510c000: FCPY  <Zd>.<T>, <Pg>/M, #<const>
   Instruction Set: A64  Groups: sve_int_dup_fpimm_pred, sve_wideimm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcpy_z_p_i, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const Pg         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcpy_z_p_i Zd=%#x imm8=%#x Pg=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, imm8, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fcpy_z_p_i
        IEM_INSTR_IMPL_A64__fcpy_z_p_i(Zd, imm8, Pg, size);
#else
        RT_NOREF(Zd, imm8, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c1a0e000: FCVT  { <Zd1>.S-<Zd2>.S }, <Zn>.H
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_mz2_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fcvt_mz2_z Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvt_mz2_z
        IEM_INSTR_IMPL_A64__fcvt_mz2_z(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c124e000: FCVT  <Zd>.B, { <Zn1>.H-<Zn2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z8_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc124e000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: fcvt_z8_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z8_mz2
            IEM_INSTR_IMPL_A64__fcvt_z8_mz2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc60/c134e000: FCVT  <Zd>.B, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_narrow_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z8_mz4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc60)) == UINT32_C(0xc134e000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: fcvt_z8_mz4 Zd=%#x Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z8_mz4
            IEM_INSTR_IMPL_A64__fcvt_z8_mz4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c120e000: FCVT  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_fp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc120e000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fcvt_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_mz2
            IEM_INSTR_IMPL_A64__fcvt_z_mz2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65c8a000: FCVT  <Zd>.H, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_0, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_d2h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvt_z_p_z_d2h Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_d2h
        IEM_INSTR_IMPL_A64__fcvt_z_p_z_d2h(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64da8000: FCVT  <Zd>.H, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_0, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_d2hz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvt_z_p_z_d2hz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_d2hz
        IEM_INSTR_IMPL_A64__fcvt_z_p_z_d2hz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65caa000: FCVT  <Zd>.S, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_0, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_d2s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvt_z_p_z_d2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_d2s
        IEM_INSTR_IMPL_A64__fcvt_z_p_z_d2s(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dac000: FCVT  <Zd>.S, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_0, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_d2sz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dac000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvt_z_p_z_d2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_d2sz
            IEM_INSTR_IMPL_A64__fcvt_z_p_z_d2sz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65c9a000: FCVT  <Zd>.D, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_0, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_h2d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvt_z_p_z_h2d Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_h2d
        IEM_INSTR_IMPL_A64__fcvt_z_p_z_h2d(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64daa000: FCVT  <Zd>.D, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_0, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_h2dz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvt_z_p_z_h2dz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_h2dz
        IEM_INSTR_IMPL_A64__fcvt_z_p_z_h2dz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6589a000: FCVT  <Zd>.S, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_0, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_h2s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6589a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fcvt_z_p_z_h2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_h2s
            IEM_INSTR_IMPL_A64__fcvt_z_p_z_h2s(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/649aa000: FCVT  <Zd>.S, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_0, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_h2sz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvt_z_p_z_h2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_h2sz
        IEM_INSTR_IMPL_A64__fcvt_z_p_z_h2sz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65cba000: FCVT  <Zd>.D, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_0, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_s2d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvt_z_p_z_s2d Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_s2d
        IEM_INSTR_IMPL_A64__fcvt_z_p_z_s2d(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dae000: FCVT  <Zd>.D, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_0, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_s2dz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dae000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvt_z_p_z_s2dz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_s2dz
            IEM_INSTR_IMPL_A64__fcvt_z_p_z_s2dz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6588a000: FCVT  <Zd>.H, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_0, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_s2h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6588a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fcvt_z_p_z_s2h Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_s2h
            IEM_INSTR_IMPL_A64__fcvt_z_p_z_s2h(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/649a8000: FCVT  <Zd>.H, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_0, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvt_z_p_z_s2hz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvt_z_p_z_s2hz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvt_z_p_z_s2hz
        IEM_INSTR_IMPL_A64__fcvt_z_p_z_s2hz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc01/c1a0e001: FCVTL  { <Zd1>.S-<Zd2>.S }, <Zn>.H
   Instruction Set: A64  Groups: mortlach_multi2_wide_fp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvtl_mz2_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc1a0e001))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
        {
            LogFlow(("%018x/%010x: fcvtl_mz2_z Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtl_mz2_z
            IEM_INSTR_IMPL_A64__fcvtl_mz2_z(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6489a000: FCVTLT  <Zd>.S, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_fcvt2_lvl2, sve_fp_fcvt2, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtlt_z_p_z_h2s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtlt_z_p_z_h2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtlt_z_p_z_h2s
        IEM_INSTR_IMPL_A64__fcvtlt_z_p_z_h2s(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6481a000: FCVTLT  <Zd>.S, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_fcvt2z_lvl2, sve_fp_fcvt2z, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtlt_z_p_z_h2sz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtlt_z_p_z_h2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtlt_z_p_z_h2sz
        IEM_INSTR_IMPL_A64__fcvtlt_z_p_z_h2sz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64cba000: FCVTLT  <Zd>.D, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_fcvt2_lvl2, sve_fp_fcvt2, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtlt_z_p_z_s2d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtlt_z_p_z_s2d Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtlt_z_p_z_s2d
        IEM_INSTR_IMPL_A64__fcvtlt_z_p_z_s2d(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64c3a000: FCVTLT  <Zd>.D, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_fcvt2z_lvl2, sve_fp_fcvt2z, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtlt_z_p_z_s2dz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtlt_z_p_z_s2dz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtlt_z_p_z_s2dz
        IEM_INSTR_IMPL_A64__fcvtlt_z_p_z_s2dz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/650a3000: FCVTN  <Zd>.B, { <Zn1>.H-<Zn2>.H }
   Instruction Set: A64  Groups: sve_fp8_fcvt_narrow, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtn_z8_mz2_h2b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0x650a3000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: fcvtn_z8_mz2_h2b Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtn_z8_mz2_h2b
            IEM_INSTR_IMPL_A64__fcvtn_z8_mz2_h2b(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc60/c134e020: FCVTN  <Zd>.B, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_narrow_fp8_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvtn_z8_mz4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc60)) == UINT32_C(0xc134e020))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: fcvtn_z8_mz4 Zd=%#x Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtn_z8_mz4
            IEM_INSTR_IMPL_A64__fcvtn_z8_mz4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c120e020: FCVTN  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_fp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvtn_z_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc120e020))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fcvtn_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtn_z_mz2
            IEM_INSTR_IMPL_A64__fcvtn_z_mz2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/650a3400: FCVTNB  <Zd>.B, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: sve_fp8_fcvt_narrow, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtnb_z8_mz2_s2b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0x650a3400))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: fcvtnb_z8_mz2_s2b Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtnb_z8_mz2_s2b
            IEM_INSTR_IMPL_A64__fcvtnb_z8_mz2_s2b(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/650a3c00: FCVTNT  <Zd>.B, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: sve_fp8_fcvt_narrow, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtnt_z8_mz2_s2b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0x650a3c00))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/)
        {
            LogFlow(("%018x/%010x: fcvtnt_z8_mz2_s2b Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtnt_z8_mz2_s2b
            IEM_INSTR_IMPL_A64__fcvtnt_z8_mz2_s2b(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64caa000: FCVTNT  <Zd>.S, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_fcvt2_lvl2, sve_fp_fcvt2, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtnt_z_p_z_d2s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtnt_z_p_z_d2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtnt_z_p_z_d2s
        IEM_INSTR_IMPL_A64__fcvtnt_z_p_z_d2s(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64c2a000: FCVTNT  <Zd>.S, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_fcvt2z_lvl2, sve_fp_fcvt2z, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtnt_z_p_z_d2sz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtnt_z_p_z_d2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtnt_z_p_z_d2sz
        IEM_INSTR_IMPL_A64__fcvtnt_z_p_z_d2sz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6488a000: FCVTNT  <Zd>.H, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_fcvt2_lvl2, sve_fp_fcvt2, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtnt_z_p_z_s2h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtnt_z_p_z_s2h Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtnt_z_p_z_s2h
        IEM_INSTR_IMPL_A64__fcvtnt_z_p_z_s2h(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6480a000: FCVTNT  <Zd>.H, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_fcvt2z_lvl2, sve_fp_fcvt2z, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtnt_z_p_z_s2hz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtnt_z_p_z_s2hz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtnt_z_p_z_s2hz
        IEM_INSTR_IMPL_A64__fcvtnt_z_p_z_s2hz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/650aa000: FCVTX  <Zd>.S, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_0, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtx_z_p_z_d2s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtx_z_p_z_d2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtx_z_p_z_d2s
        IEM_INSTR_IMPL_A64__fcvtx_z_p_z_d2s(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/641ac000: FCVTX  <Zd>.S, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_0, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtx_z_p_z_d2sz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x641ac000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvtx_z_p_z_d2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtx_z_p_z_d2sz
            IEM_INSTR_IMPL_A64__fcvtx_z_p_z_d2sz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/640aa000: FCVTXNT  <Zd>.S, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_fcvt2_lvl2, sve_fp_fcvt2, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtxnt_z_p_z_d2s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtxnt_z_p_z_d2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtxnt_z_p_z_d2s
        IEM_INSTR_IMPL_A64__fcvtxnt_z_p_z_d2s(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6402a000: FCVTXNT  <Zd>.S, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_fcvt2z_lvl2, sve_fp_fcvt2z, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtxnt_z_p_z_d2sz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtxnt_z_p_z_d2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtxnt_z_p_z_d2sz
        IEM_INSTR_IMPL_A64__fcvtxnt_z_p_z_d2sz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc21/c121e000: FCVTZS  { <Zd1>.S-<Zd2>.S }, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_fpint_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc21)) == UINT32_C(0xc121e000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fcvtzs_mz_z_2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_mz_z_2
            IEM_INSTR_IMPL_A64__fcvtzs_mz_z_2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c131e000: FCVTZS  { <Zd1>.S-<Zd4>.S }, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_fpint_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc131e000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fcvtzs_mz_z_4 Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_mz_z_4
            IEM_INSTR_IMPL_A64__fcvtzs_mz_z_4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65d8a000: FCVTZS  <Zd>.S, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_d2w, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_d2w Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_d2w
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_d2w(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64de8000: FCVTZS  <Zd>.S, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_d2wz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_d2wz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_d2wz
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_d2wz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65dea000: FCVTZS  <Zd>.D, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_d2x, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_d2x Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_d2x
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_d2x(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dfc000: FCVTZS  <Zd>.D, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_d2xz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dfc000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvtzs_z_p_z_d2xz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_d2xz
            IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_d2xz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/655aa000: FCVTZS  <Zd>.H, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_fp162h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_fp162h Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162h
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162h(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645ec000: FCVTZS  <Zd>.H, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_fp162hz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645ec000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvtzs_z_p_z_fp162hz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162hz
            IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162hz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/655ca000: FCVTZS  <Zd>.S, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_fp162w, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_fp162w Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162w
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162w(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645f8000: FCVTZS  <Zd>.S, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_fp162wz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_fp162wz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162wz
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162wz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/655ea000: FCVTZS  <Zd>.D, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_fp162x, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_fp162x Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162x
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162x(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645fc000: FCVTZS  <Zd>.D, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_fp162xz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645fc000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvtzs_z_p_z_fp162xz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162xz
            IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_fp162xz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/659ca000: FCVTZS  <Zd>.S, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_s2w, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_s2w Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_s2w
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_s2w(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/649f8000: FCVTZS  <Zd>.S, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_s2wz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_s2wz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_s2wz
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_s2wz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65dca000: FCVTZS  <Zd>.D, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_s2x, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_s2x Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_s2x
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_s2x(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64df8000: FCVTZS  <Zd>.D, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzs_z_p_z_s2xz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtzs_z_p_z_s2xz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_s2xz
        IEM_INSTR_IMPL_A64__fcvtzs_z_p_z_s2xz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc21/c121e020: FCVTZU  { <Zd1>.S-<Zd2>.S }, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_fpint_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc21)) == UINT32_C(0xc121e020))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fcvtzu_mz_z_2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_mz_z_2
            IEM_INSTR_IMPL_A64__fcvtzu_mz_z_2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c131e020: FCVTZU  { <Zd1>.S-<Zd4>.S }, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_fpint_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc131e020))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fcvtzu_mz_z_4 Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_mz_z_4
            IEM_INSTR_IMPL_A64__fcvtzu_mz_z_4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65d9a000: FCVTZU  <Zd>.S, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_d2w, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_d2w Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_d2w
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_d2w(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dea000: FCVTZU  <Zd>.S, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_d2wz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_d2wz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_d2wz
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_d2wz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65dfa000: FCVTZU  <Zd>.D, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_d2x, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_d2x Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_d2x
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_d2x(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dfe000: FCVTZU  <Zd>.D, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_d2xz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dfe000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvtzu_z_p_z_d2xz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_d2xz
            IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_d2xz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/655ba000: FCVTZU  <Zd>.H, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_fp162h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_fp162h Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162h
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162h(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645ee000: FCVTZU  <Zd>.H, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_fp162hz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645ee000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvtzu_z_p_z_fp162hz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162hz
            IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162hz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/655da000: FCVTZU  <Zd>.S, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_fp162w, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_fp162w Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162w
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162w(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645fa000: FCVTZU  <Zd>.S, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_fp162wz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_fp162wz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162wz
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162wz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/655fa000: FCVTZU  <Zd>.D, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_fp162x, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_fp162x Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162x
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162x(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645fe000: FCVTZU  <Zd>.D, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_fp162xz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645fe000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fcvtzu_z_p_z_fp162xz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162xz
            IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_fp162xz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/659da000: FCVTZU  <Zd>.S, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_s2w, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_s2w Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_s2w
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_s2w(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/649fa000: FCVTZU  <Zd>.S, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_s2wz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_s2wz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_s2wz
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_s2wz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65dda000: FCVTZU  <Zd>.D, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_s2x, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_s2x Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_s2x
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_s2x(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dfa000: FCVTZU  <Zd>.D, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fcvtzu_z_p_z_s2xz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fcvtzu_z_p_z_s2xz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_s2xz
        IEM_INSTR_IMPL_A64__fcvtzu_z_p_z_s2xz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/650d8000: FDIV  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdiv_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fdiv_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fdiv_z_p_zz
        IEM_INSTR_IMPL_A64__fdiv_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/650c8000: FDIVR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdivr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fdivr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fdivr_z_p_zz
        IEM_INSTR_IMPL_A64__fdivr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64608400: FDOT  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp_fdot, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdot_z32_zz8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Dot4 /*FEAT_FP8DOT4*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Dot4 /*FEAT_SSVE_FP8DOT4*/)
    {
        LogFlow(("%018x/%010x: fdot_z32_zz8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_z32_zz8z8
        IEM_INSTR_IMPL_A64__fdot_z32_zz8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64604400: FDOT  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_fp_fdot_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdot_z32_zz8z8i, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Dot4 /*FEAT_FP8DOT4*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Dot4 /*FEAT_SSVE_FP8DOT4*/)
    {
        LogFlow(("%018x/%010x: fdot_z32_zz8z8i Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__fdot_z32_zz8z8i
        IEM_INSTR_IMPL_A64__fdot_z32_zz8z8i(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64208400: FDOT  <Zda>.H, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp_fdot, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdot_z_zz8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Dot2 /*FEAT_FP8DOT2*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Dot2 /*FEAT_SSVE_FP8DOT2*/)
    {
        LogFlow(("%018x/%010x: fdot_z_zz8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_z_zz8z8
        IEM_INSTR_IMPL_A64__fdot_z_zz8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64204400: FDOT  <Zda>.H, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_fp_fdot_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdot_z_zz8z8i, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Dot2 /*FEAT_FP8DOT2*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Dot2 /*FEAT_SSVE_FP8DOT2*/)
    {
        LogFlow(("%018x/%010x: fdot_z_zz8z8i Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__fdot_z_zz8z8i
        IEM_INSTR_IMPL_A64__fdot_z_zz8z8i(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64208000: FDOT  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fdot, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdot_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: fdot_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_z_zzz
        IEM_INSTR_IMPL_A64__fdot_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64204000: FDOT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fdot_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdot_z_zzzi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: fdot_z_zzzi Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__fdot_z_zzzi
        IEM_INSTR_IMPL_A64__fdot_z_zzzi(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1500038: FDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za32_z8z8i_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fdot_za32_z8z8i_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za32_z8z8i_2xi
        IEM_INSTR_IMPL_A64__fdot_za32_z8z8i_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1508008: FDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za32_z8z8i_4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1508008))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
        {
            LogFlow(("%018x/%010x: fdot_za32_z8z8i_4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za32_z8z8i_4xi
            IEM_INSTR_IMPL_A64__fdot_za32_z8z8i_4xi(off3, Zn, i2, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1201018: FDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi2_z_za_fpdot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za32_z8z8v_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fdot_za32_z8z8v_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za32_z8z8v_2x1
        IEM_INSTR_IMPL_A64__fdot_za32_z8z8v_2x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1301018: FDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi4_z_za_fpdot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za32_z8z8v_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fdot_za32_z8z8v_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za32_z8z8v_4x1
        IEM_INSTR_IMPL_A64__fdot_za32_z8z8v_4x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1a01030: FDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_fpdot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za32_z8z8w_2x2, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fdot_za32_z8z8w_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za32_z8z8w_2x2
        IEM_INSTR_IMPL_A64__fdot_za32_z8z8w_2x2(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1a11030: FDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, { <Zm1>.B-<Zm4>.B }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_fpdot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za32_z8z8w_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1a11030))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
        {
            LogFlow(("%018x/%010x: fdot_za32_z8z8w_4x4 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za32_z8z8w_4x4
            IEM_INSTR_IMPL_A64__fdot_za32_z8z8w_4x4(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09030/c1d00020: FDOT  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fp8_fdot_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_z8z8i_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fdot_za_z8z8i_2xi off3=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_z8z8i_2xi
        IEM_INSTR_IMPL_A64__fdot_za_z8z8i_2xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09070/c1109040: FDOT  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_fp8_fdot_idx_h, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_z8z8i_4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fdot_za_z8z8i_4xi off3=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_z8z8i_4xi
        IEM_INSTR_IMPL_A64__fdot_za_z8z8i_4xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1201008: FDOT  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi2_z_za_fpdot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_z8z8v_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fdot_za_z8z8v_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_z8z8v_2x1
        IEM_INSTR_IMPL_A64__fdot_za_z8z8v_2x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1301008: FDOT  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi4_z_za_fpdot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_z8z8v_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fdot_za_z8z8v_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_z8z8v_4x1
        IEM_INSTR_IMPL_A64__fdot_za_z8z8v_4x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1a01020: FDOT  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_fpdot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_z8z8w_2x2, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fdot_za_z8z8w_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_z8z8w_2x2
        IEM_INSTR_IMPL_A64__fdot_za_z8z8w_2x2(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1a11020: FDOT  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, { <Zm1>.B-<Zm4>.B }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_fpdot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_z8z8w_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1a11020))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
        {
            LogFlow(("%018x/%010x: fdot_za_z8z8w_4x4 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_z8z8w_4x4
            IEM_INSTR_IMPL_A64__fdot_za_z8z8w_4x4(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1501008: FDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fdot_za_zzi_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_zzi_2xi
        IEM_INSTR_IMPL_A64__fdot_za_zzi_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1509008: FDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_zzi_4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fdot_za_zzi_4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_zzi_4xi
        IEM_INSTR_IMPL_A64__fdot_za_zzi_4xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1201000: FDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_za_fpdot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fdot_za_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_zzv_2x1
        IEM_INSTR_IMPL_A64__fdot_za_zzv_2x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1301000: FDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_za_fpdot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fdot_za_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_zzv_4x1
        IEM_INSTR_IMPL_A64__fdot_za_zzv_4x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1a01000: FDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_fpdot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fdot_za_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_zzw_2x2
        IEM_INSTR_IMPL_A64__fdot_za_zzw_2x2(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1a11000: FDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_fpdot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fdot_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1a11000))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fdot_za_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fdot_za_zzw_4x4
            IEM_INSTR_IMPL_A64__fdot_za_zzw_4x4(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/2539c000: FDUP  <Zd>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_dup_fpimm, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fdup_z_i, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fdup_z_i Zd=%#x imm8=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, imm8, size));
#ifdef IEM_INSTR_IMPL_A64__fdup_z_i
        IEM_INSTR_IMPL_A64__fdup_z_i(Zd, imm8, size);
#else
        RT_NOREF(Zd, imm8, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/0420b800: FEXPA  <Zd>.<T>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_bin_cons_misc_0_c, sve_int_unpred_misc, sve */
FNIEMOP_DEF_1(iemDecodeA64_fexpa_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x0420b800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: fexpa_z_z Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__fexpa_z_z
            IEM_INSTR_IMPL_A64__fexpa_z_z(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc200/25218000: FIRSTP  <Xd>, <Pg>, <Pn>.<T>
   Instruction Set: A64  Groups: sve_int_pcount_pred, sve_pred_count_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_firstp_r_p_p, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: firstp_r_p_p Rd=%#x Pn=%#x Pg=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Pn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__firstp_r_p_p
        IEM_INSTR_IMPL_A64__firstp_r_p_p(Rd, Pn, Pg, size);
#else
        RT_NOREF(Rd, Pn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff9e000/6518a000: FLOGB  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_d, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_flogb_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 17) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: flogb_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__flogb_z_p_z_m
        IEM_INSTR_IMPL_A64__flogb_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff8000/641e8000: FLOGB  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_d, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_flogb_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff8000)) == UINT32_C(0x641e8000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: flogb_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__flogb_z_p_z_z
            IEM_INSTR_IMPL_A64__flogb_z_p_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/65208000: FMAD  <Zdn>.<T>, <Pg>/M, <Zm>.<T>, <Za>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_b, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmad_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Za         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmad_z_p_zzz Zdn=%#x Zm=%#x Pg=%u Za=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, Za, size));
#ifdef IEM_INSTR_IMPL_A64__fmad_z_p_zzz
        IEM_INSTR_IMPL_A64__fmad_z_p_zzz(Zdn, Zm, Pg, Za, size);
#else
        RT_NOREF(Zdn, Zm, Pg, Za, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a100: FMAX  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmax_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a100))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmax_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmax_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__fmax_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a900: FMAX  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmax_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a900))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmax_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmax_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__fmax_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b100: FMAX  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmax_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b100))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmax_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmax_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__fmax_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b900: FMAX  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmax_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b900))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmax_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmax_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__fmax_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe3c0/651e8000: FMAX  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_2op_i_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmax_z_p_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651e8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const i1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fmax_z_p_zs Zdn=%#x i1=%u Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, i1, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmax_z_p_zs
            IEM_INSTR_IMPL_A64__fmax_z_p_zs(Zdn, i1, Pg, size);
#else
            RT_NOREF(Zdn, i1, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65068000: FMAX  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmax_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fmax_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmax_z_p_zz
        IEM_INSTR_IMPL_A64__fmax_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a120: FMAXNM  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnm_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a120))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmaxnm_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnm_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__fmaxnm_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a920: FMAXNM  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnm_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a920))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmaxnm_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnm_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__fmaxnm_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b120: FMAXNM  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnm_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b120))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmaxnm_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnm_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__fmaxnm_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b920: FMAXNM  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnm_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b920))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmaxnm_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnm_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__fmaxnm_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe3c0/651c8000: FMAXNM  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_2op_i_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnm_z_p_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651c8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const i1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fmaxnm_z_p_zs Zdn=%#x i1=%u Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, i1, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnm_z_p_zs
            IEM_INSTR_IMPL_A64__fmaxnm_z_p_zs(Zdn, i1, Pg, size);
#else
            RT_NOREF(Zdn, i1, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65048000: FMAXNM  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnm_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fmaxnm_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnm_z_p_zz
        IEM_INSTR_IMPL_A64__fmaxnm_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/64148000: FMAXNMP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_pairwise_lvl2, sve_fp_pairwise, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnmp_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmaxnmp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnmp_z_p_zz
        IEM_INSTR_IMPL_A64__fmaxnmp_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6414a000: FMAXNMQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_fp_fast_redq, sve_fp_fastreduceq, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnmqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: fmaxnmqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnmqv_z_p_z
        IEM_INSTR_IMPL_A64__fmaxnmqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65042000: FMAXNMV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_fast_red, sve_fp_fastreduce, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmaxnmv_v_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65042000))
    {
        uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fmaxnmv_v_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxnmv_v_p_z
            IEM_INSTR_IMPL_A64__fmaxnmv_v_p_z(Vd, Zn, Pg, size);
#else
            RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/64168000: FMAXP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_pairwise_lvl2, sve_fp_pairwise, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmaxp_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64168000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fmaxp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxp_z_p_zz
            IEM_INSTR_IMPL_A64__fmaxp_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6416a000: FMAXQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_fp_fast_redq, sve_fp_fastreduceq, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmaxqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: fmaxqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxqv_z_p_z
        IEM_INSTR_IMPL_A64__fmaxqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65062000: FMAXV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_fast_red, sve_fp_fastreduce, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmaxv_v_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65062000))
    {
        uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fmaxv_v_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmaxv_v_p_z
            IEM_INSTR_IMPL_A64__fmaxv_v_p_z(Vd, Zn, Pg, size);
#else
            RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a101: FMIN  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmin_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a101))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmin_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmin_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__fmin_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a901: FMIN  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmin_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a901))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmin_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmin_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__fmin_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b101: FMIN  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmin_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b101))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmin_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmin_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__fmin_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b901: FMIN  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmin_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b901))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmin_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmin_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__fmin_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe3c0/651f8000: FMIN  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_2op_i_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmin_z_p_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651f8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const i1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fmin_z_p_zs Zdn=%#x i1=%u Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, i1, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmin_z_p_zs
            IEM_INSTR_IMPL_A64__fmin_z_p_zs(Zdn, i1, Pg, size);
#else
            RT_NOREF(Zdn, i1, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65078000: FMIN  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmin_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fmin_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmin_z_p_zz
        IEM_INSTR_IMPL_A64__fmin_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a121: FMINNM  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fminnm_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a121))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fminnm_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fminnm_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__fminnm_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a921: FMINNM  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fminnm_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a921))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fminnm_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fminnm_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__fminnm_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b121: FMINNM  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fminmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fminnm_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b121))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fminnm_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fminnm_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__fminnm_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b921: FMINNM  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fminmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fminnm_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b921))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if ((size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fminnm_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fminnm_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__fminnm_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe3c0/651d8000: FMINNM  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_2op_i_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fminnm_z_p_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651d8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const i1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fminnm_z_p_zs Zdn=%#x i1=%u Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, i1, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fminnm_z_p_zs
            IEM_INSTR_IMPL_A64__fminnm_z_p_zs(Zdn, i1, Pg, size);
#else
            RT_NOREF(Zdn, i1, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65058000: FMINNM  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fminnm_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fminnm_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fminnm_z_p_zz
        IEM_INSTR_IMPL_A64__fminnm_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/64158000: FMINNMP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_pairwise_lvl2, sve_fp_pairwise, sve */
FNIEMOP_DEF_1(iemDecodeA64_fminnmp_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fminnmp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fminnmp_z_p_zz
        IEM_INSTR_IMPL_A64__fminnmp_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6415a000: FMINNMQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_fp_fast_redq, sve_fp_fastreduceq, sve */
FNIEMOP_DEF_1(iemDecodeA64_fminnmqv_z_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6415a000))
    {
        uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: fminnmqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fminnmqv_z_p_z
            IEM_INSTR_IMPL_A64__fminnmqv_z_p_z(Vd, Zn, Pg, size);
#else
            RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65052000: FMINNMV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_fast_red, sve_fp_fastreduce, sve */
FNIEMOP_DEF_1(iemDecodeA64_fminnmv_v_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65052000))
    {
        uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fminnmv_v_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fminnmv_v_p_z
            IEM_INSTR_IMPL_A64__fminnmv_v_p_z(Vd, Zn, Pg, size);
#else
            RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/64178000: FMINP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_pairwise_lvl2, sve_fp_pairwise, sve */
FNIEMOP_DEF_1(iemDecodeA64_fminp_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64178000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fminp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fminp_z_p_zz
            IEM_INSTR_IMPL_A64__fminp_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6417a000: FMINQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_fp_fast_redq, sve_fp_fastreduceq, sve */
FNIEMOP_DEF_1(iemDecodeA64_fminqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: fminqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fminqv_z_p_z
        IEM_INSTR_IMPL_A64__fminqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65072000: FMINV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_fast_red, sve_fp_fastreduce, sve */
FNIEMOP_DEF_1(iemDecodeA64_fminv_v_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65072000))
    {
        uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fminv_v_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fminv_v_p_z
            IEM_INSTR_IMPL_A64__fminv_v_p_z(Vd, Zn, Pg, size);
#else
            RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/65200000: FMLA  <Zda>.<T>, <Pg>/M, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_a, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmla_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fmla_z_p_zzz Zda=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmla_z_p_zzz
        IEM_INSTR_IMPL_A64__fmla_z_p_zzz(Zda, Zn, Pg, Zm, size);
#else
        RT_NOREF(Zda, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64e00000: FMLA  <Zda>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_by_indexed_elem_lvl2, sve_fp_fma_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmla_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmla_z_zzzi_d Zda=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__fmla_z_zzzi_d
        IEM_INSTR_IMPL_A64__fmla_z_zzzi_d(Zda, Zn, Zm, i1);
#else
        RT_NOREF(Zda, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/64200000: FMLA  <Zda>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_by_indexed_elem_lvl2, sve_fp_fma_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmla_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmla_z_zzzi_h Zda=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__fmla_z_zzzi_h
        IEM_INSTR_IMPL_A64__fmla_z_zzzi_h(Zda, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zda, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a00000: FMLA  <Zda>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_by_indexed_elem_lvl2, sve_fp_fma_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmla_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmla_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__fmla_z_zzzi_s
        IEM_INSTR_IMPL_A64__fmla_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09838/c1d00000: FMLA  ZA.D[<Wv>, <offs>{, VGx2}], { <Zn1>.D-<Zn2>.D }, <Zm>.D[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_d, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzi_d2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzi_d2xi off3=%u Zn=%#x i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzi_d2xi
        IEM_INSTR_IMPL_A64__fmla_za_zzi_d2xi(off3, Zn, i1, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1d08000: FMLA  ZA.D[<Wv>, <offs>{, VGx4}], { <Zn1>.D-<Zn4>.D }, <Zm>.D[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzi_d4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzi_d4xi off3=%u Zn=%u i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzi_d4xi
        IEM_INSTR_IMPL_A64__fmla_za_zzi_d4xi(off3, Zn, i1, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09030/c1101000: FMLA  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_h, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzi_h2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzi_h2xi off3=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzi_h2xi
        IEM_INSTR_IMPL_A64__fmla_za_zzi_h2xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09070/c1109000: FMLA  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_h, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzi_h4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzi_h4xi off3=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzi_h4xi
        IEM_INSTR_IMPL_A64__fmla_za_zzi_h4xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1500000: FMLA  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.S-<Zn2>.S }, <Zm>.S[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzi_s2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__fmla_za_zzi_s2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1508000: FMLA  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.S-<Zn4>.S }, <Zm>.S[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzi_s4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1508000))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmla_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzi_s4xi
            IEM_INSTR_IMPL_A64__fmla_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1201800: FMLA  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<T>-<Zn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_float_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzv_2x1
        IEM_INSTR_IMPL_A64__fmla_za_zzv_2x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1201c00: FMLA  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_f16_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzv_2x1_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzv_2x1_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzv_2x1_16
        IEM_INSTR_IMPL_A64__fmla_za_zzv_2x1_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1301800: FMLA  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<T>-<Zn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_float_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzv_4x1
        IEM_INSTR_IMPL_A64__fmla_za_zzv_4x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1301c00: FMLA  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_f16_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzv_4x1_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzv_4x1_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzv_4x1_16
        IEM_INSTR_IMPL_A64__fmla_za_zzv_4x1_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c38/c1a01800: FMLA  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<T>-<Zn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_float_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c38)) == UINT32_C(0xc1a01800))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmla_za_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzw_2x2
            IEM_INSTR_IMPL_A64__fmla_za_zzw_2x2(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1a01008: FMLA  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_f16_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzw_2x2_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmla_za_zzw_2x2_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzw_2x2_16
        IEM_INSTR_IMPL_A64__fmla_za_zzw_2x2_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c78/c1a11800: FMLA  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<T>-<Zn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_float_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c78)) == UINT32_C(0xc1a11800))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmla_za_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzw_4x4
            IEM_INSTR_IMPL_A64__fmla_za_zzw_4x4(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1a11008: FMLA  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_f16_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmla_za_zzw_4x4_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1a11008))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
        {
            LogFlow(("%018x/%010x: fmla_za_zzw_4x4_16 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmla_za_zzw_4x4_16
            IEM_INSTR_IMPL_A64__fmla_za_zzw_4x4_16(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01010/c1c00000: FMLAL  ZA.H[<Wv>, <offs1>:<offs2>], <Zn>.B, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_fp8_fma_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_z8z8i_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i4C        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4B        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i4A        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_z8z8i_1 off3=%u i4C=%u Zn=%#x i4B=%u Rv=%u i4A=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i4C, Zn, i4B, Rv, i4A, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_z8z8i_1
        IEM_INSTR_IMPL_A64__fmlal_za_z8z8i_1(off3, i4C, Zn, i4B, Rv, i4A, Zm);
#else
        RT_NOREF(off3, i4C, Zn, i4B, Rv, i4A, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09030/c1901030: FMLAL  ZA.H[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fp8_fma_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_z8z8i_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i4l        = (uOpcode >>  2) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_z8z8i_2xi off2=%u i4l=%u Zn=%#x i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_z8z8i_2xi
        IEM_INSTR_IMPL_A64__fmlal_za_z8z8i_2xi(off2, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(off2, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09070/c1909020: FMLAL  ZA.H[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_fp8_fma_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_z8z8i_4xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i4l        = (uOpcode >>  2) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_z8z8i_4xi off2=%u i4l=%u Zn=%u i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_z8z8i_4xi
        IEM_INSTR_IMPL_A64__fmlal_za_z8z8i_4xi(off2, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(off2, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1300c00: FMLAL  ZA.H[<Wv>, <offs1>:<offs2>], <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_fp8_fma_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_z8z8v_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_z8z8v_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_z8z8v_1
        IEM_INSTR_IMPL_A64__fmlal_za_z8z8v_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1200804: FMLAL  ZA.H[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_z8z8v_2x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_z8z8v_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_z8z8v_2x1
        IEM_INSTR_IMPL_A64__fmlal_za_z8z8v_2x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1300804: FMLAL  ZA.H[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_z8z8v_4x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_z8z8v_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_z8z8v_4x1
        IEM_INSTR_IMPL_A64__fmlal_za_z8z8v_4x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1a00820: FMLAL  ZA.H[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fp8_fma_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_z8z8w_2x2, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_z8z8w_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_z8z8w_2x2
        IEM_INSTR_IMPL_A64__fmlal_za_z8z8w_2x2(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1a10820: FMLAL  ZA.H[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.B-<Zn4>.B }, { <Zm1>.B-<Zm4>.B }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fp8_fma_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_z8z8w_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1a10820))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
        {
            LogFlow(("%018x/%010x: fmlal_za_z8z8w_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_z8z8w_4x4
            IEM_INSTR_IMPL_A64__fmlal_za_z8z8w_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01018/c1801000: FMLAL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_fma_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_zzi_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_zzi_1 off3=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_zzi_1
        IEM_INSTR_IMPL_A64__fmlal_za_zzi_1(off3, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off3, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1901000: FMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fma_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_zzi_2xi off2=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_zzi_2xi
        IEM_INSTR_IMPL_A64__fmlal_za_zzi_2xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1909000: FMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_fma_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_zzi_4xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_zzi_4xi off2=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_zzi_4xi
        IEM_INSTR_IMPL_A64__fmlal_za_zzi_4xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1200c00: FMLAL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_zzv_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_zzv_1
        IEM_INSTR_IMPL_A64__fmlal_za_zzv_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1200800: FMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_zzv_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_zzv_2x1
        IEM_INSTR_IMPL_A64__fmlal_za_zzv_2x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1300800: FMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_zzv_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_zzv_4x1
        IEM_INSTR_IMPL_A64__fmlal_za_zzv_4x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1a00800: FMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlal_za_zzw_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_zzw_2x2
        IEM_INSTR_IMPL_A64__fmlal_za_zzw_2x2(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1a10800: FMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlal_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1a10800))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmlal_za_zzw_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlal_za_zzw_4x4
            IEM_INSTR_IMPL_A64__fmlal_za_zzw_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a08800: FMLALB  <Zda>.H, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp8_fma_long, sve_fp8_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalb_z_z8z8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlalb_z_z8z8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlalb_z_z8z8z8
        IEM_INSTR_IMPL_A64__fmlalb_z_z8z8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/64205000: FMLALB  <Zda>.H, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_fp8_fma_long_by_indexed_elem, sve_fp8_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalb_z_z8z8z8i, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlalb_z_z8z8z8i Zda=%#x Zn=%#x i4l=%u Zm=%u i4h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i4l, Zm, i4h));
#ifdef IEM_INSTR_IMPL_A64__fmlalb_z_z8z8z8i
        IEM_INSTR_IMPL_A64__fmlalb_z_z8z8z8i(Zda, Zn, i4l, Zm, i4h);
#else
        RT_NOREF(Zda, Zn, i4l, Zm, i4h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a08000: FMLALB  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fma_long, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmlalb_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlalb_z_zzz
        IEM_INSTR_IMPL_A64__fmlalb_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64a04000: FMLALB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_long_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalb_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmlalb_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__fmlalb_z_zzzi_s
        IEM_INSTR_IMPL_A64__fmlalb_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0001c/c1400000: FMLALL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_fp8_fma_long_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlall_za32_z8z8i_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1400000))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const i4l        = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const i4h        = (uOpcode >> 15) & 0x00000001;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
        {
            LogFlow(("%018x/%010x: fmlall_za32_z8z8i_1 off2=%u Zn=%#x i4l=%u Rv=%u i4h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i4l, Rv, i4h, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlall_za32_z8z8i_1
            IEM_INSTR_IMPL_A64__fmlall_za32_z8z8i_1(off2, Zn, i4l, Rv, i4h, Zm);
#else
            RT_NOREF(off2, Zn, i4l, Rv, i4h, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1900020: FMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fp8_fma_long_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlall_za32_z8z8i_2xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09038)) == UINT32_C(0xc1900020))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
        {
            LogFlow(("%018x/%010x: fmlall_za32_z8z8i_2xi o1=%u i4l=%u Zn=%#x i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlall_za32_z8z8i_2xi
            IEM_INSTR_IMPL_A64__fmlall_za32_z8z8i_2xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
            RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1108040: FMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_fp8_fma_long_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlall_za32_z8z8i_4xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fmlall_za32_z8z8i_4xi o1=%u i4l=%u Zn=%u i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlall_za32_z8z8i_4xi
        IEM_INSTR_IMPL_A64__fmlall_za32_z8z8i_4xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1300400: FMLALL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_fp8_fma_long_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlall_za32_z8z8v_1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fmlall_za32_z8z8v_1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlall_za32_z8z8v_1
        IEM_INSTR_IMPL_A64__fmlall_za32_z8z8v_1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1e/c1200002: FMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fp8_fma_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlall_za32_z8z8v_2x1, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fmlall_za32_z8z8v_2x1 o1=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlall_za32_z8z8v_2x1
        IEM_INSTR_IMPL_A64__fmlall_za32_z8z8v_2x1(o1, Zn, Rv, Zm);
#else
        RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1e/c1300002: FMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fp8_fma_long_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlall_za32_z8z8v_4x1, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fmlall_za32_z8z8v_4x1 o1=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlall_za32_z8z8v_4x1
        IEM_INSTR_IMPL_A64__fmlall_za32_z8z8v_4x1(o1, Zn, Rv, Zm);
#else
        RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3e/c1a00020: FMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fp8_fma_long_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlall_za32_z8z8w_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c3e)) == UINT32_C(0xc1a00020))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
        {
            LogFlow(("%018x/%010x: fmlall_za32_z8z8w_2x2 o1=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlall_za32_z8z8w_2x2
            IEM_INSTR_IMPL_A64__fmlall_za32_z8z8w_2x2(o1, Zn, Rv, Zm);
#else
            RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7e/c1a10020: FMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, { <Zm1>.B-<Zm4>.B }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fp8_fma_long_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlall_za32_z8z8w_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7e)) == UINT32_C(0xc1a10020))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
        {
            LogFlow(("%018x/%010x: fmlall_za32_z8z8w_4x4 o1=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlall_za32_z8z8w_4x4
            IEM_INSTR_IMPL_A64__fmlall_za32_z8z8w_4x4(o1, Zn, Rv, Zm);
#else
            RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64208800: FMLALLBB  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp8_fma_long_long, sve_fp8_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlallbb_z32_z8z8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlallbb_z32_z8z8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlallbb_z32_z8z8z8
        IEM_INSTR_IMPL_A64__fmlallbb_z32_z8z8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/6420c000: FMLALLBB  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_fp8_fma_long_long_by_indexed_elem, sve_fp8_fma_ww_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlallbb_z32_z8z8z8i, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlallbb_z32_z8z8z8i Zda=%#x Zn=%#x i4l=%u Zm=%u i4h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i4l, Zm, i4h));
#ifdef IEM_INSTR_IMPL_A64__fmlallbb_z32_z8z8z8i
        IEM_INSTR_IMPL_A64__fmlallbb_z32_z8z8z8i(Zda, Zn, i4l, Zm, i4h);
#else
        RT_NOREF(Zda, Zn, i4l, Zm, i4h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64209800: FMLALLBT  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp8_fma_long_long, sve_fp8_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlallbt_z32_z8z8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlallbt_z32_z8z8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlallbt_z32_z8z8z8
        IEM_INSTR_IMPL_A64__fmlallbt_z32_z8z8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/6460c000: FMLALLBT  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_fp8_fma_long_long_by_indexed_elem, sve_fp8_fma_ww_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlallbt_z32_z8z8z8i, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlallbt_z32_z8z8z8i Zda=%#x Zn=%#x i4l=%u Zm=%u i4h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i4l, Zm, i4h));
#ifdef IEM_INSTR_IMPL_A64__fmlallbt_z32_z8z8z8i
        IEM_INSTR_IMPL_A64__fmlallbt_z32_z8z8z8i(Zda, Zn, i4l, Zm, i4h);
#else
        RT_NOREF(Zda, Zn, i4l, Zm, i4h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6420a800: FMLALLTB  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp8_fma_long_long, sve_fp8_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalltb_z32_z8z8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlalltb_z32_z8z8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlalltb_z32_z8z8z8
        IEM_INSTR_IMPL_A64__fmlalltb_z32_z8z8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/64a0c000: FMLALLTB  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_fp8_fma_long_long_by_indexed_elem, sve_fp8_fma_ww_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalltb_z32_z8z8z8i, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlalltb_z32_z8z8z8i Zda=%#x Zn=%#x i4l=%u Zm=%u i4h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i4l, Zm, i4h));
#ifdef IEM_INSTR_IMPL_A64__fmlalltb_z32_z8z8z8i
        IEM_INSTR_IMPL_A64__fmlalltb_z32_z8z8z8i(Zda, Zn, i4l, Zm, i4h);
#else
        RT_NOREF(Zda, Zn, i4l, Zm, i4h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6420b800: FMLALLTT  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp8_fma_long_long, sve_fp8_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalltt_z32_z8z8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlalltt_z32_z8z8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlalltt_z32_z8z8z8
        IEM_INSTR_IMPL_A64__fmlalltt_z32_z8z8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/64e0c000: FMLALLTT  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_fp8_fma_long_long_by_indexed_elem, sve_fp8_fma_ww_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalltt_z32_z8z8z8i, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlalltt_z32_z8z8z8i Zda=%#x Zn=%#x i4l=%u Zm=%u i4h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i4l, Zm, i4h));
#ifdef IEM_INSTR_IMPL_A64__fmlalltt_z32_z8z8z8i
        IEM_INSTR_IMPL_A64__fmlalltt_z32_z8z8z8i(Zda, Zn, i4l, Zm, i4h);
#else
        RT_NOREF(Zda, Zn, i4l, Zm, i4h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a09800: FMLALT  <Zda>.H, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp8_fma_long, sve_fp8_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalt_z_z8z8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlalt_z_z8z8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlalt_z_z8z8z8
        IEM_INSTR_IMPL_A64__fmlalt_z_z8z8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/64a05000: FMLALT  <Zda>.H, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_fp8_fma_long_by_indexed_elem, sve_fp8_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalt_z_z8z8z8i, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8Fma /*FEAT_FP8FMA*/) || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSsveFp8Fma /*FEAT_SSVE_FP8FMA*/)
    {
        LogFlow(("%018x/%010x: fmlalt_z_z8z8z8i Zda=%#x Zn=%#x i4l=%u Zm=%u i4h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i4l, Zm, i4h));
#ifdef IEM_INSTR_IMPL_A64__fmlalt_z_z8z8z8i
        IEM_INSTR_IMPL_A64__fmlalt_z_z8z8z8i(Zda, Zn, i4l, Zm, i4h);
#else
        RT_NOREF(Zda, Zn, i4l, Zm, i4h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a08400: FMLALT  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fma_long, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmlalt_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlalt_z_zzz
        IEM_INSTR_IMPL_A64__fmlalt_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64a04400: FMLALT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_long_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlalt_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmlalt_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__fmlalt_z_zzzi_s
        IEM_INSTR_IMPL_A64__fmlalt_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/65202000: FMLS  <Zda>.<T>, <Pg>/M, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_a, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmls_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fmls_z_p_zzz Zda=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmls_z_p_zzz
        IEM_INSTR_IMPL_A64__fmls_z_p_zzz(Zda, Zn, Pg, Zm, size);
#else
        RT_NOREF(Zda, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64e00400: FMLS  <Zda>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_by_indexed_elem_lvl2, sve_fp_fma_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmls_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmls_z_zzzi_d Zda=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__fmls_z_zzzi_d
        IEM_INSTR_IMPL_A64__fmls_z_zzzi_d(Zda, Zn, Zm, i1);
#else
        RT_NOREF(Zda, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/64200400: FMLS  <Zda>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_by_indexed_elem_lvl2, sve_fp_fma_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmls_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmls_z_zzzi_h Zda=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__fmls_z_zzzi_h
        IEM_INSTR_IMPL_A64__fmls_z_zzzi_h(Zda, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zda, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a00400: FMLS  <Zda>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_by_indexed_elem_lvl2, sve_fp_fma_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmls_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmls_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__fmls_z_zzzi_s
        IEM_INSTR_IMPL_A64__fmls_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09838/c1d00010: FMLS  ZA.D[<Wv>, <offs>{, VGx2}], { <Zn1>.D-<Zn2>.D }, <Zm>.D[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_d, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzi_d2xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09838)) == UINT32_C(0xc1d00010))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
        {
            LogFlow(("%018x/%010x: fmls_za_zzi_d2xi off3=%u Zn=%#x i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzi_d2xi
            IEM_INSTR_IMPL_A64__fmls_za_zzi_d2xi(off3, Zn, i1, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1d08010: FMLS  ZA.D[<Wv>, <offs>{, VGx4}], { <Zn1>.D-<Zn4>.D }, <Zm>.D[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzi_d4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzi_d4xi off3=%u Zn=%u i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzi_d4xi
        IEM_INSTR_IMPL_A64__fmls_za_zzi_d4xi(off3, Zn, i1, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09030/c1101010: FMLS  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_h, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzi_h2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzi_h2xi off3=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzi_h2xi
        IEM_INSTR_IMPL_A64__fmls_za_zzi_h2xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09070/c1109010: FMLS  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_h, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzi_h4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzi_h4xi off3=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzi_h4xi
        IEM_INSTR_IMPL_A64__fmls_za_zzi_h4xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1500010: FMLS  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.S-<Zn2>.S }, <Zm>.S[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzi_s2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__fmls_za_zzi_s2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1508010: FMLS  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.S-<Zn4>.S }, <Zm>.S[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzi_s4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1508010))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmls_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzi_s4xi
            IEM_INSTR_IMPL_A64__fmls_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1201808: FMLS  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<T>-<Zn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_float_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzv_2x1
        IEM_INSTR_IMPL_A64__fmls_za_zzv_2x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1201c08: FMLS  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_f16_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzv_2x1_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzv_2x1_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzv_2x1_16
        IEM_INSTR_IMPL_A64__fmls_za_zzv_2x1_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1301808: FMLS  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<T>-<Zn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_float_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzv_4x1
        IEM_INSTR_IMPL_A64__fmls_za_zzv_4x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1301c08: FMLS  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_f16_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzv_4x1_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzv_4x1_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzv_4x1_16
        IEM_INSTR_IMPL_A64__fmls_za_zzv_4x1_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c38/c1a01808: FMLS  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<T>-<Zn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_float_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c38)) == UINT32_C(0xc1a01808))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmls_za_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzw_2x2
            IEM_INSTR_IMPL_A64__fmls_za_zzw_2x2(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1a01018: FMLS  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_f16_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzw_2x2_16, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmls_za_zzw_2x2_16 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzw_2x2_16
        IEM_INSTR_IMPL_A64__fmls_za_zzw_2x2_16(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c78/c1a11808: FMLS  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<T>-<Zn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_float_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c78)) == UINT32_C(0xc1a11808))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmls_za_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzw_4x4
            IEM_INSTR_IMPL_A64__fmls_za_zzw_4x4(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1a11018: FMLS  ZA.H[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_f16_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmls_za_zzw_4x4_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1a11018))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
        {
            LogFlow(("%018x/%010x: fmls_za_zzw_4x4_16 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmls_za_zzw_4x4_16
            IEM_INSTR_IMPL_A64__fmls_za_zzw_4x4_16(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01018/c1801008: FMLSL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_fma_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlsl_za_zzi_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlsl_za_zzi_1 off3=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlsl_za_zzi_1
        IEM_INSTR_IMPL_A64__fmlsl_za_zzi_1(off3, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off3, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1901008: FMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fma_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlsl_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlsl_za_zzi_2xi off2=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlsl_za_zzi_2xi
        IEM_INSTR_IMPL_A64__fmlsl_za_zzi_2xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1909008: FMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_fma_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlsl_za_zzi_4xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlsl_za_zzi_4xi off2=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlsl_za_zzi_4xi
        IEM_INSTR_IMPL_A64__fmlsl_za_zzi_4xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1200c08: FMLSL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlsl_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlsl_za_zzv_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlsl_za_zzv_1
        IEM_INSTR_IMPL_A64__fmlsl_za_zzv_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1200808: FMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlsl_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlsl_za_zzv_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlsl_za_zzv_2x1
        IEM_INSTR_IMPL_A64__fmlsl_za_zzv_2x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1300808: FMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlsl_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlsl_za_zzv_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlsl_za_zzv_4x1
        IEM_INSTR_IMPL_A64__fmlsl_za_zzv_4x1(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1a00808: FMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_fma_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlsl_za_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fmlsl_za_zzw_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlsl_za_zzw_2x2
        IEM_INSTR_IMPL_A64__fmlsl_za_zzw_2x2(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1a10808: FMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_fma_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmlsl_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1a10808))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fmlsl_za_zzw_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlsl_za_zzw_4x4
            IEM_INSTR_IMPL_A64__fmlsl_za_zzw_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a0a000: FMLSLB  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fma_long, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlslb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmlslb_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlslb_z_zzz
        IEM_INSTR_IMPL_A64__fmlslb_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64a06000: FMLSLB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_long_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlslb_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmlslb_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__fmlslb_z_zzzi_s
        IEM_INSTR_IMPL_A64__fmlslb_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a0a400: FMLSLT  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fma_long, sve_fp_fma_w, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlslt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmlslt_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmlslt_z_zzz
        IEM_INSTR_IMPL_A64__fmlslt_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/64a06400: FMLSLT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fma_long_by_indexed_elem, sve_fp_fma_w_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmlslt_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmlslt_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__fmlslt_z_zzzi_s
        IEM_INSTR_IMPL_A64__fmlslt_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6460e000: FMMLA  <Zda>.H, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp8_fmmla_lvl2, sve_fp8_fmmla, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmmla_z16_zz8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF8F16mm /*FEAT_F8F16MM*/)
    {
        LogFlow(("%018x/%010x: fmmla_z16_zz8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmmla_z16_zz8z8
        IEM_INSTR_IMPL_A64__fmmla_z16_zz8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6420e000: FMMLA  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_fp8_fmmla_lvl2, sve_fp8_fmmla, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmmla_z32_zz8z8, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF8F32mm /*FEAT_F8F32MM*/)
    {
        LogFlow(("%018x/%010x: fmmla_z32_zz8z8 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmmla_z32_zz8z8
        IEM_INSTR_IMPL_A64__fmmla_z32_zz8z8(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/6420e400: FMMLA  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_fp_fmmla_lvl2, sve_fp_fmmla, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmmla_z32_zzz_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveF16F32mm /*FEAT_SVE_F16F32MM*/)
    {
        LogFlow(("%018x/%010x: fmmla_z32_zzz_h Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmmla_z32_zzz_h
        IEM_INSTR_IMPL_A64__fmmla_z32_zzz_h(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64e0e400: FMMLA  <Zda>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_fp_fmmla_lvl2, sve_fp_fmmla, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmmla_z_zzz_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: fmmla_z_zzz_d Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmmla_z_zzz_d
        IEM_INSTR_IMPL_A64__fmmla_z_zzz_d(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a0e400: FMMLA  <Zda>.S, <Zn>.S, <Zm>.S
   Instruction Set: A64  Groups: sve_fp_fmmla_lvl2, sve_fp_fmmla, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmmla_z_zzz_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF32mm /*FEAT_F32MM*/)
    {
        LogFlow(("%018x/%010x: fmmla_z_zzz_s Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmmla_z_zzz_s
        IEM_INSTR_IMPL_A64__fmmla_z_zzz_s(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/80200008: FMOP4A  <ZAda>.H, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_f8f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za16_z8z8_b1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x80200008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za16_z8z8_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za16_z8z8_b1x1
            IEM_INSTR_IMPL_A64__fmop4a_za16_z8z8_b1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/80300008: FMOP4A  <ZAda>.H, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_f8f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za16_z8z8_b1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x80300008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za16_z8z8_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za16_z8z8_b1x2
            IEM_INSTR_IMPL_A64__fmop4a_za16_z8z8_b1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/80200208: FMOP4A  <ZAda>.H, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_f8f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za16_z8z8_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x80200208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za16_z8z8_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za16_z8z8_b2x1
            IEM_INSTR_IMPL_A64__fmop4a_za16_z8z8_b2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/80300208: FMOP4A  <ZAda>.H, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_f8f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za16_z8z8_b2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x80300208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za16_z8z8_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za16_z8z8_b2x2
            IEM_INSTR_IMPL_A64__fmop4a_za16_z8z8_b2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80200000: FMOP4A  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_f8f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za32_z8z8_b1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80200000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za32_z8z8_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za32_z8z8_b1x1
            IEM_INSTR_IMPL_A64__fmop4a_za32_z8z8_b1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80300000: FMOP4A  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_f8f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za32_z8z8_b1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80300000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za32_z8z8_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za32_z8z8_b1x2
            IEM_INSTR_IMPL_A64__fmop4a_za32_z8z8_b1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80200200: FMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_f8f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za32_z8z8_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80200200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za32_z8z8_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za32_z8z8_b2x1
            IEM_INSTR_IMPL_A64__fmop4a_za32_z8z8_b2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80300200: FMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_f8f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za32_z8z8_b2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80300200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za32_z8z8_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za32_z8z8_b2x2
            IEM_INSTR_IMPL_A64__fmop4a_za32_z8z8_b2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81200000: FMOP4A  <ZAda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za32_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81200000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za32_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za32_zz_h1x1
            IEM_INSTR_IMPL_A64__fmop4a_za32_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81300000: FMOP4A  <ZAda>.S, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_f16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za32_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81300000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za32_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za32_zz_h1x2
            IEM_INSTR_IMPL_A64__fmop4a_za32_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81200200: FMOP4A  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za32_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81200200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za32_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za32_zz_h2x1
            IEM_INSTR_IMPL_A64__fmop4a_za32_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81300200: FMOP4A  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_f16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za32_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81300200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za32_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za32_zz_h2x2
            IEM_INSTR_IMPL_A64__fmop4a_za32_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/80c00008: FMOP4A  <ZAda>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: mortlach_f64f64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_d1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0x80c00008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_d1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_d1x1
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_d1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/80d00008: FMOP4A  <ZAda>.D, <Zn>.D, { <Zm1>.D-<Zm2>.D }
   Instruction Set: A64  Groups: mortlach_f64f64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_d1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0x80d00008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_d1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_d1x2
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_d1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/80c00208: FMOP4A  <ZAda>.D, { <Zn1>.D-<Zn2>.D }, <Zm>.D
   Instruction Set: A64  Groups: mortlach_f64f64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_d2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0x80c00208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_d2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_d2x1
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_d2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/80d00208: FMOP4A  <ZAda>.D, { <Zn1>.D-<Zn2>.D }, { <Zm1>.D-<Zm2>.D }
   Instruction Set: A64  Groups: mortlach_f64f64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_d2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0x80d00208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_d2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_d2x2
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_d2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81000008: FMOP4A  <ZAda>.H, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81000008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_h1x1
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81100008: FMOP4A  <ZAda>.H, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_f16f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81100008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_h1x2
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81000208: FMOP4A  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81000208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_h2x1
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81100208: FMOP4A  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_f16f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81100208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_h2x2
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80000000: FMOP4A  <ZAda>.S, <Zn>.S, <Zm>.S
   Instruction Set: A64  Groups: mortlach_f32f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_s1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80000000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_s1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_s1x1
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_s1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80100000: FMOP4A  <ZAda>.S, <Zn>.S, { <Zm1>.S-<Zm2>.S }
   Instruction Set: A64  Groups: mortlach_f32f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_s1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80100000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_s1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_s1x2
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_s1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80000200: FMOP4A  <ZAda>.S, { <Zn1>.S-<Zn2>.S }, <Zm>.S
   Instruction Set: A64  Groups: mortlach_f32f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_s2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80000200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_s2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_s2x1
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_s2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80100200: FMOP4A  <ZAda>.S, { <Zn1>.S-<Zn2>.S }, { <Zm1>.S-<Zm2>.S }
   Instruction Set: A64  Groups: mortlach_f32f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4a_za_zz_s2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80100200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4a_za_zz_s2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4a_za_zz_s2x2
            IEM_INSTR_IMPL_A64__fmop4a_za_zz_s2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81200010: FMOP4S  <ZAda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za32_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81200010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za32_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za32_zz_h1x1
            IEM_INSTR_IMPL_A64__fmop4s_za32_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81300010: FMOP4S  <ZAda>.S, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_f16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za32_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81300010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za32_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za32_zz_h1x2
            IEM_INSTR_IMPL_A64__fmop4s_za32_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81200210: FMOP4S  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za32_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81200210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za32_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za32_zz_h2x1
            IEM_INSTR_IMPL_A64__fmop4s_za32_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81300210: FMOP4S  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_f16f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za32_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81300210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za32_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za32_zz_h2x2
            IEM_INSTR_IMPL_A64__fmop4s_za32_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/80c00018: FMOP4S  <ZAda>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: mortlach_f64f64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_d1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmop4s_za_zz_d1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_d1x1
        IEM_INSTR_IMPL_A64__fmop4s_za_zz_d1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/80d00018: FMOP4S  <ZAda>.D, <Zn>.D, { <Zm1>.D-<Zm2>.D }
   Instruction Set: A64  Groups: mortlach_f64f64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_d1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmop4s_za_zz_d1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_d1x2
        IEM_INSTR_IMPL_A64__fmop4s_za_zz_d1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/80c00218: FMOP4S  <ZAda>.D, { <Zn1>.D-<Zn2>.D }, <Zm>.D
   Instruction Set: A64  Groups: mortlach_f64f64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_d2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmop4s_za_zz_d2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_d2x1
        IEM_INSTR_IMPL_A64__fmop4s_za_zz_d2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/80d00218: FMOP4S  <ZAda>.D, { <Zn1>.D-<Zn2>.D }, { <Zm1>.D-<Zm2>.D }
   Instruction Set: A64  Groups: mortlach_f64f64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_d2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmop4s_za_zz_d2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_d2x2
        IEM_INSTR_IMPL_A64__fmop4s_za_zz_d2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81000018: FMOP4S  <ZAda>.H, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81000018))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_h1x1
            IEM_INSTR_IMPL_A64__fmop4s_za_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81100018: FMOP4S  <ZAda>.H, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_f16f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81100018))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_h1x2
            IEM_INSTR_IMPL_A64__fmop4s_za_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81000218: FMOP4S  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81000218))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_h2x1
            IEM_INSTR_IMPL_A64__fmop4s_za_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3e/81100218: FMOP4S  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_f16f16_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3e)) == UINT32_C(0x81100218))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_h2x2
            IEM_INSTR_IMPL_A64__fmop4s_za_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80000010: FMOP4S  <ZAda>.S, <Zn>.S, <Zm>.S
   Instruction Set: A64  Groups: mortlach_f32f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_s1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80000010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za_zz_s1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_s1x1
            IEM_INSTR_IMPL_A64__fmop4s_za_zz_s1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80100010: FMOP4S  <ZAda>.S, <Zn>.S, { <Zm1>.S-<Zm2>.S }
   Instruction Set: A64  Groups: mortlach_f32f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_s1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80100010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za_zz_s1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_s1x2
            IEM_INSTR_IMPL_A64__fmop4s_za_zz_s1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80000210: FMOP4S  <ZAda>.S, { <Zn1>.S-<Zn2>.S }, <Zm>.S
   Instruction Set: A64  Groups: mortlach_f32f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_s2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80000210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za_zz_s2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_s2x1
            IEM_INSTR_IMPL_A64__fmop4s_za_zz_s2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80100210: FMOP4S  <ZAda>.S, { <Zn1>.S-<Zn2>.S }, { <Zm1>.S-<Zm2>.S }
   Instruction Set: A64  Groups: mortlach_f32f32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmop4s_za_zz_s2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80100210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: fmop4s_za_zz_s2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmop4s_za_zz_s2x2
            IEM_INSTR_IMPL_A64__fmop4s_za_zz_s2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001e/80a00008: FMOPA  <ZAda>.H, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_f8f16_prod, mortlach2_misc_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmopa_za16_pp_z8z8_8, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fmopa_za16_pp_z8z8_8 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmopa_za16_pp_z8z8_8
        IEM_INSTR_IMPL_A64__fmopa_za16_pp_z8z8_8(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/80a00000: FMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_f8f32_prod, mortlach_32bit_fp_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmopa_za32_pp_z8z8_8, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fmopa_za32_pp_z8z8_8 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmopa_za32_pp_z8z8_8
        IEM_INSTR_IMPL_A64__fmopa_za32_pp_z8z8_8(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/81a00000: FMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f32_prod, mortlach_32bit_fp_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmopa_za32_pp_zz_16, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmopa_za32_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmopa_za32_pp_zz_16
        IEM_INSTR_IMPL_A64__fmopa_za32_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001e/81800008: FMOPA  <ZAda>.H, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f16_prod, mortlach2_misc_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmopa_za_pp_zz_16, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmopa_za_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmopa_za_pp_zz_16
        IEM_INSTR_IMPL_A64__fmopa_za_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/80800000: FMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.S, <Zm>.S
   Instruction Set: A64  Groups: mortlach_f32f32_prod, mortlach_32bit_fp_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmopa_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmopa_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmopa_za_pp_zz_32
        IEM_INSTR_IMPL_A64__fmopa_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/80c00000: FMOPA  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: mortlach_f64f64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmopa_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmopa_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmopa_za_pp_zz_64
        IEM_INSTR_IMPL_A64__fmopa_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/81a00010: FMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f32_prod, mortlach_32bit_fp_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmops_za32_pp_zz_16, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmops_za32_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmops_za32_pp_zz_16
        IEM_INSTR_IMPL_A64__fmops_za32_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001e/81800018: FMOPS  <ZAda>.H, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_f16f16_prod, mortlach2_misc_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmops_za_pp_zz_16, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/)
    {
        LogFlow(("%018x/%010x: fmops_za_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmops_za_pp_zz_16
        IEM_INSTR_IMPL_A64__fmops_za_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/80800010: FMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.S, <Zm>.S
   Instruction Set: A64  Groups: mortlach_f32f32_prod, mortlach_32bit_fp_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmops_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmops_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmops_za_pp_zz_32
        IEM_INSTR_IMPL_A64__fmops_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/80c00010: FMOPS  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: mortlach_f64f64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmops_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF64F64 /*FEAT_SME_F64F64*/)
    {
        LogFlow(("%018x/%010x: fmops_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__fmops_za_pp_zz_64
        IEM_INSTR_IMPL_A64__fmops_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/6520a000: FMSB  <Zdn>.<T>, <Pg>/M, <Zm>.<T>, <Za>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_b, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmsb_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Za         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmsb_z_p_zzz Zdn=%#x Zm=%#x Pg=%u Za=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, Za, size));
#ifdef IEM_INSTR_IMPL_A64__fmsb_z_p_zzz
        IEM_INSTR_IMPL_A64__fmsb_z_p_zzz(Zdn, Zm, Pg, Za, size);
#else
        RT_NOREF(Zdn, Zm, Pg, Za, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21fc21/c120e800: FMUL  { <Zd1>.<T>-<Zd2>.<T> }, { <Zn1>.<T>-<Zn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_fmul_sm, mortlach_multi_sve_5b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmul_mz_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/ && (size != 0))
    {
        LogFlow(("%018x/%010x: fmul_mz_zzv_2x1 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmul_mz_zzv_2x1
        IEM_INSTR_IMPL_A64__fmul_mz_zzv_2x1(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21fc63/c121e800: FMUL  { <Zd1>.<T>-<Zd4>.<T> }, { <Zn1>.<T>-<Zn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_fmul_sm, mortlach_multi_sve_5b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmul_mz_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/ && (size != 0))
    {
        LogFlow(("%018x/%010x: fmul_mz_zzv_4x1 Zd=%u Zn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmul_mz_zzv_4x1
        IEM_INSTR_IMPL_A64__fmul_mz_zzv_4x1(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21fc21/c120e400: FMUL  { <Zd1>.<T>-<Zd2>.<T> }, { <Zn1>.<T>-<Zn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_fmul_mm, mortlach_multi_sve_5a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmul_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/ && (size != 0))
    {
        LogFlow(("%018x/%010x: fmul_mz_zzw_2x2 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmul_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__fmul_mz_zzw_2x2(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23fc63/c121e400: FMUL  { <Zd1>.<T>-<Zd4>.<T> }, { <Zn1>.<T>-<Zn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_fmul_mm, mortlach_multi_sve_5a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fmul_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/ && (size != 0))
    {
        LogFlow(("%018x/%010x: fmul_mz_zzw_4x4 Zd=%u Zn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmul_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__fmul_mz_zzw_4x4(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe3c0/651a8000: FMUL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_2op_i_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmul_z_p_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651a8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const i1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fmul_z_p_zs Zdn=%#x i1=%u Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, i1, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmul_z_p_zs
            IEM_INSTR_IMPL_A64__fmul_z_p_zs(Zdn, i1, Pg, size);
#else
            RT_NOREF(Zdn, i1, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65028000: FMUL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmul_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fmul_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmul_z_p_zz
        IEM_INSTR_IMPL_A64__fmul_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/65000800: FMUL  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmul_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fmul_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fmul_z_zz
        IEM_INSTR_IMPL_A64__fmul_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64e02000: FMUL  <Zd>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_fp_fmul_by_indexed_elem_lvl2, sve_fp_fmul_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmul_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmul_z_zzi_d Zd=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__fmul_z_zzi_d
        IEM_INSTR_IMPL_A64__fmul_z_zzi_d(Zd, Zn, Zm, i1);
#else
        RT_NOREF(Zd, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/64202000: FMUL  <Zd>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_fp_fmul_by_indexed_elem_lvl2, sve_fp_fmul_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmul_z_zzi_h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmul_z_zzi_h Zd=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__fmul_z_zzi_h
        IEM_INSTR_IMPL_A64__fmul_z_zzi_h(Zd, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zd, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/64a02000: FMUL  <Zd>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_fp_fmul_by_indexed_elem_lvl2, sve_fp_fmul_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmul_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmul_z_zzi_s Zd=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__fmul_z_zzi_s
        IEM_INSTR_IMPL_A64__fmul_z_zzi_s(Zd, Zn, Zm, i2);
#else
        RT_NOREF(Zd, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/650a8000: FMULX  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fmulx_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fmulx_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fmulx_z_p_zz
        IEM_INSTR_IMPL_A64__fmulx_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041da000: FNEG  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_fneg_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fneg_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fneg_z_p_z_m
        IEM_INSTR_IMPL_A64__fneg_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040da000: FNEG  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_fneg_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fneg_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fneg_z_p_z_z
        IEM_INSTR_IMPL_A64__fneg_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/6520c000: FNMAD  <Zdn>.<T>, <Pg>/M, <Zm>.<T>, <Za>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_b, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_fnmad_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Za         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fnmad_z_p_zzz Zdn=%#x Zm=%#x Pg=%u Za=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, Za, size));
#ifdef IEM_INSTR_IMPL_A64__fnmad_z_p_zzz
        IEM_INSTR_IMPL_A64__fnmad_z_p_zzz(Zdn, Zm, Pg, Za, size);
#else
        RT_NOREF(Zdn, Zm, Pg, Za, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/65204000: FNMLA  <Zda>.<T>, <Pg>/M, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_a, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_fnmla_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fnmla_z_p_zzz Zda=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fnmla_z_p_zzz
        IEM_INSTR_IMPL_A64__fnmla_z_p_zzz(Zda, Zn, Pg, Zm, size);
#else
        RT_NOREF(Zda, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/65206000: FNMLS  <Zda>.<T>, <Pg>/M, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_a, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_fnmls_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fnmls_z_p_zzz Zda=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fnmls_z_p_zzz
        IEM_INSTR_IMPL_A64__fnmls_z_p_zzz(Zda, Zn, Pg, Zm, size);
#else
        RT_NOREF(Zda, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/6520e000: FNMSB  <Zdn>.<T>, <Pg>/M, <Zm>.<T>, <Za>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_p_zds_b, sve_fp_fma, sve */
FNIEMOP_DEF_1(iemDecodeA64_fnmsb_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Za         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fnmsb_z_p_zzz Zdn=%#x Zm=%#x Pg=%u Za=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, Za, size));
#ifdef IEM_INSTR_IMPL_A64__fnmsb_z_p_zzz
        IEM_INSTR_IMPL_A64__fnmsb_z_p_zzz(Zdn, Zm, Pg, Za, size);
#else
        RT_NOREF(Zdn, Zm, Pg, Za, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/650e3000: FRECPE  <Zd>.<T>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_u_zd, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_frecpe_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frecpe_z_z Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__frecpe_z_z
        IEM_INSTR_IMPL_A64__frecpe_z_z(Zd, Zn, size);
#else
        RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/65001800: FRECPS  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_frecps_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frecps_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__frecps_z_zz
        IEM_INSTR_IMPL_A64__frecps_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/650ca000: FRECPX  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_1, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frecpx_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frecpx_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frecpx_z_p_z_m
        IEM_INSTR_IMPL_A64__frecpx_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/641b8000: FRECPX  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_1, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frecpx_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: frecpx_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frecpx_z_p_z_z
        IEM_INSTR_IMPL_A64__frecpx_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffde000/6511a000: FRINT32X  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frint32x_z_p_z_m, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffde000)) == UINT32_C(0x6511a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 17) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frint32x_z_p_z_m Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__frint32x_z_p_z_m
            IEM_INSTR_IMPL_A64__frint32x_z_p_z_m(Zd, Zn, Pg, sz);
#else
            RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffa000/641ca000: FRINT32X  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frint32x_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffa000)) == UINT32_C(0x641ca000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 14) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frint32x_z_p_z_z Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__frint32x_z_p_z_z
            IEM_INSTR_IMPL_A64__frint32x_z_p_z_z(Zd, Zn, Pg, sz);
#else
            RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffde000/6510a000: FRINT32Z  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frint32z_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 17) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: frint32z_z_p_z_m Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__frint32z_z_p_z_m
        IEM_INSTR_IMPL_A64__frint32z_z_p_z_m(Zd, Zn, Pg, sz);
#else
        RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffa000/641c8000: FRINT32Z  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frint32z_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffa000)) == UINT32_C(0x641c8000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 14) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frint32z_z_p_z_z Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__frint32z_z_p_z_z
            IEM_INSTR_IMPL_A64__frint32z_z_p_z_z(Zd, Zn, Pg, sz);
#else
            RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffde000/6515a000: FRINT64X  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frint64x_z_p_z_m, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffde000)) == UINT32_C(0x6515a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 17) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frint64x_z_p_z_m Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__frint64x_z_p_z_m
            IEM_INSTR_IMPL_A64__frint64x_z_p_z_m(Zd, Zn, Pg, sz);
#else
            RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffa000/641da000: FRINT64X  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frint64x_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffa000)) == UINT32_C(0x641da000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 14) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frint64x_z_p_z_z Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__frint64x_z_p_z_z
            IEM_INSTR_IMPL_A64__frint64x_z_p_z_z(Zd, Zn, Pg, sz);
#else
            RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffde000/6514a000: FRINT64Z  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frint64z_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 17) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: frint64z_z_p_z_m Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__frint64z_z_p_z_m
        IEM_INSTR_IMPL_A64__frint64z_z_p_z_m(Zd, Zn, Pg, sz);
#else
        RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffa000/641d8000: FRINT64Z  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frint64z_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffa000)) == UINT32_C(0x641d8000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 14) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frint64z_z_p_z_z Zd=%#x Zn=%#x Pg=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, sz));
#ifdef IEM_INSTR_IMPL_A64__frint64z_z_p_z_z
            IEM_INSTR_IMPL_A64__frint64z_z_p_z_z(Zd, Zn, Pg, sz);
#else
            RT_NOREF(Zd, Zn, Pg, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc21/c1ace000: FRINTA  { <Zd1>.S-<Zd2>.S }, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_frint, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_frinta_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc21)) == UINT32_C(0xc1ace000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: frinta_mz_z_2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__frinta_mz_z_2
            IEM_INSTR_IMPL_A64__frinta_mz_z_2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c1bce000: FRINTA  { <Zd1>.S-<Zd4>.S }, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_frint, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_frinta_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc1bce000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: frinta_mz_z_4 Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__frinta_mz_z_4
            IEM_INSTR_IMPL_A64__frinta_mz_z_4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6504a000: FRINTA  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_a, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frinta_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frinta_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frinta_z_p_z_m
        IEM_INSTR_IMPL_A64__frinta_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/64198000: FRINTA  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_a, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frinta_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: frinta_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frinta_z_p_z_z
        IEM_INSTR_IMPL_A64__frinta_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6507a000: FRINTI  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_a, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frinti_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frinti_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frinti_z_p_z_m
        IEM_INSTR_IMPL_A64__frinti_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6419e000: FRINTI  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_a, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frinti_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6419e000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frinti_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frinti_z_p_z_z
            IEM_INSTR_IMPL_A64__frinti_z_p_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc21/c1aae000: FRINTM  { <Zd1>.S-<Zd2>.S }, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_frint, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_frintm_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc21)) == UINT32_C(0xc1aae000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: frintm_mz_z_2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__frintm_mz_z_2
            IEM_INSTR_IMPL_A64__frintm_mz_z_2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c1bae000: FRINTM  { <Zd1>.S-<Zd4>.S }, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_frint, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_frintm_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc1bae000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: frintm_mz_z_4 Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__frintm_mz_z_4
            IEM_INSTR_IMPL_A64__frintm_mz_z_4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6502a000: FRINTM  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_a, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintm_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frintm_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintm_z_p_z_m
        IEM_INSTR_IMPL_A64__frintm_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6418c000: FRINTM  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_a, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintm_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6418c000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frintm_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintm_z_p_z_z
            IEM_INSTR_IMPL_A64__frintm_z_p_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc21/c1a8e000: FRINTN  { <Zd1>.S-<Zd2>.S }, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_frint, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_frintn_mz_z_2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: frintn_mz_z_2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__frintn_mz_z_2
        IEM_INSTR_IMPL_A64__frintn_mz_z_2(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c1b8e000: FRINTN  { <Zd1>.S-<Zd4>.S }, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_frint, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_frintn_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc1b8e000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: frintn_mz_z_4 Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__frintn_mz_z_4
            IEM_INSTR_IMPL_A64__frintn_mz_z_4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6500a000: FRINTN  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_a, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintn_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frintn_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintn_z_p_z_m
        IEM_INSTR_IMPL_A64__frintn_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/64188000: FRINTN  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_a, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintn_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: frintn_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintn_z_p_z_z
        IEM_INSTR_IMPL_A64__frintn_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc21/c1a9e000: FRINTP  { <Zd1>.S-<Zd2>.S }, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_frint, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_frintp_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc21)) == UINT32_C(0xc1a9e000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: frintp_mz_z_2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__frintp_mz_z_2
            IEM_INSTR_IMPL_A64__frintp_mz_z_2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c1b9e000: FRINTP  { <Zd1>.S-<Zd4>.S }, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_frint, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_frintp_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc1b9e000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: frintp_mz_z_4 Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__frintp_mz_z_4
            IEM_INSTR_IMPL_A64__frintp_mz_z_4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6501a000: FRINTP  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_a, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintp_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frintp_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintp_z_p_z_m
        IEM_INSTR_IMPL_A64__frintp_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6418a000: FRINTP  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_a, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintp_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: frintp_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintp_z_p_z_z
        IEM_INSTR_IMPL_A64__frintp_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6506a000: FRINTX  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_a, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintx_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frintx_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintx_z_p_z_m
        IEM_INSTR_IMPL_A64__frintx_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6419c000: FRINTX  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_a, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintx_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6419c000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frintx_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintx_z_p_z_z
            IEM_INSTR_IMPL_A64__frintx_z_p_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6503a000: FRINTZ  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_a, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintz_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frintz_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintz_z_p_z_m
        IEM_INSTR_IMPL_A64__frintz_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/6418e000: FRINTZ  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_a, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_frintz_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6418e000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: frintz_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__frintz_z_p_z_z
            IEM_INSTR_IMPL_A64__frintz_z_p_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/650f3000: FRSQRTE  <Zd>.<T>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_u_zd, sve_fp_unary_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_frsqrte_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frsqrte_z_z Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__frsqrte_z_z
        IEM_INSTR_IMPL_A64__frsqrte_z_z(Zd, Zn, size);
#else
        RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/65001c00: FRSQRTS  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_frsqrts_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: frsqrts_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__frsqrts_z_zz
        IEM_INSTR_IMPL_A64__frsqrts_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a180: FSCALE  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fscale_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fscale_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a180))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/ && (size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fscale_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fscale_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__fscale_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a980: FSCALE  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fscale_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fscale_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a980))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/ && (size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fscale_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fscale_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__fscale_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b180: FSCALE  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_fscale_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fscale_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b180))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/ && (size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fscale_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fscale_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__fscale_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b980: FSCALE  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_fscale_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_fscale_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b980))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fFp8 /*FEAT_FP8*/ && (size != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fscale_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fscale_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__fscale_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65098000: FSCALE  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fscale_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fscale_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fscale_z_p_zz
        IEM_INSTR_IMPL_A64__fscale_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/650da000: FSQRT  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_b_1, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fsqrt_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fsqrt_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fsqrt_z_p_z_m
        IEM_INSTR_IMPL_A64__fsqrt_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/641ba000: FSQRT  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_b_1, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_fsqrt_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: fsqrt_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fsqrt_z_p_z_z
        IEM_INSTR_IMPL_A64__fsqrt_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe3c0/65198000: FSUB  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_2op_i_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fsub_z_p_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65198000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const i1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fsub_z_p_zs Zdn=%#x i1=%u Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, i1, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fsub_z_p_zs
            IEM_INSTR_IMPL_A64__fsub_z_p_zs(Zdn, i1, Pg, size);
#else
            RT_NOREF(Zdn, i1, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65018000: FSUB  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fsub_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fsub_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fsub_z_p_zz
        IEM_INSTR_IMPL_A64__fsub_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/65000400: FSUB  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fsub_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: fsub_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__fsub_z_zz
        IEM_INSTR_IMPL_A64__fsub_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbf9c38/c1a01c08: FSUB  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_float_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fsub_za_zw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbf9c38)) == UINT32_C(0xc1a01c08))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fsub_za_zw_2x2 off3=%u Zm=%#x Rv=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv, sz));
#ifdef IEM_INSTR_IMPL_A64__fsub_za_zw_2x2
            IEM_INSTR_IMPL_A64__fsub_za_zw_2x2(off3, Zm, Rv, sz);
#else
            RT_NOREF(off3, Zm, Rv, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c38/c1a41c08: FSUB  ZA.H[<Wv>, <offs>{, VGx2}], { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_f16_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_fsub_za_zw_2x2_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c38)) == UINT32_C(0xc1a41c08))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
        {
            LogFlow(("%018x/%010x: fsub_za_zw_2x2_16 off3=%u Zm=%#x Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv));
#ifdef IEM_INSTR_IMPL_A64__fsub_za_zw_2x2_16
            IEM_INSTR_IMPL_A64__fsub_za_zw_2x2_16(off3, Zm, Rv);
#else
            RT_NOREF(off3, Zm, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbf9c78/c1a11c08: FSUB  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_float_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fsub_za_zw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbf9c78)) == UINT32_C(0xc1a11c08))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: fsub_za_zw_4x4 off3=%u Zm=%u Rv=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv, sz));
#ifdef IEM_INSTR_IMPL_A64__fsub_za_zw_4x4
            IEM_INSTR_IMPL_A64__fsub_za_zw_4x4(off3, Zm, Rv, sz);
#else
            RT_NOREF(off3, Zm, Rv, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c78/c1a51c08: FSUB  ZA.H[<Wv>, <offs>{, VGx4}], { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_f16_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_fsub_za_zw_4x4_16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c78)) == UINT32_C(0xc1a51c08))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
        {
            LogFlow(("%018x/%010x: fsub_za_zw_4x4_16 off3=%u Zm=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv));
#ifdef IEM_INSTR_IMPL_A64__fsub_za_zw_4x4_16
            IEM_INSTR_IMPL_A64__fsub_za_zw_4x4_16(off3, Zm, Rv);
#else
            RT_NOREF(off3, Zm, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe3c0/651b8000: FSUBR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <const>
   Instruction Set: A64  Groups: sve_fp_2op_i_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fsubr_z_p_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651b8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const i1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: fsubr_z_p_zs Zdn=%#x i1=%u Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, i1, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fsubr_z_p_zs
            IEM_INSTR_IMPL_A64__fsubr_z_p_zs(Zdn, i1, Pg, size);
#else
            RT_NOREF(Zdn, i1, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/65038000: FSUBR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_2op_p_zds, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_fsubr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: fsubr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__fsubr_z_p_zz
        IEM_INSTR_IMPL_A64__fsubr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff38fc00/65108000: FTMAD  <Zdn>.<T>, <Zdn>.<T>, <Zm>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_fp_ftmad, sve_fp_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_ftmad_z_zzi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ftmad_z_zzi Zdn=%#x Zm=%#x imm3=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, imm3, size));
#ifdef IEM_INSTR_IMPL_A64__ftmad_z_zzi
        IEM_INSTR_IMPL_A64__ftmad_z_zzi(Zdn, Zm, imm3, size);
#else
        RT_NOREF(Zdn, Zm, imm3, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00e/80600008: FTMOPA  <ZAda>.H, { <Zn1>.B-<Zn2>.B }, <Zm>.B, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_f8f16_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_ftmopa_za16_z8z8zi_b2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: ftmopa_za16_z8z8zi_b2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__ftmopa_za16_z8z8zi_b2x1
        IEM_INSTR_IMPL_A64__ftmopa_za16_z8z8zi_b2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/80600000: FTMOPA  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_f8f32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_ftmopa_za32_z8z8zi_b2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: ftmopa_za32_z8z8zi_b2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__ftmopa_za32_z8z8zi_b2x1
        IEM_INSTR_IMPL_A64__ftmopa_za32_z8z8zi_b2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/81600000: FTMOPA  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_f16f32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_ftmopa_za32_zzzi_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: ftmopa_za32_zzzi_h2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__ftmopa_za32_zzzi_h2x1
        IEM_INSTR_IMPL_A64__ftmopa_za32_zzzi_h2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00e/81400008: FTMOPA  <ZAda>.H, { <Zn1>.H-<Zn2>.H }, <Zm>.H, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_f16f16_1in2ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_ftmopa_za_zzzi_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000001;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF16F16 /*FEAT_SME_F16F16*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: ftmopa_za_zzzi_h2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__ftmopa_za_zzzi_h2x1
        IEM_INSTR_IMPL_A64__ftmopa_za_zzzi_h2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/80400000: FTMOPA  <ZAda>.S, { <Zn1>.S-<Zn2>.S }, <Zm>.S, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_f32f32_1in2ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_ftmopa_za_zzzi_s2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x80400000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
        uint32_t const K          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
        {
            LogFlow(("%018x/%010x: ftmopa_za_zzzi_s2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__ftmopa_za_zzzi_s2x1
            IEM_INSTR_IMPL_A64__ftmopa_za_zzzi_s2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
            RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/65000c00: FTSMUL  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_fp_3op_u_zd, sve_fp_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_ftsmul_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ftsmul_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__ftsmul_z_zz
        IEM_INSTR_IMPL_A64__ftsmul_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/0420b000: FTSSEL  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_cons_misc_0_b, sve_int_unpred_misc, sve */
FNIEMOP_DEF_1(iemDecodeA64_ftssel_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ftssel_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__ftssel_z_zz
        IEM_INSTR_IMPL_A64__ftssel_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09030/c1d01020: FVDOT  ZA.H[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fp8_fdot_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fvdot_za_z8z8i_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i3l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F16 /*FEAT_SME_F8F16*/)
    {
        LogFlow(("%018x/%010x: fvdot_za_z8z8i_2xi off3=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fvdot_za_z8z8i_2xi
        IEM_INSTR_IMPL_A64__fvdot_za_z8z8i_2xi(off3, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off3, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1500008: FVDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fvdot_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: fvdot_za_zzi_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fvdot_za_zzi_2xi
        IEM_INSTR_IMPL_A64__fvdot_za_zzi_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09830/c1d00800: FVDOTB  ZA.S[<Wv>, <offs>, VGx4], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fp8_fvdot_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fvdotb_za32_z8z8i_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i2l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fvdotb_za32_z8z8i_2xi off3=%u i2l=%u Zn=%#x i2h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i2l, Zn, i2h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fvdotb_za32_z8z8i_2xi
        IEM_INSTR_IMPL_A64__fvdotb_za32_z8z8i_2xi(off3, i2l, Zn, i2h, Rv, Zm);
#else
        RT_NOREF(off3, i2l, Zn, i2h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09830/c1d00810: FVDOTT  ZA.S[<Wv>, <offs>, VGx4], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_fp8_fvdot_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_fvdott_za32_z8z8i_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const i2l        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeF8F32 /*FEAT_SME_F8F32*/)
    {
        LogFlow(("%018x/%010x: fvdott_za32_z8z8i_2xi off3=%u i2l=%u Zn=%#x i2h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, i2l, Zn, i2h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__fvdott_za32_z8z8i_2xi
        IEM_INSTR_IMPL_A64__fvdott_za32_z8z8i_2xi(off3, i2l, Zn, i2h, Rv, Zm);
#else
        RT_NOREF(off3, i2l, Zn, i2h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/4520c000: HISTCNT  <Zd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_histcnt_lvl2, sve_intx_histcnt, sve */
FNIEMOP_DEF_1(iemDecodeA64_histcnt_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: histcnt_z_p_zz Zd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__histcnt_z_p_zz
        IEM_INSTR_IMPL_A64__histcnt_z_p_zz(Zd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Zd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4520a000: HISTSEG  <Zd>.B, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_intx_histseg, sve_intx_histseg_lut, sve */
FNIEMOP_DEF_1(iemDecodeA64_histseg_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: histseg_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__histseg_z_zz
        IEM_INSTR_IMPL_A64__histseg_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0430e000: INCB  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_a, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_incb_r_rs, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: incb_r_rs Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__incb_r_rs
        IEM_INSTR_IMPL_A64__incb_r_rs(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04f0e000: INCD  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_a, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_incd_r_rs, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: incd_r_rs Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__incd_r_rs
        IEM_INSTR_IMPL_A64__incd_r_rs(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04f0c000: INCD  <Zdn>.D{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv1, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_incd_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: incd_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__incd_z_zs
        IEM_INSTR_IMPL_A64__incd_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0470e000: INCH  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_a, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_inch_r_rs, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: inch_r_rs Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__inch_r_rs
        IEM_INSTR_IMPL_A64__inch_r_rs(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0470c000: INCH  <Zdn>.H{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv1, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_inch_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: inch_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__inch_z_zs
        IEM_INSTR_IMPL_A64__inch_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252c8800: INCP  <Xdn>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_r, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_incp_r_p_r, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: incp_r_p_r Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__incp_r_p_r
        IEM_INSTR_IMPL_A64__incp_r_p_r(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252c8000: INCP  <Zdn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_v, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_incp_z_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252c8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: incp_z_p_z Zdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__incp_z_p_z
            IEM_INSTR_IMPL_A64__incp_z_p_z(Zdn, Pm, size);
#else
            RT_NOREF(Zdn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04b0e000: INCW  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_a, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_incw_r_rs, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: incw_r_rs Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__incw_r_rs
        IEM_INSTR_IMPL_A64__incw_r_rs(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04b0c000: INCW  <Zdn>.S{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv1, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_incw_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: incw_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__incw_z_zs
        IEM_INSTR_IMPL_A64__incw_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04204000: INDEX  <Zd>.<T>, #<imm1>, #<imm2>
   Instruction Set: A64  Groups: sve_int_index_ii, sve_index, sve */
FNIEMOP_DEF_1(iemDecodeA64_index_z_ii, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm5       = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm5b      = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: index_z_ii Zd=%#x imm5=%#x imm5b=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, imm5, imm5b, size));
#ifdef IEM_INSTR_IMPL_A64__index_z_ii
        IEM_INSTR_IMPL_A64__index_z_ii(Zd, imm5, imm5b, size);
#else
        RT_NOREF(Zd, imm5, imm5b, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04204800: INDEX  <Zd>.<T>, #<imm>, <R><m>
   Instruction Set: A64  Groups: sve_int_index_ir, sve_index, sve */
FNIEMOP_DEF_1(iemDecodeA64_index_z_ir, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm5       = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: index_z_ir Zd=%#x imm5=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, imm5, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__index_z_ir
        IEM_INSTR_IMPL_A64__index_z_ir(Zd, imm5, Rm, size);
#else
        RT_NOREF(Zd, imm5, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04204400: INDEX  <Zd>.<T>, <R><n>, #<imm>
   Instruction Set: A64  Groups: sve_int_index_ri, sve_index, sve */
FNIEMOP_DEF_1(iemDecodeA64_index_z_ri, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: index_z_ri Zd=%#x Rn=%#x imm5=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Rn, imm5, size));
#ifdef IEM_INSTR_IMPL_A64__index_z_ri
        IEM_INSTR_IMPL_A64__index_z_ri(Zd, Rn, imm5, size);
#else
        RT_NOREF(Zd, Rn, imm5, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04204c00: INDEX  <Zd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_index_rr, sve_index, sve */
FNIEMOP_DEF_1(iemDecodeA64_index_z_rr, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: index_z_rr Zd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__index_z_rr
        IEM_INSTR_IMPL_A64__index_z_rr(Zd, Rn, Rm, size);
#else
        RT_NOREF(Zd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/05243800: INSR  <Zdn>.<T>, <R><m>
   Instruction Set: A64  Groups: sve_int_perm_insrs, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_insr_z_r, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: insr_z_r Zdn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__insr_z_r
        IEM_INSTR_IMPL_A64__insr_z_r(Zdn, Rm, size);
#else
        RT_NOREF(Zdn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/05343800: INSR  <Zdn>.<T>, <V><m>
   Instruction Set: A64  Groups: sve_int_perm_insrv, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_insr_z_v, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Vm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: insr_z_v Zdn=%#x Vm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Vm, size));
#ifdef IEM_INSTR_IMPL_A64__insr_z_v
        IEM_INSTR_IMPL_A64__insr_z_v(Zdn, Vm, size);
#else
        RT_NOREF(Zdn, Vm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0520a000: LASTA  <R><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_last_r, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_lasta_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lasta_r_p_z Rd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lasta_r_p_z
        IEM_INSTR_IMPL_A64__lasta_r_p_z(Rd, Zn, Pg, size);
#else
        RT_NOREF(Rd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05228000: LASTA  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_last_v, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_lasta_v_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lasta_v_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lasta_v_p_z
        IEM_INSTR_IMPL_A64__lasta_v_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0521a000: LASTB  <R><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_last_r, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_lastb_r_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0521a000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: lastb_r_p_z Rd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lastb_r_p_z
            IEM_INSTR_IMPL_A64__lastb_r_p_z(Rd, Zn, Pg, size);
#else
            RT_NOREF(Rd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05238000: LASTB  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_last_v, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_lastb_v_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lastb_v_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lastb_v_p_z
        IEM_INSTR_IMPL_A64__lastb_v_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc200/25228000: LASTP  <Xd>, <Pg>, <Pn>.<T>
   Instruction Set: A64  Groups: sve_int_pcount_pred, sve_pred_count_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_lastp_r_p_p, uint32_t, uOpcode)
{
    uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: lastp_r_p_p Rd=%#x Pn=%#x Pg=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, Pn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lastp_r_p_p
        IEM_INSTR_IMPL_A64__lastp_r_p_p(Rd, Pn, Pg, size);
#else
        RT_NOREF(Rd, Pn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0400000: LD1B  { <Zt1>.B-<Zt2>.B }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1b_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1b_mz_p_bi_2
        IEM_INSTR_IMPL_A64__ld1b_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a0408000: LD1B  { <Zt1>.B-<Zt4>.B }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1b_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1b_mz_p_bi_4
        IEM_INSTR_IMPL_A64__ld1b_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0000000: LD1B  { <Zt1>.B-<Zt2>.B }, <PNg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1b_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_mz_p_br_2
        IEM_INSTR_IMPL_A64__ld1b_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a0008000: LD1B  { <Zt1>.B-<Zt4>.B }, <PNg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1b_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_mz_p_br_4
        IEM_INSTR_IMPL_A64__ld1b_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1400000: LD1B  { <Zt1>.B, <Zt2>.B }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1b_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1b_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__ld1b_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a1408000: LD1B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1b_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1b_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__ld1b_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1000000: LD1B  { <Zt1>.B, <Zt2>.B }, <PNg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1b_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__ld1b_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a1008000: LD1B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <PNg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1b_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__ld1b_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c420c000: LD1B  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_ai_d
        IEM_INSTR_IMPL_A64__ld1b_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/8420c000: LD1B  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_ai_s
        IEM_INSTR_IMPL_A64__ld1b_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a420a000: LD1B  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_bi_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_bi_u16 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_bi_u16
        IEM_INSTR_IMPL_A64__ld1b_z_p_bi_u16(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a440a000: LD1B  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ld1b_z_p_bi_u32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a460a000: LD1B  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1b_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a400a000: LD1B  { <Zt>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_bi_u8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_bi_u8 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_bi_u8
        IEM_INSTR_IMPL_A64__ld1b_z_p_bi_u8(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4204000: LD1B  { <Zt>.H }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_br_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1b_z_p_br_u16 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_br_u16
        IEM_INSTR_IMPL_A64__ld1b_z_p_br_u16(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4404000: LD1B  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_br_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1b_z_p_br_u32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_br_u32
        IEM_INSTR_IMPL_A64__ld1b_z_p_br_u32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4604000: LD1B  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_br_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1b_z_p_br_u64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_br_u64
        IEM_INSTR_IMPL_A64__ld1b_z_p_br_u64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4004000: LD1B  { <Zt>.B }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_br_u8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1b_z_p_br_u8 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_br_u8
        IEM_INSTR_IMPL_A64__ld1b_z_p_br_u8(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c440c000: LD1B  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ld1b_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4004000: LD1B  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1b_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84004000: LD1B  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x0 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1b_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1b_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1b_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e0000000: LD1B  { ZA0<HV>.B[<Ws>, <offs>] }, <Pg>/Z, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: mortlach_contig_load, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1b_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe0000000))
    {
        uint32_t const off4       = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ld1b_za_p_rrr off4=%#x Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off4, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1b_za_p_rrr
            IEM_INSTR_IMPL_A64__ld1b_za_p_rrr(off4, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(off4, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0406000: LD1D  { <Zt1>.D-<Zt2>.D }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1d_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1d_mz_p_bi_2
        IEM_INSTR_IMPL_A64__ld1d_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a040e000: LD1D  { <Zt1>.D-<Zt4>.D }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1d_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1d_mz_p_bi_4
        IEM_INSTR_IMPL_A64__ld1d_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0006000: LD1D  { <Zt1>.D-<Zt2>.D }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1d_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_mz_p_br_2
        IEM_INSTR_IMPL_A64__ld1d_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a000e000: LD1D  { <Zt1>.D-<Zt4>.D }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1d_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_mz_p_br_4
        IEM_INSTR_IMPL_A64__ld1d_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1406000: LD1D  { <Zt1>.D, <Zt2>.D }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1d_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1d_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__ld1d_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a140e000: LD1D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1d_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1d_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__ld1d_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1006000: LD1D  { <Zt1>.D, <Zt2>.D }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1d_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__ld1d_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a100e000: LD1D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1d_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__ld1d_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5a0c000: LD1D  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1d_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_ai_d
        IEM_INSTR_IMPL_A64__ld1d_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5902000: LD1D  { <Zt>.Q }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si_q, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_bi_u128, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1d_z_p_bi_u128 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_bi_u128
        IEM_INSTR_IMPL_A64__ld1d_z_p_bi_u128(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5e0a000: LD1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1d_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1d_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5808000: LD1D  { <Zt>.Q }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_cld_ss_q, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_br_u128, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1d_z_p_br_u128 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_br_u128
        IEM_INSTR_IMPL_A64__ld1d_z_p_br_u128(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5e04000: LD1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_br_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1d_z_p_br_u64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_br_u64
        IEM_INSTR_IMPL_A64__ld1d_z_p_br_u64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5e0c000: LD1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #3]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x3 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1d_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ld1d_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5c0c000: LD1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1d_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ld1d_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5a04000: LD1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #3]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x3 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1d_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ld1d_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5804000: LD1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1d_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1d_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1d_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e0c00000: LD1D  { <ZAt><HV>.D[<Ws>, <offs>] }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #3}]
   Instruction Set: A64  Groups: mortlach_contig_load, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1d_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe0c00000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const ZAt        = (uOpcode >>  1) & 0x00000007;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ld1d_za_p_rrr o1=%u ZAt=%u Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, ZAt, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1d_za_p_rrr
            IEM_INSTR_IMPL_A64__ld1d_za_p_rrr(o1, ZAt, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(o1, ZAt, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0402000: LD1H  { <Zt1>.H-<Zt2>.H }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1h_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1h_mz_p_bi_2
        IEM_INSTR_IMPL_A64__ld1h_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a040a000: LD1H  { <Zt1>.H-<Zt4>.H }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1h_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1h_mz_p_bi_4
        IEM_INSTR_IMPL_A64__ld1h_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0002000: LD1H  { <Zt1>.H-<Zt2>.H }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1h_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_mz_p_br_2
        IEM_INSTR_IMPL_A64__ld1h_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a000a000: LD1H  { <Zt1>.H-<Zt4>.H }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1h_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_mz_p_br_4
        IEM_INSTR_IMPL_A64__ld1h_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1402000: LD1H  { <Zt1>.H, <Zt2>.H }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1h_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1h_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__ld1h_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a140a000: LD1H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1h_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1h_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__ld1h_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1002000: LD1H  { <Zt1>.H, <Zt2>.H }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1h_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__ld1h_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a100a000: LD1H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1h_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__ld1h_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4a0c000: LD1H  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_ai_d
        IEM_INSTR_IMPL_A64__ld1h_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/84a0c000: LD1H  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_ai_s
        IEM_INSTR_IMPL_A64__ld1h_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4a0a000: LD1H  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bi_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bi_u16 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bi_u16
        IEM_INSTR_IMPL_A64__ld1h_z_p_bi_u16(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4c0a000: LD1H  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ld1h_z_p_bi_u32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4e0a000: LD1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1h_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4a04000: LD1H  { <Zt>.H }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_br_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1h_z_p_br_u16 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_br_u16
        IEM_INSTR_IMPL_A64__ld1h_z_p_br_u16(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4c04000: LD1H  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_br_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1h_z_p_br_u32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_br_u32
        IEM_INSTR_IMPL_A64__ld1h_z_p_br_u32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4e04000: LD1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_br_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1h_z_p_br_u64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_br_u64
        IEM_INSTR_IMPL_A64__ld1h_z_p_br_u64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4e0c000: LD1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #1]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x1 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ld1h_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4c0c000: LD1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ld1h_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4a04000: LD1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x1 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ld1h_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4804000: LD1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1h_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84a04000: LD1H  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_32b_gld_sv_a, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bz_s_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bz_s_x32_scaled
        IEM_INSTR_IMPL_A64__ld1h_z_p_bz_s_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84804000: LD1H  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x1 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1h_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1h_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1h_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e0400000: LD1H  { <ZAt><HV>.H[<Ws>, <offs>] }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #1}]
   Instruction Set: A64  Groups: mortlach_contig_load, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1h_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe0400000))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const ZAt        = (uOpcode >>  3) & 0x00000001;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ld1h_za_p_rrr off3=%u ZAt=%u Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, ZAt, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1h_za_p_rrr
            IEM_INSTR_IMPL_A64__ld1h_za_p_rrr(off3, ZAt, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(off3, ZAt, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c400a000: LD1Q  { <Zt>.Q }, <Pg>/Z, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gldq_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1q_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1q_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1q_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__ld1q_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e1c00000: LD1Q  { <ZAt><HV>.Q[<Ws>, <offs>] }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #4}]
   Instruction Set: A64  Groups: mortlach_contig_qload, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1q_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1c00000))
    {
        uint32_t const ZAt        = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ld1q_za_p_rrr ZAt=%#x Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAt, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1q_za_p_rrr
            IEM_INSTR_IMPL_A64__ld1q_za_p_rrr(ZAt, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(ZAt, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/8440a000: LD1RB  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rb_z_p_bi_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rb_z_p_bi_u16 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rb_z_p_bi_u16
        IEM_INSTR_IMPL_A64__ld1rb_z_p_bi_u16(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/8440c000: LD1RB  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rb_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rb_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rb_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ld1rb_z_p_bi_u32(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/8440e000: LD1RB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rb_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rb_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rb_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1rb_z_p_bi_u64(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/84408000: LD1RB  { <Zt>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rb_z_p_bi_u8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rb_z_p_bi_u8 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rb_z_p_bi_u8
        IEM_INSTR_IMPL_A64__ld1rb_z_p_bi_u8(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/85c0e000: LD1RD  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rd_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rd_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rd_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1rd_z_p_bi_u64(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/84c0a000: LD1RH  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rh_z_p_bi_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rh_z_p_bi_u16 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rh_z_p_bi_u16
        IEM_INSTR_IMPL_A64__ld1rh_z_p_bi_u16(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/84c0c000: LD1RH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rh_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rh_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rh_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ld1rh_z_p_bi_u32(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/84c0e000: LD1RH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rh_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rh_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rh_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1rh_z_p_bi_u64(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4202000: LD1ROB  { <Zt>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ldqr_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rob_z_p_bi_u8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4202000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
        {
            LogFlow(("%018x/%010x: ld1rob_z_p_bi_u8 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1rob_z_p_bi_u8
            IEM_INSTR_IMPL_A64__ld1rob_z_p_bi_u8(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4200000: LD1ROB  { <Zt>.B }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_ldqr_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rob_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: ld1rob_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1rob_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld1rob_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5a02000: LD1ROD  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ldqr_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rod_z_p_bi_u64, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5a02000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
        {
            LogFlow(("%018x/%010x: ld1rod_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1rod_z_p_bi_u64
            IEM_INSTR_IMPL_A64__ld1rod_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5a00000: LD1ROD  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_ldqr_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rod_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: ld1rod_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1rod_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld1rod_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4a02000: LD1ROH  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ldqr_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1roh_z_p_bi_u16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4a02000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
        {
            LogFlow(("%018x/%010x: ld1roh_z_p_bi_u16 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1roh_z_p_bi_u16
            IEM_INSTR_IMPL_A64__ld1roh_z_p_bi_u16(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4a00000: LD1ROH  { <Zt>.H }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_ldqr_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1roh_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: ld1roh_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1roh_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld1roh_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5202000: LD1ROW  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ldqr_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1row_z_p_bi_u32, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5202000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
        {
            LogFlow(("%018x/%010x: ld1row_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1row_z_p_bi_u32
            IEM_INSTR_IMPL_A64__ld1row_z_p_bi_u32(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5200000: LD1ROW  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_ldqr_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1row_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: ld1row_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1row_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld1row_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4002000: LD1RQB  { <Zt>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ldqr_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rqb_z_p_bi_u8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4002000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ld1rqb_z_p_bi_u8 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1rqb_z_p_bi_u8
            IEM_INSTR_IMPL_A64__ld1rqb_z_p_bi_u8(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4000000: LD1RQB  { <Zt>.B }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_ldqr_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rqb_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1rqb_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1rqb_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld1rqb_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5802000: LD1RQD  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ldqr_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rqd_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rqd_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1rqd_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1rqd_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5800000: LD1RQD  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_ldqr_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rqd_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1rqd_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1rqd_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld1rqd_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4802000: LD1RQH  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ldqr_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rqh_z_p_bi_u16, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4802000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ld1rqh_z_p_bi_u16 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1rqh_z_p_bi_u16
            IEM_INSTR_IMPL_A64__ld1rqh_z_p_bi_u16(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4800000: LD1RQH  { <Zt>.H }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_ldqr_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rqh_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1rqh_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1rqh_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld1rqh_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5002000: LD1RQW  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ldqr_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rqw_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rqw_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1rqw_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ld1rqw_z_p_bi_u32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5000000: LD1RQW  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_ldqr_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rqw_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1rqw_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1rqw_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld1rqw_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/85c0c000: LD1RSB  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rsb_z_p_bi_s16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rsb_z_p_bi_s16 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rsb_z_p_bi_s16
        IEM_INSTR_IMPL_A64__ld1rsb_z_p_bi_s16(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/85c0a000: LD1RSB  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rsb_z_p_bi_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rsb_z_p_bi_s32 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rsb_z_p_bi_s32
        IEM_INSTR_IMPL_A64__ld1rsb_z_p_bi_s32(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/85c08000: LD1RSB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rsb_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rsb_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rsb_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ld1rsb_z_p_bi_s64(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/8540a000: LD1RSH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rsh_z_p_bi_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rsh_z_p_bi_s32 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rsh_z_p_bi_s32
        IEM_INSTR_IMPL_A64__ld1rsh_z_p_bi_s32(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/85408000: LD1RSH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rsh_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rsh_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rsh_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ld1rsh_z_p_bi_s64(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/84c08000: LD1RSW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rsw_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rsw_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rsw_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ld1rsw_z_p_bi_s64(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/8540c000: LD1RW  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rw_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rw_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rw_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ld1rw_z_p_bi_u32(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/8540e000: LD1RW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_ld_dup, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1rw_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1rw_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__ld1rw_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1rw_z_p_bi_u64(Zt, Rn, Pg, imm6);
#else
        RT_NOREF(Zt, Rn, Pg, imm6, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4208000: LD1SB  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_ai_d
        IEM_INSTR_IMPL_A64__ld1sb_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/84208000: LD1SB  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_ai_s
        IEM_INSTR_IMPL_A64__ld1sb_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5c0a000: LD1SB  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_bi_s16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_bi_s16 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_bi_s16
        IEM_INSTR_IMPL_A64__ld1sb_z_p_bi_s16(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5a0a000: LD1SB  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_bi_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_bi_s32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_bi_s32
        IEM_INSTR_IMPL_A64__ld1sb_z_p_bi_s32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a580a000: LD1SB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ld1sb_z_p_bi_s64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5c04000: LD1SB  { <Zt>.H }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_br_s16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_br_s16 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_br_s16
        IEM_INSTR_IMPL_A64__ld1sb_z_p_br_s16(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5a04000: LD1SB  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_br_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_br_s32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_br_s32
        IEM_INSTR_IMPL_A64__ld1sb_z_p_br_s32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5804000: LD1SB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_br_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_br_s64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_br_s64
        IEM_INSTR_IMPL_A64__ld1sb_z_p_br_s64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4408000: LD1SB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ld1sb_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4000000: LD1SB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1sb_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84000000: LD1SB  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x0 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sb_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1sb_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1sb_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4a08000: LD1SH  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_ai_d
        IEM_INSTR_IMPL_A64__ld1sh_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/84a08000: LD1SH  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_ai_s
        IEM_INSTR_IMPL_A64__ld1sh_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a520a000: LD1SH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_bi_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_bi_s32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_bi_s32
        IEM_INSTR_IMPL_A64__ld1sh_z_p_bi_s32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a500a000: LD1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ld1sh_z_p_bi_s64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5204000: LD1SH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_br_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_br_s32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_br_s32
        IEM_INSTR_IMPL_A64__ld1sh_z_p_br_s32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5004000: LD1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_br_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_br_s64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_br_s64
        IEM_INSTR_IMPL_A64__ld1sh_z_p_br_s64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4e08000: LD1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #1]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x1 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4c08000: LD1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4a00000: LD1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x1 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4800000: LD1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0xc4800000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: ld1sh_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_d_x32_unscaled
            IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
            RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84a00000: LD1SH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_32b_gld_sv_a, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sh_z_p_bz_s_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_s_x32_scaled
        IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_s_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84800000: LD1SH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0x84800000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if ((0x1 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: ld1sh_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_s_x32_unscaled
            IEM_INSTR_IMPL_A64__ld1sh_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
            RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5208000: LD1SW  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sw_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sw_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1sw_z_p_ai_d
        IEM_INSTR_IMPL_A64__ld1sw_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a480a000: LD1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sw_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1sw_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1sw_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ld1sw_z_p_bi_s64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4804000: LD1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sw_z_p_br_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1sw_z_p_br_s64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1sw_z_p_br_s64
        IEM_INSTR_IMPL_A64__ld1sw_z_p_br_s64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5608000: LD1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #2]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sw_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x2 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sw_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1sw_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ld1sw_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5408000: LD1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sw_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1sw_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ld1sw_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5200000: LD1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x2 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sw_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1sw_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ld1sw_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5000000: LD1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1sw_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1sw_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1sw_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0404000: LD1W  { <Zt1>.S-<Zt2>.S }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1w_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1w_mz_p_bi_2
        IEM_INSTR_IMPL_A64__ld1w_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a040c000: LD1W  { <Zt1>.S-<Zt4>.S }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1w_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1w_mz_p_bi_4
        IEM_INSTR_IMPL_A64__ld1w_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0004000: LD1W  { <Zt1>.S-<Zt2>.S }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1w_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_mz_p_br_2
        IEM_INSTR_IMPL_A64__ld1w_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a000c000: LD1W  { <Zt1>.S-<Zt4>.S }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1w_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_mz_p_br_4
        IEM_INSTR_IMPL_A64__ld1w_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1404000: LD1W  { <Zt1>.S, <Zt2>.S }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1w_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1w_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__ld1w_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a140c000: LD1W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1w_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1w_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__ld1w_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1004000: LD1W  { <Zt1>.S, <Zt2>.S }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1w_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__ld1w_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a100c000: LD1W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ld1w_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__ld1w_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c520c000: LD1W  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_ai_d
        IEM_INSTR_IMPL_A64__ld1w_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/8520c000: LD1W  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_ai_s
        IEM_INSTR_IMPL_A64__ld1w_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5102000: LD1W  { <Zt>.Q }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si_q, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bi_u128, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bi_u128 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bi_u128
        IEM_INSTR_IMPL_A64__ld1w_z_p_bi_u128(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a540a000: LD1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ld1w_z_p_bi_u32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a560a000: LD1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ld1w_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5008000: LD1W  { <Zt>.Q }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_cld_ss_q, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_br_u128, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_br_u128 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_br_u128
        IEM_INSTR_IMPL_A64__ld1w_z_p_br_u128(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5404000: LD1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_br_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1w_z_p_br_u32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_br_u32
        IEM_INSTR_IMPL_A64__ld1w_z_p_br_u32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5604000: LD1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_cld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_br_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld1w_z_p_br_u64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_br_u64
        IEM_INSTR_IMPL_A64__ld1w_z_p_br_u64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c560c000: LD1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #2]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x2 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ld1w_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c540c000: LD1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ld1w_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5204000: LD1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x2 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ld1w_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5004000: LD1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1w_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/85204000: LD1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_32b_gld_sv_b, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bz_s_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bz_s_x32_scaled
        IEM_INSTR_IMPL_A64__ld1w_z_p_bz_s_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/85004000: LD1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x2 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ld1w_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ld1w_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ld1w_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e0800000: LD1W  { <ZAt><HV>.S[<Ws>, <offs>] }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #2}]
   Instruction Set: A64  Groups: mortlach_contig_load, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_ld1w_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe0800000))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const ZAt        = (uOpcode >>  2) & 0x00000003;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ld1w_za_p_rrr off2=%u ZAt=%u Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, ZAt, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld1w_za_p_rrr
            IEM_INSTR_IMPL_A64__ld1w_za_p_rrr(off2, ZAt, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(off2, ZAt, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a420e000: LD2B  { <Zt1>.B, <Zt2>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2b_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa420e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld2b_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld2b_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld2b_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a420c000: LD2B  { <Zt1>.B, <Zt2>.B }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2b_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld2b_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld2b_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld2b_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5a0e000: LD2D  { <Zt1>.D, <Zt2>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2d_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5a0e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld2d_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld2d_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld2d_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5a0c000: LD2D  { <Zt1>.D, <Zt2>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2d_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld2d_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld2d_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld2d_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4a0e000: LD2H  { <Zt1>.H, <Zt2>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2h_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4a0e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld2h_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld2h_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld2h_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4a0c000: LD2H  { <Zt1>.H, <Zt2>.H }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2h_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld2h_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld2h_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld2h_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a490e000: LD2Q  { <Zt1>.Q, <Zt2>.Q }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eldq_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2q_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: ld2q_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld2q_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__ld2q_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4a08000: LD2Q  { <Zt1>.Q, <Zt2>.Q }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #4]
   Instruction Set: A64  Groups: sve_mem_eldq_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2q_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/))
    {
        LogFlow(("%018x/%010x: ld2q_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld2q_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld2q_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a520e000: LD2W  { <Zt1>.S, <Zt2>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2w_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa520e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld2w_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld2w_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld2w_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a520c000: LD2W  { <Zt1>.S, <Zt2>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld2w_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld2w_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld2w_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld2w_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a440e000: LD3B  { <Zt1>.B, <Zt2>.B, <Zt3>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3b_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa440e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld3b_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld3b_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld3b_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a440c000: LD3B  { <Zt1>.B, <Zt2>.B, <Zt3>.B }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3b_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld3b_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld3b_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld3b_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5c0e000: LD3D  { <Zt1>.D, <Zt2>.D, <Zt3>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3d_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5c0e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld3d_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld3d_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld3d_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5c0c000: LD3D  { <Zt1>.D, <Zt2>.D, <Zt3>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3d_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld3d_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld3d_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld3d_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4c0e000: LD3H  { <Zt1>.H, <Zt2>.H, <Zt3>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3h_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4c0e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld3h_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld3h_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld3h_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4c0c000: LD3H  { <Zt1>.H, <Zt2>.H, <Zt3>.H }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3h_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld3h_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld3h_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld3h_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a510e000: LD3Q  { <Zt1>.Q, <Zt2>.Q, <Zt3>.Q }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eldq_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3q_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: ld3q_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld3q_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__ld3q_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5208000: LD3Q  { <Zt1>.Q, <Zt2>.Q, <Zt3>.Q }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #4]
   Instruction Set: A64  Groups: sve_mem_eldq_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3q_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/))
    {
        LogFlow(("%018x/%010x: ld3q_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld3q_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld3q_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a540e000: LD3W  { <Zt1>.S, <Zt2>.S, <Zt3>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3w_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa540e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld3w_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld3w_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld3w_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a540c000: LD3W  { <Zt1>.S, <Zt2>.S, <Zt3>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld3w_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld3w_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld3w_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld3w_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a460e000: LD4B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4b_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa460e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld4b_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld4b_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld4b_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a460c000: LD4B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4b_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld4b_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld4b_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld4b_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5e0e000: LD4D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4d_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5e0e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld4d_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld4d_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld4d_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5e0c000: LD4D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4d_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld4d_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld4d_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld4d_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4e0e000: LD4H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4h_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4e0e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld4h_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld4h_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld4h_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4e0c000: LD4H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4h_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld4h_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld4h_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld4h_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a590e000: LD4Q  { <Zt1>.Q, <Zt2>.Q, <Zt3>.Q, <Zt4>.Q }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eldq_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4q_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: ld4q_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld4q_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__ld4q_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5a08000: LD4Q  { <Zt1>.Q, <Zt2>.Q, <Zt3>.Q, <Zt4>.Q }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #4]
   Instruction Set: A64  Groups: sve_mem_eldq_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4q_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/))
    {
        LogFlow(("%018x/%010x: ld4q_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld4q_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld4q_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a560e000: LD4W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_eld_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4w_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa560e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: ld4w_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ld4w_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ld4w_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a560c000: LD4W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_eld_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ld4w_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ld4w_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ld4w_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ld4w_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c420e000: LDFF1B  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_ai_d
        IEM_INSTR_IMPL_A64__ldff1b_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/8420e000: LDFF1B  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_ai_s
        IEM_INSTR_IMPL_A64__ldff1b_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4206000: LDFF1B  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_br_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_br_u16 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_br_u16
        IEM_INSTR_IMPL_A64__ldff1b_z_p_br_u16(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4406000: LDFF1B  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_br_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_br_u32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_br_u32
        IEM_INSTR_IMPL_A64__ldff1b_z_p_br_u32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4606000: LDFF1B  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_br_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_br_u64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_br_u64
        IEM_INSTR_IMPL_A64__ldff1b_z_p_br_u64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4006000: LDFF1B  { <Zt>.B }, <Pg>/Z, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_br_u8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_br_u8 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_br_u8
        IEM_INSTR_IMPL_A64__ldff1b_z_p_br_u8(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c440e000: LDFF1B  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldff1b_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4006000: LDFF1B  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1b_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84006000: LDFF1B  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x0 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1b_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1b_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1b_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5a0e000: LDFF1D  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1d_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1d_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1d_z_p_ai_d
        IEM_INSTR_IMPL_A64__ldff1d_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5e06000: LDFF1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #3}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1d_z_p_br_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1d_z_p_br_u64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1d_z_p_br_u64
        IEM_INSTR_IMPL_A64__ldff1d_z_p_br_u64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5e0e000: LDFF1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #3]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1d_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x3 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1d_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1d_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ldff1d_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5c0e000: LDFF1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1d_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1d_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldff1d_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5a06000: LDFF1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #3]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x3 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1d_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1d_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ldff1d_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5806000: LDFF1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1d_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1d_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1d_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4a0e000: LDFF1H  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_ai_d
        IEM_INSTR_IMPL_A64__ldff1h_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/84a0e000: LDFF1H  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_ai_s
        IEM_INSTR_IMPL_A64__ldff1h_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4a06000: LDFF1H  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #1}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_br_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_br_u16 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_br_u16
        IEM_INSTR_IMPL_A64__ldff1h_z_p_br_u16(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4c06000: LDFF1H  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #1}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_br_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_br_u32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_br_u32
        IEM_INSTR_IMPL_A64__ldff1h_z_p_br_u32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4e06000: LDFF1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #1}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_br_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_br_u64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_br_u64
        IEM_INSTR_IMPL_A64__ldff1h_z_p_br_u64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4e0e000: LDFF1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #1]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x1 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4c0e000: LDFF1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4a06000: LDFF1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x1 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4806000: LDFF1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84a06000: LDFF1H  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_32b_gld_sv_a, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_bz_s_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_s_x32_scaled
        IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_s_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84806000: LDFF1H  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x1 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1h_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1h_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c420a000: LDFF1SB  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sb_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sb_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1sb_z_p_ai_d
        IEM_INSTR_IMPL_A64__ldff1sb_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/8420a000: LDFF1SB  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sb_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sb_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1sb_z_p_ai_s
        IEM_INSTR_IMPL_A64__ldff1sb_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5c06000: LDFF1SB  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sb_z_p_br_s16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sb_z_p_br_s16 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sb_z_p_br_s16
        IEM_INSTR_IMPL_A64__ldff1sb_z_p_br_s16(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5a06000: LDFF1SB  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sb_z_p_br_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sb_z_p_br_s32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sb_z_p_br_s32
        IEM_INSTR_IMPL_A64__ldff1sb_z_p_br_s32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5806000: LDFF1SB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sb_z_p_br_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sb_z_p_br_s64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sb_z_p_br_s64
        IEM_INSTR_IMPL_A64__ldff1sb_z_p_br_s64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c440a000: LDFF1SB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sb_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sb_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sb_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldff1sb_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4002000: LDFF1SB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sb_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1sb_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1sb_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84002000: LDFF1SB  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x0 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sb_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1sb_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1sb_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4a0a000: LDFF1SH  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_ai_d
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/84a0a000: LDFF1SH  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_ai_s
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5206000: LDFF1SH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #1}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_br_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_br_s32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_br_s32
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_br_s32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5006000: LDFF1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #1}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_br_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_br_s64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_br_s64
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_br_s64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4e0a000: LDFF1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #1]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x1 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4c0a000: LDFF1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4a02000: LDFF1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x1 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c4802000: LDFF1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84a02000: LDFF1SH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_32b_gld_sv_a, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_bz_s_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_s_x32_scaled
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_s_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/84802000: LDFF1SH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x1 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sh_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1sh_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c520a000: LDFF1SW  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sw_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sw_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1sw_z_p_ai_d
        IEM_INSTR_IMPL_A64__ldff1sw_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a4806000: LDFF1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #2}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sw_z_p_br_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sw_z_p_br_s64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sw_z_p_br_s64
        IEM_INSTR_IMPL_A64__ldff1sw_z_p_br_s64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c560a000: LDFF1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #2]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sw_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x2 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sw_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sw_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ldff1sw_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c540a000: LDFF1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sw_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1sw_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldff1sw_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5202000: LDFF1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x2 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sw_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1sw_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ldff1sw_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5002000: LDFF1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1sw_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1sw_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1sw_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c520e000: LDFF1W  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_ai_d
        IEM_INSTR_IMPL_A64__ldff1w_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/8520e000: LDFF1W  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_ai_s
        IEM_INSTR_IMPL_A64__ldff1w_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5406000: LDFF1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #2}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_br_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_br_u32 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_br_u32
        IEM_INSTR_IMPL_A64__ldff1w_z_p_br_u32(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a5606000: LDFF1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, <Xm>, LSL #2}]
   Instruction Set: A64  Groups: sve_mem_cldff_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_br_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_br_u64 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_br_u64
        IEM_INSTR_IMPL_A64__ldff1w_z_p_br_u64(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c560e000: LDFF1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, LSL #2]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((0x2 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c540e000: LDFF1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5206000: LDFF1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_64b_gld_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x2 /*opc@23*/ != 0) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_d_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/c5006000: LDFF1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_gld_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/85206000: LDFF1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_32b_gld_sv_b, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_bz_s_x32_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_s_x32_scaled
        IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_s_x32_scaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e000/85006000: LDFF1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_gld_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
    if ((0x2 /*opc@23*/ != 3) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldff1w_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ldff1w_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, Zm, xs);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, xs, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a430a000: LDNF1B  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1b_z_p_bi_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1b_z_p_bi_u16 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1b_z_p_bi_u16
        IEM_INSTR_IMPL_A64__ldnf1b_z_p_bi_u16(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a450a000: LDNF1B  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1b_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1b_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1b_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ldnf1b_z_p_bi_u32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a470a000: LDNF1B  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1b_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1b_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1b_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ldnf1b_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a410a000: LDNF1B  { <Zt>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1b_z_p_bi_u8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1b_z_p_bi_u8 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1b_z_p_bi_u8
        IEM_INSTR_IMPL_A64__ldnf1b_z_p_bi_u8(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5f0a000: LDNF1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1d_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1d_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1d_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ldnf1d_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4b0a000: LDNF1H  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1h_z_p_bi_u16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1h_z_p_bi_u16 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1h_z_p_bi_u16
        IEM_INSTR_IMPL_A64__ldnf1h_z_p_bi_u16(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4d0a000: LDNF1H  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1h_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1h_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1h_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ldnf1h_z_p_bi_u32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a4f0a000: LDNF1H  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1h_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1h_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1h_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ldnf1h_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5d0a000: LDNF1SB  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1sb_z_p_bi_s16, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1sb_z_p_bi_s16 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1sb_z_p_bi_s16
        IEM_INSTR_IMPL_A64__ldnf1sb_z_p_bi_s16(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a5b0a000: LDNF1SB  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1sb_z_p_bi_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1sb_z_p_bi_s32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1sb_z_p_bi_s32
        IEM_INSTR_IMPL_A64__ldnf1sb_z_p_bi_s32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a590a000: LDNF1SB  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1sb_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1sb_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1sb_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ldnf1sb_z_p_bi_s64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a530a000: LDNF1SH  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1sh_z_p_bi_s32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1sh_z_p_bi_s32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1sh_z_p_bi_s32
        IEM_INSTR_IMPL_A64__ldnf1sh_z_p_bi_s32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a510a000: LDNF1SH  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1sh_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1sh_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1sh_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ldnf1sh_z_p_bi_s64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a490a000: LDNF1SW  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1sw_z_p_bi_s64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1sw_z_p_bi_s64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1sw_z_p_bi_s64
        IEM_INSTR_IMPL_A64__ldnf1sw_z_p_bi_s64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a550a000: LDNF1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1w_z_p_bi_u32, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1w_z_p_bi_u32 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1w_z_p_bi_u32
        IEM_INSTR_IMPL_A64__ldnf1w_z_p_bi_u32(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a570a000: LDNF1W  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnf_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnf1w_z_p_bi_u64, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: ldnf1w_z_p_bi_u64 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnf1w_z_p_bi_u64
        IEM_INSTR_IMPL_A64__ldnf1w_z_p_bi_u64(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0400001: LDNT1B  { <Zt1>.B-<Zt2>.B }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_mz_p_bi_2
        IEM_INSTR_IMPL_A64__ldnt1b_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a0408001: LDNT1B  { <Zt1>.B-<Zt4>.B }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_mz_p_bi_4
        IEM_INSTR_IMPL_A64__ldnt1b_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0000001: LDNT1B  { <Zt1>.B-<Zt2>.B }, <PNg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_mz_p_br_2
        IEM_INSTR_IMPL_A64__ldnt1b_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a0008001: LDNT1B  { <Zt1>.B-<Zt4>.B }, <PNg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_mz_p_br_4
        IEM_INSTR_IMPL_A64__ldnt1b_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1400008: LDNT1B  { <Zt1>.B, <Zt2>.B }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__ldnt1b_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a1408008: LDNT1B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__ldnt1b_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1000008: LDNT1B  { <Zt1>.B, <Zt2>.B }, <PNg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__ldnt1b_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a1008008: LDNT1B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <PNg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__ldnt1b_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c400c000: LDNT1B  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gldnt_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldnt1b_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/8400a000: LDNT1B  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gldnt_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_z_p_ar_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1b_z_p_ar_s_x32_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_z_p_ar_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ldnt1b_z_p_ar_s_x32_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a400e000: LDNT1B  { <Zt>.B }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnt_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa400e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ldnt1b_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__ldnt1b_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a400c000: LDNT1B  { <Zt>.B }, <Pg>/Z, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cldnt_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1b_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ldnt1b_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1b_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ldnt1b_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0406001: LDNT1D  { <Zt1>.D-<Zt2>.D }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_mz_p_bi_2
        IEM_INSTR_IMPL_A64__ldnt1d_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a040e001: LDNT1D  { <Zt1>.D-<Zt4>.D }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_mz_p_bi_4
        IEM_INSTR_IMPL_A64__ldnt1d_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0006001: LDNT1D  { <Zt1>.D-<Zt2>.D }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_mz_p_br_2
        IEM_INSTR_IMPL_A64__ldnt1d_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a000e001: LDNT1D  { <Zt1>.D-<Zt4>.D }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_mz_p_br_4
        IEM_INSTR_IMPL_A64__ldnt1d_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1406008: LDNT1D  { <Zt1>.D, <Zt2>.D }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__ldnt1d_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a140e008: LDNT1D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__ldnt1d_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1006008: LDNT1D  { <Zt1>.D, <Zt2>.D }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__ldnt1d_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a100e008: LDNT1D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__ldnt1d_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c580c000: LDNT1D  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gldnt_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldnt1d_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a580e000: LDNT1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnt_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ldnt1d_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__ldnt1d_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a580c000: LDNT1D  { <Zt>.D }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_cldnt_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1d_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ldnt1d_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1d_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ldnt1d_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0402001: LDNT1H  { <Zt1>.H-<Zt2>.H }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_mz_p_bi_2
        IEM_INSTR_IMPL_A64__ldnt1h_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a040a001: LDNT1H  { <Zt1>.H-<Zt4>.H }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_mz_p_bi_4
        IEM_INSTR_IMPL_A64__ldnt1h_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0002001: LDNT1H  { <Zt1>.H-<Zt2>.H }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_mz_p_br_2
        IEM_INSTR_IMPL_A64__ldnt1h_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a000a001: LDNT1H  { <Zt1>.H-<Zt4>.H }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_mz_p_br_4
        IEM_INSTR_IMPL_A64__ldnt1h_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1402008: LDNT1H  { <Zt1>.H, <Zt2>.H }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__ldnt1h_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a140a008: LDNT1H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__ldnt1h_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1002008: LDNT1H  { <Zt1>.H, <Zt2>.H }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__ldnt1h_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a100a008: LDNT1H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__ldnt1h_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c480c000: LDNT1H  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gldnt_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldnt1h_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/8480a000: LDNT1H  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gldnt_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0x8480a000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
        {
            LogFlow(("%018x/%010x: ldnt1h_z_p_ar_s_x32_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_z_p_ar_s_x32_unscaled
            IEM_INSTR_IMPL_A64__ldnt1h_z_p_ar_s_x32_unscaled(Zt, Zn, Pg, Rm);
#else
            RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a480e000: LDNT1H  { <Zt>.H }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnt_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ldnt1h_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__ldnt1h_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a480c000: LDNT1H  { <Zt>.H }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_cldnt_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1h_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ldnt1h_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1h_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ldnt1h_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4008000: LDNT1SB  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gldnt_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1sb_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1sb_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1sb_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldnt1sb_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/84008000: LDNT1SB  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gldnt_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1sb_z_p_ar_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1sb_z_p_ar_s_x32_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1sb_z_p_ar_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ldnt1sb_z_p_ar_s_x32_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c4808000: LDNT1SH  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gldnt_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1sh_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1sh_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1sh_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldnt1sh_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/84808000: LDNT1SH  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gldnt_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0x84808000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
        {
            LogFlow(("%018x/%010x: ldnt1sh_z_p_ar_s_x32_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1sh_z_p_ar_s_x32_unscaled
            IEM_INSTR_IMPL_A64__ldnt1sh_z_p_ar_s_x32_unscaled(Zt, Zn, Pg, Rm);
#else
            RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c5008000: LDNT1SW  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gldnt_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1sw_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1sw_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldnt1sw_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0404001: LDNT1W  { <Zt1>.S-<Zt2>.S }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_mz_p_bi_2
        IEM_INSTR_IMPL_A64__ldnt1w_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a040c001: LDNT1W  { <Zt1>.S-<Zt4>.S }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_mz_p_bi_4
        IEM_INSTR_IMPL_A64__ldnt1w_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0004001: LDNT1W  { <Zt1>.S-<Zt2>.S }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_mz_p_br_2
        IEM_INSTR_IMPL_A64__ldnt1w_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a000c001: LDNT1W  { <Zt1>.S-<Zt4>.S }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_mz_p_br_4
        IEM_INSTR_IMPL_A64__ldnt1w_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1404008: LDNT1W  { <Zt1>.S, <Zt2>.S }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__ldnt1w_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a140c008: LDNT1W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <PNg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__ldnt1w_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1004008: LDNT1W  { <Zt1>.S, <Zt2>.S }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi2_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__ldnt1w_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a100c008: LDNT1W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <PNg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi4_cld_cldnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__ldnt1w_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/c500c000: LDNT1W  { <Zt>.D }, <Pg>/Z, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_64b_gldnt_vs, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__ldnt1w_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/8500a000: LDNT1W  { <Zt>.S }, <Pg>/Z, [<Zn>.S{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_32b_gldnt_vs, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_z_p_ar_s_x32_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_z_p_ar_s_x32_unscaled
        IEM_INSTR_IMPL_A64__ldnt1w_z_p_ar_s_x32_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/a500e000: LDNT1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cldnt_si, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ldnt1w_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__ldnt1w_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/a500c000: LDNT1W  { <Zt>.S }, <Pg>/Z, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_cldnt_ss, sve_memcld, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldnt1w_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: ldnt1w_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__ldnt1w_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__ldnt1w_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e010/85800000: LDR  <Pt>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_32b_pfill, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldr_p_bi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e010)) == UINT32_C(0x85800000))
    {
        uint32_t const Pt         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm9l      = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm9h      = (uOpcode >> 16) & 0x0000003f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ldr_p_bi Pt=%#x Rn=%#x imm9l=%u imm9h=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pt, Rn, imm9l, imm9h));
#ifdef IEM_INSTR_IMPL_A64__ldr_p_bi
            IEM_INSTR_IMPL_A64__ldr_p_bi(Pt, Rn, imm9l, imm9h);
#else
            RT_NOREF(Pt, Rn, imm9l, imm9h, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/85804000: LDR  <Zt>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_32b_fill, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_ldr_z_bi, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9l      = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm9h      = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ldr_z_bi Zt=%#x Rn=%#x imm9l=%u imm9h=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, imm9l, imm9h));
#ifdef IEM_INSTR_IMPL_A64__ldr_z_bi
        IEM_INSTR_IMPL_A64__ldr_z_bi(Zt, Rn, imm9l, imm9h);
#else
        RT_NOREF(Zt, Rn, imm9l, imm9h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c10/e1000000: LDR  ZA[<Wv>, <offs>], [<Xn|SP>{, #<offs>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_ctxt_ldst, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldr_za_ri, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c10)) == UINT32_C(0xe1000000))
    {
        uint32_t const off4       = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ldr_za_ri off4=%#x Rn=%#x Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off4, Rn, Rv));
#ifdef IEM_INSTR_IMPL_A64__ldr_za_ri
            IEM_INSTR_IMPL_A64__ldr_za_ri(off4, Rn, Rv);
#else
            RT_NOREF(off4, Rn, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/e11f8000: LDR  ZT0, [<Xn|SP>]
   Instruction Set: A64  Groups: mortlach_zt_ldst, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_ldr_zt_br, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xe11f8000))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: ldr_zt_br Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__ldr_zt_br
            IEM_INSTR_IMPL_A64__ldr_zt_br(Rn);
#else
            RT_NOREF(Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04038000: LSL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsl_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsl_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__lsl_z_p_zi
        IEM_INSTR_IMPL_A64__lsl_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041b8000: LSL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_2, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsl_z_p_zw, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsl_z_p_zw Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lsl_z_p_zw
        IEM_INSTR_IMPL_A64__lsl_z_p_zw(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04138000: LSL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_1, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsl_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsl_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lsl_z_p_zz
        IEM_INSTR_IMPL_A64__lsl_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04209c00: LSL  <Zd>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_cons_shift_b, sve_int_unpred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsl_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsl_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__lsl_z_zi
        IEM_INSTR_IMPL_A64__lsl_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04208c00: LSL  <Zd>.<T>, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_shift_a, sve_int_unpred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsl_z_zw, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsl_z_zw Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__lsl_z_zw
        IEM_INSTR_IMPL_A64__lsl_z_zw(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04178000: LSLR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_1, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lslr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lslr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lslr_z_p_zz
        IEM_INSTR_IMPL_A64__lslr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04018000: LSR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsr_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsr_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__lsr_z_p_zi
        IEM_INSTR_IMPL_A64__lsr_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04198000: LSR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_2, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsr_z_p_zw, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsr_z_p_zw Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lsr_z_p_zw
        IEM_INSTR_IMPL_A64__lsr_z_p_zw(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04118000: LSR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_1, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lsr_z_p_zz
        IEM_INSTR_IMPL_A64__lsr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04209400: LSR  <Zd>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_cons_shift_b, sve_int_unpred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsr_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsr_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__lsr_z_zi
        IEM_INSTR_IMPL_A64__lsr_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04208400: LSR  <Zd>.<T>, <Zn>.<T>, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_shift_a, sve_int_unpred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsr_z_zw, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsr_z_zw Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__lsr_z_zw
        IEM_INSTR_IMPL_A64__lsr_z_zw(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04158000: LSRR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_1, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_lsrr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: lsrr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__lsrr_z_p_zz
        IEM_INSTR_IMPL_A64__lsrr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc4c01/c08c4000: LUTI2  { <Zd1>.<T>-<Zd2>.<T> }, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_2dst_ctg, mortlach_zt_expand_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti2_mz2_ztz_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc4c01)) == UINT32_C(0xc08c4000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i3         = (uOpcode >> 15) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: luti2_mz2_ztz_1 Zd=%#x Zn=%#x size=%u i3=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size, i3));
#ifdef IEM_INSTR_IMPL_A64__luti2_mz2_ztz_1
            IEM_INSTR_IMPL_A64__luti2_mz2_ztz_1(Zd, Zn, size, i3);
#else
            RT_NOREF(Zd, Zn, size, i3, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc4c08/c09c4000: LUTI2  { <Zd1>.<T>, <Zd2>.<T> }, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_2dst_nctg, mortlach_zt_expand_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti2_mz2_ztz_8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc4c08)) == UINT32_C(0xc09c4000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x00000007;
        uint32_t const D          = (uOpcode >>  4) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i3         = (uOpcode >> 15) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: luti2_mz2_ztz_8 Zd=%u D=%u Zn=%#x size=%u i3=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, D, Zn, size, i3));
#ifdef IEM_INSTR_IMPL_A64__luti2_mz2_ztz_8
            IEM_INSTR_IMPL_A64__luti2_mz2_ztz_8(Zd, D, Zn, size, i3);
#else
            RT_NOREF(Zd, D, Zn, size, i3, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffccc03/c08c8000: LUTI2  { <Zd1>.<T>-<Zd4>.<T> }, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_4dst_ctg, mortlach_zt_expand_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti2_mz4_ztz_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffccc03)) == UINT32_C(0xc08c8000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i2         = (uOpcode >> 16) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: luti2_mz4_ztz_1 Zd=%u Zn=%#x size=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size, i2));
#ifdef IEM_INSTR_IMPL_A64__luti2_mz4_ztz_1
            IEM_INSTR_IMPL_A64__luti2_mz4_ztz_1(Zd, Zn, size, i2);
#else
            RT_NOREF(Zd, Zn, size, i2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffccc0c/c09c8000: LUTI2  { <Zd1>.<T>, <Zd2>.<T>, <Zd3>.<T>, <Zd4>.<T> }, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_4dst_nctg, mortlach_zt_expand_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti2_mz4_ztz_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffccc0c)) == UINT32_C(0xc09c8000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x00000003;
        uint32_t const D          = (uOpcode >>  4) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i2         = (uOpcode >> 16) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: luti2_mz4_ztz_4 Zd=%u D=%u Zn=%#x size=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, D, Zn, size, i2));
#ifdef IEM_INSTR_IMPL_A64__luti2_mz4_ztz_4
            IEM_INSTR_IMPL_A64__luti2_mz4_ztz_4(Zd, D, Zn, size, i2);
#else
            RT_NOREF(Zd, D, Zn, size, i2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0c00/c0cc0000: LUTI2  <Zd>.<T>, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_1dst, mortlach_zt_expand_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti2_z_ztz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0c00)) == UINT32_C(0xc0cc0000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i4         = (uOpcode >> 14) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: luti2_z_ztz Zd=%#x Zn=%#x size=%u i4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size, i4));
#ifdef IEM_INSTR_IMPL_A64__luti2_z_ztz
            IEM_INSTR_IMPL_A64__luti2_z_ztz(Zd, Zn, size, i4);
#else
            RT_NOREF(Zd, Zn, size, i4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec00/4520a800: LUTI2  <Zd>.H, { <Zn>.H }, <Zm>[<index>]
   Instruction Set: A64  Groups: sve_intx_lut2_16, sve_intx_histseg_lut, sve */
FNIEMOP_DEF_1(iemDecodeA64_luti2_z_zz_16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
    {
        LogFlow(("%018x/%010x: luti2_z_zz_16 Zd=%#x Zn=%#x i3l=%u Zm=%#x i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__luti2_z_zz_16
        IEM_INSTR_IMPL_A64__luti2_z_zz_16(Zd, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zd, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4520b000: LUTI2  <Zd>.B, { <Zn>.B }, <Zm>[<index>]
   Instruction Set: A64  Groups: sve_intx_lut2_8, sve_intx_histseg_lut, sve */
FNIEMOP_DEF_1(iemDecodeA64_luti2_z_zz_8, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
    {
        LogFlow(("%018x/%010x: luti2_z_zz_8 Zd=%#x Zn=%#x Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__luti2_z_zz_8
        IEM_INSTR_IMPL_A64__luti2_z_zz_8(Zd, Zn, Zm, i2);
#else
        RT_NOREF(Zd, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffe4c01/c08a4000: LUTI4  { <Zd1>.<T>-<Zd2>.<T> }, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_2dst_ctg, mortlach_zt_expand_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti4_mz2_ztz_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffe4c01)) == UINT32_C(0xc08a4000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i2         = (uOpcode >> 15) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: luti4_mz2_ztz_1 Zd=%#x Zn=%#x size=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size, i2));
#ifdef IEM_INSTR_IMPL_A64__luti4_mz2_ztz_1
            IEM_INSTR_IMPL_A64__luti4_mz2_ztz_1(Zd, Zn, size, i2);
#else
            RT_NOREF(Zd, Zn, size, i2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffe4c08/c09a4000: LUTI4  { <Zd1>.<T>, <Zd2>.<T> }, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_2dst_nctg, mortlach_zt_expand_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti4_mz2_ztz_8, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffe4c08)) == UINT32_C(0xc09a4000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x00000007;
        uint32_t const D          = (uOpcode >>  4) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i2         = (uOpcode >> 15) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: luti4_mz2_ztz_8 Zd=%u D=%u Zn=%#x size=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, D, Zn, size, i2));
#ifdef IEM_INSTR_IMPL_A64__luti4_mz2_ztz_8
            IEM_INSTR_IMPL_A64__luti4_mz2_ztz_8(Zd, D, Zn, size, i2);
#else
            RT_NOREF(Zd, D, Zn, size, i2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffcc23/c08b0000: LUTI4  { <Zd1>.B-<Zd4>.B }, ZT0, { <Zn1>-<Zn2> }
   Instruction Set: A64  Groups: mortlach_expand_4dst2src_ctg, mortlach_zt_expand_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti4_mz4_ztmz2_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffcc23)) == UINT32_C(0xc08b0000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeLutv2 /*FEAT_SME_LUTv2*/)
        {
            LogFlow(("%018x/%010x: luti4_mz4_ztmz2_1 Zd=%u Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__luti4_mz4_ztmz2_1
            IEM_INSTR_IMPL_A64__luti4_mz4_ztmz2_1(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffcc2c/c09b0000: LUTI4  { <Zd1>.B, <Zd2>.B, <Zd3>.B, <Zd4>.B }, ZT0, { <Zn1>-<Zn2> }
   Instruction Set: A64  Groups: mortlach_expand_4dst2src_nctg, mortlach_zt_expand_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti4_mz4_ztmz2_4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x00000003;
    uint32_t const D          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 12) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeLutv2 /*FEAT_SME_LUTv2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: luti4_mz4_ztmz2_4 Zd=%u D=%u Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, D, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__luti4_mz4_ztmz2_4
        IEM_INSTR_IMPL_A64__luti4_mz4_ztmz2_4(Zd, D, Zn, size);
#else
        RT_NOREF(Zd, D, Zn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffecc03/c08a8000: LUTI4  { <Zd1>.<T>-<Zd4>.<T> }, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_4dst_ctg, mortlach_zt_expand_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti4_mz4_ztz_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffecc03)) == UINT32_C(0xc08a8000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i1         = (uOpcode >> 16) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: luti4_mz4_ztz_1 Zd=%u Zn=%#x size=%u i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size, i1));
#ifdef IEM_INSTR_IMPL_A64__luti4_mz4_ztz_1
            IEM_INSTR_IMPL_A64__luti4_mz4_ztz_1(Zd, Zn, size, i1);
#else
            RT_NOREF(Zd, Zn, size, i1, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffecc0c/c09a8000: LUTI4  { <Zd1>.H, <Zd2>.H, <Zd3>.H, <Zd4>.H }, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_4dst_nctg, mortlach_zt_expand_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti4_mz4_ztz_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffecc0c)) == UINT32_C(0xc09a8000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x00000003;
        uint32_t const D          = (uOpcode >>  4) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i1         = (uOpcode >> 16) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: luti4_mz4_ztz_4 Zd=%u D=%u Zn=%#x size=%u i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, D, Zn, size, i1));
#ifdef IEM_INSTR_IMPL_A64__luti4_mz4_ztz_4
            IEM_INSTR_IMPL_A64__luti4_mz4_ztz_4(Zd, D, Zn, size, i1);
#else
            RT_NOREF(Zd, D, Zn, size, i1, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffe0c00/c0ca0000: LUTI4  <Zd>.<T>, ZT0, <Zn>[<index>]
   Instruction Set: A64  Groups: mortlach_expand_1dst, mortlach_zt_expand_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_luti4_z_ztz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffe0c00)) == UINT32_C(0xc0ca0000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 12) & 0x00000003;
        uint32_t const i3         = (uOpcode >> 14) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: luti4_z_ztz Zd=%#x Zn=%#x size=%u i3=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size, i3));
#ifdef IEM_INSTR_IMPL_A64__luti4_z_ztz
            IEM_INSTR_IMPL_A64__luti4_z_ztz(Zd, Zn, size, i3);
#else
            RT_NOREF(Zd, Zn, size, i3, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4520bc00: LUTI4  <Zd>.H, { <Zn>.H }, <Zm>[<index>]
   Instruction Set: A64  Groups: sve_intx_lut4_16, sve_intx_histseg_lut, sve */
FNIEMOP_DEF_1(iemDecodeA64_luti4_z_zz_1x16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
    {
        LogFlow(("%018x/%010x: luti4_z_zz_1x16 Zd=%#x Zn=%#x Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__luti4_z_zz_1x16
        IEM_INSTR_IMPL_A64__luti4_z_zz_1x16(Zd, Zn, Zm, i2);
#else
        RT_NOREF(Zd, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4520b400: LUTI4  <Zd>.H, { <Zn1>.H, <Zn2>.H }, <Zm>[<index>]
   Instruction Set: A64  Groups: sve_intx_lut4_16, sve_intx_histseg_lut, sve */
FNIEMOP_DEF_1(iemDecodeA64_luti4_z_zz_2x16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const i2         = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
    {
        LogFlow(("%018x/%010x: luti4_z_zz_2x16 Zd=%#x Zn=%#x Zm=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__luti4_z_zz_2x16
        IEM_INSTR_IMPL_A64__luti4_z_zz_2x16(Zd, Zn, Zm, i2);
#else
        RT_NOREF(Zd, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff60fc00/4560a400: LUTI4  <Zd>.B, { <Zn>.B }, <Zm>[<index>]
   Instruction Set: A64  Groups: sve_intx_lut4_8, sve_intx_histseg_lut, sve */
FNIEMOP_DEF_1(iemDecodeA64_luti4_z_zz_8, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const i1         = (uOpcode >> 23) & 0x00000001;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fLut /*FEAT_LUT*/)
    {
        LogFlow(("%018x/%010x: luti4_z_zz_8 Zd=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__luti4_z_zz_8
        IEM_INSTR_IMPL_A64__luti4_z_zz_8(Zd, Zn, Zm, i1);
#else
        RT_NOREF(Zd, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/0400c000: MAD  <Zdn>.<T>, <Pg>/M, <Zm>.<T>, <Za>.<T>
   Instruction Set: A64  Groups: sve_int_mladdsub_vvv_pred, sve_int_muladd_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_mad_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Za         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mad_z_p_zzz Zdn=%#x Za=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Za, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__mad_z_p_zzz
        IEM_INSTR_IMPL_A64__mad_z_p_zzz(Zdn, Za, Pg, Zm, size);
#else
        RT_NOREF(Zdn, Za, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44c0d800: MADPT  <Zdn>.D, <Zm>.D, <Za>.D
   Instruction Set: A64  Groups: sve_ptr_muladd_unpred_lvl2, sve_ptr_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_madpt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Za         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
    {
        LogFlow(("%018x/%010x: madpt_z_zzz Zdn=%#x Za=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Za, Zm));
#ifdef IEM_INSTR_IMPL_A64__madpt_z_zzz
        IEM_INSTR_IMPL_A64__madpt_z_zzz(Zdn, Za, Zm);
#else
        RT_NOREF(Zdn, Za, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/45208000: MATCH  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_match, sve_intx_string, sve */
FNIEMOP_DEF_1(iemDecodeA64_match_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: match_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__match_p_p_zz
        IEM_INSTR_IMPL_A64__match_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/04004000: MLA  <Zda>.<T>, <Pg>/M, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_mlas_vvv_pred, sve_int_muladd_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_mla_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mla_z_p_zzz Zda=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__mla_z_p_zzz
        IEM_INSTR_IMPL_A64__mla_z_p_zzz(Zda, Zn, Pg, Zm, size);
#else
        RT_NOREF(Zda, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e00800: MLA  <Zda>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mla_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mla_z_zzzi_d Zda=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__mla_z_zzzi_d
        IEM_INSTR_IMPL_A64__mla_z_zzzi_d(Zda, Zn, Zm, i1);
#else
        RT_NOREF(Zda, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/44200800: MLA  <Zda>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mla_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mla_z_zzzi_h Zda=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__mla_z_zzzi_h
        IEM_INSTR_IMPL_A64__mla_z_zzzi_h(Zda, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zda, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a00800: MLA  <Zda>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mla_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mla_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__mla_z_zzzi_s
        IEM_INSTR_IMPL_A64__mla_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44c0d000: MLAPT  <Zda>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_ptr_muladd_unpred_lvl2, sve_ptr_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_mlapt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
    {
        LogFlow(("%018x/%010x: mlapt_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__mlapt_z_zzz
        IEM_INSTR_IMPL_A64__mlapt_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/04006000: MLS  <Zda>.<T>, <Pg>/M, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_mlas_vvv_pred, sve_int_muladd_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_mls_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mls_z_p_zzz Zda=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__mls_z_p_zzz
        IEM_INSTR_IMPL_A64__mls_z_p_zzz(Zda, Zn, Pg, Zm, size);
#else
        RT_NOREF(Zda, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e00c00: MLS  <Zda>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mls_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mls_z_zzzi_d Zda=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__mls_z_zzzi_d
        IEM_INSTR_IMPL_A64__mls_z_zzzi_d(Zda, Zn, Zm, i1);
#else
        RT_NOREF(Zda, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/44200c00: MLS  <Zda>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mls_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mls_z_zzzi_h Zda=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__mls_z_zzzi_h
        IEM_INSTR_IMPL_A64__mls_z_zzzi_h(Zda, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zda, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a00c00: MLS  <Zda>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mls_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mls_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__mls_z_zzzi_s
        IEM_INSTR_IMPL_A64__mls_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f01/c0060000: MOVA  { <Zd1>.B-<Zd2>.B }, ZA0<HV>.B[<Ws>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi2_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz2_za_b1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const off3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz2_za_b1 Zd=%#x off3=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off3, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_mz2_za_b1
        IEM_INSTR_IMPL_A64__mova_mz2_za_b1(Zd, off3, Rs, V);
#else
        RT_NOREF(Zd, off3, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f01/c0c60000: MOVA  { <Zd1>.D-<Zd2>.D }, <ZAn><HV>.D[<Ws>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi2_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz2_za_d1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const ZAn        = (uOpcode >>  5) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz2_za_d1 Zd=%#x ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_mz2_za_d1
        IEM_INSTR_IMPL_A64__mova_mz2_za_d1(Zd, ZAn, Rs, V);
#else
        RT_NOREF(Zd, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f01/c0460000: MOVA  { <Zd1>.H-<Zd2>.H }, <ZAn><HV>.H[<Ws>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi2_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz2_za_h1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0460000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const off2       = (uOpcode >>  5) & 0x00000003;
        uint32_t const ZAn        = (uOpcode >>  7) & 0x00000001;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: mova_mz2_za_h1 Zd=%#x off2=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off2, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_mz2_za_h1
            IEM_INSTR_IMPL_A64__mova_mz2_za_h1(Zd, off2, ZAn, Rs, V);
#else
            RT_NOREF(Zd, off2, ZAn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f01/c0860000: MOVA  { <Zd1>.S-<Zd2>.S }, <ZAn><HV>.S[<Ws>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi2_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz2_za_w1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const o1         = (uOpcode >>  5) & 0x00000001;
    uint32_t const ZAn        = (uOpcode >>  6) & 0x00000003;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz2_za_w1 Zd=%#x o1=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, o1, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_mz2_za_w1
        IEM_INSTR_IMPL_A64__mova_mz2_za_w1(Zd, o1, ZAn, Rs, V);
#else
        RT_NOREF(Zd, o1, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f83/c0060400: MOVA  { <Zd1>.B-<Zd4>.B }, ZA0<HV>.B[<Ws>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi4_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz4_za_b1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const off2       = (uOpcode >>  5) & 0x00000003;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz4_za_b1 Zd=%u off2=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off2, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_mz4_za_b1
        IEM_INSTR_IMPL_A64__mova_mz4_za_b1(Zd, off2, Rs, V);
#else
        RT_NOREF(Zd, off2, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f03/c0c60400: MOVA  { <Zd1>.D-<Zd4>.D }, <ZAn><HV>.D[<Ws>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi4_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz4_za_d1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const ZAn        = (uOpcode >>  5) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz4_za_d1 Zd=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_mz4_za_d1
        IEM_INSTR_IMPL_A64__mova_mz4_za_d1(Zd, ZAn, Rs, V);
#else
        RT_NOREF(Zd, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f83/c0460400: MOVA  { <Zd1>.H-<Zd4>.H }, <ZAn><HV>.H[<Ws>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi4_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz4_za_h1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const o1         = (uOpcode >>  5) & 0x00000001;
    uint32_t const ZAn        = (uOpcode >>  6) & 0x00000001;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz4_za_h1 Zd=%u o1=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, o1, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_mz4_za_h1
        IEM_INSTR_IMPL_A64__mova_mz4_za_h1(Zd, o1, ZAn, Rs, V);
#else
        RT_NOREF(Zd, o1, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f83/c0860400: MOVA  { <Zd1>.S-<Zd4>.S }, <ZAn><HV>.S[<Ws>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi4_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz4_za_w1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const ZAn        = (uOpcode >>  5) & 0x00000003;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz4_za_w1 Zd=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_mz4_za_w1
        IEM_INSTR_IMPL_A64__mova_mz4_za_w1(Zd, ZAn, Rs, V);
#else
        RT_NOREF(Zd, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9f01/c0060800: MOVA  { <Zd1>.D-<Zd2>.D }, ZA.D[<Wv>, <offs>{, VGx2}]
   Instruction Set: A64  Groups: mortlach_multi2_za_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz_za2_1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const off3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz_za2_1 Zd=%#x off3=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off3, Rv));
#ifdef IEM_INSTR_IMPL_A64__mova_mz_za2_1
        IEM_INSTR_IMPL_A64__mova_mz_za2_1(Zd, off3, Rv);
#else
        RT_NOREF(Zd, off3, Rv, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9f03/c0060c00: MOVA  { <Zd1>.D-<Zd4>.D }, ZA.D[<Wv>, <offs>{, VGx4}]
   Instruction Set: A64  Groups: mortlach_multi4_za_extract_ctg, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_mz_za4_1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const off3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_mz_za4_1 Zd=%u off3=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off3, Rv));
#ifdef IEM_INSTR_IMPL_A64__mova_mz_za4_1
        IEM_INSTR_IMPL_A64__mova_mz_za4_1(Zd, off3, Rv);
#else
        RT_NOREF(Zd, off3, Rv, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0200/c0020000: MOVA  <Zd>.B, <Pg>/M, ZA0<HV>.B[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_pred, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_z_p_rza_b, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const off4       = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mova_z_p_rza_b Zd=%#x off4=%#x Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off4, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_z_p_rza_b
        IEM_INSTR_IMPL_A64__mova_z_p_rza_b(Zd, off4, Pg, Rs, V);
#else
        RT_NOREF(Zd, off4, Pg, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0200/c0c20000: MOVA  <Zd>.D, <Pg>/M, <ZAn><HV>.D[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_pred, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_z_p_rza_d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c20000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const o1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const ZAn        = (uOpcode >>  6) & 0x00000007;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: mova_z_p_rza_d Zd=%#x o1=%u ZAn=%u Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, o1, ZAn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_z_p_rza_d
            IEM_INSTR_IMPL_A64__mova_z_p_rza_d(Zd, o1, ZAn, Pg, Rs, V);
#else
            RT_NOREF(Zd, o1, ZAn, Pg, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0200/c0420000: MOVA  <Zd>.H, <Pg>/M, <ZAn><HV>.H[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_pred, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_z_p_rza_h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const off3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const ZAn        = (uOpcode >>  8) & 0x00000001;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mova_z_p_rza_h Zd=%#x off3=%u ZAn=%u Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off3, ZAn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_z_p_rza_h
        IEM_INSTR_IMPL_A64__mova_z_p_rza_h(Zd, off3, ZAn, Pg, Rs, V);
#else
        RT_NOREF(Zd, off3, ZAn, Pg, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0200/c0c30000: MOVA  <Zd>.Q, <Pg>/M, <ZAn><HV>.Q[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_pred, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_z_p_rza_q, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c30000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const ZAn        = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: mova_z_p_rza_q Zd=%#x ZAn=%#x Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, ZAn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_z_p_rza_q
            IEM_INSTR_IMPL_A64__mova_z_p_rza_q(Zd, ZAn, Pg, Rs, V);
#else
            RT_NOREF(Zd, ZAn, Pg, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0200/c0820000: MOVA  <Zd>.S, <Pg>/M, <ZAn><HV>.S[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_pred, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_z_p_rza_w, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const off2       = (uOpcode >>  5) & 0x00000003;
    uint32_t const ZAn        = (uOpcode >>  7) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mova_z_p_rza_w Zd=%#x off2=%u ZAn=%u Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off2, ZAn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_z_p_rza_w
        IEM_INSTR_IMPL_A64__mova_z_p_rza_w(Zd, off2, ZAn, Pg, Rs, V);
#else
        RT_NOREF(Zd, off2, ZAn, Pg, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1c38/c0040000: MOVA  ZA0<HV>.B[<Ws>, <offs1>:<offs2>], { <Zn1>.B-<Zn2>.B }
   Instruction Set: A64  Groups: mortlach_multi2_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za2_z_b1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1c38)) == UINT32_C(0xc0040000))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: mova_za2_z_b1 off3=%u Zn=%#x Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za2_z_b1
            IEM_INSTR_IMPL_A64__mova_za2_z_b1(off3, Zn, Rs, V);
#else
            RT_NOREF(off3, Zn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1c38/c0c40000: MOVA  <ZAd><HV>.D[<Ws>, <offs1>:<offs2>], { <Zn1>.D-<Zn2>.D }
   Instruction Set: A64  Groups: mortlach_multi2_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za2_z_d1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1c38)) == UINT32_C(0xc0c40000))
    {
        uint32_t const ZAd        = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: mova_za2_z_d1 ZAd=%u Zn=%#x Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAd, Zn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za2_z_d1
            IEM_INSTR_IMPL_A64__mova_za2_z_d1(ZAd, Zn, Rs, V);
#else
            RT_NOREF(ZAd, Zn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1c38/c0440000: MOVA  <ZAd><HV>.H[<Ws>, <offs1>:<offs2>], { <Zn1>.H-<Zn2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za2_z_h1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1c38)) == UINT32_C(0xc0440000))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const ZAd        = (uOpcode >>  2) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: mova_za2_z_h1 off2=%u ZAd=%u Zn=%#x Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, ZAd, Zn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za2_z_h1
            IEM_INSTR_IMPL_A64__mova_za2_z_h1(off2, ZAd, Zn, Rs, V);
#else
            RT_NOREF(off2, ZAd, Zn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1c38/c0840000: MOVA  <ZAd><HV>.S[<Ws>, <offs1>:<offs2>], { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za2_z_w1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1c38)) == UINT32_C(0xc0840000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const ZAd        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: mova_za2_z_w1 o1=%u ZAd=%u Zn=%#x Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, ZAd, Zn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za2_z_w1
            IEM_INSTR_IMPL_A64__mova_za2_z_w1(o1, ZAd, Zn, Rs, V);
#else
            RT_NOREF(o1, ZAd, Zn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1c7c/c0040400: MOVA  ZA0<HV>.B[<Ws>, <offs1>:<offs4>], { <Zn1>.B-<Zn4>.B }
   Instruction Set: A64  Groups: mortlach_multi4_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za4_z_b1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_za4_z_b1 off2=%u Zn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za4_z_b1
        IEM_INSTR_IMPL_A64__mova_za4_z_b1(off2, Zn, Rs, V);
#else
        RT_NOREF(off2, Zn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1c78/c0c40400: MOVA  <ZAd><HV>.D[<Ws>, <offs1>:<offs4>], { <Zn1>.D-<Zn4>.D }
   Instruction Set: A64  Groups: mortlach_multi4_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za4_z_d1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1c78)) == UINT32_C(0xc0c40400))
    {
        uint32_t const ZAd        = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: mova_za4_z_d1 ZAd=%u Zn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAd, Zn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za4_z_d1
            IEM_INSTR_IMPL_A64__mova_za4_z_d1(ZAd, Zn, Rs, V);
#else
            RT_NOREF(ZAd, Zn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1c7c/c0440400: MOVA  <ZAd><HV>.H[<Ws>, <offs1>:<offs4>], { <Zn1>.H-<Zn4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za4_z_h1, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const ZAd        = (uOpcode >>  1) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_za4_z_h1 o1=%u ZAd=%u Zn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, ZAd, Zn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za4_z_h1
        IEM_INSTR_IMPL_A64__mova_za4_z_h1(o1, ZAd, Zn, Rs, V);
#else
        RT_NOREF(o1, ZAd, Zn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1c7c/c0840400: MOVA  <ZAd><HV>.S[<Ws>, <offs1>:<offs4>], { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za4_z_w1, uint32_t, uOpcode)
{
    uint32_t const ZAd        = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_za4_z_w1 ZAd=%u Zn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAd, Zn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za4_z_w1
        IEM_INSTR_IMPL_A64__mova_za4_z_w1(ZAd, Zn, Rs, V);
#else
        RT_NOREF(ZAd, Zn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c38/c0040800: MOVA  ZA.D[<Wv>, <offs>{, VGx2}], { <Zn1>.D-<Zn2>.D }
   Instruction Set: A64  Groups: mortlach_multi2_za_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za_mz2_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_za_mz2_1 off3=%u Zn=%#x Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv));
#ifdef IEM_INSTR_IMPL_A64__mova_za_mz2_1
        IEM_INSTR_IMPL_A64__mova_za_mz2_1(off3, Zn, Rv);
#else
        RT_NOREF(off3, Zn, Rv, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c78/c0040c00: MOVA  ZA.D[<Wv>, <offs>{, VGx4}], { <Zn1>.D-<Zn4>.D }
   Instruction Set: A64  Groups: mortlach_multi4_za_insert_ctg, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za_mz4_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: mova_za_mz4_1 off3=%u Zn=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv));
#ifdef IEM_INSTR_IMPL_A64__mova_za_mz4_1
        IEM_INSTR_IMPL_A64__mova_za_mz4_1(off3, Zn, Rv);
#else
        RT_NOREF(off3, Zn, Rv, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0010/c0000000: MOVA  ZA0<HV>.B[<Ws>, <offs>], <Pg>/M, <Zn>.B
   Instruction Set: A64  Groups: mortlach_insert_pred, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za_p_rz_b, uint32_t, uOpcode)
{
    uint32_t const off4       = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mova_za_p_rz_b off4=%#x Zn=%#x Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off4, Zn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za_p_rz_b
        IEM_INSTR_IMPL_A64__mova_za_p_rz_b(off4, Zn, Pg, Rs, V);
#else
        RT_NOREF(off4, Zn, Pg, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0010/c0c00000: MOVA  <ZAd><HV>.D[<Ws>, <offs>], <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: mortlach_insert_pred, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za_p_rz_d, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const ZAd        = (uOpcode >>  1) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mova_za_p_rz_d o1=%u ZAd=%u Zn=%#x Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, ZAd, Zn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za_p_rz_d
        IEM_INSTR_IMPL_A64__mova_za_p_rz_d(o1, ZAd, Zn, Pg, Rs, V);
#else
        RT_NOREF(o1, ZAd, Zn, Pg, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0010/c0400000: MOVA  <ZAd><HV>.H[<Ws>, <offs>], <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: mortlach_insert_pred, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za_p_rz_h, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const ZAd        = (uOpcode >>  3) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mova_za_p_rz_h off3=%u ZAd=%u Zn=%#x Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, ZAd, Zn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za_p_rz_h
        IEM_INSTR_IMPL_A64__mova_za_p_rz_h(off3, ZAd, Zn, Pg, Rs, V);
#else
        RT_NOREF(off3, ZAd, Zn, Pg, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0010/c0c10000: MOVA  <ZAd><HV>.Q[<Ws>, <offs>], <Pg>/M, <Zn>.Q
   Instruction Set: A64  Groups: mortlach_insert_pred, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za_p_rz_q, uint32_t, uOpcode)
{
    uint32_t const ZAd        = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mova_za_p_rz_q ZAd=%#x Zn=%#x Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAd, Zn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za_p_rz_q
        IEM_INSTR_IMPL_A64__mova_za_p_rz_q(ZAd, Zn, Pg, Rs, V);
#else
        RT_NOREF(ZAd, Zn, Pg, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff0010/c0800000: MOVA  <ZAd><HV>.S[<Ws>, <offs>], <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: mortlach_insert_pred, mortlach_ins, sme */
FNIEMOP_DEF_1(iemDecodeA64_mova_za_p_rz_w, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const ZAd        = (uOpcode >>  2) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mova_za_p_rz_w off2=%u ZAd=%u Zn=%#x Pg=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, ZAd, Zn, Pg, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__mova_za_p_rz_w
        IEM_INSTR_IMPL_A64__mova_za_p_rz_w(off2, ZAd, Zn, Pg, Rs, V);
#else
        RT_NOREF(off2, ZAd, Zn, Pg, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f01/c0060200: MOVAZ  { <Zd1>.B-<Zd2>.B }, ZA0<HV>.B[<Ws>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi2_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz2_za_b1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const off3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_mz2_za_b1 Zd=%#x off3=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off3, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz2_za_b1
        IEM_INSTR_IMPL_A64__movaz_mz2_za_b1(Zd, off3, Rs, V);
#else
        RT_NOREF(Zd, off3, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f01/c0c60200: MOVAZ  { <Zd1>.D-<Zd2>.D }, <ZAn><HV>.D[<Ws>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi2_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz2_za_d1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const ZAn        = (uOpcode >>  5) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_mz2_za_d1 Zd=%#x ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz2_za_d1
        IEM_INSTR_IMPL_A64__movaz_mz2_za_d1(Zd, ZAn, Rs, V);
#else
        RT_NOREF(Zd, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f01/c0460200: MOVAZ  { <Zd1>.H-<Zd2>.H }, <ZAn><HV>.H[<Ws>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi2_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz2_za_h1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0460200))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const off2       = (uOpcode >>  5) & 0x00000003;
        uint32_t const ZAn        = (uOpcode >>  7) & 0x00000001;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: movaz_mz2_za_h1 Zd=%#x off2=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off2, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz2_za_h1
            IEM_INSTR_IMPL_A64__movaz_mz2_za_h1(Zd, off2, ZAn, Rs, V);
#else
            RT_NOREF(Zd, off2, ZAn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f01/c0860200: MOVAZ  { <Zd1>.S-<Zd2>.S }, <ZAn><HV>.S[<Ws>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi2_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz2_za_w1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const o1         = (uOpcode >>  5) & 0x00000001;
    uint32_t const ZAn        = (uOpcode >>  6) & 0x00000003;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_mz2_za_w1 Zd=%#x o1=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, o1, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz2_za_w1
        IEM_INSTR_IMPL_A64__movaz_mz2_za_w1(Zd, o1, ZAn, Rs, V);
#else
        RT_NOREF(Zd, o1, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f83/c0060600: MOVAZ  { <Zd1>.B-<Zd4>.B }, ZA0<HV>.B[<Ws>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi4_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz4_za_b1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f83)) == UINT32_C(0xc0060600))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const off2       = (uOpcode >>  5) & 0x00000003;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: movaz_mz4_za_b1 Zd=%u off2=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off2, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz4_za_b1
            IEM_INSTR_IMPL_A64__movaz_mz4_za_b1(Zd, off2, Rs, V);
#else
            RT_NOREF(Zd, off2, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f03/c0c60600: MOVAZ  { <Zd1>.D-<Zd4>.D }, <ZAn><HV>.D[<Ws>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi4_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz4_za_d1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const ZAn        = (uOpcode >>  5) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_mz4_za_d1 Zd=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz4_za_d1
        IEM_INSTR_IMPL_A64__movaz_mz4_za_d1(Zd, ZAn, Rs, V);
#else
        RT_NOREF(Zd, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f83/c0460600: MOVAZ  { <Zd1>.H-<Zd4>.H }, <ZAn><HV>.H[<Ws>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi4_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz4_za_h1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f83)) == UINT32_C(0xc0460600))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const o1         = (uOpcode >>  5) & 0x00000001;
        uint32_t const ZAn        = (uOpcode >>  6) & 0x00000001;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: movaz_mz4_za_h1 Zd=%u o1=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, o1, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz4_za_h1
            IEM_INSTR_IMPL_A64__movaz_mz4_za_h1(Zd, o1, ZAn, Rs, V);
#else
            RT_NOREF(Zd, o1, ZAn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1f83/c0860600: MOVAZ  { <Zd1>.S-<Zd4>.S }, <ZAn><HV>.S[<Ws>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi4_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz4_za_w1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const ZAn        = (uOpcode >>  5) & 0x00000003;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_mz4_za_w1 Zd=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz4_za_w1
        IEM_INSTR_IMPL_A64__movaz_mz4_za_w1(Zd, ZAn, Rs, V);
#else
        RT_NOREF(Zd, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9f01/c0060a00: MOVAZ  { <Zd1>.D-<Zd2>.D }, ZA.D[<Wv>, <offs>{, VGx2}]
   Instruction Set: A64  Groups: mortlach_multi2_za_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz_za2_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9f01)) == UINT32_C(0xc0060a00))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const off3       = (uOpcode >>  5) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: movaz_mz_za2_1 Zd=%#x off3=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off3, Rv));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz_za2_1
            IEM_INSTR_IMPL_A64__movaz_mz_za2_1(Zd, off3, Rv);
#else
            RT_NOREF(Zd, off3, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9f03/c0060e00: MOVAZ  { <Zd1>.D-<Zd4>.D }, ZA.D[<Wv>, <offs>{, VGx4}]
   Instruction Set: A64  Groups: mortlach_multi4_za_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_mz_za4_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9f03)) == UINT32_C(0xc0060e00))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const off3       = (uOpcode >>  5) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: movaz_mz_za4_1 Zd=%u off3=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off3, Rv));
#ifdef IEM_INSTR_IMPL_A64__movaz_mz_za4_1
            IEM_INSTR_IMPL_A64__movaz_mz_za4_1(Zd, off3, Rv);
#else
            RT_NOREF(Zd, off3, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1e00/c0020200: MOVAZ  <Zd>.B, ZA0<HV>.B[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_z_rza_b, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const off4       = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_z_rza_b Zd=%#x off4=%#x Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off4, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_z_rza_b
        IEM_INSTR_IMPL_A64__movaz_z_rza_b(Zd, off4, Rs, V);
#else
        RT_NOREF(Zd, off4, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1e00/c0c20200: MOVAZ  <Zd>.D, <ZAn><HV>.D[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_z_rza_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const o1         = (uOpcode >>  5) & 0x00000001;
    uint32_t const ZAn        = (uOpcode >>  6) & 0x00000007;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_z_rza_d Zd=%#x o1=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, o1, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_z_rza_d
        IEM_INSTR_IMPL_A64__movaz_z_rza_d(Zd, o1, ZAn, Rs, V);
#else
        RT_NOREF(Zd, o1, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1e00/c0420200: MOVAZ  <Zd>.H, <ZAn><HV>.H[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_z_rza_h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0420200))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const off3       = (uOpcode >>  5) & 0x00000007;
        uint32_t const ZAn        = (uOpcode >>  8) & 0x00000001;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: movaz_z_rza_h Zd=%#x off3=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off3, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_z_rza_h
            IEM_INSTR_IMPL_A64__movaz_z_rza_h(Zd, off3, ZAn, Rs, V);
#else
            RT_NOREF(Zd, off3, ZAn, Rs, V, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1e00/c0c30200: MOVAZ  <Zd>.Q, <ZAn><HV>.Q[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_z_rza_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const ZAn        = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_z_rza_q Zd=%#x ZAn=%#x Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_z_rza_q
        IEM_INSTR_IMPL_A64__movaz_z_rza_q(Zd, ZAn, Rs, V);
#else
        RT_NOREF(Zd, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff1e00/c0820200: MOVAZ  <Zd>.S, <ZAn><HV>.S[<Ws>, <offs>]
   Instruction Set: A64  Groups: mortlach_extract_zero, mortlach_ext, sme */
FNIEMOP_DEF_1(iemDecodeA64_movaz_z_rza_w, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const off2       = (uOpcode >>  5) & 0x00000003;
    uint32_t const ZAn        = (uOpcode >>  7) & 0x00000003;
    uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
    uint32_t const V          = (uOpcode >> 15) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: movaz_z_rza_w Zd=%#x off2=%u ZAn=%u Rs=%u V=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, off2, ZAn, Rs, V));
#ifdef IEM_INSTR_IMPL_A64__movaz_z_rza_w
        IEM_INSTR_IMPL_A64__movaz_z_rza_w(Zd, off2, ZAn, Rs, V);
#else
        RT_NOREF(Zd, off2, ZAn, Rs, V, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ee000/04102000: MOVPRFX  <Zd>.<T>, <Pg>/<ZM>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_movprfx_pred, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_movprfx_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const M          = (uOpcode >> 16) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: movprfx_z_p_z Zd=%#x Zn=%#x Pg=%u M=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, M, size));
#ifdef IEM_INSTR_IMPL_A64__movprfx_z_p_z
        IEM_INSTR_IMPL_A64__movprfx_z_p_z(Zd, Zn, Pg, M, size);
#else
        RT_NOREF(Zd, Zn, Pg, M, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/0420bc00: MOVPRFX  <Zd>, <Zn>
   Instruction Set: A64  Groups: sve_int_bin_cons_misc_0_d, sve_int_unpred_misc, sve */
FNIEMOP_DEF_1(iemDecodeA64_movprfx_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x0420bc00))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: movprfx_z_z Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__movprfx_z_z
            IEM_INSTR_IMPL_A64__movprfx_z_z(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff8fe0/c04c03e0: MOVT  <Xt>, ZT0[<offs>]
   Instruction Set: A64  Groups: mortlach_extract_zt, mortlach_mov_zt, sme */
FNIEMOP_DEF_1(iemDecodeA64_movt_r_zt, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const off3       = (uOpcode >> 12) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: movt_r_zt Rt=%#x off3=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, off3));
#ifdef IEM_INSTR_IMPL_A64__movt_r_zt
        IEM_INSTR_IMPL_A64__movt_r_zt(Rt, off3);
#else
        RT_NOREF(Rt, off3, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff8fe0/c04e03e0: MOVT  ZT0[<offs>], <Xt>
   Instruction Set: A64  Groups: mortlach_insert_zt, mortlach_mov_zt, sme */
FNIEMOP_DEF_1(iemDecodeA64_movt_zt_r, uint32_t, uOpcode)
{
    uint32_t const Rt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const off3       = (uOpcode >> 12) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: movt_zt_r Rt=%#x off3=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rt, off3));
#ifdef IEM_INSTR_IMPL_A64__movt_zt_r
        IEM_INSTR_IMPL_A64__movt_zt_r(Rt, off3);
#else
        RT_NOREF(Rt, off3, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffcfe0/c04f03e0: MOVT  ZT0{[<offs>, MUL VL]}, <Zt>
   Instruction Set: A64  Groups: mortlach_move_to_zt, mortlach_mov_zt, sme */
FNIEMOP_DEF_1(iemDecodeA64_movt_zt_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffcfe0)) == UINT32_C(0xc04f03e0))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const off2       = (uOpcode >> 12) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeLutv2 /*FEAT_SME_LUTv2*/)
        {
            LogFlow(("%018x/%010x: movt_zt_z Zt=%#x off2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, off2));
#ifdef IEM_INSTR_IMPL_A64__movt_zt_z
            IEM_INSTR_IMPL_A64__movt_zt_z(Zt, off2);
#else
            RT_NOREF(Zt, off2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e000/0400e000: MSB  <Zdn>.<T>, <Pg>/M, <Zm>.<T>, <Za>.<T>
   Instruction Set: A64  Groups: sve_int_mladdsub_vvv_pred, sve_int_muladd_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_msb_z_p_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Za         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: msb_z_p_zzz Zdn=%#x Za=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Za, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__msb_z_p_zzz
        IEM_INSTR_IMPL_A64__msb_z_p_zzz(Zdn, Za, Pg, Zm, size);
#else
        RT_NOREF(Zdn, Za, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04100000: MUL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_2, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_mul_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04100000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: mul_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__mul_z_p_zz
            IEM_INSTR_IMPL_A64__mul_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/2530c000: MUL  <Zdn>.<T>, <Zdn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_imm2, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_mul_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mul_z_zi Zdn=%#x imm8=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, size));
#ifdef IEM_INSTR_IMPL_A64__mul_z_zi
        IEM_INSTR_IMPL_A64__mul_z_zi(Zdn, imm8, size);
#else
        RT_NOREF(Zdn, imm8, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04206000: MUL  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_mul_b, sve_int_unpred_arit_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_mul_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mul_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__mul_z_zz
        IEM_INSTR_IMPL_A64__mul_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e0f800: MUL  <Zd>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mul_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mul_z_zzi_d Zd=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__mul_z_zzi_d
        IEM_INSTR_IMPL_A64__mul_z_zzi_d(Zd, Zn, Zm, i1);
#else
        RT_NOREF(Zd, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4420f800: MUL  <Zd>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mul_z_zzi_h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mul_z_zzi_h Zd=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__mul_z_zzi_h
        IEM_INSTR_IMPL_A64__mul_z_zzi_h(Zd, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zd, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a0f800: MUL  <Zd>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_mul_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: mul_z_zzi_s Zd=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__mul_z_zzi_s
        IEM_INSTR_IMPL_A64__mul_z_zzi_s(Zd, Zn, Zm, i2);
#else
        RT_NOREF(Zd, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25804210: NAND  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_nand_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: nand_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__nand_p_p_pp_z
        IEM_INSTR_IMPL_A64__nand_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25c04210: NANDS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_nands_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: nands_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__nands_p_p_pp_z
        IEM_INSTR_IMPL_A64__nands_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04e03c00: NBSL  <Zdn>.D, <Zdn>.D, <Zm>.D, <Zk>.D
   Instruction Set: A64  Groups: sve_int_tern_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_nbsl_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zk         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: nbsl_z_zzz Zdn=%#x Zk=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zk, Zm));
#ifdef IEM_INSTR_IMPL_A64__nbsl_z_zzz
        IEM_INSTR_IMPL_A64__nbsl_z_zzz(Zdn, Zk, Zm);
#else
        RT_NOREF(Zdn, Zk, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0417a000: NEG  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_neg_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: neg_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__neg_z_p_z_m
        IEM_INSTR_IMPL_A64__neg_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0407a000: NEG  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_neg_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: neg_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__neg_z_p_z_z
        IEM_INSTR_IMPL_A64__neg_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20e010/45208010: NMATCH  <Pd>.<T>, <Pg>/Z, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_match, sve_intx_string, sve */
FNIEMOP_DEF_1(iemDecodeA64_nmatch_p_p_zz, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: nmatch_p_p_zz Pd=%#x Zn=%#x Pg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, Pg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__nmatch_p_p_zz
        IEM_INSTR_IMPL_A64__nmatch_p_p_zz(Pd, Zn, Pg, Zm, size);
#else
        RT_NOREF(Pd, Zn, Pg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25804200: NOR  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_nor_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: nor_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__nor_p_p_pp_z
        IEM_INSTR_IMPL_A64__nor_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25c04200: NORS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_nors_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: nors_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__nors_p_p_pp_z
        IEM_INSTR_IMPL_A64__nors_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041ea000: NOT  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_not_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: not_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__not_z_p_z_m
        IEM_INSTR_IMPL_A64__not_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040ea000: NOT  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_1, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_not_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: not_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__not_z_p_z_z
        IEM_INSTR_IMPL_A64__not_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25804010: ORN  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_orn_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: orn_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__orn_p_p_pp_z
        IEM_INSTR_IMPL_A64__orn_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25c04010: ORNS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_orns_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: orns_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__orns_p_p_pp_z
        IEM_INSTR_IMPL_A64__orns_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/041c2000: ORQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_reduce_2q, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_orqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: orqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__orqv_z_p_z
        IEM_INSTR_IMPL_A64__orqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25804000: ORR  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_orr_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: orr_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__orr_p_p_pp_z
        IEM_INSTR_IMPL_A64__orr_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04180000: ORR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_log, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_orr_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04180000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: orr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__orr_z_p_zz
            IEM_INSTR_IMPL_A64__orr_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffc0000/05000000: ORR  <Zdn>.<T>, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_log_imm, sve_maskimm, sve */
FNIEMOP_DEF_1(iemDecodeA64_orr_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05000000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm13      = (uOpcode >>  5) & 0x00001fff;
        if ((0x0 /*opc@22*/ != 3) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: orr_z_zi Zdn=%#x imm13=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm13));
#ifdef IEM_INSTR_IMPL_A64__orr_z_zi
            IEM_INSTR_IMPL_A64__orr_z_zi(Zdn, imm13);
#else
            RT_NOREF(Zdn, imm13, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04603000: ORR  <Zd>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_log, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_orr_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: orr_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__orr_z_zz
        IEM_INSTR_IMPL_A64__orr_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25c04000: ORRS  <Pd>.B, <Pg>/Z, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_orrs_p_p_pp_z, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: orrs_p_p_pp_z Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__orrs_p_p_pp_z
        IEM_INSTR_IMPL_A64__orrs_p_p_pp_z(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04182000: ORV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_2, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_orv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: orv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__orv_r_p_z
        IEM_INSTR_IMPL_A64__orv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc10/25207010: PEXT  <Pd>.<T>, <PNn>[<imm>]
   Instruction Set: A64  Groups: sve_int_ctr_to_mask, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_pext_pn_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const PNn        = (uOpcode >>  5) & 0x00000007;
    uint32_t const imm2       = (uOpcode >>  8) & 0x00000003;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: pext_pn_rr Pd=%#x PNn=%u imm2=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, PNn, imm2, size));
#ifdef IEM_INSTR_IMPL_A64__pext_pn_rr
        IEM_INSTR_IMPL_A64__pext_pn_rr(Pd, PNn, imm2, size);
#else
        RT_NOREF(Pd, PNn, imm2, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe10/25207410: PEXT  { <Pd1>.<T>, <Pd2>.<T> }, <PNn>[<imm>]
   Instruction Set: A64  Groups: sve_int_ctr_to_mask, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_pext_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const PNn        = (uOpcode >>  5) & 0x00000007;
    uint32_t const i1         = (uOpcode >>  8) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: pext_pp_rr Pd=%#x PNn=%u i1=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, PNn, i1, size));
#ifdef IEM_INSTR_IMPL_A64__pext_pp_rr
        IEM_INSTR_IMPL_A64__pext_pp_rr(Pd, PNn, i1, size);
#else
        RT_NOREF(Pd, PNn, i1, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffff0/2518e400: PFALSE  <Pd>.B
   Instruction Set: A64  Groups: sve_int_pfalse, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pfalse_p, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: pfalse_p Pd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd));
#ifdef IEM_INSTR_IMPL_A64__pfalse_p
        IEM_INSTR_IMPL_A64__pfalse_p(Pd);
#else
        RT_NOREF(Pd, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffe10/2558c000: PFIRST  <Pdn>.B, <Pg>, <Pdn>.B
   Instruction Set: A64  Groups: sve_int_pfirst, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pfirst_p_p_p, uint32_t, uOpcode)
{
    uint32_t const Pdn        = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >>  5) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: pfirst_p_p_p Pdn=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pdn, Pg));
#ifdef IEM_INSTR_IMPL_A64__pfirst_p_p_p
        IEM_INSTR_IMPL_A64__pfirst_p_p_p(Pdn, Pg);
#else
        RT_NOREF(Pdn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc01/4520fc00: PMLAL  { <Zda1>.Q-<Zda2>.Q }, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_crypto_pmlal_multi, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmlal_mz_zzzw_1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc01)) == UINT32_C(0x4520fc00))
    {
        uint32_t const Zda        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
        {
            LogFlow(("%018x/%010x: pmlal_mz_zzzw_1x2 Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__pmlal_mz_zzzw_1x2
            IEM_INSTR_IMPL_A64__pmlal_mz_zzzw_1x2(Zda, Zn, Zm);
#else
            RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc10/052a3800: PMOV  <Pd>.B, <Zn>
   Instruction Set: A64  Groups: sve_int_mov_v2p, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmov_p_zi_b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc10)) == UINT32_C(0x052a3800))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: pmov_p_zi_b Pd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn));
#ifdef IEM_INSTR_IMPL_A64__pmov_p_zi_b
            IEM_INSTR_IMPL_A64__pmov_p_zi_b(Pd, Zn);
#else
            RT_NOREF(Pd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb9fc10/05a83800: PMOV  <Pd>.D, <Zn>{[<imm>]}
   Instruction Set: A64  Groups: sve_int_mov_v2p, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmov_p_zi_d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb9fc10)) == UINT32_C(0x05a83800))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const i3l        = (uOpcode >> 17) & 0x00000003;
        uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: pmov_p_zi_d Pd=%#x Zn=%#x i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__pmov_p_zi_d
            IEM_INSTR_IMPL_A64__pmov_p_zi_d(Pd, Zn, i3l, i3h);
#else
            RT_NOREF(Pd, Zn, i3l, i3h, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffdfc10/052c3800: PMOV  <Pd>.H, <Zn>{[<imm>]}
   Instruction Set: A64  Groups: sve_int_mov_v2p, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmov_p_zi_h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffdfc10)) == UINT32_C(0x052c3800))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const i1         = (uOpcode >> 17) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: pmov_p_zi_h Pd=%#x Zn=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, i1));
#ifdef IEM_INSTR_IMPL_A64__pmov_p_zi_h
            IEM_INSTR_IMPL_A64__pmov_p_zi_h(Pd, Zn, i1);
#else
            RT_NOREF(Pd, Zn, i1, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff9fc10/05683800: PMOV  <Pd>.S, <Zn>{[<imm>]}
   Instruction Set: A64  Groups: sve_int_mov_v2p, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmov_p_zi_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff9fc10)) == UINT32_C(0x05683800))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const i2         = (uOpcode >> 17) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: pmov_p_zi_s Pd=%#x Zn=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Zn, i2));
#ifdef IEM_INSTR_IMPL_A64__pmov_p_zi_s
            IEM_INSTR_IMPL_A64__pmov_p_zi_s(Pd, Zn, i2);
#else
            RT_NOREF(Pd, Zn, i2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffe00/052b3800: PMOV  <Zd>, <Pn>.B
   Instruction Set: A64  Groups: sve_int_mov_p2v, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmov_z_pi_b, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffe00)) == UINT32_C(0x052b3800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: pmov_z_pi_b Zd=%#x Pn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Pn));
#ifdef IEM_INSTR_IMPL_A64__pmov_z_pi_b
            IEM_INSTR_IMPL_A64__pmov_z_pi_b(Zd, Pn);
#else
            RT_NOREF(Zd, Pn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb9fe00/05a93800: PMOV  <Zd>{[<imm>]}, <Pn>.D
   Instruction Set: A64  Groups: sve_int_mov_p2v, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmov_z_pi_d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb9fe00)) == UINT32_C(0x05a93800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const i3l        = (uOpcode >> 17) & 0x00000003;
        uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: pmov_z_pi_d Zd=%#x Pn=%#x i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Pn, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__pmov_z_pi_d
            IEM_INSTR_IMPL_A64__pmov_z_pi_d(Zd, Pn, i3l, i3h);
#else
            RT_NOREF(Zd, Pn, i3l, i3h, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffdfe00/052d3800: PMOV  <Zd>{[<imm>]}, <Pn>.H
   Instruction Set: A64  Groups: sve_int_mov_p2v, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmov_z_pi_h, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffdfe00)) == UINT32_C(0x052d3800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const i1         = (uOpcode >> 17) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: pmov_z_pi_h Zd=%#x Pn=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Pn, i1));
#ifdef IEM_INSTR_IMPL_A64__pmov_z_pi_h
            IEM_INSTR_IMPL_A64__pmov_z_pi_h(Zd, Pn, i1);
#else
            RT_NOREF(Zd, Pn, i1, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff9fe00/05693800: PMOV  <Zd>{[<imm>]}, <Pn>.S
   Instruction Set: A64  Groups: sve_int_mov_p2v, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmov_z_pi_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff9fe00)) == UINT32_C(0x05693800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const i2         = (uOpcode >> 17) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: pmov_z_pi_s Zd=%#x Pn=%#x i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Pn, i2));
#ifdef IEM_INSTR_IMPL_A64__pmov_z_pi_s
            IEM_INSTR_IMPL_A64__pmov_z_pi_s(Zd, Pn, i2);
#else
            RT_NOREF(Zd, Pn, i2, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04206400: PMUL  <Zd>.B, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_int_mul_b, sve_int_unpred_arit_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmul_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: pmul_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__pmul_z_zz
        IEM_INSTR_IMPL_A64__pmul_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc01/4520f800: PMULL  { <Zd1>.Q-<Zd2>.Q }, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_crypto_pmull_multi, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmull_mz_zzw_1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc01)) == UINT32_C(0x4520f800))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveAes2 /*FEAT_SVE_AES2*/)
        {
            LogFlow(("%018x/%010x: pmull_mz_zzw_1x2 Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__pmull_mz_zzw_1x2
            IEM_INSTR_IMPL_A64__pmull_mz_zzw_1x2(Zd, Zn, Zm);
#else
            RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45006800: PMULLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmullb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: pmullb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__pmullb_z_zz
        IEM_INSTR_IMPL_A64__pmullb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/45006800: PMULLB  <Zd>.Q, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmullb_z_zz_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSvePmull128 /*FEAT_SVE_PMULL128*/)
    {
        LogFlow(("%018x/%010x: pmullb_z_zz_q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__pmullb_z_zz_q
        IEM_INSTR_IMPL_A64__pmullb_z_zz_q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45006c00: PMULLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmullt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (size != 0))
    {
        LogFlow(("%018x/%010x: pmullt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__pmullt_z_zz
        IEM_INSTR_IMPL_A64__pmullt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/45006c00: PMULLT  <Zd>.Q, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_pmullt_z_zz_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSvePmull128 /*FEAT_SVE_PMULL128*/)
    {
        LogFlow(("%018x/%010x: pmullt_z_zz_q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__pmullt_z_zz_q
        IEM_INSTR_IMPL_A64__pmullt_z_zz_q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe10/2519c400: PNEXT  <Pdn>.<T>, <Pv>, <Pdn>.<T>
   Instruction Set: A64  Groups: sve_int_pnext, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_pnext_p_p_p, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe10)) == UINT32_C(0x2519c400))
    {
        uint32_t const Pdn        = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Pv         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: pnext_p_p_p Pdn=%#x Pv=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pdn, Pv, size));
#ifdef IEM_INSTR_IMPL_A64__pnext_p_p_p
            IEM_INSTR_IMPL_A64__pnext_p_p_p(Pdn, Pv, size);
#else
            RT_NOREF(Pdn, Pv, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/c400e000: PRFB  <prfop>, <Pg>, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfb_i_p_ai_d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0xc400e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfb_i_p_ai_d prfop=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__prfb_i_p_ai_d
            IEM_INSTR_IMPL_A64__prfb_i_p_ai_d(prfop, Zn, Pg, imm5);
#else
            RT_NOREF(prfop, Zn, Pg, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/8400e000: PRFB  <prfop>, <Pg>, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_prfm_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfb_i_p_ai_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0x8400e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfb_i_p_ai_s prfop=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__prfb_i_p_ai_s
            IEM_INSTR_IMPL_A64__prfb_i_p_ai_s(prfop, Zn, Pg, imm5);
#else
            RT_NOREF(prfop, Zn, Pg, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e010/85c00000: PRFB  <prfop>, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_prfm_si, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfb_i_p_bi_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e010)) == UINT32_C(0x85c00000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: prfb_i_p_bi_s prfop=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__prfb_i_p_bi_s
            IEM_INSTR_IMPL_A64__prfb_i_p_bi_s(prfop, Rn, Pg, imm6);
#else
            RT_NOREF(prfop, Rn, Pg, imm6, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/8400c000: PRFB  <prfop>, <Pg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_prfm_ss, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfb_i_p_br_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0x8400c000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: prfb_i_p_br_s prfop=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__prfb_i_p_br_s
            IEM_INSTR_IMPL_A64__prfb_i_p_br_s(prfop, Rn, Pg, Rm);
#else
            RT_NOREF(prfop, Rn, Pg, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/c4608000: PRFB  <prfop>, <Pg>, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfb_i_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0xc4608000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfb_i_p_bz_d_64_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__prfb_i_p_bz_d_64_scaled
            IEM_INSTR_IMPL_A64__prfb_i_p_bz_d_64_scaled(prfop, Rn, Pg, Zm);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e010/c4200000: PRFB  <prfop>, <Pg>, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfb_i_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e010)) == UINT32_C(0xc4200000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfb_i_p_bz_d_x32_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__prfb_i_p_bz_d_x32_scaled
            IEM_INSTR_IMPL_A64__prfb_i_p_bz_d_x32_scaled(prfop, Rn, Pg, Zm, xs);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e010/84200000: PRFB  <prfop>, <Pg>, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_32b_prfm_sv, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfb_i_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e010)) == UINT32_C(0x84200000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfb_i_p_bz_s_x32_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__prfb_i_p_bz_s_x32_scaled
            IEM_INSTR_IMPL_A64__prfb_i_p_bz_s_x32_scaled(prfop, Rn, Pg, Zm, xs);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/c580e000: PRFD  <prfop>, <Pg>, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfd_i_p_ai_d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0xc580e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfd_i_p_ai_d prfop=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__prfd_i_p_ai_d
            IEM_INSTR_IMPL_A64__prfd_i_p_ai_d(prfop, Zn, Pg, imm5);
#else
            RT_NOREF(prfop, Zn, Pg, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/8580e000: PRFD  <prfop>, <Pg>, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_prfm_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfd_i_p_ai_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0x8580e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfd_i_p_ai_s prfop=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__prfd_i_p_ai_s
            IEM_INSTR_IMPL_A64__prfd_i_p_ai_s(prfop, Zn, Pg, imm5);
#else
            RT_NOREF(prfop, Zn, Pg, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e010/85c06000: PRFD  <prfop>, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_prfm_si, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfd_i_p_bi_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e010)) == UINT32_C(0x85c06000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: prfd_i_p_bi_s prfop=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__prfd_i_p_bi_s
            IEM_INSTR_IMPL_A64__prfd_i_p_bi_s(prfop, Rn, Pg, imm6);
#else
            RT_NOREF(prfop, Rn, Pg, imm6, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/8580c000: PRFD  <prfop>, <Pg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_prfm_ss, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfd_i_p_br_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0x8580c000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: prfd_i_p_br_s prfop=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__prfd_i_p_br_s
            IEM_INSTR_IMPL_A64__prfd_i_p_br_s(prfop, Rn, Pg, Rm);
#else
            RT_NOREF(prfop, Rn, Pg, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/c460e000: PRFD  <prfop>, <Pg>, [<Xn|SP>, <Zm>.D, LSL #3]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfd_i_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0xc460e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfd_i_p_bz_d_64_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__prfd_i_p_bz_d_64_scaled
            IEM_INSTR_IMPL_A64__prfd_i_p_bz_d_64_scaled(prfop, Rn, Pg, Zm);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e010/c4206000: PRFD  <prfop>, <Pg>, [<Xn|SP>, <Zm>.D, <mod> #3]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfd_i_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e010)) == UINT32_C(0xc4206000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfd_i_p_bz_d_x32_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__prfd_i_p_bz_d_x32_scaled
            IEM_INSTR_IMPL_A64__prfd_i_p_bz_d_x32_scaled(prfop, Rn, Pg, Zm, xs);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e010/84206000: PRFD  <prfop>, <Pg>, [<Xn|SP>, <Zm>.S, <mod> #3]
   Instruction Set: A64  Groups: sve_mem_32b_prfm_sv, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfd_i_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e010)) == UINT32_C(0x84206000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfd_i_p_bz_s_x32_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__prfd_i_p_bz_s_x32_scaled
            IEM_INSTR_IMPL_A64__prfd_i_p_bz_s_x32_scaled(prfop, Rn, Pg, Zm, xs);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/c480e000: PRFH  <prfop>, <Pg>, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfh_i_p_ai_d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0xc480e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfh_i_p_ai_d prfop=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__prfh_i_p_ai_d
            IEM_INSTR_IMPL_A64__prfh_i_p_ai_d(prfop, Zn, Pg, imm5);
#else
            RT_NOREF(prfop, Zn, Pg, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/8480e000: PRFH  <prfop>, <Pg>, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_prfm_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfh_i_p_ai_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0x8480e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfh_i_p_ai_s prfop=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__prfh_i_p_ai_s
            IEM_INSTR_IMPL_A64__prfh_i_p_ai_s(prfop, Zn, Pg, imm5);
#else
            RT_NOREF(prfop, Zn, Pg, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e010/85c02000: PRFH  <prfop>, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_prfm_si, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfh_i_p_bi_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e010)) == UINT32_C(0x85c02000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: prfh_i_p_bi_s prfop=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__prfh_i_p_bi_s
            IEM_INSTR_IMPL_A64__prfh_i_p_bi_s(prfop, Rn, Pg, imm6);
#else
            RT_NOREF(prfop, Rn, Pg, imm6, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/8480c000: PRFH  <prfop>, <Pg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_prfm_ss, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfh_i_p_br_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0x8480c000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: prfh_i_p_br_s prfop=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__prfh_i_p_br_s
            IEM_INSTR_IMPL_A64__prfh_i_p_br_s(prfop, Rn, Pg, Rm);
#else
            RT_NOREF(prfop, Rn, Pg, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/c460a000: PRFH  <prfop>, <Pg>, [<Xn|SP>, <Zm>.D, LSL #1]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfh_i_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0xc460a000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfh_i_p_bz_d_64_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__prfh_i_p_bz_d_64_scaled
            IEM_INSTR_IMPL_A64__prfh_i_p_bz_d_64_scaled(prfop, Rn, Pg, Zm);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e010/c4202000: PRFH  <prfop>, <Pg>, [<Xn|SP>, <Zm>.D, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfh_i_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e010)) == UINT32_C(0xc4202000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfh_i_p_bz_d_x32_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__prfh_i_p_bz_d_x32_scaled
            IEM_INSTR_IMPL_A64__prfh_i_p_bz_d_x32_scaled(prfop, Rn, Pg, Zm, xs);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e010/84202000: PRFH  <prfop>, <Pg>, [<Xn|SP>, <Zm>.S, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_32b_prfm_sv, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfh_i_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e010)) == UINT32_C(0x84202000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfh_i_p_bz_s_x32_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__prfh_i_p_bz_s_x32_scaled
            IEM_INSTR_IMPL_A64__prfh_i_p_bz_s_x32_scaled(prfop, Rn, Pg, Zm, xs);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/c500e000: PRFW  <prfop>, <Pg>, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_vi, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfw_i_p_ai_d, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0xc500e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfw_i_p_ai_d prfop=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__prfw_i_p_ai_d
            IEM_INSTR_IMPL_A64__prfw_i_p_ai_d(prfop, Zn, Pg, imm5);
#else
            RT_NOREF(prfop, Zn, Pg, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/8500e000: PRFW  <prfop>, <Pg>, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_32b_prfm_vi, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfw_i_p_ai_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0x8500e000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfw_i_p_ai_s prfop=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__prfw_i_p_ai_s
            IEM_INSTR_IMPL_A64__prfw_i_p_ai_s(prfop, Zn, Pg, imm5);
#else
            RT_NOREF(prfop, Zn, Pg, imm5, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e010/85c04000: PRFW  <prfop>, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_prfm_si, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfw_i_p_bi_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e010)) == UINT32_C(0x85c04000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm6       = (uOpcode >> 16) & 0x0000003f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: prfw_i_p_bi_s prfop=%#x Rn=%#x Pg=%u imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, imm6));
#ifdef IEM_INSTR_IMPL_A64__prfw_i_p_bi_s
            IEM_INSTR_IMPL_A64__prfw_i_p_bi_s(prfop, Rn, Pg, imm6);
#else
            RT_NOREF(prfop, Rn, Pg, imm6, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/8500c000: PRFW  <prfop>, <Pg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_prfm_ss, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfw_i_p_br_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0x8500c000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: prfw_i_p_br_s prfop=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__prfw_i_p_br_s
            IEM_INSTR_IMPL_A64__prfw_i_p_br_s(prfop, Rn, Pg, Rm);
#else
            RT_NOREF(prfop, Rn, Pg, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e010/c460c000: PRFW  <prfop>, <Pg>, [<Xn|SP>, <Zm>.D, LSL #2]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_sv2, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfw_i_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e010)) == UINT32_C(0xc460c000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfw_i_p_bz_d_64_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__prfw_i_p_bz_d_64_scaled
            IEM_INSTR_IMPL_A64__prfw_i_p_bz_d_64_scaled(prfop, Rn, Pg, Zm);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e010/c4204000: PRFW  <prfop>, <Pg>, [<Xn|SP>, <Zm>.D, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_64b_prfm_sv, sve_mem64, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfw_i_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e010)) == UINT32_C(0xc4204000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfw_i_p_bz_d_x32_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__prfw_i_p_bz_d_x32_scaled
            IEM_INSTR_IMPL_A64__prfw_i_p_bz_d_x32_scaled(prfop, Rn, Pg, Zm, xs);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0e010/84204000: PRFW  <prfop>, <Pg>, [<Xn|SP>, <Zm>.S, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_32b_prfm_sv, sve_mem32, sve */
FNIEMOP_DEF_1(iemDecodeA64_prfw_i_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e010)) == UINT32_C(0x84204000))
    {
        uint32_t const prfop      = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        uint32_t const xs         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: prfw_i_p_bz_s_x32_scaled prfop=%#x Rn=%#x Pg=%u Zm=%#x xs=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, prfop, Rn, Pg, Zm, xs));
#ifdef IEM_INSTR_IMPL_A64__prfw_i_p_bz_s_x32_scaled
            IEM_INSTR_IMPL_A64__prfw_i_p_bz_s_x32_scaled(prfop, Rn, Pg, Zm, xs);
#else
            RT_NOREF(prfop, Rn, Pg, Zm, xs, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20c210/25204000: PSEL  <Pd>, <Pn>, <Pm>.<T>[<Wv>, <imm>]
   Instruction Set: A64  Groups: sve_int_pred_dup, sve_pred_dup, sve */
FNIEMOP_DEF_1(iemDecodeA64_psel_p_ppi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pn         = (uOpcode >> 10) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 16) & 0x00000003;
        uint32_t const tszl       = (uOpcode >> 18) & 0x00000007;
        uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
        uint32_t const i1         = (uOpcode >> 23) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
        {
            LogFlow(("%018x/%010x: psel_p_ppi Pd=%#x Pm=%#x Pn=%#x Rv=%u tszl=%u tszh=%u i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pm, Pn, Rv, tszl, tszh, i1));
#ifdef IEM_INSTR_IMPL_A64__psel_p_ppi
            IEM_INSTR_IMPL_A64__psel_p_ppi(Pd, Pm, Pn, Rv, tszl, tszh, i1);
#else
            RT_NOREF(Pd, Pm, Pn, Rv, tszl, tszh, i1, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffc21f/2550c000: PTEST  <Pg>, <Pn>.B
   Instruction Set: A64  Groups: sve_int_ptest, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_ptest__p_p, uint32_t, uOpcode)
{
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ptest__p_p Pn=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ptest__p_p
        IEM_INSTR_IMPL_A64__ptest__p_p(Pn, Pg);
#else
        RT_NOREF(Pn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc10/2518e000: PTRUE  <Pd>.<T>{, <pattern>}
   Instruction Set: A64  Groups: sve_int_ptrue, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_ptrue_p_s, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ptrue_p_s Pd=%#x pattern=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, pattern, size));
#ifdef IEM_INSTR_IMPL_A64__ptrue_p_s
        IEM_INSTR_IMPL_A64__ptrue_p_s(Pd, pattern, size);
#else
        RT_NOREF(Pd, pattern, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffff8/25207810: PTRUE  <PNd>.<T>
   Instruction Set: A64  Groups: sve_int_pn_ptrue, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_ptrue_pn_i, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: ptrue_pn_i PNd=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, size));
#ifdef IEM_INSTR_IMPL_A64__ptrue_pn_i
        IEM_INSTR_IMPL_A64__ptrue_pn_i(PNd, size);
#else
        RT_NOREF(PNd, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc10/2519e000: PTRUES  <Pd>.<T>{, <pattern>}
   Instruction Set: A64  Groups: sve_int_ptrue, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_ptrues_p_s, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ptrues_p_s Pd=%#x pattern=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, pattern, size));
#ifdef IEM_INSTR_IMPL_A64__ptrues_p_s
        IEM_INSTR_IMPL_A64__ptrues_p_s(Pd, pattern, size);
#else
        RT_NOREF(Pd, pattern, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffe10/05314000: PUNPKHI  <Pd>.H, <Pn>.B
   Instruction Set: A64  Groups: sve_int_perm_punpk, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_punpkhi_p_p, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: punpkhi_p_p Pd=%#x Pn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn));
#ifdef IEM_INSTR_IMPL_A64__punpkhi_p_p
        IEM_INSTR_IMPL_A64__punpkhi_p_p(Pd, Pn);
#else
        RT_NOREF(Pd, Pn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffe10/05304000: PUNPKLO  <Pd>.H, <Pn>.B
   Instruction Set: A64  Groups: sve_int_perm_punpk, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_punpklo_p_p, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: punpklo_p_p Pd=%#x Pn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn));
#ifdef IEM_INSTR_IMPL_A64__punpklo_p_p
        IEM_INSTR_IMPL_A64__punpklo_p_p(Pd, Pn);
#else
        RT_NOREF(Pd, Pn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45206800: RADDHNB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_arith_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_raddhnb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: raddhnb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__raddhnb_z_zz
        IEM_INSTR_IMPL_A64__raddhnb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45206c00: RADDHNT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_arith_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_raddhnt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: raddhnt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__raddhnt_z_zz
        IEM_INSTR_IMPL_A64__raddhnt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4520f400: RAX1  <Zd>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_crypto_binary_const, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_rax1_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveSha3 /*FEAT_SVE_SHA3*/)
    {
        LogFlow(("%018x/%010x: rax1_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__rax1_z_zz
        IEM_INSTR_IMPL_A64__rax1_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05278000: RBIT  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_rev, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_rbit_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: rbit_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__rbit_z_p_z_m
        IEM_INSTR_IMPL_A64__rbit_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0527a000: RBIT  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_rev, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_rbit_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0527a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: rbit_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__rbit_z_p_z_z
            IEM_INSTR_IMPL_A64__rbit_z_p_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffff0/2519f000: RDFFR  <Pd>.B
   Instruction Set: A64  Groups: sve_int_rdffr_2, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_rdffr_p_f, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: rdffr_p_f Pd=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd));
#ifdef IEM_INSTR_IMPL_A64__rdffr_p_f
        IEM_INSTR_IMPL_A64__rdffr_p_f(Pd);
#else
        RT_NOREF(Pd, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffe10/2518f000: RDFFR  <Pd>.B, <Pg>/Z
   Instruction Set: A64  Groups: sve_int_rdffr, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_rdffr_p_p_f, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >>  5) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: rdffr_p_p_f Pd=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pg));
#ifdef IEM_INSTR_IMPL_A64__rdffr_p_p_f
        IEM_INSTR_IMPL_A64__rdffr_p_p_f(Pd, Pg);
#else
        RT_NOREF(Pd, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffe10/2558f000: RDFFRS  <Pd>.B, <Pg>/Z
   Instruction Set: A64  Groups: sve_int_rdffr, sve_pred_gen_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_rdffrs_p_p_f, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >>  5) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: rdffrs_p_p_f Pd=%#x Pg=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pg));
#ifdef IEM_INSTR_IMPL_A64__rdffrs_p_p_f
        IEM_INSTR_IMPL_A64__rdffrs_p_p_f(Pd, Pg);
#else
        RT_NOREF(Pd, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffff800/04bf5800: RDSVL  <Xd>, #<imm>
   Instruction Set: A64  Groups: sve_int_read_svl_a, sve_alloca, sve */
FNIEMOP_DEF_1(iemDecodeA64_rdsvl_r_i, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff800)) == UINT32_C(0x04bf5800))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >>  5) & 0x0000003f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: rdsvl_r_i Rd=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm6));
#ifdef IEM_INSTR_IMPL_A64__rdsvl_r_i
            IEM_INSTR_IMPL_A64__rdsvl_r_i(Rd, imm6);
#else
            RT_NOREF(Rd, imm6, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffff800/04bf5000: RDVL  <Xd>, #<imm>
   Instruction Set: A64  Groups: sve_int_read_vl_a, sve_alloca, sve */
FNIEMOP_DEF_1(iemDecodeA64_rdvl_r_i, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff800)) == UINT32_C(0x04bf5000))
    {
        uint32_t const Rd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm6       = (uOpcode >>  5) & 0x0000003f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: rdvl_r_i Rd=%#x imm6=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rd, imm6));
#ifdef IEM_INSTR_IMPL_A64__rdvl_r_i
            IEM_INSTR_IMPL_A64__rdvl_r_i(Rd, imm6);
#else
            RT_NOREF(Rd, imm6, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe10/05344000: REV  <Pd>.<T>, <Pn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_reverse_p, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_rev_p_p, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: rev_p_p Pd=%#x Pn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, size));
#ifdef IEM_INSTR_IMPL_A64__rev_p_p
        IEM_INSTR_IMPL_A64__rev_p_p(Pd, Pn, size);
#else
        RT_NOREF(Pd, Pn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/05383800: REV  <Zd>.<T>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_reverse_z, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_rev_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: rev_z_z Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__rev_z_z
        IEM_INSTR_IMPL_A64__rev_z_z(Zd, Zn, size);
#else
        RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05248000: REVB  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_rev, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_revb_z_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: revb_z_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__revb_z_z_m
        IEM_INSTR_IMPL_A64__revb_z_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0524a000: REVB  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_rev, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_revb_z_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0524a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: revb_z_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__revb_z_z_z
            IEM_INSTR_IMPL_A64__revb_z_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/052e8000: REVD  <Zd>.Q, <Pg>/M, <Zn>.Q
   Instruction Set: A64  Groups: sve_int_perm_revd, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_revd_z_p_z_m, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x052e8000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
        {
            LogFlow(("%018x/%010x: revd_z_p_z_m Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__revd_z_p_z_m
            IEM_INSTR_IMPL_A64__revd_z_p_z_m(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/052ea000: REVD  <Zd>.Q, <Pg>/Z, <Zn>.Q
   Instruction Set: A64  Groups: sve_int_perm_revd, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_revd_z_p_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x052ea000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: revd_z_p_z_z Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__revd_z_p_z_z
            IEM_INSTR_IMPL_A64__revd_z_p_z_z(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05258000: REVH  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_rev, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_revh_z_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: revh_z_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__revh_z_z_m
        IEM_INSTR_IMPL_A64__revh_z_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0525a000: REVH  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_perm_rev, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_revh_z_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0525a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: revh_z_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__revh_z_z_z
            IEM_INSTR_IMPL_A64__revh_z_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/05268000: REVW  <Zd>.D, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_int_perm_rev, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_revw_z_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: revw_z_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__revw_z_z_m
        IEM_INSTR_IMPL_A64__revw_z_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0526a000: REVW  <Zd>.D, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_int_perm_rev, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_revw_z_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0526a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: revw_z_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__revw_z_z_z
            IEM_INSTR_IMPL_A64__revw_z_z_z(Zd, Zn, Pg, size);
#else
            RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45201800: RSHRNB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_rshrnb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: rshrnb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__rshrnb_z_zi
        IEM_INSTR_IMPL_A64__rshrnb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45201c00: RSHRNT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_rshrnt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: rshrnt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__rshrnt_z_zi
        IEM_INSTR_IMPL_A64__rshrnt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45207800: RSUBHNB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_arith_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_rsubhnb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: rsubhnb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__rsubhnb_z_zz
        IEM_INSTR_IMPL_A64__rsubhnb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45207c00: RSUBHNT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_arith_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_rsubhnt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: rsubhnt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__rsubhnt_z_zz
        IEM_INSTR_IMPL_A64__rsubhnt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500f800: SABA  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_aba, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_saba_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: saba_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__saba_z_zzz
        IEM_INSTR_IMPL_A64__saba_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500c000: SABALB  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_aba_long, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_sabalb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sabalb_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sabalb_z_zzz
        IEM_INSTR_IMPL_A64__sabalb_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500c400: SABALT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_aba_long, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_sabalt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sabalt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sabalt_z_zzz
        IEM_INSTR_IMPL_A64__sabalt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040c0000: SABD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_1, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_sabd_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040c0000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sabd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sabd_z_p_zz
            IEM_INSTR_IMPL_A64__sabd_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45003000: SABDLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_sabdlb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sabdlb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sabdlb_z_zz
        IEM_INSTR_IMPL_A64__sabdlb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45003400: SABDLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_sabdlt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sabdlt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sabdlt_z_zz
        IEM_INSTR_IMPL_A64__sabdlt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4404a000: SADALP  <Zda>.<T>, <Pg>/M, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_intx_accumulate_long_pairs, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sadalp_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sadalp_z_p_z Zda=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sadalp_z_p_z
        IEM_INSTR_IMPL_A64__sadalp_z_p_z(Zda, Zn, Pg, size);
#else
        RT_NOREF(Zda, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45000000: SADDLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_saddlb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: saddlb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__saddlb_z_zz
        IEM_INSTR_IMPL_A64__saddlb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45008000: SADDLBT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_clong, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_saddlbt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: saddlbt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__saddlbt_z_zz
        IEM_INSTR_IMPL_A64__saddlbt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45000400: SADDLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_saddlt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: saddlt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__saddlt_z_zz
        IEM_INSTR_IMPL_A64__saddlt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04002000: SADDV  <Dd>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_0, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_saddv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: saddv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__saddv_r_p_z
        IEM_INSTR_IMPL_A64__saddv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45004000: SADDWB  <Zd>.<T>, <Zn>.<T>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_wide, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_saddwb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: saddwb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__saddwb_z_zz
        IEM_INSTR_IMPL_A64__saddwb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45004400: SADDWT  <Zd>.<T>, <Zn>.<T>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_wide, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_saddwt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: saddwt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__saddwt_z_zz
        IEM_INSTR_IMPL_A64__saddwt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4580d000: SBCLB  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_adc_long, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_sbclb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sbclb_z_zzz Zda=%#x Zn=%#x Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sbclb_z_zzz
        IEM_INSTR_IMPL_A64__sbclb_z_zzz(Zda, Zn, Zm, sz);
#else
        RT_NOREF(Zda, Zn, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4580d400: SBCLT  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_adc_long, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_sbclt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sbclt_z_zzz Zda=%#x Zn=%#x Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sbclt_z_zzz
        IEM_INSTR_IMPL_A64__sbclt_z_zzz(Zda, Zn, Zm, sz);
#else
        RT_NOREF(Zda, Zn, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc01/c120c400: SCLAMP  { <Zd1>.<T>-<Zd2>.<T> }, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_clamp_int, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sclamp_mz_zz_2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sclamp_mz_zz_2 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sclamp_mz_zz_2
        IEM_INSTR_IMPL_A64__sclamp_mz_zz_2(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc03/c120cc00: SCLAMP  { <Zd1>.<T>-<Zd4>.<T> }, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_clamp_int, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sclamp_mz_zz_4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sclamp_mz_zz_4 Zd=%u Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sclamp_mz_zz_4
        IEM_INSTR_IMPL_A64__sclamp_mz_zz_4(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4400c000: SCLAMP  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_clamp_lvl2, sve_intx_clamp, sve */
FNIEMOP_DEF_1(iemDecodeA64_sclamp_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: sclamp_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sclamp_z_zz
        IEM_INSTR_IMPL_A64__sclamp_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc21/c122e000: SCVTF  { <Zd1>.S-<Zd2>.S }, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_intfp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc21)) == UINT32_C(0xc122e000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: scvtf_mz_z_2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__scvtf_mz_z_2
            IEM_INSTR_IMPL_A64__scvtf_mz_z_2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c132e000: SCVTF  { <Zd1>.S-<Zd4>.S }, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_intfp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc132e000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: scvtf_mz_z_4 Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__scvtf_mz_z_4
            IEM_INSTR_IMPL_A64__scvtf_mz_z_4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6552a000: SCVTF  <Zd>.H, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_h2fp16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_h2fp16 Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_h2fp16
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_h2fp16(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645cc000: SCVTF  <Zd>.H, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_h2fp16z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645cc000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: scvtf_z_p_z_h2fp16z Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_h2fp16z
            IEM_INSTR_IMPL_A64__scvtf_z_p_z_h2fp16z(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65d0a000: SCVTF  <Zd>.D, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_w2d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_w2d Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2d
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2d(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dc8000: SCVTF  <Zd>.D, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_w2dz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_w2dz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2dz
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2dz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6554a000: SCVTF  <Zd>.H, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_w2fp16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_w2fp16 Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2fp16
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2fp16(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645d8000: SCVTF  <Zd>.H, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_w2fp16z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_w2fp16z Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2fp16z
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2fp16z(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6594a000: SCVTF  <Zd>.S, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_w2s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_w2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2s
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2s(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/649d8000: SCVTF  <Zd>.S, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_w2sz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_w2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2sz
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_w2sz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65d6a000: SCVTF  <Zd>.D, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_x2d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_x2d Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2d
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2d(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64ddc000: SCVTF  <Zd>.D, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_x2dz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64ddc000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: scvtf_z_p_z_x2dz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2dz
            IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2dz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6556a000: SCVTF  <Zd>.H, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_x2fp16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_x2fp16 Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2fp16
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2fp16(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645dc000: SCVTF  <Zd>.H, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_x2fp16z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645dc000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: scvtf_z_p_z_x2fp16z Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2fp16z
            IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2fp16z(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65d4a000: SCVTF  <Zd>.S, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_x2s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_x2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2s
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2s(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dd8000: SCVTF  <Zd>.S, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_scvtf_z_p_z_x2sz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: scvtf_z_p_z_x2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2sz
        IEM_INSTR_IMPL_A64__scvtf_z_p_z_x2sz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04140000: SDIV  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_div, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_sdiv_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04140000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sdiv_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sdiv_z_p_zz
            IEM_INSTR_IMPL_A64__sdiv_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04160000: SDIVR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_div, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_sdivr_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04160000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sdivr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sdivr_z_p_zz
            IEM_INSTR_IMPL_A64__sdivr_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4400c800: SDOT  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_intx_dot2_lvl2, sve_intx_dot2, sve */
FNIEMOP_DEF_1(iemDecodeA64_sdot_z32_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: sdot_z32_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_z32_zzz
        IEM_INSTR_IMPL_A64__sdot_z32_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4480c800: SDOT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_dot2_by_indexed_elem_lvl2, sve_intx_dot2_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sdot_z32_zzzi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: sdot_z32_zzzi Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__sdot_z32_zzzi
        IEM_INSTR_IMPL_A64__sdot_z32_zzzi(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/44800000: SDOT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_dot, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sdot_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sdot_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sdot_z_zzz
        IEM_INSTR_IMPL_A64__sdot_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e00000: SDOT  <Zda>.D, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_dot_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sdot_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sdot_z_zzzi_d Zda=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__sdot_z_zzzi_d
        IEM_INSTR_IMPL_A64__sdot_z_zzzi_d(Zda, Zn, Zm, i1);
#else
        RT_NOREF(Zda, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a00000: SDOT  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_intx_dot_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sdot_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sdot_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__sdot_z_zzzi_s
        IEM_INSTR_IMPL_A64__sdot_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1501000: SDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za32_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sdot_za32_zzi_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za32_zzi_2xi
        IEM_INSTR_IMPL_A64__sdot_za32_zzi_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1509000: SDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za32_zzi_4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sdot_za32_zzi_4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za32_zzi_4xi
        IEM_INSTR_IMPL_A64__sdot_za32_zzi_4xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1601408: SDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_za_2way_dot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za32_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sdot_za32_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za32_zzv_2x1
        IEM_INSTR_IMPL_A64__sdot_za32_zzv_2x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1701408: SDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_za_2way_dot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za32_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sdot_za32_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za32_zzv_4x1
        IEM_INSTR_IMPL_A64__sdot_za32_zzv_4x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1e01408: SDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_2way_dot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za32_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c38)) == UINT32_C(0xc1e01408))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sdot_za32_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za32_zzw_2x2
            IEM_INSTR_IMPL_A64__sdot_za32_zzw_2x2(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1e11408: SDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_2way_dot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za32_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1e11408))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sdot_za32_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za32_zzw_4x4
            IEM_INSTR_IMPL_A64__sdot_za32_zzw_4x4(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09838/c1d00008: SDOT  ZA.D[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_d, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za_zzi_d2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sdot_za_zzi_d2xi off3=%u Zn=%#x i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za_zzi_d2xi
        IEM_INSTR_IMPL_A64__sdot_za_zzi_d2xi(off3, Zn, i1, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1d08008: SDOT  ZA.D[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za_zzi_d4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sdot_za_zzi_d4xi off3=%u Zn=%u i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za_zzi_d4xi
        IEM_INSTR_IMPL_A64__sdot_za_zzi_d4xi(off3, Zn, i1, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1501020: SDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sdot_za_zzi_s2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__sdot_za_zzi_s2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1509020: SDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za_zzi_s4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sdot_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sdot_za_zzi_s4xi
        IEM_INSTR_IMPL_A64__sdot_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1201400: SDOT  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi2_z_za_4way_dot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sdot_za_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sdot_za_zzv_2x1
        IEM_INSTR_IMPL_A64__sdot_za_zzv_2x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1301400: SDOT  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi4_z_za_4way_dot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sdot_za_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sdot_za_zzv_4x1
        IEM_INSTR_IMPL_A64__sdot_za_zzv_4x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c38/c1a01400: SDOT  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, { <Zm1>.<Tb>-<Zm2>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_4way_dot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c38)) == UINT32_C(0xc1a01400))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sdot_za_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sdot_za_zzw_2x2
            IEM_INSTR_IMPL_A64__sdot_za_zzw_2x2(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c78/c1a11400: SDOT  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, { <Zm1>.<Tb>-<Zm4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_4way_dot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sdot_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c78)) == UINT32_C(0xc1a11400))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sdot_za_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sdot_za_zzw_4x4
            IEM_INSTR_IMPL_A64__sdot_za_zzw_4x4(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21e021/c1208000: SEL  { <Zd1>.<T>-<Zd2>.<T> }, <PNg>, { <Zn1>.<T>-<Zn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_select_int, mortlach_multi_sve_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_sel_mz_p_zz_2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sel_mz_p_zz_2 Zd=%#x Zn=%#x PNg=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, PNg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sel_mz_p_zz_2
        IEM_INSTR_IMPL_A64__sel_mz_p_zz_2(Zd, Zn, PNg, Zm, size);
#else
        RT_NOREF(Zd, Zn, PNg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23e063/c1218000: SEL  { <Zd1>.<T>-<Zd4>.<T> }, <PNg>, { <Zn1>.<T>-<Zn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_select_int, mortlach_multi_sve_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_sel_mz_p_zz_4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sel_mz_p_zz_4 Zd=%u Zn=%u PNg=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, PNg, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sel_mz_p_zz_4
        IEM_INSTR_IMPL_A64__sel_mz_p_zz_4(Zd, Zn, PNg, Zm, size);
#else
        RT_NOREF(Zd, Zn, PNg, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0c210/25004210: SEL  <Pd>.B, <Pg>, <Pn>.B, <Pm>.B
   Instruction Set: A64  Groups: sve_int_pred_log, sve_pred_gen_a, sve */
FNIEMOP_DEF_1(iemDecodeA64_sel_p_p_pp, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sel_p_p_pp Pd=%#x Pn=%#x Pg=%#x Pm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pg, Pm));
#ifdef IEM_INSTR_IMPL_A64__sel_p_p_pp
        IEM_INSTR_IMPL_A64__sel_p_p_pp(Pd, Pn, Pg, Pm);
#else
        RT_NOREF(Pd, Pn, Pg, Pm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20c000/0520c000: SEL  <Zd>.<T>, <Pv>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_sel_vvv, sve_int_select, sve */
FNIEMOP_DEF_1(iemDecodeA64_sel_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pv         = (uOpcode >> 10) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sel_z_p_zz Zd=%#x Zn=%#x Pv=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pv, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sel_z_p_zz
        IEM_INSTR_IMPL_A64__sel_z_p_zz(Zd, Zn, Pv, Zm, size);
#else
        RT_NOREF(Zd, Zn, Pv, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/252c9000: SETFFR
   Instruction Set: A64  Groups: sve_int_setffr, sve_pred_wrffr, sve */
FNIEMOP_DEF_1(iemDecodeA64_setffr_f, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0x252c9000))
    {
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: setffr_f\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__setffr_f
            IEM_INSTR_IMPL_A64__setffr_f();
#else
            RT_NOREF(pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44108000: SHADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_shadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: shadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__shadd_z_p_zz
        IEM_INSTR_IMPL_A64__shadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45201000: SHRNB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_shrnb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: shrnb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__shrnb_z_zi
        IEM_INSTR_IMPL_A64__shrnb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45201400: SHRNT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_shrnt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: shrnt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__shrnt_z_zi
        IEM_INSTR_IMPL_A64__shrnt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44128000: SHSUB  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_shsub_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: shsub_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__shsub_z_p_zz
        IEM_INSTR_IMPL_A64__shsub_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44168000: SHSUBR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_shsubr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: shsubr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__shsubr_z_p_zz
        IEM_INSTR_IMPL_A64__shsubr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500f400: SLI  <Zd>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_insert, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_sli_z_zzi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sli_z_zzi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sli_z_zzi
        IEM_INSTR_IMPL_A64__sli_z_zzi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc00/4523e000: SM4E  <Zdn>.S, <Zdn>.S, <Zm>.S
   Instruction Set: A64  Groups: sve_crypto_binary_dest, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_sm4e_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveSm4 /*FEAT_SVE_SM4*/)
    {
        LogFlow(("%018x/%010x: sm4e_z_zz Zdn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sm4e_z_zz
        IEM_INSTR_IMPL_A64__sm4e_z_zz(Zdn, Zm);
#else
        RT_NOREF(Zdn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4520f000: SM4EKEY  <Zd>.S, <Zn>.S, <Zm>.S
   Instruction Set: A64  Groups: sve_crypto_binary_const, sve_intx_crypto, sve */
FNIEMOP_DEF_1(iemDecodeA64_sm4ekey_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSveSm4 /*FEAT_SVE_SM4*/)
    {
        LogFlow(("%018x/%010x: sm4ekey_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sm4ekey_z_zz
        IEM_INSTR_IMPL_A64__sm4ekey_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a000: SMAX  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_minmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smax_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a000))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smax_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smax_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__smax_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a800: SMAX  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_minmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smax_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a800))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smax_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smax_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__smax_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b000: SMAX  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_minmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_smax_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b000))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smax_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smax_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__smax_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b800: SMAX  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_minmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_smax_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b800))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smax_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smax_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__smax_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04080000: SMAX  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_1, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_smax_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04080000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: smax_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__smax_z_p_zz
            IEM_INSTR_IMPL_A64__smax_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/2528c000: SMAX  <Zdn>.<T>, <Zdn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_imm1, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_smax_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smax_z_zi Zdn=%#x imm8=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, size));
#ifdef IEM_INSTR_IMPL_A64__smax_z_zi
        IEM_INSTR_IMPL_A64__smax_z_zi(Zdn, imm8, size);
#else
        RT_NOREF(Zdn, imm8, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4414a000: SMAXP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_arith_binary_pairs, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_smaxp_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smaxp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__smaxp_z_p_zz
        IEM_INSTR_IMPL_A64__smaxp_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040c2000: SMAXQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_reduce_1q, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_smaxqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: smaxqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__smaxqv_z_p_z
        IEM_INSTR_IMPL_A64__smaxqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04082000: SMAXV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_1, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_smaxv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smaxv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__smaxv_r_p_z
        IEM_INSTR_IMPL_A64__smaxv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a020: SMIN  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_minmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smin_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a020))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smin_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smin_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__smin_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a820: SMIN  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_minmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smin_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a820))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smin_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smin_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__smin_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b020: SMIN  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_minmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_smin_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smin_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smin_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__smin_mz_zzw_2x2(Zdn, Zm, size);
#else
        RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b820: SMIN  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_minmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_smin_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smin_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smin_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__smin_mz_zzw_4x4(Zdn, Zm, size);
#else
        RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040a0000: SMIN  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_1, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_smin_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040a0000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: smin_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__smin_z_p_zz
            IEM_INSTR_IMPL_A64__smin_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/252ac000: SMIN  <Zdn>.<T>, <Zdn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_imm1, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_smin_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smin_z_zi Zdn=%#x imm8=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, size));
#ifdef IEM_INSTR_IMPL_A64__smin_z_zi
        IEM_INSTR_IMPL_A64__smin_z_zi(Zdn, imm8, size);
#else
        RT_NOREF(Zdn, imm8, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4416a000: SMINP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_arith_binary_pairs, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sminp_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sminp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sminp_z_p_zz
        IEM_INSTR_IMPL_A64__sminp_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040e2000: SMINQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_reduce_1q, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_sminqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: sminqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sminqv_z_p_z
        IEM_INSTR_IMPL_A64__sminqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040a2000: SMINV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_1, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_sminv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sminv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sminv_r_p_z
        IEM_INSTR_IMPL_A64__sminv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01018/c1c01000: SMLAL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlal_za_zzi_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlal_za_zzi_1 off3=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlal_za_zzi_1
        IEM_INSTR_IMPL_A64__smlal_za_zzi_1(off3, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off3, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1d01000: SMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlal_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlal_za_zzi_2xi off2=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlal_za_zzi_2xi
        IEM_INSTR_IMPL_A64__smlal_za_zzi_2xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1d09000: SMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlal_za_zzi_4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09000))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlal_za_zzi_4xi off2=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlal_za_zzi_4xi
            IEM_INSTR_IMPL_A64__smlal_za_zzi_4xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1600c00: SMLAL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlal_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlal_za_zzv_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlal_za_zzv_1
        IEM_INSTR_IMPL_A64__smlal_za_zzv_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1600800: SMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlal_za_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c1c)) == UINT32_C(0xc1600800))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlal_za_zzv_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlal_za_zzv_2x1
            IEM_INSTR_IMPL_A64__smlal_za_zzv_2x1(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1700800: SMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlal_za_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c1c)) == UINT32_C(0xc1700800))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlal_za_zzv_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlal_za_zzv_4x1
            IEM_INSTR_IMPL_A64__smlal_za_zzv_4x1(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1e00800: SMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlal_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c3c)) == UINT32_C(0xc1e00800))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlal_za_zzw_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlal_za_zzw_2x2
            IEM_INSTR_IMPL_A64__smlal_za_zzw_2x2(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1e10800: SMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlal_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1e10800))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlal_za_zzw_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlal_za_zzw_4x4
            IEM_INSTR_IMPL_A64__smlal_za_zzw_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44004000: SMLALB  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_mlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlalb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlalb_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smlalb_z_zzz
        IEM_INSTR_IMPL_A64__smlalb_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e08000: SMLALB  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlalb_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlalb_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__smlalb_z_zzzi_d
        IEM_INSTR_IMPL_A64__smlalb_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a08000: SMLALB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlalb_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlalb_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__smlalb_z_zzzi_s
        IEM_INSTR_IMPL_A64__smlalb_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0101c/c1800000: SMLALL  ZA.D[<Wv>, <offs1>:<offs4>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_d, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzi_d, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smlall_za_zzi_d off2=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzi_d
        IEM_INSTR_IMPL_A64__smlall_za_zzi_d(off2, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off2, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09838/c1900000: SMLALL  ZA.D[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_d, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzi_d2xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i3l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smlall_za_zzi_d2xi o1=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzi_d2xi
        IEM_INSTR_IMPL_A64__smlall_za_zzi_d2xi(o1, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(o1, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1908000: SMLALL  ZA.D[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzi_d4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1908000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i3l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: smlall_za_zzi_d4xi o1=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzi_d4xi
            IEM_INSTR_IMPL_A64__smlall_za_zzi_d4xi(o1, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(o1, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0001c/c1000000: SMLALL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_s, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzi_s, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i4h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlall_za_zzi_s off2=%u Zn=%#x i4l=%u Rv=%u i4h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i4l, Rv, i4h, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzi_s
        IEM_INSTR_IMPL_A64__smlall_za_zzi_s(off2, Zn, i4l, Rv, i4h, Zm);
#else
        RT_NOREF(off2, Zn, i4l, Rv, i4h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1100000: SMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlall_za_zzi_s2xi o1=%u i4l=%u Zn=%#x i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__smlall_za_zzi_s2xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1108000: SMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzi_s4xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlall_za_zzi_s4xi o1=%u i4l=%u Zn=%u i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzi_s4xi
        IEM_INSTR_IMPL_A64__smlall_za_zzi_s4xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1c/c1200400: SMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>], <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlall_za_zzv_1 off2=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzv_1
        IEM_INSTR_IMPL_A64__smlall_za_zzv_1(off2, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off2, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1e/c1200000: SMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1e)) == UINT32_C(0xc1200000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlall_za_zzv_2x1 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzv_2x1
            IEM_INSTR_IMPL_A64__smlall_za_zzv_2x1(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1e/c1300000: SMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1e)) == UINT32_C(0xc1300000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlall_za_zzv_4x1 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzv_4x1
            IEM_INSTR_IMPL_A64__smlall_za_zzv_4x1(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c3e/c1a00000: SMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, { <Zm1>.<Tb>-<Zm2>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c3e)) == UINT32_C(0xc1a00000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlall_za_zzw_2x2 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzw_2x2
            IEM_INSTR_IMPL_A64__smlall_za_zzw_2x2(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c7e/c1a10000: SMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, { <Zm1>.<Tb>-<Zm4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlall_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c7e)) == UINT32_C(0xc1a10000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlall_za_zzw_4x4 o1=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlall_za_zzw_4x4
            IEM_INSTR_IMPL_A64__smlall_za_zzw_4x4(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44004400: SMLALT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_mlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlalt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlalt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smlalt_z_zzz
        IEM_INSTR_IMPL_A64__smlalt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e08400: SMLALT  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlalt_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlalt_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__smlalt_z_zzzi_d
        IEM_INSTR_IMPL_A64__smlalt_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a08400: SMLALT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlalt_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlalt_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__smlalt_z_zzzi_s
        IEM_INSTR_IMPL_A64__smlalt_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01018/c1c01008: SMLSL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsl_za_zzi_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlsl_za_zzi_1 off3=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsl_za_zzi_1
        IEM_INSTR_IMPL_A64__smlsl_za_zzi_1(off3, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off3, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1d01008: SMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsl_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlsl_za_zzi_2xi off2=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsl_za_zzi_2xi
        IEM_INSTR_IMPL_A64__smlsl_za_zzi_2xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1d09008: SMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsl_za_zzi_4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09008))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsl_za_zzi_4xi off2=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsl_za_zzi_4xi
            IEM_INSTR_IMPL_A64__smlsl_za_zzi_4xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1600c08: SMLSL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsl_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlsl_za_zzv_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsl_za_zzv_1
        IEM_INSTR_IMPL_A64__smlsl_za_zzv_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1600808: SMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsl_za_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c1c)) == UINT32_C(0xc1600808))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsl_za_zzv_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsl_za_zzv_2x1
            IEM_INSTR_IMPL_A64__smlsl_za_zzv_2x1(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1700808: SMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsl_za_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c1c)) == UINT32_C(0xc1700808))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsl_za_zzv_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsl_za_zzv_4x1
            IEM_INSTR_IMPL_A64__smlsl_za_zzv_4x1(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1e00808: SMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsl_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c3c)) == UINT32_C(0xc1e00808))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsl_za_zzw_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsl_za_zzw_2x2
            IEM_INSTR_IMPL_A64__smlsl_za_zzw_2x2(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1e10808: SMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsl_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1e10808))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsl_za_zzw_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsl_za_zzw_4x4
            IEM_INSTR_IMPL_A64__smlsl_za_zzw_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44005000: SMLSLB  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_mlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlslb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlslb_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smlslb_z_zzz
        IEM_INSTR_IMPL_A64__smlslb_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0a000: SMLSLB  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlslb_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlslb_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__smlslb_z_zzzi_d
        IEM_INSTR_IMPL_A64__smlslb_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0a000: SMLSLB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlslb_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlslb_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__smlslb_z_zzzi_s
        IEM_INSTR_IMPL_A64__smlslb_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0101c/c1800008: SMLSLL  ZA.D[<Wv>, <offs1>:<offs4>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_d, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzi_d, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smlsll_za_zzi_d off2=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzi_d
        IEM_INSTR_IMPL_A64__smlsll_za_zzi_d(off2, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off2, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09838/c1900008: SMLSLL  ZA.D[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_d, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzi_d2xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09838)) == UINT32_C(0xc1900008))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i3l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzi_d2xi o1=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzi_d2xi
            IEM_INSTR_IMPL_A64__smlsll_za_zzi_d2xi(o1, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(o1, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1908008: SMLSLL  ZA.D[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzi_d4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1908008))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i3l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzi_d4xi o1=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzi_d4xi
            IEM_INSTR_IMPL_A64__smlsll_za_zzi_d4xi(o1, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(o1, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0001c/c1000008: SMLSLL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_s, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzi_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000008))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const i4l        = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const i4h        = (uOpcode >> 15) & 0x00000001;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzi_s off2=%u Zn=%#x i4l=%u Rv=%u i4h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i4l, Rv, i4h, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzi_s
            IEM_INSTR_IMPL_A64__smlsll_za_zzi_s(off2, Zn, i4l, Rv, i4h, Zm);
#else
            RT_NOREF(off2, Zn, i4l, Rv, i4h, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1100008: SMLSLL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzi_s2xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09038)) == UINT32_C(0xc1100008))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzi_s2xi o1=%u i4l=%u Zn=%#x i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzi_s2xi
            IEM_INSTR_IMPL_A64__smlsll_za_zzi_s2xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
            RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1108008: SMLSLL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzi_s4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1108008))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzi_s4xi o1=%u i4l=%u Zn=%u i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzi_s4xi
            IEM_INSTR_IMPL_A64__smlsll_za_zzi_s4xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
            RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1c/c1200408: SMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>], <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smlsll_za_zzv_1 off2=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzv_1
        IEM_INSTR_IMPL_A64__smlsll_za_zzv_1(off2, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off2, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1e/c1200008: SMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1e)) == UINT32_C(0xc1200008))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzv_2x1 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzv_2x1
            IEM_INSTR_IMPL_A64__smlsll_za_zzv_2x1(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1e/c1300008: SMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1e)) == UINT32_C(0xc1300008))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzv_4x1 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzv_4x1
            IEM_INSTR_IMPL_A64__smlsll_za_zzv_4x1(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c3e/c1a00008: SMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, { <Zm1>.<Tb>-<Zm2>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c3e)) == UINT32_C(0xc1a00008))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzw_2x2 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzw_2x2
            IEM_INSTR_IMPL_A64__smlsll_za_zzw_2x2(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c7e/c1a10008: SMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, { <Zm1>.<Tb>-<Zm4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_smlsll_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c7e)) == UINT32_C(0xc1a10008))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: smlsll_za_zzw_4x4 o1=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__smlsll_za_zzw_4x4
            IEM_INSTR_IMPL_A64__smlsll_za_zzw_4x4(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44005400: SMLSLT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_mlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlslt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlslt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smlslt_z_zzz
        IEM_INSTR_IMPL_A64__smlslt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0a400: SMLSLT  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlslt_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlslt_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__smlslt_z_zzzi_d
        IEM_INSTR_IMPL_A64__smlslt_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0a400: SMLSLT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smlslt_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smlslt_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__smlslt_z_zzzi_s
        IEM_INSTR_IMPL_A64__smlslt_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/45009800: SMMLA  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_intx_mmla, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_smmla_z_zzz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x45009800))
    {
        uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
        {
            LogFlow(("%018x/%010x: smmla_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smmla_z_zzz
            IEM_INSTR_IMPL_A64__smmla_z_zzz(Zda, Zn, Zm);
#else
            RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80008008: SMOP4A  <ZAda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za32_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4a_za32_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za32_zz_h1x1
        IEM_INSTR_IMPL_A64__smop4a_za32_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80108008: SMOP4A  <ZAda>.S, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za32_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4a_za32_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za32_zz_h1x2
        IEM_INSTR_IMPL_A64__smop4a_za32_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80008208: SMOP4A  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za32_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4a_za32_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za32_zz_h2x1
        IEM_INSTR_IMPL_A64__smop4a_za32_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80108208: SMOP4A  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za32_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4a_za32_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za32_zz_h2x2
        IEM_INSTR_IMPL_A64__smop4a_za32_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80008000: SMOP4A  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za_zz_b1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4a_za_zz_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za_zz_b1x1
        IEM_INSTR_IMPL_A64__smop4a_za_zz_b1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80108000: SMOP4A  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za_zz_b1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4a_za_zz_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za_zz_b1x2
        IEM_INSTR_IMPL_A64__smop4a_za_zz_b1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80008200: SMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za_zz_b2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4a_za_zz_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za_zz_b2x1
        IEM_INSTR_IMPL_A64__smop4a_za_zz_b2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80108200: SMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za_zz_b2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4a_za_zz_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za_zz_b2x2
        IEM_INSTR_IMPL_A64__smop4a_za_zz_b2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0c00008: SMOP4A  <ZAda>.D, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0c00008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: smop4a_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za_zz_h1x1
            IEM_INSTR_IMPL_A64__smop4a_za_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0d00008: SMOP4A  <ZAda>.D, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0d00008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: smop4a_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za_zz_h1x2
            IEM_INSTR_IMPL_A64__smop4a_za_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0c00208: SMOP4A  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0c00208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: smop4a_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za_zz_h2x1
            IEM_INSTR_IMPL_A64__smop4a_za_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0d00208: SMOP4A  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4a_za_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0d00208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: smop4a_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4a_za_zz_h2x2
            IEM_INSTR_IMPL_A64__smop4a_za_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80008018: SMOP4S  <ZAda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za32_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4s_za32_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za32_zz_h1x1
        IEM_INSTR_IMPL_A64__smop4s_za32_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80108018: SMOP4S  <ZAda>.S, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za32_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4s_za32_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za32_zz_h1x2
        IEM_INSTR_IMPL_A64__smop4s_za32_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80008218: SMOP4S  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za32_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4s_za32_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za32_zz_h2x1
        IEM_INSTR_IMPL_A64__smop4s_za32_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80108218: SMOP4S  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za32_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4s_za32_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za32_zz_h2x2
        IEM_INSTR_IMPL_A64__smop4s_za32_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80008010: SMOP4S  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za_zz_b1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4s_za_zz_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za_zz_b1x1
        IEM_INSTR_IMPL_A64__smop4s_za_zz_b1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80108010: SMOP4S  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za_zz_b1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4s_za_zz_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za_zz_b1x2
        IEM_INSTR_IMPL_A64__smop4s_za_zz_b1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80008210: SMOP4S  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za_zz_b2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4s_za_zz_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za_zz_b2x1
        IEM_INSTR_IMPL_A64__smop4s_za_zz_b2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80108210: SMOP4S  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za_zz_b2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
    {
        LogFlow(("%018x/%010x: smop4s_za_zz_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za_zz_b2x2
        IEM_INSTR_IMPL_A64__smop4s_za_zz_b2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0c00018: SMOP4S  <ZAda>.D, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smop4s_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za_zz_h1x1
        IEM_INSTR_IMPL_A64__smop4s_za_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0d00018: SMOP4S  <ZAda>.D, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smop4s_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za_zz_h1x2
        IEM_INSTR_IMPL_A64__smop4s_za_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0c00218: SMOP4S  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smop4s_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za_zz_h2x1
        IEM_INSTR_IMPL_A64__smop4s_za_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0d00218: SMOP4S  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_smop4s_za_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smop4s_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__smop4s_za_zz_h2x2
        IEM_INSTR_IMPL_A64__smop4s_za_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a0800008: SMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_smopa_za32_pp_zz_16, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smopa_za32_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__smopa_za32_pp_zz_16
        IEM_INSTR_IMPL_A64__smopa_za32_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a0800000: SMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_smopa_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smopa_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__smopa_za_pp_zz_32
        IEM_INSTR_IMPL_A64__smopa_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/a0c00000: SMOPA  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_smopa_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smopa_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__smopa_za_pp_zz_64
        IEM_INSTR_IMPL_A64__smopa_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a0800018: SMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_smops_za32_pp_zz_16, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: smops_za32_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__smops_za32_pp_zz_16
        IEM_INSTR_IMPL_A64__smops_za32_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a0800010: SMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_smops_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smops_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__smops_za_pp_zz_32
        IEM_INSTR_IMPL_A64__smops_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/a0c00010: SMOPS  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_smops_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: smops_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__smops_za_pp_zz_64
        IEM_INSTR_IMPL_A64__smops_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04120000: SMULH  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_2, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_smulh_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04120000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: smulh_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__smulh_z_p_zz
            IEM_INSTR_IMPL_A64__smulh_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04206800: SMULH  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_mul_b, sve_int_unpred_arit_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_smulh_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smulh_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smulh_z_zz
        IEM_INSTR_IMPL_A64__smulh_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45007000: SMULLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_smullb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smullb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smullb_z_zz
        IEM_INSTR_IMPL_A64__smullb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0c000: SMULLB  <Zd>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smullb_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smullb_z_zzi_d Zd=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__smullb_z_zzi_d
        IEM_INSTR_IMPL_A64__smullb_z_zzi_d(Zd, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zd, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0c000: SMULLB  <Zd>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smullb_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smullb_z_zzi_s Zd=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__smullb_z_zzi_s
        IEM_INSTR_IMPL_A64__smullb_z_zzi_s(Zd, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zd, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45007400: SMULLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_smullt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smullt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__smullt_z_zz
        IEM_INSTR_IMPL_A64__smullt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0c400: SMULLT  <Zd>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smullt_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smullt_z_zzi_d Zd=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__smullt_z_zzi_d
        IEM_INSTR_IMPL_A64__smullt_z_zzi_d(Zd, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zd, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0c400: SMULLT  <Zd>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_smullt_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: smullt_z_zzi_s Zd=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__smullt_z_zzi_s
        IEM_INSTR_IMPL_A64__smullt_z_zzi_s(Zd, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zd, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/052d8000: SPLICE  <Zd>.<T>, <Pv>, { <Zn1>.<T>, <Zn2>.<T> }
   Instruction Set: A64  Groups: sve_intx_perm_splice, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_splice_z_p_zz_con, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pv         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: splice_z_p_zz_con Zd=%#x Zn=%#x Pv=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pv, size));
#ifdef IEM_INSTR_IMPL_A64__splice_z_p_zz_con
        IEM_INSTR_IMPL_A64__splice_z_p_zz_con(Zd, Zn, Pv, size);
#else
        RT_NOREF(Zd, Zn, Pv, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/052c8000: SPLICE  <Zdn>.<T>, <Pv>, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_splice, sve_perm_pred, sve */
FNIEMOP_DEF_1(iemDecodeA64_splice_z_p_zz_des, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pv         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: splice_z_p_zz_des Zdn=%#x Zm=%#x Pv=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pv, size));
#ifdef IEM_INSTR_IMPL_A64__splice_z_p_zz_des
        IEM_INSTR_IMPL_A64__splice_z_p_zz_des(Zdn, Zm, Pv, size);
#else
        RT_NOREF(Zdn, Zm, Pv, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4408a000: SQABS  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_unary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqabs_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqabs_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqabs_z_p_z_m
        IEM_INSTR_IMPL_A64__sqabs_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/440aa000: SQABS  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_unary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqabs_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: sqabs_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqabs_z_p_z_z
        IEM_INSTR_IMPL_A64__sqabs_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44188000: SQADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary_sat, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqadd_z_p_zz
        IEM_INSTR_IMPL_A64__sqadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc000/2524c000: SQADD  <Zdn>.<T>, <Zdn>.<T>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_arith_imm0, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqadd_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc000)) == UINT32_C(0x2524c000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
        uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqadd_z_zi Zdn=%#x imm8=%#x sh=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, sh, size));
#ifdef IEM_INSTR_IMPL_A64__sqadd_z_zi
            IEM_INSTR_IMPL_A64__sqadd_z_zi(Zdn, imm8, sh, size);
#else
            RT_NOREF(Zdn, imm8, sh, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04201000: SQADD  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_cons_arit_0, sve_int_unpred_arit, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqadd_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqadd_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqadd_z_zz
        IEM_INSTR_IMPL_A64__sqadd_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ff800/4501d800: SQCADD  <Zdn>.<T>, <Zdn>.<T>, <Zm>.<T>, <const>
   Instruction Set: A64  Groups: sve_intx_cadd, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqcadd_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000001;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqcadd_z_zz Zdn=%#x Zm=%#x rot=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, rot, size));
#ifdef IEM_INSTR_IMPL_A64__sqcadd_z_zz
        IEM_INSTR_IMPL_A64__sqcadd_z_zz(Zdn, Zm, rot, size);
#else
        RT_NOREF(Zdn, Zm, rot, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c123e000: SQCVT  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqcvt_z_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc123e000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sqcvt_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__sqcvt_z_mz2
            IEM_INSTR_IMPL_A64__sqcvt_z_mz2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff7ffc60/c133e000: SQCVT  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqcvt_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 23) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqcvt_z_mz4 Zd=%#x Zn=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, sz));
#ifdef IEM_INSTR_IMPL_A64__sqcvt_z_mz4
        IEM_INSTR_IMPL_A64__sqcvt_z_mz4(Zd, Zn, sz);
#else
        RT_NOREF(Zd, Zn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/45314000: SQCVTN  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: sve_intx_multi_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqcvtn_z_mz2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: sqcvtn_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__sqcvtn_z_mz2
        IEM_INSTR_IMPL_A64__sqcvtn_z_mz2(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff7ffc60/c133e040: SQCVTN  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqcvtn_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 23) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqcvtn_z_mz4 Zd=%#x Zn=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, sz));
#ifdef IEM_INSTR_IMPL_A64__sqcvtn_z_mz4
        IEM_INSTR_IMPL_A64__sqcvtn_z_mz4(Zd, Zn, sz);
#else
        RT_NOREF(Zd, Zn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c163e000: SQCVTU  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqcvtu_z_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc163e000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sqcvtu_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__sqcvtu_z_mz2
            IEM_INSTR_IMPL_A64__sqcvtu_z_mz2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff7ffc60/c173e000: SQCVTU  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqcvtu_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 23) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqcvtu_z_mz4 Zd=%#x Zn=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, sz));
#ifdef IEM_INSTR_IMPL_A64__sqcvtu_z_mz4
        IEM_INSTR_IMPL_A64__sqcvtu_z_mz4(Zd, Zn, sz);
#else
        RT_NOREF(Zd, Zn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/45315000: SQCVTUN  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: sve_intx_multi_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqcvtun_z_mz2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: sqcvtun_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__sqcvtun_z_mz2
        IEM_INSTR_IMPL_A64__sqcvtun_z_mz2(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff7ffc60/c173e040: SQCVTUN  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqcvtun_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 23) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqcvtun_z_mz4 Zd=%#x Zn=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, sz));
#ifdef IEM_INSTR_IMPL_A64__sqcvtun_z_mz4
        IEM_INSTR_IMPL_A64__sqcvtun_z_mz4(Zd, Zn, sz);
#else
        RT_NOREF(Zd, Zn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0420f800: SQDECB  <Xdn>, <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecb_r_rs_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdecb_r_rs_sx Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdecb_r_rs_sx
        IEM_INSTR_IMPL_A64__sqdecb_r_rs_sx(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0430f800: SQDECB  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecb_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdecb_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdecb_r_rs_x
        IEM_INSTR_IMPL_A64__sqdecb_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0f800: SQDECD  <Xdn>, <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecd_r_rs_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdecd_r_rs_sx Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdecd_r_rs_sx
        IEM_INSTR_IMPL_A64__sqdecd_r_rs_sx(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04f0f800: SQDECD  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecd_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdecd_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdecd_r_rs_x
        IEM_INSTR_IMPL_A64__sqdecd_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0c800: SQDECD  <Zdn>.D{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecd_z_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0c800))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqdecd_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdecd_z_zs
            IEM_INSTR_IMPL_A64__sqdecd_z_zs(Zdn, pattern, imm4);
#else
            RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460f800: SQDECH  <Xdn>, <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdech_r_rs_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdech_r_rs_sx Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdech_r_rs_sx
        IEM_INSTR_IMPL_A64__sqdech_r_rs_sx(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0470f800: SQDECH  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdech_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdech_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdech_r_rs_x
        IEM_INSTR_IMPL_A64__sqdech_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460c800: SQDECH  <Zdn>.H{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdech_z_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460c800))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqdech_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdech_z_zs
            IEM_INSTR_IMPL_A64__sqdech_z_zs(Zdn, pattern, imm4);
#else
            RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252a8800: SQDECP  <Xdn>, <Pm>.<T>, <Wdn>
   Instruction Set: A64  Groups: sve_int_count_r_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecp_r_p_r_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdecp_r_p_r_sx Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdecp_r_p_r_sx
        IEM_INSTR_IMPL_A64__sqdecp_r_p_r_sx(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252a8c00: SQDECP  <Xdn>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_r_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecp_r_p_r_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdecp_r_p_r_x Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdecp_r_p_r_x
        IEM_INSTR_IMPL_A64__sqdecp_r_p_r_x(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252a8000: SQDECP  <Zdn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_v_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecp_z_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252a8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqdecp_z_p_z Zdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdecp_z_p_z
            IEM_INSTR_IMPL_A64__sqdecp_z_p_z(Zdn, Pm, size);
#else
            RT_NOREF(Zdn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0f800: SQDECW  <Xdn>, <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecw_r_rs_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdecw_r_rs_sx Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdecw_r_rs_sx
        IEM_INSTR_IMPL_A64__sqdecw_r_rs_sx(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04b0f800: SQDECW  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecw_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdecw_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdecw_r_rs_x
        IEM_INSTR_IMPL_A64__sqdecw_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0c800: SQDECW  <Zdn>.S{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdecw_z_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0c800))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqdecw_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqdecw_z_zs
            IEM_INSTR_IMPL_A64__sqdecw_z_zs(Zdn, pattern, imm4);
#else
            RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44006000: SQDMLALB  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_qdmlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlalb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlalb_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmlalb_z_zzz
        IEM_INSTR_IMPL_A64__sqdmlalb_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e02000: SQDMLALB  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlalb_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlalb_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__sqdmlalb_z_zzzi_d
        IEM_INSTR_IMPL_A64__sqdmlalb_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a02000: SQDMLALB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlalb_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlalb_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqdmlalb_z_zzzi_s
        IEM_INSTR_IMPL_A64__sqdmlalb_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44000800: SQDMLALBT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_qdmlalbt, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlalbt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlalbt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmlalbt_z_zzz
        IEM_INSTR_IMPL_A64__sqdmlalbt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44006400: SQDMLALT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_qdmlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlalt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlalt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmlalt_z_zzz
        IEM_INSTR_IMPL_A64__sqdmlalt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e02400: SQDMLALT  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlalt_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlalt_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__sqdmlalt_z_zzzi_d
        IEM_INSTR_IMPL_A64__sqdmlalt_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a02400: SQDMLALT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlalt_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlalt_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqdmlalt_z_zzzi_s
        IEM_INSTR_IMPL_A64__sqdmlalt_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44006800: SQDMLSLB  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_qdmlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlslb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlslb_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmlslb_z_zzz
        IEM_INSTR_IMPL_A64__sqdmlslb_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e03000: SQDMLSLB  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlslb_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlslb_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__sqdmlslb_z_zzzi_d
        IEM_INSTR_IMPL_A64__sqdmlslb_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a03000: SQDMLSLB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlslb_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlslb_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqdmlslb_z_zzzi_s
        IEM_INSTR_IMPL_A64__sqdmlslb_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44000c00: SQDMLSLBT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_qdmlalbt, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlslbt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlslbt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmlslbt_z_zzz
        IEM_INSTR_IMPL_A64__sqdmlslbt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44006c00: SQDMLSLT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_qdmlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlslt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlslt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmlslt_z_zzz
        IEM_INSTR_IMPL_A64__sqdmlslt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e03400: SQDMLSLT  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlslt_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlslt_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__sqdmlslt_z_zzzi_d
        IEM_INSTR_IMPL_A64__sqdmlslt_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a03400: SQDMLSLT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmlslt_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmlslt_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqdmlslt_z_zzzi_s
        IEM_INSTR_IMPL_A64__sqdmlslt_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a400: SQDMULH  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_sqdmulh_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqdmulh_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a400))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sqdmulh_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmulh_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__sqdmulh_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120ac00: SQDMULH  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_sqdmulh_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqdmulh_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120ac00))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sqdmulh_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmulh_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__sqdmulh_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b400: SQDMULH  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_sqdmulh_mm, mortlach_multi_sve_2c1, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqdmulh_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b400))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sqdmulh_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmulh_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__sqdmulh_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120bc00: SQDMULH  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_sqdmulh_mm, mortlach_multi_sve_2d1, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqdmulh_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120bc00))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sqdmulh_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmulh_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__sqdmulh_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04207000: SQDMULH  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_sqdmulh, sve_int_unpred_arit_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmulh_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmulh_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmulh_z_zz
        IEM_INSTR_IMPL_A64__sqdmulh_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e0f000: SQDMULH  <Zd>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmulh_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmulh_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmulh_z_zzi_d Zd=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__sqdmulh_z_zzi_d
        IEM_INSTR_IMPL_A64__sqdmulh_z_zzi_d(Zd, Zn, Zm, i1);
#else
        RT_NOREF(Zd, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4420f000: SQDMULH  <Zd>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmulh_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmulh_z_zzi_h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmulh_z_zzi_h Zd=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqdmulh_z_zzi_h
        IEM_INSTR_IMPL_A64__sqdmulh_z_zzi_h(Zd, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zd, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a0f000: SQDMULH  <Zd>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmulh_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmulh_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmulh_z_zzi_s Zd=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__sqdmulh_z_zzi_s
        IEM_INSTR_IMPL_A64__sqdmulh_z_zzi_s(Zd, Zn, Zm, i2);
#else
        RT_NOREF(Zd, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45006000: SQDMULLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmullb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmullb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmullb_z_zz
        IEM_INSTR_IMPL_A64__sqdmullb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0e000: SQDMULLB  <Zd>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmullb_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmullb_z_zzi_d Zd=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__sqdmullb_z_zzi_d
        IEM_INSTR_IMPL_A64__sqdmullb_z_zzi_d(Zd, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zd, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0e000: SQDMULLB  <Zd>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmullb_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmullb_z_zzi_s Zd=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqdmullb_z_zzi_s
        IEM_INSTR_IMPL_A64__sqdmullb_z_zzi_s(Zd, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zd, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45006400: SQDMULLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmullt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmullt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqdmullt_z_zz
        IEM_INSTR_IMPL_A64__sqdmullt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0e400: SQDMULLT  <Zd>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmullt_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmullt_z_zzi_d Zd=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__sqdmullt_z_zzi_d
        IEM_INSTR_IMPL_A64__sqdmullt_z_zzi_d(Zd, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zd, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0e400: SQDMULLT  <Zd>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqdmullt_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqdmullt_z_zzi_s Zd=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqdmullt_z_zzi_s
        IEM_INSTR_IMPL_A64__sqdmullt_z_zzi_s(Zd, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zd, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0420f000: SQINCB  <Xdn>, <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincb_r_rs_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincb_r_rs_sx Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqincb_r_rs_sx
        IEM_INSTR_IMPL_A64__sqincb_r_rs_sx(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0430f000: SQINCB  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincb_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincb_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqincb_r_rs_x
        IEM_INSTR_IMPL_A64__sqincb_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0f000: SQINCD  <Xdn>, <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincd_r_rs_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincd_r_rs_sx Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqincd_r_rs_sx
        IEM_INSTR_IMPL_A64__sqincd_r_rs_sx(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04f0f000: SQINCD  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincd_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincd_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqincd_r_rs_x
        IEM_INSTR_IMPL_A64__sqincd_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0c000: SQINCD  <Zdn>.D{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincd_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincd_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqincd_z_zs
        IEM_INSTR_IMPL_A64__sqincd_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460f000: SQINCH  <Xdn>, <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqinch_r_rs_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqinch_r_rs_sx Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqinch_r_rs_sx
        IEM_INSTR_IMPL_A64__sqinch_r_rs_sx(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0470f000: SQINCH  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqinch_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqinch_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqinch_r_rs_x
        IEM_INSTR_IMPL_A64__sqinch_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460c000: SQINCH  <Zdn>.H{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqinch_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqinch_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqinch_z_zs
        IEM_INSTR_IMPL_A64__sqinch_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/25288800: SQINCP  <Xdn>, <Pm>.<T>, <Wdn>
   Instruction Set: A64  Groups: sve_int_count_r_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincp_r_p_r_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincp_r_p_r_sx Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__sqincp_r_p_r_sx
        IEM_INSTR_IMPL_A64__sqincp_r_p_r_sx(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/25288c00: SQINCP  <Xdn>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_r_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincp_r_p_r_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincp_r_p_r_x Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__sqincp_r_p_r_x
        IEM_INSTR_IMPL_A64__sqincp_r_p_r_x(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/25288000: SQINCP  <Zdn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_v_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincp_z_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x25288000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqincp_z_p_z Zdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__sqincp_z_p_z
            IEM_INSTR_IMPL_A64__sqincp_z_p_z(Zdn, Pm, size);
#else
            RT_NOREF(Zdn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0f000: SQINCW  <Xdn>, <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincw_r_rs_sx, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincw_r_rs_sx Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqincw_r_rs_sx
        IEM_INSTR_IMPL_A64__sqincw_r_rs_sx(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04b0f000: SQINCW  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincw_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincw_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqincw_r_rs_x
        IEM_INSTR_IMPL_A64__sqincw_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0c000: SQINCW  <Zdn>.S{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqincw_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqincw_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqincw_z_zs
        IEM_INSTR_IMPL_A64__sqincw_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4409a000: SQNEG  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_unary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqneg_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqneg_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqneg_z_p_z_m
        IEM_INSTR_IMPL_A64__sqneg_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/440ba000: SQNEG  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_unary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqneg_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: sqneg_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqneg_z_p_z_z
        IEM_INSTR_IMPL_A64__sqneg_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20f000/44003000: SQRDCMLAH  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>, <const>
   Instruction Set: A64  Groups: sve_intx_cmla, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdcmlah_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdcmlah_z_zzz Zda=%#x Zn=%#x rot=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqrdcmlah_z_zzz
        IEM_INSTR_IMPL_A64__sqrdcmlah_z_zzz(Zda, Zn, rot, Zm, size);
#else
        RT_NOREF(Zda, Zn, rot, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/44a07000: SQRDCMLAH  <Zda>.H, <Zn>.H, <Zm>.H[<imm>], <const>
   Instruction Set: A64  Groups: sve_intx_qrdcmla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdcmlah_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdcmlah_z_zzzi_h Zda=%#x Zn=%#x rot=%u Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__sqrdcmlah_z_zzzi_h
        IEM_INSTR_IMPL_A64__sqrdcmlah_z_zzzi_h(Zda, Zn, rot, Zm, i2);
#else
        RT_NOREF(Zda, Zn, rot, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f000/44e07000: SQRDCMLAH  <Zda>.S, <Zn>.S, <Zm>.S[<imm>], <const>
   Instruction Set: A64  Groups: sve_intx_qrdcmla_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdcmlah_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const rot        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdcmlah_z_zzzi_s Zda=%#x Zn=%#x rot=%u Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, rot, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__sqrdcmlah_z_zzzi_s
        IEM_INSTR_IMPL_A64__sqrdcmlah_z_zzzi_s(Zda, Zn, rot, Zm, i1);
#else
        RT_NOREF(Zda, Zn, rot, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44007000: SQRDMLAH  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_qrdmlah, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmlah_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmlah_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqrdmlah_z_zzz
        IEM_INSTR_IMPL_A64__sqrdmlah_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e01000: SQRDMLAH  <Zda>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_intx_qrdmlah_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmlah_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmlah_z_zzzi_d Zda=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__sqrdmlah_z_zzzi_d
        IEM_INSTR_IMPL_A64__sqrdmlah_z_zzzi_d(Zda, Zn, Zm, i1);
#else
        RT_NOREF(Zda, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/44201000: SQRDMLAH  <Zda>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qrdmlah_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmlah_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmlah_z_zzzi_h Zda=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqrdmlah_z_zzzi_h
        IEM_INSTR_IMPL_A64__sqrdmlah_z_zzzi_h(Zda, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zda, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a01000: SQRDMLAH  <Zda>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qrdmlah_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmlah_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmlah_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__sqrdmlah_z_zzzi_s
        IEM_INSTR_IMPL_A64__sqrdmlah_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44007400: SQRDMLSH  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_qrdmlah, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmlsh_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmlsh_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqrdmlsh_z_zzz
        IEM_INSTR_IMPL_A64__sqrdmlsh_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e01400: SQRDMLSH  <Zda>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_intx_qrdmlah_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmlsh_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmlsh_z_zzzi_d Zda=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__sqrdmlsh_z_zzzi_d
        IEM_INSTR_IMPL_A64__sqrdmlsh_z_zzzi_d(Zda, Zn, Zm, i1);
#else
        RT_NOREF(Zda, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/44201400: SQRDMLSH  <Zda>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qrdmlah_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmlsh_z_zzzi_h, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmlsh_z_zzzi_h Zda=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqrdmlsh_z_zzzi_h
        IEM_INSTR_IMPL_A64__sqrdmlsh_z_zzzi_h(Zda, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zda, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a01400: SQRDMLSH  <Zda>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qrdmlah_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmlsh_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmlsh_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__sqrdmlsh_z_zzzi_s
        IEM_INSTR_IMPL_A64__sqrdmlsh_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04207400: SQRDMULH  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_sqdmulh, sve_int_unpred_arit_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmulh_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmulh_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqrdmulh_z_zz
        IEM_INSTR_IMPL_A64__sqrdmulh_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e0f400: SQRDMULH  <Zd>.D, <Zn>.D, <Zm>.D[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmulh_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmulh_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmulh_z_zzi_d Zd=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__sqrdmulh_z_zzi_d
        IEM_INSTR_IMPL_A64__sqrdmulh_z_zzi_d(Zd, Zn, Zm, i1);
#else
        RT_NOREF(Zd, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4420f400: SQRDMULH  <Zd>.H, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmulh_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmulh_z_zzi_h, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3l        = (uOpcode >> 19) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmulh_z_zzi_h Zd=%#x Zn=%#x Zm=%u i3l=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i3l, i3h));
#ifdef IEM_INSTR_IMPL_A64__sqrdmulh_z_zzi_h
        IEM_INSTR_IMPL_A64__sqrdmulh_z_zzi_h(Zd, Zn, Zm, i3l, i3h);
#else
        RT_NOREF(Zd, Zn, Zm, i3l, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a0f400: SQRDMULH  <Zd>.S, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_qdmulh_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrdmulh_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrdmulh_z_zzi_s Zd=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__sqrdmulh_z_zzi_s
        IEM_INSTR_IMPL_A64__sqrdmulh_z_zzi_s(Zd, Zn, Zm, i2);
#else
        RT_NOREF(Zd, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/440a8000: SQRSHL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrshl_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrshl_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqrshl_z_p_zz
        IEM_INSTR_IMPL_A64__sqrshl_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/440e8000: SQRSHLR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrshlr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrshlr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqrshlr_z_p_zz
        IEM_INSTR_IMPL_A64__sqrshlr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc20/c1e0d400: SQRSHR  <Zd>.H, { <Zn1>.S-<Zn2>.S }, #<const>
   Instruction Set: A64  Groups: mortlach_multi2_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqrshr_z_mz2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqrshr_z_mz2 Zd=%#x Zn=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqrshr_z_mz2
        IEM_INSTR_IMPL_A64__sqrshr_z_mz2(Zd, Zn, imm4);
#else
        RT_NOREF(Zd, Zn, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc60/c120d800: SQRSHR  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }, #<const>
   Instruction Set: A64  Groups: mortlach_multi4_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqrshr_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const tsize      = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqrshr_z_mz4 Zd=%#x Zn=%u imm5=%#x tsize=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm5, tsize));
#ifdef IEM_INSTR_IMPL_A64__sqrshr_z_mz4
        IEM_INSTR_IMPL_A64__sqrshr_z_mz4(Zd, Zn, imm5, tsize);
#else
        RT_NOREF(Zd, Zn, imm5, tsize, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc20/45b02800: SQRSHRN  <Zd>.H, { <Zn1>.S-<Zn2>.S }, #<const>
   Instruction Set: A64  Groups: sve_intx_multi_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrshrn_z_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc20)) == UINT32_C(0x45b02800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
        {
            LogFlow(("%018x/%010x: sqrshrn_z_mz2 Zd=%#x Zn=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqrshrn_z_mz2
            IEM_INSTR_IMPL_A64__sqrshrn_z_mz2(Zd, Zn, imm4);
#else
            RT_NOREF(Zd, Zn, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc60/c120dc00: SQRSHRN  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }, #<const>
   Instruction Set: A64  Groups: mortlach_multi4_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqrshrn_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const tsize      = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqrshrn_z_mz4 Zd=%#x Zn=%u imm5=%#x tsize=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm5, tsize));
#ifdef IEM_INSTR_IMPL_A64__sqrshrn_z_mz4
        IEM_INSTR_IMPL_A64__sqrshrn_z_mz4(Zd, Zn, imm5, tsize);
#else
        RT_NOREF(Zd, Zn, imm5, tsize, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45202800: SQRSHRNB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrshrnb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrshrnb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqrshrnb_z_zi
        IEM_INSTR_IMPL_A64__sqrshrnb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45202c00: SQRSHRNT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrshrnt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrshrnt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqrshrnt_z_zi
        IEM_INSTR_IMPL_A64__sqrshrnt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc20/c1f0d400: SQRSHRU  <Zd>.H, { <Zn1>.S-<Zn2>.S }, #<const>
   Instruction Set: A64  Groups: mortlach_multi2_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqrshru_z_mz2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqrshru_z_mz2 Zd=%#x Zn=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqrshru_z_mz2
        IEM_INSTR_IMPL_A64__sqrshru_z_mz2(Zd, Zn, imm4);
#else
        RT_NOREF(Zd, Zn, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc60/c120d840: SQRSHRU  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }, #<const>
   Instruction Set: A64  Groups: mortlach_multi4_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqrshru_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const tsize      = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqrshru_z_mz4 Zd=%#x Zn=%u imm5=%#x tsize=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm5, tsize));
#ifdef IEM_INSTR_IMPL_A64__sqrshru_z_mz4
        IEM_INSTR_IMPL_A64__sqrshru_z_mz4(Zd, Zn, imm5, tsize);
#else
        RT_NOREF(Zd, Zn, imm5, tsize, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc20/45b00800: SQRSHRUN  <Zd>.H, { <Zn1>.S-<Zn2>.S }, #<const>
   Instruction Set: A64  Groups: sve_intx_multi_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrshrun_z_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc20)) == UINT32_C(0x45b00800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
        {
            LogFlow(("%018x/%010x: sqrshrun_z_mz2 Zd=%#x Zn=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm4));
#ifdef IEM_INSTR_IMPL_A64__sqrshrun_z_mz2
            IEM_INSTR_IMPL_A64__sqrshrun_z_mz2(Zd, Zn, imm4);
#else
            RT_NOREF(Zd, Zn, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc60/c120dc40: SQRSHRUN  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }, #<const>
   Instruction Set: A64  Groups: mortlach_multi4_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sqrshrun_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const tsize      = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sqrshrun_z_mz4 Zd=%#x Zn=%u imm5=%#x tsize=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm5, tsize));
#ifdef IEM_INSTR_IMPL_A64__sqrshrun_z_mz4
        IEM_INSTR_IMPL_A64__sqrshrun_z_mz4(Zd, Zn, imm5, tsize);
#else
        RT_NOREF(Zd, Zn, imm5, tsize, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45200800: SQRSHRUNB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrshrunb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrshrunb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqrshrunb_z_zi
        IEM_INSTR_IMPL_A64__sqrshrunb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45200c00: SQRSHRUNT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqrshrunt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqrshrunt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqrshrunt_z_zi
        IEM_INSTR_IMPL_A64__sqrshrunt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04068000: SQSHL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqshl_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqshl_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqshl_z_p_zi
        IEM_INSTR_IMPL_A64__sqshl_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44088000: SQSHL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqshl_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqshl_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqshl_z_p_zz
        IEM_INSTR_IMPL_A64__sqshl_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/440c8000: SQSHLR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqshlr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqshlr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqshlr_z_p_zz
        IEM_INSTR_IMPL_A64__sqshlr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040f8000: SQSHLU  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqshlu_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqshlu_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqshlu_z_p_zi
        IEM_INSTR_IMPL_A64__sqshlu_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45202000: SQSHRNB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqshrnb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqshrnb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqshrnb_z_zi
        IEM_INSTR_IMPL_A64__sqshrnb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45202400: SQSHRNT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqshrnt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqshrnt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqshrnt_z_zi
        IEM_INSTR_IMPL_A64__sqshrnt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45200000: SQSHRUNB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqshrunb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqshrunb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqshrunb_z_zi
        IEM_INSTR_IMPL_A64__sqshrunb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45200400: SQSHRUNT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqshrunt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqshrunt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqshrunt_z_zi
        IEM_INSTR_IMPL_A64__sqshrunt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/441a8000: SQSUB  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary_sat, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqsub_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqsub_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqsub_z_p_zz
        IEM_INSTR_IMPL_A64__sqsub_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc000/2526c000: SQSUB  <Zdn>.<T>, <Zdn>.<T>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_arith_imm0, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqsub_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc000)) == UINT32_C(0x2526c000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
        uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqsub_z_zi Zdn=%#x imm8=%#x sh=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, sh, size));
#ifdef IEM_INSTR_IMPL_A64__sqsub_z_zi
            IEM_INSTR_IMPL_A64__sqsub_z_zi(Zdn, imm8, sh, size);
#else
            RT_NOREF(Zdn, imm8, sh, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04201800: SQSUB  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_cons_arit_0, sve_int_unpred_arit, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqsub_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqsub_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sqsub_z_zz
        IEM_INSTR_IMPL_A64__sqsub_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/441e8000: SQSUBR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary_sat, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqsubr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sqsubr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sqsubr_z_p_zz
        IEM_INSTR_IMPL_A64__sqsubr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa7fc00/45204000: SQXTNB  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_intx_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqxtnb_z_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45204000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
        uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqxtnb_z_zz Zd=%#x Zn=%#x tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqxtnb_z_zz
            IEM_INSTR_IMPL_A64__sqxtnb_z_zz(Zd, Zn, tszl, tszh);
#else
            RT_NOREF(Zd, Zn, tszl, tszh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa7fc00/45204400: SQXTNT  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_intx_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqxtnt_z_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45204400))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
        uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqxtnt_z_zz Zd=%#x Zn=%#x tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqxtnt_z_zz
            IEM_INSTR_IMPL_A64__sqxtnt_z_zz(Zd, Zn, tszl, tszh);
#else
            RT_NOREF(Zd, Zn, tszl, tszh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa7fc00/45205000: SQXTUNB  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_intx_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqxtunb_z_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45205000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
        uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqxtunb_z_zz Zd=%#x Zn=%#x tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqxtunb_z_zz
            IEM_INSTR_IMPL_A64__sqxtunb_z_zz(Zd, Zn, tszl, tszh);
#else
            RT_NOREF(Zd, Zn, tszl, tszh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa7fc00/45205400: SQXTUNT  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_intx_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_sqxtunt_z_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45205400))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
        uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sqxtunt_z_zz Zd=%#x Zn=%#x tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sqxtunt_z_zz
            IEM_INSTR_IMPL_A64__sqxtunt_z_zz(Zd, Zn, tszl, tszh);
#else
            RT_NOREF(Zd, Zn, tszl, tszh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44148000: SRHADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_srhadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: srhadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__srhadd_z_p_zz
        IEM_INSTR_IMPL_A64__srhadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500f000: SRI  <Zd>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_insert, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_sri_z_zzi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sri_z_zzi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sri_z_zzi
        IEM_INSTR_IMPL_A64__sri_z_zzi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a220: SRSHL  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_shift_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_srshl_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a220))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: srshl_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__srshl_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__srshl_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120aa20: SRSHL  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_shift_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_srshl_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120aa20))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: srshl_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__srshl_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__srshl_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b220: SRSHL  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_shift_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_srshl_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: srshl_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__srshl_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__srshl_mz_zzw_2x2(Zdn, Zm, size);
#else
        RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120ba20: SRSHL  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_shift_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_srshl_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: srshl_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__srshl_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__srshl_mz_zzw_4x4(Zdn, Zm, size);
#else
        RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44028000: SRSHL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_srshl_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: srshl_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__srshl_z_p_zz
        IEM_INSTR_IMPL_A64__srshl_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44068000: SRSHLR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_srshlr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: srshlr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__srshlr_z_p_zz
        IEM_INSTR_IMPL_A64__srshlr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040c8000: SRSHR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_srshr_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: srshr_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__srshr_z_p_zi
        IEM_INSTR_IMPL_A64__srshr_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500e800: SRSRA  <Zda>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_intx_sra, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_srsra_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: srsra_z_zi Zda=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__srsra_z_zi
        IEM_INSTR_IMPL_A64__srsra_z_zi(Zda, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zda, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4500a000: SSHLLB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_long, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_sshllb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sshllb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sshllb_z_zi
        IEM_INSTR_IMPL_A64__sshllb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4500a400: SSHLLT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_long, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_sshllt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sshllt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__sshllt_z_zi
        IEM_INSTR_IMPL_A64__sshllt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500e000: SSRA  <Zda>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_intx_sra, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_ssra_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ssra_z_zi Zda=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__ssra_z_zi
        IEM_INSTR_IMPL_A64__ssra_z_zi(Zda, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zda, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45001000: SSUBLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_ssublb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ssublb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__ssublb_z_zz
        IEM_INSTR_IMPL_A64__ssublb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45008800: SSUBLBT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_clong, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_ssublbt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ssublbt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__ssublbt_z_zz
        IEM_INSTR_IMPL_A64__ssublbt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45001400: SSUBLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_ssublt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ssublt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__ssublt_z_zz
        IEM_INSTR_IMPL_A64__ssublt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45008c00: SSUBLTB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_clong, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_ssubltb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ssubltb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__ssubltb_z_zz
        IEM_INSTR_IMPL_A64__ssubltb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45005000: SSUBWB  <Zd>.<T>, <Zn>.<T>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_wide, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_ssubwb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ssubwb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__ssubwb_z_zz
        IEM_INSTR_IMPL_A64__ssubwb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45005400: SSUBWT  <Zd>.<T>, <Zn>.<T>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_wide, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_ssubwt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ssubwt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__ssubwt_z_zz
        IEM_INSTR_IMPL_A64__ssubwt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0600000: ST1B  { <Zt1>.B-<Zt2>.B }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1b_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1b_mz_p_bi_2
        IEM_INSTR_IMPL_A64__st1b_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a0608000: ST1B  { <Zt1>.B-<Zt4>.B }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1b_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1b_mz_p_bi_4
        IEM_INSTR_IMPL_A64__st1b_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0200000: ST1B  { <Zt1>.B-<Zt2>.B }, <PNg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1b_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1b_mz_p_br_2
        IEM_INSTR_IMPL_A64__st1b_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a0208000: ST1B  { <Zt1>.B-<Zt4>.B }, <PNg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1b_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1b_mz_p_br_4
        IEM_INSTR_IMPL_A64__st1b_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1600000: ST1B  { <Zt1>.B, <Zt2>.B }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1b_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1b_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__st1b_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a1608000: ST1B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1b_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1b_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__st1b_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1200000: ST1B  { <Zt1>.B, <Zt2>.B }, <PNg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1b_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1b_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__st1b_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a1208000: ST1B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <PNg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1b_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1b_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__st1b_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e440a000: ST1B  { <Zt>.D }, <Pg>, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_sst_vi_a, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1b_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1b_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__st1b_z_p_ai_d
        IEM_INSTR_IMPL_A64__st1b_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e460a000: ST1B  { <Zt>.S }, <Pg>, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_sst_vi_b, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1b_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1b_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__st1b_z_p_ai_s
        IEM_INSTR_IMPL_A64__st1b_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff90e000/e400e000: ST1B  { <Zt>.<T> }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cst_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1b_z_p_bi, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 21) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: st1b_z_p_bi Zt=%#x Rn=%#x Pg=%u imm4=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4, size));
#ifdef IEM_INSTR_IMPL_A64__st1b_z_p_bi
        IEM_INSTR_IMPL_A64__st1b_z_p_bi(Zt, Rn, Pg, imm4, size);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80e000/e4004000: ST1B  { <Zt>.<T> }, <Pg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cst_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1b_z_p_br, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 21) & 0x00000003;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (((uOpcode >> 22) & 0x7) != 6))
    {
        LogFlow(("%018x/%010x: st1b_z_p_br Zt=%#x Rn=%#x Pg=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__st1b_z_p_br
        IEM_INSTR_IMPL_A64__st1b_z_p_br(Zt, Rn, Pg, Rm, size);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e400a000: ST1B  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_sst_vs2, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1b_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1b_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1b_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__st1b_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e4008000: ST1B  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_sst_vs_a, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1b_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1b_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1b_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__st1b_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e4408000: ST1B  { <Zt>.S }, <Pg>, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_sst_vs_b, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1b_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1b_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1b_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__st1b_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e0200000: ST1B  { ZA0<HV>.B[<Ws>, <offs>] }, <Pg>, [<Xn|SP>{, <Xm>}]
   Instruction Set: A64  Groups: mortlach_contig_store, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1b_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe0200000))
    {
        uint32_t const off4       = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: st1b_za_p_rrr off4=%#x Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off4, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1b_za_p_rrr
            IEM_INSTR_IMPL_A64__st1b_za_p_rrr(off4, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(off4, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0606000: ST1D  { <Zt1>.D-<Zt2>.D }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1d_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1d_mz_p_bi_2
        IEM_INSTR_IMPL_A64__st1d_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a060e000: ST1D  { <Zt1>.D-<Zt4>.D }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1d_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1d_mz_p_bi_4
        IEM_INSTR_IMPL_A64__st1d_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0206000: ST1D  { <Zt1>.D-<Zt2>.D }, <PNg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1d_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1d_mz_p_br_2
        IEM_INSTR_IMPL_A64__st1d_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a020e000: ST1D  { <Zt1>.D-<Zt4>.D }, <PNg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1d_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1d_mz_p_br_4
        IEM_INSTR_IMPL_A64__st1d_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1606000: ST1D  { <Zt1>.D, <Zt2>.D }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1d_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1d_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__st1d_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a160e000: ST1D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1d_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1d_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__st1d_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1206000: ST1D  { <Zt1>.D, <Zt2>.D }, <PNg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1d_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1d_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__st1d_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a120e000: ST1D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <PNg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1d_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1d_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__st1d_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5c0a000: ST1D  { <Zt>.D }, <Pg>, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_sst_vi_a, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1d_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_ai_d
        IEM_INSTR_IMPL_A64__st1d_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e5e0e000: ST1D  { <Zt>.D }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cst_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_bi, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: st1d_z_p_bi Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_bi
        IEM_INSTR_IMPL_A64__st1d_z_p_bi(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e5c0e000: ST1D  { <Zt>.Q }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cst_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_bi_u128, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1d_z_p_bi_u128 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_bi_u128
        IEM_INSTR_IMPL_A64__st1d_z_p_bi_u128(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5e04000: ST1D  { <Zt>.D }, <Pg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_cst_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_br, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (0x7 /*opc@22*/ != 6))
    {
        LogFlow(("%018x/%010x: st1d_z_p_br Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_br
        IEM_INSTR_IMPL_A64__st1d_z_p_br(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5c04000: ST1D  { <Zt>.Q }, <Pg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_cst_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_br_u128, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ && (Rm != 0x1f) && (0x7 /*opc@22*/ != 6))
    {
        LogFlow(("%018x/%010x: st1d_z_p_br_u128 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_br_u128
        IEM_INSTR_IMPL_A64__st1d_z_p_br_u128(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5a0a000: ST1D  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, LSL #3]
   Instruction Set: A64  Groups: sve_mem_sst_sv2, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1d_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__st1d_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e580a000: ST1D  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_sst_vs2, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1d_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__st1d_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e5a08000: ST1D  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, <mod> #3]
   Instruction Set: A64  Groups: sve_mem_sst_sv_a, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1d_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__st1d_z_p_bz_d_x32_scaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e5808000: ST1D  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_sst_vs_a, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1d_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1d_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1d_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__st1d_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e0e00000: ST1D  { <ZAt><HV>.D[<Ws>, <offs>] }, <Pg>, [<Xn|SP>{, <Xm>, LSL #3}]
   Instruction Set: A64  Groups: mortlach_contig_store, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1d_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe0e00000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const ZAt        = (uOpcode >>  1) & 0x00000007;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: st1d_za_p_rrr o1=%u ZAt=%u Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, ZAt, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1d_za_p_rrr
            IEM_INSTR_IMPL_A64__st1d_za_p_rrr(o1, ZAt, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(o1, ZAt, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0602000: ST1H  { <Zt1>.H-<Zt2>.H }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1h_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1h_mz_p_bi_2
        IEM_INSTR_IMPL_A64__st1h_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a060a000: ST1H  { <Zt1>.H-<Zt4>.H }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1h_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1h_mz_p_bi_4
        IEM_INSTR_IMPL_A64__st1h_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0202000: ST1H  { <Zt1>.H-<Zt2>.H }, <PNg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1h_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1h_mz_p_br_2
        IEM_INSTR_IMPL_A64__st1h_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a020a000: ST1H  { <Zt1>.H-<Zt4>.H }, <PNg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1h_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1h_mz_p_br_4
        IEM_INSTR_IMPL_A64__st1h_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1602000: ST1H  { <Zt1>.H, <Zt2>.H }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1h_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1h_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__st1h_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a160a000: ST1H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1h_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1h_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__st1h_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1202000: ST1H  { <Zt1>.H, <Zt2>.H }, <PNg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1h_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1h_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__st1h_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a120a000: ST1H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <PNg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1h_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1h_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__st1h_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4c0a000: ST1H  { <Zt>.D }, <Pg>, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_sst_vi_a, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_ai_d
        IEM_INSTR_IMPL_A64__st1h_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4e0a000: ST1H  { <Zt>.S }, <Pg>, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_sst_vi_b, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_ai_s
        IEM_INSTR_IMPL_A64__st1h_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff90e000/e480e000: ST1H  { <Zt>.<T> }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cst_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_bi, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 21) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_bi Zt=%#x Rn=%#x Pg=%u imm4=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4, size));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_bi
        IEM_INSTR_IMPL_A64__st1h_z_p_bi(Zt, Rn, Pg, imm4, size);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff80e000/e4804000: ST1H  { <Zt>.<T> }, <Pg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_cst_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_br, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 21) & 0x00000003;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (((uOpcode >> 22) & 0x7) != 6))
    {
        LogFlow(("%018x/%010x: st1h_z_p_br Zt=%#x Rn=%#x Pg=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_br
        IEM_INSTR_IMPL_A64__st1h_z_p_br(Zt, Rn, Pg, Rm, size);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4a0a000: ST1H  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, LSL #1]
   Instruction Set: A64  Groups: sve_mem_sst_sv2, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__st1h_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e480a000: ST1H  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_sst_vs2, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__st1h_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e4a08000: ST1H  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_sst_sv_a, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__st1h_z_p_bz_d_x32_scaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e4808000: ST1H  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_sst_vs_a, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__st1h_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e4e08000: ST1H  { <Zt>.S }, <Pg>, [<Xn|SP>, <Zm>.S, <mod> #1]
   Instruction Set: A64  Groups: sve_mem_sst_sv_b, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_bz_s_x32_scaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_bz_s_x32_scaled
        IEM_INSTR_IMPL_A64__st1h_z_p_bz_s_x32_scaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e4c08000: ST1H  { <Zt>.S }, <Pg>, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_sst_vs_b, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1h_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1h_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1h_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__st1h_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e0600000: ST1H  { <ZAt><HV>.H[<Ws>, <offs>] }, <Pg>, [<Xn|SP>{, <Xm>, LSL #1}]
   Instruction Set: A64  Groups: mortlach_contig_store, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1h_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe0600000))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const ZAt        = (uOpcode >>  3) & 0x00000001;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: st1h_za_p_rrr off3=%u ZAt=%u Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, ZAt, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1h_za_p_rrr
            IEM_INSTR_IMPL_A64__st1h_za_p_rrr(off3, ZAt, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(off3, ZAt, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4202000: ST1Q  { <Zt>.Q }, <Pg>, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_sstq_64b_vs, sve_memsst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1q_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1q_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1q_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__st1q_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e1e00000: ST1Q  { <ZAt><HV>.Q[<Ws>, <offs>] }, <Pg>, [<Xn|SP>{, <Xm>, LSL #4}]
   Instruction Set: A64  Groups: mortlach_contig_qstore, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1q_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
    {
        uint32_t const ZAt        = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: st1q_za_p_rrr ZAt=%#x Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAt, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1q_za_p_rrr
            IEM_INSTR_IMPL_A64__st1q_za_p_rrr(ZAt, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(ZAt, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0604000: ST1W  { <Zt1>.S-<Zt2>.S }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1w_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1w_mz_p_bi_2
        IEM_INSTR_IMPL_A64__st1w_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a060c000: ST1W  { <Zt1>.S-<Zt4>.S }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1w_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1w_mz_p_bi_4
        IEM_INSTR_IMPL_A64__st1w_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0204000: ST1W  { <Zt1>.S-<Zt2>.S }, <PNg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1w_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1w_mz_p_br_2
        IEM_INSTR_IMPL_A64__st1w_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a020c000: ST1W  { <Zt1>.S-<Zt4>.S }, <PNg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1w_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1w_mz_p_br_4
        IEM_INSTR_IMPL_A64__st1w_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1604000: ST1W  { <Zt1>.S, <Zt2>.S }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1w_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1w_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__st1w_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a160c000: ST1W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1w_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1w_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__st1w_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1204000: ST1W  { <Zt1>.S, <Zt2>.S }, <PNg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1w_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1w_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__st1w_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a120c000: ST1W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <PNg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: st1w_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1w_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__st1w_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e540a000: ST1W  { <Zt>.D }, <Pg>, [<Zn>.D{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_sst_vi_a, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_ai_d, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_ai_d Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_ai_d
        IEM_INSTR_IMPL_A64__st1w_z_p_ai_d(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e560a000: ST1W  { <Zt>.S }, <Pg>, [<Zn>.S{, #<imm>}]
   Instruction Set: A64  Groups: sve_mem_sst_vi_b, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_ai_s, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_ai_s Zt=%#x Zn=%#x Pg=%u imm5=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, imm5));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_ai_s
        IEM_INSTR_IMPL_A64__st1w_z_p_ai_s(Zt, Zn, Pg, imm5);
#else
        RT_NOREF(Zt, Zn, Pg, imm5, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffd0e000/e540e000: ST1W  { <Zt>.<T> }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cst_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_bi, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 21) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_bi Zt=%#x Rn=%#x Pg=%u imm4=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4, sz));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_bi
        IEM_INSTR_IMPL_A64__st1w_z_p_bi(Zt, Rn, Pg, imm4, sz);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e500e000: ST1W  { <Zt>.Q }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cst_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_bi_u128, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_bi_u128 Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_bi_u128
        IEM_INSTR_IMPL_A64__st1w_z_p_bi_u128(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/e5404000: ST1W  { <Zt>.<T> }, <Pg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_cst_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_br, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const sz         = (uOpcode >> 21) & 0x00000001;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && (0x5 /*opc@22*/ != 6))
    {
        LogFlow(("%018x/%010x: st1w_z_p_br Zt=%#x Rn=%#x Pg=%u Rm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm, sz));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_br
        IEM_INSTR_IMPL_A64__st1w_z_p_br(Zt, Rn, Pg, Rm, sz);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5004000: ST1W  { <Zt>.Q }, <Pg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_cst_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_br_u128, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ && (Rm != 0x1f) && (0x4 /*opc@22*/ != 6))
    {
        LogFlow(("%018x/%010x: st1w_z_p_br_u128 Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_br_u128
        IEM_INSTR_IMPL_A64__st1w_z_p_br_u128(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e520a000: ST1W  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, LSL #2]
   Instruction Set: A64  Groups: sve_mem_sst_sv2, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_bz_d_64_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_bz_d_64_scaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_bz_d_64_scaled
        IEM_INSTR_IMPL_A64__st1w_z_p_bz_d_64_scaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e500a000: ST1W  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D]
   Instruction Set: A64  Groups: sve_mem_sst_vs2, sve_memst_ss2, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_bz_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_bz_d_64_unscaled Zt=%#x Rn=%#x Pg=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_bz_d_64_unscaled
        IEM_INSTR_IMPL_A64__st1w_z_p_bz_d_64_unscaled(Zt, Rn, Pg, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e5208000: ST1W  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_sst_sv_a, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_bz_d_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_bz_d_x32_scaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_bz_d_x32_scaled
        IEM_INSTR_IMPL_A64__st1w_z_p_bz_d_x32_scaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e5008000: ST1W  { <Zt>.D }, <Pg>, [<Xn|SP>, <Zm>.D, <mod>]
   Instruction Set: A64  Groups: sve_mem_sst_vs_a, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_bz_d_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_bz_d_x32_unscaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_bz_d_x32_unscaled
        IEM_INSTR_IMPL_A64__st1w_z_p_bz_d_x32_unscaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e5608000: ST1W  { <Zt>.S }, <Pg>, [<Xn|SP>, <Zm>.S, <mod> #2]
   Instruction Set: A64  Groups: sve_mem_sst_sv_b, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_bz_s_x32_scaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_bz_s_x32_scaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_bz_s_x32_scaled
        IEM_INSTR_IMPL_A64__st1w_z_p_bz_s_x32_scaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0a000/e5408000: ST1W  { <Zt>.S }, <Pg>, [<Xn|SP>, <Zm>.S, <mod>]
   Instruction Set: A64  Groups: sve_mem_sst_vs_b, sve_memst_ss, sve */
FNIEMOP_DEF_1(iemDecodeA64_st1w_z_p_bz_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const xs         = (uOpcode >> 14) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
    {
        LogFlow(("%018x/%010x: st1w_z_p_bz_s_x32_unscaled Zt=%#x Rn=%#x Pg=%u xs=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, xs, Zm));
#ifdef IEM_INSTR_IMPL_A64__st1w_z_p_bz_s_x32_unscaled
        IEM_INSTR_IMPL_A64__st1w_z_p_bz_s_x32_unscaled(Zt, Rn, Pg, xs, Zm);
#else
        RT_NOREF(Zt, Rn, Pg, xs, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00010/e0a00000: ST1W  { <ZAt><HV>.S[<Ws>, <offs>] }, <Pg>, [<Xn|SP>{, <Xm>, LSL #2}]
   Instruction Set: A64  Groups: mortlach_contig_store, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_st1w_za_p_rrr, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe0a00000))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const ZAt        = (uOpcode >>  2) & 0x00000003;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rs         = (uOpcode >> 13) & 0x00000003;
        uint32_t const V          = (uOpcode >> 15) & 0x00000001;
        uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: st1w_za_p_rrr off2=%u ZAt=%u Rn=%#x Pg=%u Rs=%u V=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, ZAt, Rn, Pg, Rs, V, Rm));
#ifdef IEM_INSTR_IMPL_A64__st1w_za_p_rrr
            IEM_INSTR_IMPL_A64__st1w_za_p_rrr(off2, ZAt, Rn, Pg, Rs, V, Rm);
#else
            RT_NOREF(off2, ZAt, Rn, Pg, Rs, V, Rm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e430e000: ST2B  { <Zt1>.B, <Zt2>.B }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2b_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st2b_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st2b_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st2b_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4206000: ST2B  { <Zt1>.B, <Zt2>.B }, <Pg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2b_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st2b_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st2b_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st2b_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e5b0e000: ST2D  { <Zt1>.D, <Zt2>.D }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2d_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe5b0e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: st2d_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st2d_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__st2d_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5a06000: ST2D  { <Zt1>.D, <Zt2>.D }, <Pg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2d_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st2d_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st2d_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st2d_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e4b0e000: ST2H  { <Zt1>.H, <Zt2>.H }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2h_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st2h_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st2h_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st2h_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4a06000: ST2H  { <Zt1>.H, <Zt2>.H }, <Pg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2h_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st2h_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st2h_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st2h_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e4400000: ST2Q  { <Zt1>.Q, <Zt2>.Q }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_estq_si, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2q_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4400000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: st2q_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st2q_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__st2q_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4600000: ST2Q  { <Zt1>.Q, <Zt2>.Q }, <Pg>, [<Xn|SP>, <Xm>, LSL #4]
   Instruction Set: A64  Groups: sve_mem_estq_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2q_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/))
    {
        LogFlow(("%018x/%010x: st2q_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st2q_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st2q_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e530e000: ST2W  { <Zt1>.S, <Zt2>.S }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2w_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe530e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if ((0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
        {
            LogFlow(("%018x/%010x: st2w_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st2w_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__st2w_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5206000: ST2W  { <Zt1>.S, <Zt2>.S }, <Pg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st2w_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x1 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st2w_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st2w_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st2w_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e450e000: ST3B  { <Zt1>.B, <Zt2>.B, <Zt3>.B }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3b_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st3b_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st3b_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st3b_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4406000: ST3B  { <Zt1>.B, <Zt2>.B, <Zt3>.B }, <Pg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3b_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st3b_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st3b_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st3b_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e5d0e000: ST3D  { <Zt1>.D, <Zt2>.D, <Zt3>.D }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3d_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st3d_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st3d_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st3d_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5c06000: ST3D  { <Zt1>.D, <Zt2>.D, <Zt3>.D }, <Pg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3d_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st3d_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st3d_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st3d_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e4d0e000: ST3H  { <Zt1>.H, <Zt2>.H, <Zt3>.H }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3h_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st3h_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st3h_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st3h_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4c06000: ST3H  { <Zt1>.H, <Zt2>.H, <Zt3>.H }, <Pg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3h_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st3h_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st3h_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st3h_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e4800000: ST3Q  { <Zt1>.Q, <Zt2>.Q, <Zt3>.Q }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_estq_si, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3q_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: st3q_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st3q_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st3q_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4a00000: ST3Q  { <Zt1>.Q, <Zt2>.Q, <Zt3>.Q }, <Pg>, [<Xn|SP>, <Xm>, LSL #4]
   Instruction Set: A64  Groups: sve_mem_estq_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3q_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/))
    {
        LogFlow(("%018x/%010x: st3q_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st3q_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st3q_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e550e000: ST3W  { <Zt1>.S, <Zt2>.S, <Zt3>.S }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3w_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st3w_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st3w_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st3w_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5406000: ST3W  { <Zt1>.S, <Zt2>.S, <Zt3>.S }, <Pg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st3w_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x2 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st3w_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st3w_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st3w_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e470e000: ST4B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4b_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st4b_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st4b_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st4b_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4606000: ST4B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <Pg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4b_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st4b_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st4b_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st4b_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e5f0e000: ST4D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4d_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st4d_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st4d_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st4d_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5e06000: ST4D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <Pg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4d_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st4d_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st4d_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st4d_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e4f0e000: ST4H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4h_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st4h_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st4h_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st4h_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4e06000: ST4H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <Pg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4h_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st4h_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st4h_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st4h_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e4c00000: ST4Q  { <Zt1>.Q, <Zt2>.Q, <Zt3>.Q, <Zt4>.Q }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_estq_si, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4q_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: st4q_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st4q_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st4q_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4e00000: ST4Q  { <Zt1>.Q, <Zt2>.Q, <Zt3>.Q, <Zt4>.Q }, <Pg>, [<Xn|SP>, <Xm>, LSL #4]
   Instruction Set: A64  Groups: sve_mem_estq_ss, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4q_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/))
    {
        LogFlow(("%018x/%010x: st4q_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st4q_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st4q_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e570e000: ST4W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_est_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4w_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if ((0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st4w_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__st4w_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__st4w_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5606000: ST4W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <Pg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_est_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_st4w_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (0x3 /*opc@21*/ != 0) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: st4w_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__st4w_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__st4w_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/80408008: STMOPA  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_i16i32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_stmopa_za32_zzzi_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: stmopa_za32_zzzi_h2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__stmopa_za32_zzzi_h2x1
        IEM_INSTR_IMPL_A64__stmopa_za32_zzzi_h2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/80408000: STMOPA  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_i8i32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_stmopa_za_zzzi_b2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: stmopa_za_zzzi_b2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__stmopa_za_zzzi_b2x1
        IEM_INSTR_IMPL_A64__stmopa_za_zzzi_b2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0600001: STNT1B  { <Zt1>.B-<Zt2>.B }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1b_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_mz_p_bi_2
        IEM_INSTR_IMPL_A64__stnt1b_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a0608001: STNT1B  { <Zt1>.B-<Zt4>.B }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1b_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_mz_p_bi_4
        IEM_INSTR_IMPL_A64__stnt1b_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0200001: STNT1B  { <Zt1>.B-<Zt2>.B }, <PNg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1b_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_mz_p_br_2
        IEM_INSTR_IMPL_A64__stnt1b_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a0208001: STNT1B  { <Zt1>.B-<Zt4>.B }, <PNg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1b_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_mz_p_br_4
        IEM_INSTR_IMPL_A64__stnt1b_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1600008: STNT1B  { <Zt1>.B, <Zt2>.B }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1b_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__stnt1b_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a1608008: STNT1B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1b_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__stnt1b_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1200008: STNT1B  { <Zt1>.B, <Zt2>.B }, <PNg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1b_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__stnt1b_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a1208008: STNT1B  { <Zt1>.B, <Zt2>.B, <Zt3>.B, <Zt4>.B }, <PNg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1b_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__stnt1b_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4002000: STNT1B  { <Zt>.D }, <Pg>, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_sstnt_64b_vs, sve_memsst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: stnt1b_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__stnt1b_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4402000: STNT1B  { <Zt>.S }, <Pg>, [<Zn>.S{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_sstnt_32b_vs, sve_memsst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: stnt1b_z_p_ar_s_x32_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_z_p_ar_s_x32_unscaled
        IEM_INSTR_IMPL_A64__stnt1b_z_p_ar_s_x32_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e410e000: STNT1B  { <Zt>.B }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cstnt_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: stnt1b_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__stnt1b_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4006000: STNT1B  { <Zt>.B }, <Pg>, [<Xn|SP>, <Xm>]
   Instruction Set: A64  Groups: sve_mem_cstnt_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1b_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: stnt1b_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1b_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__stnt1b_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0606001: STNT1D  { <Zt1>.D-<Zt2>.D }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1d_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_mz_p_bi_2
        IEM_INSTR_IMPL_A64__stnt1d_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a060e001: STNT1D  { <Zt1>.D-<Zt4>.D }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1d_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_mz_p_bi_4
        IEM_INSTR_IMPL_A64__stnt1d_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0206001: STNT1D  { <Zt1>.D-<Zt2>.D }, <PNg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1d_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_mz_p_br_2
        IEM_INSTR_IMPL_A64__stnt1d_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a020e001: STNT1D  { <Zt1>.D-<Zt4>.D }, <PNg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1d_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_mz_p_br_4
        IEM_INSTR_IMPL_A64__stnt1d_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1606008: STNT1D  { <Zt1>.D, <Zt2>.D }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1d_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__stnt1d_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a160e008: STNT1D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1d_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__stnt1d_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1206008: STNT1D  { <Zt1>.D, <Zt2>.D }, <PNg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1d_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__stnt1d_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a120e008: STNT1D  { <Zt1>.D, <Zt2>.D, <Zt3>.D, <Zt4>.D }, <PNg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1d_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__stnt1d_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5802000: STNT1D  { <Zt>.D }, <Pg>, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_sstnt_64b_vs, sve_memsst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: stnt1d_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__stnt1d_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e590e000: STNT1D  { <Zt>.D }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cstnt_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_z_p_bi_contiguous, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe590e000))
    {
        uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: stnt1d_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_z_p_bi_contiguous
            IEM_INSTR_IMPL_A64__stnt1d_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
            RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5806000: STNT1D  { <Zt>.D }, <Pg>, [<Xn|SP>, <Xm>, LSL #3]
   Instruction Set: A64  Groups: sve_mem_cstnt_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1d_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: stnt1d_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1d_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__stnt1d_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0602001: STNT1H  { <Zt1>.H-<Zt2>.H }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1h_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_mz_p_bi_2
        IEM_INSTR_IMPL_A64__stnt1h_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a060a001: STNT1H  { <Zt1>.H-<Zt4>.H }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1h_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_mz_p_bi_4
        IEM_INSTR_IMPL_A64__stnt1h_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0202001: STNT1H  { <Zt1>.H-<Zt2>.H }, <PNg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1h_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_mz_p_br_2
        IEM_INSTR_IMPL_A64__stnt1h_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a020a001: STNT1H  { <Zt1>.H-<Zt4>.H }, <PNg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1h_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_mz_p_br_4
        IEM_INSTR_IMPL_A64__stnt1h_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1602008: STNT1H  { <Zt1>.H, <Zt2>.H }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1h_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__stnt1h_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a160a008: STNT1H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1h_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__stnt1h_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1202008: STNT1H  { <Zt1>.H, <Zt2>.H }, <PNg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1h_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__stnt1h_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a120a008: STNT1H  { <Zt1>.H, <Zt2>.H, <Zt3>.H, <Zt4>.H }, <PNg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1h_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__stnt1h_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4802000: STNT1H  { <Zt>.D }, <Pg>, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_sstnt_64b_vs, sve_memsst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: stnt1h_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__stnt1h_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4c02000: STNT1H  { <Zt>.S }, <Pg>, [<Zn>.S{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_sstnt_32b_vs, sve_memsst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: stnt1h_z_p_ar_s_x32_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_z_p_ar_s_x32_unscaled
        IEM_INSTR_IMPL_A64__stnt1h_z_p_ar_s_x32_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e490e000: STNT1H  { <Zt>.H }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cstnt_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: stnt1h_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__stnt1h_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e4806000: STNT1H  { <Zt>.H }, <Pg>, [<Xn|SP>, <Xm>, LSL #1]
   Instruction Set: A64  Groups: sve_mem_cstnt_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1h_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: stnt1h_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1h_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__stnt1h_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e001/a0604001: STNT1W  { <Zt1>.S-<Zt2>.S }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_mz_p_bi_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1w_mz_p_bi_2 Zt=%#x Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_mz_p_bi_2
        IEM_INSTR_IMPL_A64__stnt1w_mz_p_bi_2(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e003/a060c001: STNT1W  { <Zt1>.S-<Zt4>.S }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_mz_p_bi_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1w_mz_p_bi_4 Zt=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_mz_p_bi_4
        IEM_INSTR_IMPL_A64__stnt1w_mz_p_bi_4(Zt, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e001/a0204001: STNT1W  { <Zt1>.S-<Zt2>.S }, <PNg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_mz_p_br_2, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1w_mz_p_br_2 Zt=%#x Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_mz_p_br_2
        IEM_INSTR_IMPL_A64__stnt1w_mz_p_br_2(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e003/a020c001: STNT1W  { <Zt1>.S-<Zt4>.S }, <PNg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_ctg, mortlach_multi_mem_ctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_mz_p_br_4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: stnt1w_mz_p_br_4 Zt=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_mz_p_br_4
        IEM_INSTR_IMPL_A64__stnt1w_mz_p_br_4(Zt, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e008/a1604008: STNT1W  { <Zt1>.S, <Zt2>.S }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_mzx_p_bi_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1w_mzx_p_bi_2x8 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_mzx_p_bi_2x8
        IEM_INSTR_IMPL_A64__stnt1w_mzx_p_bi_2x8(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e00c/a160c008: STNT1W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <PNg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_si_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_mzx_p_bi_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1w_mzx_p_bi_4x4 Zt=%u T=%u Rn=%#x PNg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_mzx_p_bi_4x4
        IEM_INSTR_IMPL_A64__stnt1w_mzx_p_bi_4x4(Zt, T, Rn, PNg, imm4);
#else
        RT_NOREF(Zt, T, Rn, PNg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e008/a1204008: STNT1W  { <Zt1>.S, <Zt2>.S }, <PNg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi2_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_mzx_p_br_2x8, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000007;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1w_mzx_p_br_2x8 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_mzx_p_br_2x8
        IEM_INSTR_IMPL_A64__stnt1w_mzx_p_br_2x8(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/a120c008: STNT1W  { <Zt1>.S, <Zt2>.S, <Zt3>.S, <Zt4>.S }, <PNg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: mortlach_multi4_cst_cstnt_ss_nctg, mortlach_multi_mem_nctg, sme */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_mzx_p_br_4x4, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x00000003;
    uint32_t const T          = (uOpcode >>  4) & 0x00000001;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const PNg        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: stnt1w_mzx_p_br_4x4 Zt=%u T=%u Rn=%#x PNg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, T, Rn, PNg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_mzx_p_br_4x4
        IEM_INSTR_IMPL_A64__stnt1w_mzx_p_br_4x4(Zt, T, Rn, PNg, Rm);
#else
        RT_NOREF(Zt, T, Rn, PNg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5002000: STNT1W  { <Zt>.D }, <Pg>, [<Zn>.D{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_sstnt_64b_vs, sve_memsst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: stnt1w_z_p_ar_d_64_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_z_p_ar_d_64_unscaled
        IEM_INSTR_IMPL_A64__stnt1w_z_p_ar_d_64_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5402000: STNT1W  { <Zt>.S }, <Pg>, [<Zn>.S{, <Xm>}]
   Instruction Set: A64  Groups: sve_mem_sstnt_32b_vs, sve_memsst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_z_p_ar_s_x32_unscaled, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/)
    {
        LogFlow(("%018x/%010x: stnt1w_z_p_ar_s_x32_unscaled Zt=%#x Zn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Zn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_z_p_ar_s_x32_unscaled
        IEM_INSTR_IMPL_A64__stnt1w_z_p_ar_s_x32_unscaled(Zt, Zn, Pg, Rm);
#else
        RT_NOREF(Zt, Zn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0e000/e510e000: STNT1W  { <Zt>.S }, <Pg>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_cstnt_si, sve_memst_si, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_z_p_bi_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: stnt1w_z_p_bi_contiguous Zt=%#x Rn=%#x Pg=%u imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, imm4));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_z_p_bi_contiguous
        IEM_INSTR_IMPL_A64__stnt1w_z_p_bi_contiguous(Zt, Rn, Pg, imm4);
#else
        RT_NOREF(Zt, Rn, Pg, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e000/e5006000: STNT1W  { <Zt>.S }, <Pg>, [<Xn|SP>, <Xm>, LSL #2]
   Instruction Set: A64  Groups: sve_mem_cstnt_ss, sve_memcst_nt, sve */
FNIEMOP_DEF_1(iemDecodeA64_stnt1w_z_p_br_contiguous, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    if ((Rm != 0x1f) && (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/))
    {
        LogFlow(("%018x/%010x: stnt1w_z_p_br_contiguous Zt=%#x Rn=%#x Pg=%u Rm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, Pg, Rm));
#ifdef IEM_INSTR_IMPL_A64__stnt1w_z_p_br_contiguous
        IEM_INSTR_IMPL_A64__stnt1w_z_p_br_contiguous(Zt, Rn, Pg, Rm);
#else
        RT_NOREF(Zt, Rn, Pg, Rm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e010/e5800000: STR  <Pt>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_pspill, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_str_p_bi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e010)) == UINT32_C(0xe5800000))
    {
        uint32_t const Pt         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm9l      = (uOpcode >> 10) & 0x00000007;
        uint32_t const imm9h      = (uOpcode >> 16) & 0x0000003f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: str_p_bi Pt=%#x Rn=%#x imm9l=%u imm9h=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pt, Rn, imm9l, imm9h));
#ifdef IEM_INSTR_IMPL_A64__str_p_bi
            IEM_INSTR_IMPL_A64__str_p_bi(Pt, Rn, imm9l, imm9h);
#else
            RT_NOREF(Pt, Rn, imm9l, imm9h, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffc0e000/e5804000: STR  <Zt>, [<Xn|SP>{, #<imm>, MUL VL}]
   Instruction Set: A64  Groups: sve_mem_spill, sve_memst_cs, sve */
FNIEMOP_DEF_1(iemDecodeA64_str_z_bi, uint32_t, uOpcode)
{
    uint32_t const Zt         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm9l      = (uOpcode >> 10) & 0x00000007;
    uint32_t const imm9h      = (uOpcode >> 16) & 0x0000003f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: str_z_bi Zt=%#x Rn=%#x imm9l=%u imm9h=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zt, Rn, imm9l, imm9h));
#ifdef IEM_INSTR_IMPL_A64__str_z_bi
        IEM_INSTR_IMPL_A64__str_z_bi(Zt, Rn, imm9l, imm9h);
#else
        RT_NOREF(Zt, Rn, imm9l, imm9h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9c10/e1200000: STR  ZA[<Wv>, <offs>], [<Xn|SP>{, #<offs>, MUL VL}]
   Instruction Set: A64  Groups: mortlach_ctxt_ldst, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_str_za_ri, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9c10)) == UINT32_C(0xe1200000))
    {
        uint32_t const off4       = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: str_za_ri off4=%#x Rn=%#x Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off4, Rn, Rv));
#ifdef IEM_INSTR_IMPL_A64__str_za_ri
            IEM_INSTR_IMPL_A64__str_za_ri(off4, Rn, Rv);
#else
            RT_NOREF(off4, Rn, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc1f/e13f8000: STR  ZT0, [<Xn|SP>]
   Instruction Set: A64  Groups: mortlach_zt_ldst, mortlach_mem, sme */
FNIEMOP_DEF_1(iemDecodeA64_str_zt_br, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xe13f8000))
    {
        uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: str_zt_br Rn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rn));
#ifdef IEM_INSTR_IMPL_A64__str_zt_br
            IEM_INSTR_IMPL_A64__str_zt_br(Rn);
#else
            RT_NOREF(Rn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04010000: SUB  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_0, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_sub_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04010000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sub_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sub_z_p_zz
            IEM_INSTR_IMPL_A64__sub_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc000/2521c000: SUB  <Zdn>.<T>, <Zdn>.<T>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_arith_imm0, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_sub_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc000)) == UINT32_C(0x2521c000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
        uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sub_z_zi Zdn=%#x imm8=%#x sh=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, sh, size));
#ifdef IEM_INSTR_IMPL_A64__sub_z_zi
            IEM_INSTR_IMPL_A64__sub_z_zi(Zdn, imm8, sh, size);
#else
            RT_NOREF(Zdn, imm8, sh, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04200400: SUB  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_cons_arit_0, sve_int_unpred_arit, sve */
FNIEMOP_DEF_1(iemDecodeA64_sub_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sub_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__sub_z_zz
        IEM_INSTR_IMPL_A64__sub_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbf9c38/c1a01c18: SUB  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_int_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sub_za_zw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbf9c38)) == UINT32_C(0xc1a01c18))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sub_za_zw_2x2 off3=%u Zm=%#x Rv=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv, sz));
#ifdef IEM_INSTR_IMPL_A64__sub_za_zw_2x2
            IEM_INSTR_IMPL_A64__sub_za_zw_2x2(off3, Zm, Rv, sz);
#else
            RT_NOREF(off3, Zm, Rv, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffbf9c78/c1a11c18: SUB  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_int_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sub_za_zw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbf9c78)) == UINT32_C(0xc1a11c18))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zm         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sub_za_zw_4x4 off3=%u Zm=%u Rv=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zm, Rv, sz));
#ifdef IEM_INSTR_IMPL_A64__sub_za_zw_4x4
            IEM_INSTR_IMPL_A64__sub_za_zw_4x4(off3, Zm, Rv, sz);
#else
            RT_NOREF(off3, Zm, Rv, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1201818: SUB  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<T>-<Zn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_int_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sub_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sub_za_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sub_za_zzv_2x1
        IEM_INSTR_IMPL_A64__sub_za_zzv_2x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1301818: SUB  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<T>-<Zn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_int_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sub_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sub_za_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sub_za_zzv_4x1
        IEM_INSTR_IMPL_A64__sub_za_zzv_4x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c38/c1a01818: SUB  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<T>-<Zn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_int_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sub_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c38)) == UINT32_C(0xc1a01818))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sub_za_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sub_za_zzw_2x2
            IEM_INSTR_IMPL_A64__sub_za_zzw_2x2(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c78/c1a11818: SUB  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<T>-<Zn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_int_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sub_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c78)) == UINT32_C(0xc1a11818))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sub_za_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__sub_za_zzw_4x4
            IEM_INSTR_IMPL_A64__sub_za_zzw_4x4(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45207000: SUBHNB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_arith_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_subhnb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: subhnb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__subhnb_z_zz
        IEM_INSTR_IMPL_A64__subhnb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45207400: SUBHNT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_arith_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_subhnt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: subhnt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__subhnt_z_zz
        IEM_INSTR_IMPL_A64__subhnt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/04c50000: SUBPT  <Zdn>.D, <Pg>/M, <Zdn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_0, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_subpt_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x04c50000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
        {
            LogFlow(("%018x/%010x: subpt_z_p_zz Zdn=%#x Zm=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg));
#ifdef IEM_INSTR_IMPL_A64__subpt_z_p_zz
            IEM_INSTR_IMPL_A64__subpt_z_p_zz(Zdn, Zm, Pg);
#else
            RT_NOREF(Zdn, Zm, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/04e00c00: SUBPT  <Zd>.D, <Zn>.D, <Zm>.D
   Instruction Set: A64  Groups: sve_int_bin_cons_arit_0, sve_int_unpred_arit, sve */
FNIEMOP_DEF_1(iemDecodeA64_subpt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fCpa /*FEAT_CPA*/)
    {
        LogFlow(("%018x/%010x: subpt_z_zz Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__subpt_z_zz
        IEM_INSTR_IMPL_A64__subpt_z_zz(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04030000: SUBR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_0, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_subr_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04030000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: subr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__subr_z_p_zz
            IEM_INSTR_IMPL_A64__subr_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc000/2523c000: SUBR  <Zdn>.<T>, <Zdn>.<T>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_arith_imm0, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_subr_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc000)) == UINT32_C(0x2523c000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
        uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: subr_z_zi Zdn=%#x imm8=%#x sh=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, sh, size));
#ifdef IEM_INSTR_IMPL_A64__subr_z_zi
            IEM_INSTR_IMPL_A64__subr_z_zi(Zdn, imm8, sh, size);
#else
            RT_NOREF(Zdn, imm8, sh, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a01c00: SUDOT  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_intx_mixed_dot_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_sudot_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
    {
        LogFlow(("%018x/%010x: sudot_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__sudot_z_zzzi_s
        IEM_INSTR_IMPL_A64__sudot_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1501038: SUDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_sudot_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sudot_za_zzi_s2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sudot_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__sudot_za_zzi_s2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1509038: SUDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sudot_za_zzi_s4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sudot_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sudot_za_zzi_s4xi
        IEM_INSTR_IMPL_A64__sudot_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1201418: SUDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi2_z_za_mixed_dot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sudot_za_zzv_s2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sudot_za_zzv_s2x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sudot_za_zzv_s2x1
        IEM_INSTR_IMPL_A64__sudot_za_zzv_s2x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1301418: SUDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi4_z_za_mixed_dot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sudot_za_zzv_s4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sudot_za_zzv_s4x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sudot_za_zzv_s4x1
        IEM_INSTR_IMPL_A64__sudot_za_zzv_s4x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0001c/c1000014: SUMLALL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_s, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumlall_za_zzi_s, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i4h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sumlall_za_zzi_s off2=%u Zn=%#x i4l=%u Rv=%u i4h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i4l, Rv, i4h, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumlall_za_zzi_s
        IEM_INSTR_IMPL_A64__sumlall_za_zzi_s(off2, Zn, i4l, Rv, i4h, Zm);
#else
        RT_NOREF(off2, Zn, i4l, Rv, i4h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1100030: SUMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumlall_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sumlall_za_zzi_s2xi o1=%u i4l=%u Zn=%#x i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumlall_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__sumlall_za_zzi_s2xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1108030: SUMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumlall_za_zzi_s4xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sumlall_za_zzi_s4xi o1=%u i4l=%u Zn=%u i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumlall_za_zzi_s4xi
        IEM_INSTR_IMPL_A64__sumlall_za_zzi_s4xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1e/c1200014: SUMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumlall_za_zzv_s2x1, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sumlall_za_zzv_s2x1 o1=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumlall_za_zzv_s2x1
        IEM_INSTR_IMPL_A64__sumlall_za_zzv_s2x1(o1, Zn, Rv, Zm);
#else
        RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1e/c1300014: SUMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumlall_za_zzv_s4x1, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: sumlall_za_zzv_s4x1 o1=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumlall_za_zzv_s4x1
        IEM_INSTR_IMPL_A64__sumlall_za_zzv_s4x1(o1, Zn, Rv, Zm);
#else
        RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80208000: SUMOP4A  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4a_za_zz_b1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80208000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: sumop4a_za_zz_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4a_za_zz_b1x1
            IEM_INSTR_IMPL_A64__sumop4a_za_zz_b1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80308000: SUMOP4A  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4a_za_zz_b1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80308000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: sumop4a_za_zz_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4a_za_zz_b1x2
            IEM_INSTR_IMPL_A64__sumop4a_za_zz_b1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80208200: SUMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4a_za_zz_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80208200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: sumop4a_za_zz_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4a_za_zz_b2x1
            IEM_INSTR_IMPL_A64__sumop4a_za_zz_b2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80308200: SUMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4a_za_zz_b2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80308200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: sumop4a_za_zz_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4a_za_zz_b2x2
            IEM_INSTR_IMPL_A64__sumop4a_za_zz_b2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0e00008: SUMOP4A  <ZAda>.D, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4a_za_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumop4a_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4a_za_zz_h1x1
        IEM_INSTR_IMPL_A64__sumop4a_za_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0f00008: SUMOP4A  <ZAda>.D, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4a_za_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumop4a_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4a_za_zz_h1x2
        IEM_INSTR_IMPL_A64__sumop4a_za_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0e00208: SUMOP4A  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4a_za_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumop4a_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4a_za_zz_h2x1
        IEM_INSTR_IMPL_A64__sumop4a_za_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0f00208: SUMOP4A  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4a_za_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumop4a_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4a_za_zz_h2x2
        IEM_INSTR_IMPL_A64__sumop4a_za_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80208010: SUMOP4S  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4s_za_zz_b1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80208010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: sumop4s_za_zz_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4s_za_zz_b1x1
            IEM_INSTR_IMPL_A64__sumop4s_za_zz_b1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80308010: SUMOP4S  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4s_za_zz_b1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80308010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: sumop4s_za_zz_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4s_za_zz_b1x2
            IEM_INSTR_IMPL_A64__sumop4s_za_zz_b1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80208210: SUMOP4S  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4s_za_zz_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80208210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: sumop4s_za_zz_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4s_za_zz_b2x1
            IEM_INSTR_IMPL_A64__sumop4s_za_zz_b2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/80308210: SUMOP4S  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4s_za_zz_b2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80308210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: sumop4s_za_zz_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4s_za_zz_b2x2
            IEM_INSTR_IMPL_A64__sumop4s_za_zz_b2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0e00018: SUMOP4S  <ZAda>.D, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4s_za_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumop4s_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4s_za_zz_h1x1
        IEM_INSTR_IMPL_A64__sumop4s_za_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0f00018: SUMOP4S  <ZAda>.D, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4s_za_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumop4s_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4s_za_zz_h1x2
        IEM_INSTR_IMPL_A64__sumop4s_za_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0e00218: SUMOP4S  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4s_za_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumop4s_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4s_za_zz_h2x1
        IEM_INSTR_IMPL_A64__sumop4s_za_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a0f00218: SUMOP4S  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumop4s_za_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumop4s_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumop4s_za_zz_h2x2
        IEM_INSTR_IMPL_A64__sumop4s_za_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a0a00000: SUMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumopa_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sumopa_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumopa_za_pp_zz_32
        IEM_INSTR_IMPL_A64__sumopa_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/a0e00000: SUMOPA  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumopa_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumopa_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumopa_za_pp_zz_64
        IEM_INSTR_IMPL_A64__sumopa_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a0a00010: SUMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumops_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sumops_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumops_za_pp_zz_32
        IEM_INSTR_IMPL_A64__sumops_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/a0e00010: SUMOPS  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_sumops_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: sumops_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__sumops_za_pp_zz_64
        IEM_INSTR_IMPL_A64__sumops_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc01/c125e000: SUNPK  { <Zd1>.<T>-<Zd2>.<T> }, <Zn>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi2_wide_int, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sunpk_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc01)) == UINT32_C(0xc125e000))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sunpk_mz_z_2 Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__sunpk_mz_z_2
            IEM_INSTR_IMPL_A64__sunpk_mz_z_2(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc23/c135e000: SUNPK  { <Zd1>.<T>-<Zd4>.<T> }, { <Zn1>.<Tb>-<Zn2>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_wide_int, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_sunpk_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc23)) == UINT32_C(0xc135e000))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: sunpk_mz_z_4 Zd=%u Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__sunpk_mz_z_4
            IEM_INSTR_IMPL_A64__sunpk_mz_z_4(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/05313800: SUNPKHI  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_perm_unpk, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_sunpkhi_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05313800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: sunpkhi_z_z Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__sunpkhi_z_z
            IEM_INSTR_IMPL_A64__sunpkhi_z_z(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/05303800: SUNPKLO  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_perm_unpk, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_sunpklo_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sunpklo_z_z Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__sunpklo_z_z
        IEM_INSTR_IMPL_A64__sunpklo_z_z(Zd, Zn, size);
#else
        RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/441c8000: SUQADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary_sat, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_suqadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: suqadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__suqadd_z_p_zz
        IEM_INSTR_IMPL_A64__suqadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/80608000: SUTMOPA  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_i8i32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_sutmopa_za_zzzi_b2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: sutmopa_za_zzzi_b2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__sutmopa_za_zzzi_b2x1
        IEM_INSTR_IMPL_A64__sutmopa_za_zzzi_b2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1508038: SUVDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_suvdot_za_zzi_s4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1508038))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: suvdot_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__suvdot_za_zzi_s4xi
            IEM_INSTR_IMPL_A64__suvdot_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1500020: SVDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_svdot_za32_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: svdot_za32_zzi_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__svdot_za32_zzi_2xi
        IEM_INSTR_IMPL_A64__svdot_za32_zzi_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1d08808: SVDOT  ZA.D[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_svdot_za_zzi_d4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: svdot_za_zzi_d4xi off3=%u Zn=%u i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__svdot_za_zzi_d4xi
        IEM_INSTR_IMPL_A64__svdot_za_zzi_d4xi(off3, Zn, i1, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1508020: SVDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_svdot_za_zzi_s4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1508020))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: svdot_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__svdot_za_zzi_s4xi
            IEM_INSTR_IMPL_A64__svdot_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0410a000: SXTB  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_sxtb_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sxtb_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sxtb_z_p_z_m
        IEM_INSTR_IMPL_A64__sxtb_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0400a000: SXTB  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_sxtb_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: sxtb_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sxtb_z_p_z_z
        IEM_INSTR_IMPL_A64__sxtb_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0412a000: SXTH  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_sxth_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sxth_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sxth_z_p_z_m
        IEM_INSTR_IMPL_A64__sxth_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0402a000: SXTH  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_sxth_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: sxth_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sxth_z_p_z_z
        IEM_INSTR_IMPL_A64__sxth_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0414a000: SXTW  <Zd>.D, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_sxtw_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: sxtw_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sxtw_z_p_z_m
        IEM_INSTR_IMPL_A64__sxtw_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0404a000: SXTW  <Zd>.D, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_sxtw_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: sxtw_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__sxtw_z_p_z_z
        IEM_INSTR_IMPL_A64__sxtw_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05203000: TBL  <Zd>.<T>, { <Zn>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_tbl, sve_perm_unpred_c, sve */
FNIEMOP_DEF_1(iemDecodeA64_tbl_z_zz_1, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: tbl_z_zz_1 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__tbl_z_zz_1
        IEM_INSTR_IMPL_A64__tbl_z_zz_1(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05202800: TBL  <Zd>.<T>, { <Zn1>.<T>, <Zn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_tbl_3src, sve_perm_unpred_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_tbl_z_zz_2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: tbl_z_zz_2 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__tbl_z_zz_2
        IEM_INSTR_IMPL_A64__tbl_z_zz_2(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4400f800: TBLQ  <Zd>.<T>, { <Zn>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_binquads, sve_perm_quads_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_tblq_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: tblq_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__tblq_z_zz
        IEM_INSTR_IMPL_A64__tblq_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05202c00: TBX  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_tbl_3src, sve_perm_unpred_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_tbx_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: tbx_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__tbx_z_zz
        IEM_INSTR_IMPL_A64__tbx_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05203400: TBXQ  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_tbxquads, sve_perm_quads_c, sve */
FNIEMOP_DEF_1(iemDecodeA64_tbxq_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: tbxq_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__tbxq_z_zz
        IEM_INSTR_IMPL_A64__tbxq_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30fe10/05205000: TRN1  <Pd>.<T>, <Pn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_pp, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_trn1_p_pp, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30fe10)) == UINT32_C(0x05205000))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: trn1_p_pp Pd=%#x Pn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__trn1_p_pp
            IEM_INSTR_IMPL_A64__trn1_p_pp(Pd, Pn, Pm, size);
#else
            RT_NOREF(Pd, Pn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05207000: TRN1  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_zz, sve_perm_inter, sve */
FNIEMOP_DEF_1(iemDecodeA64_trn1_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: trn1_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__trn1_z_zz
        IEM_INSTR_IMPL_A64__trn1_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/05a01800: TRN1  <Zd>.Q, <Zn>.Q, <Zm>.Q
   Instruction Set: A64  Groups: sve_int_perm_bin_long_perm_zz, sve_perm_inter_long, sve */
FNIEMOP_DEF_1(iemDecodeA64_trn1_z_zz_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: trn1_z_zz_q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__trn1_z_zz_q
        IEM_INSTR_IMPL_A64__trn1_z_zz_q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30fe10/05205400: TRN2  <Pd>.<T>, <Pn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_pp, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_trn2_p_pp, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30fe10)) == UINT32_C(0x05205400))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: trn2_p_pp Pd=%#x Pn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__trn2_p_pp
            IEM_INSTR_IMPL_A64__trn2_p_pp(Pd, Pn, Pm, size);
#else
            RT_NOREF(Pd, Pn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05207400: TRN2  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_zz, sve_perm_inter, sve */
FNIEMOP_DEF_1(iemDecodeA64_trn2_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: trn2_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__trn2_z_zz
        IEM_INSTR_IMPL_A64__trn2_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/05a01c00: TRN2  <Zd>.Q, <Zn>.Q, <Zm>.Q
   Instruction Set: A64  Groups: sve_int_perm_bin_long_perm_zz, sve_perm_inter_long, sve */
FNIEMOP_DEF_1(iemDecodeA64_trn2_z_zz_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: trn2_z_zz_q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__trn2_z_zz_q
        IEM_INSTR_IMPL_A64__trn2_z_zz_q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500fc00: UABA  <Zda>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_aba, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_uaba_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uaba_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uaba_z_zzz
        IEM_INSTR_IMPL_A64__uaba_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500c800: UABALB  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_aba_long, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_uabalb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uabalb_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uabalb_z_zzz
        IEM_INSTR_IMPL_A64__uabalb_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500cc00: UABALT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_aba_long, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_uabalt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uabalt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uabalt_z_zzz
        IEM_INSTR_IMPL_A64__uabalt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040d0000: UABD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_1, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_uabd_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040d0000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uabd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uabd_z_p_zz
            IEM_INSTR_IMPL_A64__uabd_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45003800: UABDLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_uabdlb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uabdlb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uabdlb_z_zz
        IEM_INSTR_IMPL_A64__uabdlb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45003c00: UABDLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_uabdlt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uabdlt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uabdlt_z_zz
        IEM_INSTR_IMPL_A64__uabdlt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4405a000: UADALP  <Zda>.<T>, <Pg>/M, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_intx_accumulate_long_pairs, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uadalp_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uadalp_z_p_z Zda=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uadalp_z_p_z
        IEM_INSTR_IMPL_A64__uadalp_z_p_z(Zda, Zn, Pg, size);
#else
        RT_NOREF(Zda, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45000800: UADDLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_uaddlb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uaddlb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uaddlb_z_zz
        IEM_INSTR_IMPL_A64__uaddlb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45000c00: UADDLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_uaddlt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uaddlt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uaddlt_z_zz
        IEM_INSTR_IMPL_A64__uaddlt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04012000: UADDV  <Dd>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_0, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_uaddv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uaddv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uaddv_r_p_z
        IEM_INSTR_IMPL_A64__uaddv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45004800: UADDWB  <Zd>.<T>, <Zn>.<T>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_wide, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_uaddwb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uaddwb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uaddwb_z_zz
        IEM_INSTR_IMPL_A64__uaddwb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45004c00: UADDWT  <Zd>.<T>, <Zn>.<T>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_wide, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_uaddwt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uaddwt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uaddwt_z_zz
        IEM_INSTR_IMPL_A64__uaddwt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc01/c120c401: UCLAMP  { <Zd1>.<T>-<Zd2>.<T> }, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_clamp_int, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uclamp_mz_zz_2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uclamp_mz_zz_2 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uclamp_mz_zz_2
        IEM_INSTR_IMPL_A64__uclamp_mz_zz_2(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc03/c120cc01: UCLAMP  { <Zd1>.<T>-<Zd4>.<T> }, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_clamp_int, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uclamp_mz_zz_4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uclamp_mz_zz_4 Zd=%u Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uclamp_mz_zz_4
        IEM_INSTR_IMPL_A64__uclamp_mz_zz_4(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4400c400: UCLAMP  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_clamp_lvl2, sve_intx_clamp, sve */
FNIEMOP_DEF_1(iemDecodeA64_uclamp_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: uclamp_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uclamp_z_zz
        IEM_INSTR_IMPL_A64__uclamp_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc21/c122e020: UCVTF  { <Zd1>.S-<Zd2>.S }, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_intfp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc21)) == UINT32_C(0xc122e020))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: ucvtf_mz_z_2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_mz_z_2
            IEM_INSTR_IMPL_A64__ucvtf_mz_z_2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c132e020: UCVTF  { <Zd1>.S-<Zd4>.S }, { <Zn1>.S-<Zn4>.S }
   Instruction Set: A64  Groups: mortlach_multi4_intfp_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc132e020))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: ucvtf_mz_z_4 Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_mz_z_4
            IEM_INSTR_IMPL_A64__ucvtf_mz_z_4(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6553a000: UCVTF  <Zd>.H, <Pg>/M, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_h2fp16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ucvtf_z_p_z_h2fp16 Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_h2fp16
        IEM_INSTR_IMPL_A64__ucvtf_z_p_z_h2fp16(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645ce000: UCVTF  <Zd>.H, <Pg>/Z, <Zn>.H
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_h2fp16z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645ce000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: ucvtf_z_p_z_h2fp16z Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_h2fp16z
            IEM_INSTR_IMPL_A64__ucvtf_z_p_z_h2fp16z(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65d1a000: UCVTF  <Zd>.D, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_w2d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ucvtf_z_p_z_w2d Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2d
        IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2d(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dca000: UCVTF  <Zd>.D, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_w2dz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: ucvtf_z_p_z_w2dz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2dz
        IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2dz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6555a000: UCVTF  <Zd>.H, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_w2fp16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ucvtf_z_p_z_w2fp16 Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2fp16
        IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2fp16(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645da000: UCVTF  <Zd>.H, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_w2fp16z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645da000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: ucvtf_z_p_z_w2fp16z Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2fp16z
            IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2fp16z(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6595a000: UCVTF  <Zd>.S, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_w2s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6595a000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: ucvtf_z_p_z_w2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2s
            IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2s(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/649da000: UCVTF  <Zd>.S, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_w2sz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: ucvtf_z_p_z_w2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2sz
        IEM_INSTR_IMPL_A64__ucvtf_z_p_z_w2sz(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65d7a000: UCVTF  <Zd>.D, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_x2d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ucvtf_z_p_z_x2d Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2d
        IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2d(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dde000: UCVTF  <Zd>.D, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_x2dz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dde000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: ucvtf_z_p_z_x2dz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2dz
            IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2dz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/6557a000: UCVTF  <Zd>.H, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_x2fp16, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ucvtf_z_p_z_x2fp16 Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2fp16
        IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2fp16(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/645de000: UCVTF  <Zd>.H, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_x2fp16z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645de000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: ucvtf_z_p_z_x2fp16z Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2fp16z
            IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2fp16z(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/65d5a000: UCVTF  <Zd>.S, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_2op_p_zd_c, sve_fp_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_x2s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ucvtf_z_p_z_x2s Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2s
        IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2s(Zd, Zn, Pg);
#else
        RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffe000/64dda000: UCVTF  <Zd>.S, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_fp_z2op_p_zd_c, sve_fp_zeroing_unary, sve */
FNIEMOP_DEF_1(iemDecodeA64_ucvtf_z_p_z_x2sz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dda000))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
        {
            LogFlow(("%018x/%010x: ucvtf_z_p_z_x2sz Zd=%#x Zn=%#x Pg=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg));
#ifdef IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2sz
            IEM_INSTR_IMPL_A64__ucvtf_z_p_z_x2sz(Zd, Zn, Pg);
#else
            RT_NOREF(Zd, Zn, Pg, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04150000: UDIV  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_div, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_udiv_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04150000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: udiv_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__udiv_z_p_zz
            IEM_INSTR_IMPL_A64__udiv_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04170000: UDIVR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_div, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_udivr_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04170000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: udivr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__udivr_z_p_zz
            IEM_INSTR_IMPL_A64__udivr_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4400cc00: UDOT  <Zda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: sve_intx_dot2_lvl2, sve_intx_dot2, sve */
FNIEMOP_DEF_1(iemDecodeA64_udot_z32_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: udot_z32_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_z32_zzz
        IEM_INSTR_IMPL_A64__udot_z32_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/4480cc00: UDOT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_dot2_by_indexed_elem_lvl2, sve_intx_dot2_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_udot_z32_zzzi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: udot_z32_zzzi Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__udot_z32_zzzi
        IEM_INSTR_IMPL_A64__udot_z32_zzzi(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/44800400: UDOT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_dot, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_udot_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: udot_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__udot_z_zzz
        IEM_INSTR_IMPL_A64__udot_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44e00400: UDOT  <Zda>.D, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_dot_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_udot_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i1         = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: udot_z_zzzi_d Zda=%#x Zn=%#x Zm=%#x i1=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i1));
#ifdef IEM_INSTR_IMPL_A64__udot_z_zzzi_d
        IEM_INSTR_IMPL_A64__udot_z_zzzi_d(Zda, Zn, Zm, i1);
#else
        RT_NOREF(Zda, Zn, Zm, i1, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a00400: UDOT  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_intx_dot_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_udot_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: udot_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__udot_z_zzzi_s
        IEM_INSTR_IMPL_A64__udot_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1501010: UDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za32_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: udot_za32_zzi_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za32_zzi_2xi
        IEM_INSTR_IMPL_A64__udot_za32_zzi_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1509010: UDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za32_zzi_4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: udot_za32_zzi_4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za32_zzi_4xi
        IEM_INSTR_IMPL_A64__udot_za32_zzi_4xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1601418: UDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_z_za_2way_dot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za32_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: udot_za32_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za32_zzv_2x1
        IEM_INSTR_IMPL_A64__udot_za32_zzv_2x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1701418: UDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_z_za_2way_dot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za32_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: udot_za32_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za32_zzv_4x1
        IEM_INSTR_IMPL_A64__udot_za32_zzv_4x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1e01418: UDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_2way_dot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za32_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c38)) == UINT32_C(0xc1e01418))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: udot_za32_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za32_zzw_2x2
            IEM_INSTR_IMPL_A64__udot_za32_zzw_2x2(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1e11418: UDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_2way_dot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za32_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1e11418))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: udot_za32_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za32_zzw_4x4
            IEM_INSTR_IMPL_A64__udot_za32_zzw_4x4(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09838/c1d00018: UDOT  ZA.D[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_d, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za_zzi_d2xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09838)) == UINT32_C(0xc1d00018))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: udot_za_zzi_d2xi off3=%u Zn=%#x i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za_zzi_d2xi
            IEM_INSTR_IMPL_A64__udot_za_zzi_d2xi(off3, Zn, i1, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1d08018: UDOT  ZA.D[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za_zzi_d4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: udot_za_zzi_d4xi off3=%u Zn=%u i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za_zzi_d4xi
        IEM_INSTR_IMPL_A64__udot_za_zzi_d4xi(off3, Zn, i1, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1501030: UDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: udot_za_zzi_s2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__udot_za_zzi_s2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1509030: UDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za_zzi_s4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: udot_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__udot_za_zzi_s4xi
        IEM_INSTR_IMPL_A64__udot_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1201410: UDOT  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi2_z_za_4way_dot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za_zzv_2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: udot_za_zzv_2x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__udot_za_zzv_2x1
        IEM_INSTR_IMPL_A64__udot_za_zzv_2x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c18/c1301410: UDOT  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi4_z_za_4way_dot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za_zzv_4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: udot_za_zzv_4x1 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__udot_za_zzv_4x1
        IEM_INSTR_IMPL_A64__udot_za_zzv_4x1(off3, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c38/c1a01410: UDOT  ZA.<T>[<Wv>, <offs>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, { <Zm1>.<Tb>-<Zm2>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_4way_dot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c38)) == UINT32_C(0xc1a01410))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: udot_za_zzw_2x2 off3=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__udot_za_zzw_2x2
            IEM_INSTR_IMPL_A64__udot_za_zzw_2x2(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c78/c1a11410: UDOT  ZA.<T>[<Wv>, <offs>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, { <Zm1>.<Tb>-<Zm4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_4way_dot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_udot_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c78)) == UINT32_C(0xc1a11410))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: udot_za_zzw_4x4 off3=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__udot_za_zzw_4x4
            IEM_INSTR_IMPL_A64__udot_za_zzw_4x4(off3, Zn, Rv, Zm, sz);
#else
            RT_NOREF(off3, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44118000: UHADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uhadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uhadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uhadd_z_p_zz
        IEM_INSTR_IMPL_A64__uhadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44138000: UHSUB  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uhsub_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uhsub_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uhsub_z_p_zz
        IEM_INSTR_IMPL_A64__uhsub_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44178000: UHSUBR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uhsubr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uhsubr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uhsubr_z_p_zz
        IEM_INSTR_IMPL_A64__uhsubr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a001: UMAX  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_minmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umax_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a001))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umax_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umax_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__umax_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a801: UMAX  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_minmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umax_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a801))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umax_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umax_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__umax_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b001: UMAX  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_minmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_umax_mz_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b001))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umax_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umax_mz_zzw_2x2
            IEM_INSTR_IMPL_A64__umax_mz_zzw_2x2(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b801: UMAX  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_minmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_umax_mz_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b801))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umax_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umax_mz_zzw_4x4
            IEM_INSTR_IMPL_A64__umax_mz_zzw_4x4(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04090000: UMAX  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_1, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_umax_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04090000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: umax_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__umax_z_p_zz
            IEM_INSTR_IMPL_A64__umax_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/2529c000: UMAX  <Zdn>.<T>, <Zdn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_imm1, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_umax_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umax_z_zi Zdn=%#x imm8=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, size));
#ifdef IEM_INSTR_IMPL_A64__umax_z_zi
        IEM_INSTR_IMPL_A64__umax_z_zi(Zdn, imm8, size);
#else
        RT_NOREF(Zdn, imm8, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4415a000: UMAXP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_arith_binary_pairs, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_umaxp_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umaxp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__umaxp_z_p_zz
        IEM_INSTR_IMPL_A64__umaxp_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040d2000: UMAXQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_reduce_1q, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_umaxqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: umaxqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__umaxqv_z_p_z
        IEM_INSTR_IMPL_A64__umaxqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04092000: UMAXV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_1, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_umaxv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umaxv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__umaxv_r_p_z
        IEM_INSTR_IMPL_A64__umaxv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a021: UMIN  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_minmax_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umin_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a021))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umin_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umin_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__umin_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120a821: UMIN  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_minmax_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umin_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a821))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umin_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umin_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__umin_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b021: UMIN  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_minmax_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_umin_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umin_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umin_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__umin_mz_zzw_2x2(Zdn, Zm, size);
#else
        RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120b821: UMIN  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_minmax_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_umin_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umin_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umin_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__umin_mz_zzw_4x4(Zdn, Zm, size);
#else
        RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040b0000: UMIN  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_1, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_umin_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040b0000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: umin_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__umin_z_p_zz
            IEM_INSTR_IMPL_A64__umin_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/252bc000: UMIN  <Zdn>.<T>, <Zdn>.<T>, #<imm>
   Instruction Set: A64  Groups: sve_int_arith_imm1, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_umin_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umin_z_zi Zdn=%#x imm8=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, size));
#ifdef IEM_INSTR_IMPL_A64__umin_z_zi
        IEM_INSTR_IMPL_A64__umin_z_zi(Zdn, imm8, size);
#else
        RT_NOREF(Zdn, imm8, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4417a000: UMINP  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_arith_binary_pairs, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uminp_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uminp_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uminp_z_p_zz
        IEM_INSTR_IMPL_A64__uminp_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040f2000: UMINQV  <Vd>.<T>, <Pg>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_reduce_1q, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_uminqv_z_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: uminqv_z_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uminqv_z_p_z
        IEM_INSTR_IMPL_A64__uminqv_z_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040b2000: UMINV  <V><d>, <Pg>, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_reduce_1, sve_int_pred_red, sve */
FNIEMOP_DEF_1(iemDecodeA64_uminv_r_p_z, uint32_t, uOpcode)
{
    uint32_t const Vd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uminv_r_p_z Vd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Vd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uminv_r_p_z
        IEM_INSTR_IMPL_A64__uminv_r_p_z(Vd, Zn, Pg, size);
#else
        RT_NOREF(Vd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01018/c1c01010: UMLAL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlal_za_zzi_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlal_za_zzi_1 off3=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlal_za_zzi_1
        IEM_INSTR_IMPL_A64__umlal_za_zzi_1(off3, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off3, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1d01010: UMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlal_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlal_za_zzi_2xi off2=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlal_za_zzi_2xi
        IEM_INSTR_IMPL_A64__umlal_za_zzi_2xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1d09010: UMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlal_za_zzi_4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09010))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlal_za_zzi_4xi off2=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlal_za_zzi_4xi
            IEM_INSTR_IMPL_A64__umlal_za_zzi_4xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1600c10: UMLAL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlal_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlal_za_zzv_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlal_za_zzv_1
        IEM_INSTR_IMPL_A64__umlal_za_zzv_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1600810: UMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlal_za_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c1c)) == UINT32_C(0xc1600810))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlal_za_zzv_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlal_za_zzv_2x1
            IEM_INSTR_IMPL_A64__umlal_za_zzv_2x1(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1700810: UMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlal_za_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c1c)) == UINT32_C(0xc1700810))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlal_za_zzv_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlal_za_zzv_4x1
            IEM_INSTR_IMPL_A64__umlal_za_zzv_4x1(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1e00810: UMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlal_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c3c)) == UINT32_C(0xc1e00810))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlal_za_zzw_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlal_za_zzw_2x2
            IEM_INSTR_IMPL_A64__umlal_za_zzw_2x2(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1e10810: UMLAL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlal_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1e10810))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlal_za_zzw_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlal_za_zzw_4x4
            IEM_INSTR_IMPL_A64__umlal_za_zzw_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44004800: UMLALB  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_mlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlalb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlalb_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umlalb_z_zzz
        IEM_INSTR_IMPL_A64__umlalb_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e09000: UMLALB  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlalb_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlalb_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__umlalb_z_zzzi_d
        IEM_INSTR_IMPL_A64__umlalb_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a09000: UMLALB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlalb_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlalb_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__umlalb_z_zzzi_s
        IEM_INSTR_IMPL_A64__umlalb_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0101c/c1800010: UMLALL  ZA.D[<Wv>, <offs1>:<offs4>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_d, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzi_d, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umlall_za_zzi_d off2=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzi_d
        IEM_INSTR_IMPL_A64__umlall_za_zzi_d(off2, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off2, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09838/c1900010: UMLALL  ZA.D[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_d, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzi_d2xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09838)) == UINT32_C(0xc1900010))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i3l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: umlall_za_zzi_d2xi o1=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzi_d2xi
            IEM_INSTR_IMPL_A64__umlall_za_zzi_d2xi(o1, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(o1, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1908010: UMLALL  ZA.D[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzi_d4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1908010))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i3l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: umlall_za_zzi_d4xi o1=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzi_d4xi
            IEM_INSTR_IMPL_A64__umlall_za_zzi_d4xi(o1, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(o1, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0001c/c1000010: UMLALL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_s, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzi_s, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i4h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlall_za_zzi_s off2=%u Zn=%#x i4l=%u Rv=%u i4h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i4l, Rv, i4h, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzi_s
        IEM_INSTR_IMPL_A64__umlall_za_zzi_s(off2, Zn, i4l, Rv, i4h, Zm);
#else
        RT_NOREF(off2, Zn, i4l, Rv, i4h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1100010: UMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlall_za_zzi_s2xi o1=%u i4l=%u Zn=%#x i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__umlall_za_zzi_s2xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1108010: UMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzi_s4xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlall_za_zzi_s4xi o1=%u i4l=%u Zn=%u i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzi_s4xi
        IEM_INSTR_IMPL_A64__umlall_za_zzi_s4xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1c/c1200410: UMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>], <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlall_za_zzv_1 off2=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzv_1
        IEM_INSTR_IMPL_A64__umlall_za_zzv_1(off2, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off2, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1e/c1200010: UMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1e)) == UINT32_C(0xc1200010))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlall_za_zzv_2x1 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzv_2x1
            IEM_INSTR_IMPL_A64__umlall_za_zzv_2x1(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1e/c1300010: UMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1e)) == UINT32_C(0xc1300010))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlall_za_zzv_4x1 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzv_4x1
            IEM_INSTR_IMPL_A64__umlall_za_zzv_4x1(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c3e/c1a00010: UMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, { <Zm1>.<Tb>-<Zm2>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c3e)) == UINT32_C(0xc1a00010))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlall_za_zzw_2x2 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzw_2x2
            IEM_INSTR_IMPL_A64__umlall_za_zzw_2x2(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c7e/c1a10010: UMLALL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, { <Zm1>.<Tb>-<Zm4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlall_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c7e)) == UINT32_C(0xc1a10010))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlall_za_zzw_4x4 o1=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlall_za_zzw_4x4
            IEM_INSTR_IMPL_A64__umlall_za_zzw_4x4(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44004c00: UMLALT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_mlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlalt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlalt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umlalt_z_zzz
        IEM_INSTR_IMPL_A64__umlalt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e09400: UMLALT  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlalt_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlalt_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__umlalt_z_zzzi_d
        IEM_INSTR_IMPL_A64__umlalt_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a09400: UMLALT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlalt_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlalt_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__umlalt_z_zzzi_s
        IEM_INSTR_IMPL_A64__umlalt_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff01018/c1c01018: UMLSL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_idx, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsl_za_zzi_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlsl_za_zzi_1 off3=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsl_za_zzi_1
        IEM_INSTR_IMPL_A64__umlsl_za_zzi_1(off3, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off3, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1d01018: UMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_idx, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsl_za_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlsl_za_zzi_2xi off2=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsl_za_zzi_2xi
        IEM_INSTR_IMPL_A64__umlsl_za_zzi_2xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
        RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1d09018: UMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_idx, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsl_za_zzi_4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09018))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const i3l        = (uOpcode >>  2) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsl_za_zzi_4xi off2=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsl_za_zzi_4xi
            IEM_INSTR_IMPL_A64__umlsl_za_zzi_4xi(off2, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(off2, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1600c18: UMLSL  ZA.S[<Wv>, <offs1>:<offs2>], <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsl_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlsl_za_zzv_1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsl_za_zzv_1
        IEM_INSTR_IMPL_A64__umlsl_za_zzv_1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1600818: UMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsl_za_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c1c)) == UINT32_C(0xc1600818))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsl_za_zzv_2x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsl_za_zzv_2x1
            IEM_INSTR_IMPL_A64__umlsl_za_zzv_2x1(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1700818: UMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsl_za_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c1c)) == UINT32_C(0xc1700818))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsl_za_zzv_4x1 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsl_za_zzv_4x1
            IEM_INSTR_IMPL_A64__umlsl_za_zzv_4x1(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3c/c1e00818: UMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx2}], { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsl_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c3c)) == UINT32_C(0xc1e00818))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsl_za_zzw_2x2 off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsl_za_zzw_2x2
            IEM_INSTR_IMPL_A64__umlsl_za_zzw_2x2(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7c/c1e10818: UMLSL  ZA.S[<Wv>, <offs1>:<offs2>{, VGx4}], { <Zn1>.H-<Zn4>.H }, { <Zm1>.H-<Zm4>.H }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsl_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7c)) == UINT32_C(0xc1e10818))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsl_za_zzw_4x4 off2=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsl_za_zzw_4x4
            IEM_INSTR_IMPL_A64__umlsl_za_zzw_4x4(off2, Zn, Rv, Zm);
#else
            RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44005800: UMLSLB  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_mlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlslb_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlslb_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umlslb_z_zzz
        IEM_INSTR_IMPL_A64__umlslb_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0b000: UMLSLB  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlslb_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlslb_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__umlslb_z_zzzi_d
        IEM_INSTR_IMPL_A64__umlslb_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0b000: UMLSLB  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlslb_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlslb_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__umlslb_z_zzzi_s
        IEM_INSTR_IMPL_A64__umlslb_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0101c/c1800018: UMLSLL  ZA.D[<Wv>, <offs1>:<offs4>], <Zn>.H, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_d, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzi_d, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i3h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umlsll_za_zzi_d off2=%u Zn=%#x i3l=%u Rv=%u i3h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i3l, Rv, i3h, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzi_d
        IEM_INSTR_IMPL_A64__umlsll_za_zzi_d(off2, Zn, i3l, Rv, i3h, Zm);
#else
        RT_NOREF(off2, Zn, i3l, Rv, i3h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09838/c1900018: UMLSLL  ZA.D[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_d, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzi_d2xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09838)) == UINT32_C(0xc1900018))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i3l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzi_d2xi o1=%u i3l=%u Zn=%#x i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzi_d2xi
            IEM_INSTR_IMPL_A64__umlsll_za_zzi_d2xi(o1, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(o1, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1908018: UMLSLL  ZA.D[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzi_d4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1908018))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i3l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i3h        = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzi_d4xi o1=%u i3l=%u Zn=%u i3h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i3l, Zn, i3h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzi_d4xi
            IEM_INSTR_IMPL_A64__umlsll_za_zzi_d4xi(o1, i3l, Zn, i3h, Rv, Zm);
#else
            RT_NOREF(o1, i3l, Zn, i3h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0001c/c1000018: UMLSLL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_s, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzi_s, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000018))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const i4l        = (uOpcode >> 10) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const i4h        = (uOpcode >> 15) & 0x00000001;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzi_s off2=%u Zn=%#x i4l=%u Rv=%u i4h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i4l, Rv, i4h, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzi_s
            IEM_INSTR_IMPL_A64__umlsll_za_zzi_s(off2, Zn, i4l, Rv, i4h, Zm);
#else
            RT_NOREF(off2, Zn, i4l, Rv, i4h, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1100018: UMLSLL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzi_s2xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09038)) == UINT32_C(0xc1100018))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzi_s2xi o1=%u i4l=%u Zn=%#x i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzi_s2xi
            IEM_INSTR_IMPL_A64__umlsll_za_zzi_s2xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
            RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1108018: UMLSLL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzi_s4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1108018))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzi_s4xi o1=%u i4l=%u Zn=%u i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzi_s4xi
            IEM_INSTR_IMPL_A64__umlsll_za_zzi_s4xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
            RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1c/c1200418: UMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>], <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzv_1, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umlsll_za_zzv_1 off2=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzv_1
        IEM_INSTR_IMPL_A64__umlsll_za_zzv_1(off2, Zn, Rv, Zm, sz);
#else
        RT_NOREF(off2, Zn, Rv, Zm, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1e/c1200018: UMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1e)) == UINT32_C(0xc1200018))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzv_2x1 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzv_2x1
            IEM_INSTR_IMPL_A64__umlsll_za_zzv_2x1(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffb09c1e/c1300018: UMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, <Zm>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1e)) == UINT32_C(0xc1300018))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzv_4x1 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzv_4x1
            IEM_INSTR_IMPL_A64__umlsll_za_zzv_4x1(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa19c3e/c1a00018: UMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.<Tb>-<Zn2>.<Tb> }, { <Zm1>.<Tb>-<Zm2>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzw_2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c3e)) == UINT32_C(0xc1a00018))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzw_2x2 o1=%u Zn=%#x Rv=%u Zm=%#x sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzw_2x2
            IEM_INSTR_IMPL_A64__umlsll_za_zzw_2x2(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa39c7e/c1a10018: UMLSLL  ZA.<T>[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.<Tb>-<Zn4>.<Tb> }, { <Zm1>.<Tb>-<Zm4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_umlsll_za_zzw_4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa39c7e)) == UINT32_C(0xc1a10018))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        uint32_t const sz         = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: umlsll_za_zzw_4x4 o1=%u Zn=%u Rv=%u Zm=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm, sz));
#ifdef IEM_INSTR_IMPL_A64__umlsll_za_zzw_4x4
            IEM_INSTR_IMPL_A64__umlsll_za_zzw_4x4(o1, Zn, Rv, Zm, sz);
#else
            RT_NOREF(o1, Zn, Rv, Zm, sz, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/44005c00: UMLSLT  <Zda>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_mlal_long, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlslt_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlslt_z_zzz Zda=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umlslt_z_zzz
        IEM_INSTR_IMPL_A64__umlslt_z_zzz(Zda, Zn, Zm, size);
#else
        RT_NOREF(Zda, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0b400: UMLSLT  <Zda>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlslt_z_zzzi_d, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlslt_z_zzzi_d Zda=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__umlslt_z_zzzi_d
        IEM_INSTR_IMPL_A64__umlslt_z_zzzi_d(Zda, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zda, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0b400: UMLSLT  <Zda>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mla_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umlslt_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umlslt_z_zzzi_s Zda=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__umlslt_z_zzzi_s
        IEM_INSTR_IMPL_A64__umlslt_z_zzzi_s(Zda, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zda, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/45c09800: UMMLA  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_intx_mmla, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_ummla_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
    {
        LogFlow(("%018x/%010x: ummla_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__ummla_z_zzz
        IEM_INSTR_IMPL_A64__ummla_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81008008: UMOP4A  <ZAda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za32_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81008008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4a_za32_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za32_zz_h1x1
            IEM_INSTR_IMPL_A64__umop4a_za32_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81108008: UMOP4A  <ZAda>.S, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za32_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81108008))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4a_za32_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za32_zz_h1x2
            IEM_INSTR_IMPL_A64__umop4a_za32_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81008208: UMOP4A  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za32_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81008208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4a_za32_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za32_zz_h2x1
            IEM_INSTR_IMPL_A64__umop4a_za32_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81108208: UMOP4A  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za32_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81108208))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4a_za32_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za32_zz_h2x2
            IEM_INSTR_IMPL_A64__umop4a_za32_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81208000: UMOP4A  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za_zz_b1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81208000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4a_za_zz_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za_zz_b1x1
            IEM_INSTR_IMPL_A64__umop4a_za_zz_b1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81308000: UMOP4A  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za_zz_b1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81308000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4a_za_zz_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za_zz_b1x2
            IEM_INSTR_IMPL_A64__umop4a_za_zz_b1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81208200: UMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za_zz_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81208200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4a_za_zz_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za_zz_b2x1
            IEM_INSTR_IMPL_A64__umop4a_za_zz_b2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81308200: UMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za_zz_b2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81308200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4a_za_zz_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za_zz_b2x2
            IEM_INSTR_IMPL_A64__umop4a_za_zz_b2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1e00008: UMOP4A  <ZAda>.D, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umop4a_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za_zz_h1x1
        IEM_INSTR_IMPL_A64__umop4a_za_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1f00008: UMOP4A  <ZAda>.D, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umop4a_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za_zz_h1x2
        IEM_INSTR_IMPL_A64__umop4a_za_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1e00208: UMOP4A  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umop4a_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za_zz_h2x1
        IEM_INSTR_IMPL_A64__umop4a_za_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1f00208: UMOP4A  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4a_za_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umop4a_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4a_za_zz_h2x2
        IEM_INSTR_IMPL_A64__umop4a_za_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81008018: UMOP4S  <ZAda>.S, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za32_zz_h1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81008018))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4s_za32_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za32_zz_h1x1
            IEM_INSTR_IMPL_A64__umop4s_za32_zz_h1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81108018: UMOP4S  <ZAda>.S, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za32_zz_h1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81108018))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4s_za32_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za32_zz_h1x2
            IEM_INSTR_IMPL_A64__umop4s_za32_zz_h1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81008218: UMOP4S  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za32_zz_h2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81008218))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4s_za32_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za32_zz_h2x1
            IEM_INSTR_IMPL_A64__umop4s_za32_zz_h2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81108218: UMOP4S  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za32_zz_h2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81108218))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4s_za32_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za32_zz_h2x2
            IEM_INSTR_IMPL_A64__umop4s_za32_zz_h2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81208010: UMOP4S  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za_zz_b1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81208010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4s_za_zz_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za_zz_b1x1
            IEM_INSTR_IMPL_A64__umop4s_za_zz_b1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81308010: UMOP4S  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za_zz_b1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81308010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4s_za_zz_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za_zz_b1x2
            IEM_INSTR_IMPL_A64__umop4s_za_zz_b1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81208210: UMOP4S  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za_zz_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81208210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4s_za_zz_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za_zz_b2x1
            IEM_INSTR_IMPL_A64__umop4s_za_zz_b2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81308210: UMOP4S  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za_zz_b2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81308210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: umop4s_za_zz_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za_zz_b2x2
            IEM_INSTR_IMPL_A64__umop4s_za_zz_b2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1e00018: UMOP4S  <ZAda>.D, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umop4s_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za_zz_h1x1
        IEM_INSTR_IMPL_A64__umop4s_za_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1f00018: UMOP4S  <ZAda>.D, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umop4s_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za_zz_h1x2
        IEM_INSTR_IMPL_A64__umop4s_za_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1e00218: UMOP4S  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umop4s_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za_zz_h2x1
        IEM_INSTR_IMPL_A64__umop4s_za_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1f00218: UMOP4S  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_umop4s_za_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umop4s_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__umop4s_za_zz_h2x2
        IEM_INSTR_IMPL_A64__umop4s_za_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a1800008: UMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_umopa_za32_pp_zz_16, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umopa_za32_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__umopa_za32_pp_zz_16
        IEM_INSTR_IMPL_A64__umopa_za32_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a1a00000: UMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_umopa_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umopa_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__umopa_za_pp_zz_32
        IEM_INSTR_IMPL_A64__umopa_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/a1e00000: UMOPA  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_umopa_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umopa_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__umopa_za_pp_zz_64
        IEM_INSTR_IMPL_A64__umopa_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a1800018: UMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_umops_za32_pp_zz_16, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: umops_za32_pp_zz_16 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__umops_za32_pp_zz_16
        IEM_INSTR_IMPL_A64__umops_za32_pp_zz_16(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a1a00010: UMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_umops_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umops_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__umops_za_pp_zz_32
        IEM_INSTR_IMPL_A64__umops_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/a1e00010: UMOPS  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_umops_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: umops_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__umops_za_pp_zz_64
        IEM_INSTR_IMPL_A64__umops_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04130000: UMULH  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_pred_arit_2, sve_int_pred_bin, sve */
FNIEMOP_DEF_1(iemDecodeA64_umulh_z_p_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04130000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: umulh_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__umulh_z_p_zz
            IEM_INSTR_IMPL_A64__umulh_z_p_zz(Zdn, Zm, Pg, size);
#else
            RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04206c00: UMULH  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_mul_b, sve_int_unpred_arit_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_umulh_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umulh_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umulh_z_zz
        IEM_INSTR_IMPL_A64__umulh_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45007800: UMULLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_umullb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umullb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umullb_z_zz
        IEM_INSTR_IMPL_A64__umullb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0d000: UMULLB  <Zd>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umullb_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umullb_z_zzi_d Zd=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__umullb_z_zzi_d
        IEM_INSTR_IMPL_A64__umullb_z_zzi_d(Zd, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zd, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0d000: UMULLB  <Zd>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umullb_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umullb_z_zzi_s Zd=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__umullb_z_zzi_s
        IEM_INSTR_IMPL_A64__umullb_z_zzi_s(Zd, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zd, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45007c00: UMULLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_mul_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_umullt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umullt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__umullt_z_zz
        IEM_INSTR_IMPL_A64__umullt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44e0d400: UMULLT  <Zd>.D, <Zn>.S, <Zm>.S[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umullt_z_zzi_d, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i2l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const i2h        = (uOpcode >> 20) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umullt_z_zzi_d Zd=%#x Zn=%#x i2l=%u Zm=%#x i2h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i2l, Zm, i2h));
#ifdef IEM_INSTR_IMPL_A64__umullt_z_zzi_d
        IEM_INSTR_IMPL_A64__umullt_z_zzi_d(Zd, Zn, i2l, Zm, i2h);
#else
        RT_NOREF(Zd, Zn, i2l, Zm, i2h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0f400/44a0d400: UMULLT  <Zd>.S, <Zn>.H, <Zm>.H[<imm>]
   Instruction Set: A64  Groups: sve_intx_mul_long_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_umullt_z_zzi_s, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i3l        = (uOpcode >> 11) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i3h        = (uOpcode >> 19) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: umullt_z_zzi_s Zd=%#x Zn=%#x i3l=%u Zm=%u i3h=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, i3l, Zm, i3h));
#ifdef IEM_INSTR_IMPL_A64__umullt_z_zzi_s
        IEM_INSTR_IMPL_A64__umullt_z_zzi_s(Zd, Zn, i3l, Zm, i3h);
#else
        RT_NOREF(Zd, Zn, i3l, Zm, i3h, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44198000: UQADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary_sat, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uqadd_z_p_zz
        IEM_INSTR_IMPL_A64__uqadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc000/2525c000: UQADD  <Zdn>.<T>, <Zdn>.<T>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_arith_imm0, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqadd_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc000)) == UINT32_C(0x2525c000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
        uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqadd_z_zi Zdn=%#x imm8=%#x sh=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, sh, size));
#ifdef IEM_INSTR_IMPL_A64__uqadd_z_zi
            IEM_INSTR_IMPL_A64__uqadd_z_zi(Zdn, imm8, sh, size);
#else
            RT_NOREF(Zdn, imm8, sh, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04201400: UQADD  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_cons_arit_0, sve_int_unpred_arit, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqadd_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqadd_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uqadd_z_zz
        IEM_INSTR_IMPL_A64__uqadd_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/c123e020: UQCVT  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: mortlach_multi2_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_uqcvt_z_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc123e020))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: uqcvt_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__uqcvt_z_mz2
            IEM_INSTR_IMPL_A64__uqcvt_z_mz2(Zd, Zn);
#else
            RT_NOREF(Zd, Zn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff7ffc60/c133e020: UQCVT  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_uqcvt_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 23) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uqcvt_z_mz4 Zd=%#x Zn=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, sz));
#ifdef IEM_INSTR_IMPL_A64__uqcvt_z_mz4
        IEM_INSTR_IMPL_A64__uqcvt_z_mz4(Zd, Zn, sz);
#else
        RT_NOREF(Zd, Zn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc20/45314800: UQCVTN  <Zd>.H, { <Zn1>.S-<Zn2>.S }
   Instruction Set: A64  Groups: sve_intx_multi_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqcvtn_z_mz2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: uqcvtn_z_mz2 Zd=%#x Zn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__uqcvtn_z_mz2
        IEM_INSTR_IMPL_A64__uqcvtn_z_mz2(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff7ffc60/c133e060: UQCVTN  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_narrow_int_cvrt, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_uqcvtn_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const sz         = (uOpcode >> 23) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uqcvtn_z_mz4 Zd=%#x Zn=%u sz=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, sz));
#ifdef IEM_INSTR_IMPL_A64__uqcvtn_z_mz4
        IEM_INSTR_IMPL_A64__uqcvtn_z_mz4(Zd, Zn, sz);
#else
        RT_NOREF(Zd, Zn, sz, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0420fc00: UQDECB  <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecb_r_rs_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdecb_r_rs_uw Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdecb_r_rs_uw
        IEM_INSTR_IMPL_A64__uqdecb_r_rs_uw(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0430fc00: UQDECB  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecb_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdecb_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdecb_r_rs_x
        IEM_INSTR_IMPL_A64__uqdecb_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0fc00: UQDECD  <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecd_r_rs_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdecd_r_rs_uw Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdecd_r_rs_uw
        IEM_INSTR_IMPL_A64__uqdecd_r_rs_uw(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04f0fc00: UQDECD  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecd_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdecd_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdecd_r_rs_x
        IEM_INSTR_IMPL_A64__uqdecd_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0cc00: UQDECD  <Zdn>.D{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecd_z_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0cc00))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqdecd_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdecd_z_zs
            IEM_INSTR_IMPL_A64__uqdecd_z_zs(Zdn, pattern, imm4);
#else
            RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460fc00: UQDECH  <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdech_r_rs_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdech_r_rs_uw Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdech_r_rs_uw
        IEM_INSTR_IMPL_A64__uqdech_r_rs_uw(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0470fc00: UQDECH  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdech_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdech_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdech_r_rs_x
        IEM_INSTR_IMPL_A64__uqdech_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460cc00: UQDECH  <Zdn>.H{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdech_z_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460cc00))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqdech_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdech_z_zs
            IEM_INSTR_IMPL_A64__uqdech_z_zs(Zdn, pattern, imm4);
#else
            RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252b8800: UQDECP  <Wdn>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_r_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecp_r_p_r_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdecp_r_p_r_uw Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__uqdecp_r_p_r_uw
        IEM_INSTR_IMPL_A64__uqdecp_r_p_r_uw(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252b8c00: UQDECP  <Xdn>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_r_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecp_r_p_r_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdecp_r_p_r_x Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__uqdecp_r_p_r_x
        IEM_INSTR_IMPL_A64__uqdecp_r_p_r_x(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/252b8000: UQDECP  <Zdn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_v_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecp_z_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252b8000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqdecp_z_p_z Zdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__uqdecp_z_p_z
            IEM_INSTR_IMPL_A64__uqdecp_z_p_z(Zdn, Pm, size);
#else
            RT_NOREF(Zdn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0fc00: UQDECW  <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecw_r_rs_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdecw_r_rs_uw Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdecw_r_rs_uw
        IEM_INSTR_IMPL_A64__uqdecw_r_rs_uw(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04b0fc00: UQDECW  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecw_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqdecw_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdecw_r_rs_x
        IEM_INSTR_IMPL_A64__uqdecw_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0cc00: UQDECW  <Zdn>.S{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqdecw_z_zs, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0cc00))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqdecw_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqdecw_z_zs
            IEM_INSTR_IMPL_A64__uqdecw_z_zs(Zdn, pattern, imm4);
#else
            RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0420f400: UQINCB  <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincb_r_rs_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincb_r_rs_uw Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqincb_r_rs_uw
        IEM_INSTR_IMPL_A64__uqincb_r_rs_uw(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0430f400: UQINCB  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincb_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincb_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqincb_r_rs_x
        IEM_INSTR_IMPL_A64__uqincb_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0f400: UQINCD  <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincd_r_rs_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincd_r_rs_uw Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqincd_r_rs_uw
        IEM_INSTR_IMPL_A64__uqincd_r_rs_uw(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04f0f400: UQINCD  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincd_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincd_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqincd_r_rs_x
        IEM_INSTR_IMPL_A64__uqincd_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04e0c400: UQINCD  <Zdn>.D{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincd_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincd_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqincd_z_zs
        IEM_INSTR_IMPL_A64__uqincd_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460f400: UQINCH  <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqinch_r_rs_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqinch_r_rs_uw Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqinch_r_rs_uw
        IEM_INSTR_IMPL_A64__uqinch_r_rs_uw(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0470f400: UQINCH  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqinch_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqinch_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqinch_r_rs_x
        IEM_INSTR_IMPL_A64__uqinch_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/0460c400: UQINCH  <Zdn>.H{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqinch_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqinch_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqinch_z_zs
        IEM_INSTR_IMPL_A64__uqinch_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/25298800: UQINCP  <Wdn>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_r_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincp_r_p_r_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincp_r_p_r_uw Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__uqincp_r_p_r_uw
        IEM_INSTR_IMPL_A64__uqincp_r_p_r_uw(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/25298c00: UQINCP  <Xdn>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_r_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincp_r_p_r_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincp_r_p_r_x Rdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__uqincp_r_p_r_x
        IEM_INSTR_IMPL_A64__uqincp_r_p_r_x(Rdn, Pm, size);
#else
        RT_NOREF(Rdn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffe00/25298000: UQINCP  <Zdn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_count_v_sat, sve_pred_count_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincp_z_p_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x25298000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Pm         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqincp_z_p_z Zdn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__uqincp_z_p_z
            IEM_INSTR_IMPL_A64__uqincp_z_p_z(Zdn, Pm, size);
#else
            RT_NOREF(Zdn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0f400: UQINCW  <Wdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincw_r_rs_uw, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincw_r_rs_uw Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqincw_r_rs_uw
        IEM_INSTR_IMPL_A64__uqincw_r_rs_uw(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04b0f400: UQINCW  <Xdn>{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_pred_pattern_b, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincw_r_rs_x, uint32_t, uOpcode)
{
    uint32_t const Rdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincw_r_rs_x Rdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Rdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqincw_r_rs_x
        IEM_INSTR_IMPL_A64__uqincw_r_rs_x(Rdn, pattern, imm4);
#else
        RT_NOREF(Rdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc00/04a0c400: UQINCW  <Zdn>.S{, <pattern>{, MUL #<imm>}}
   Instruction Set: A64  Groups: sve_int_countvlv0, sve_countelt, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqincw_z_zs, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const pattern    = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqincw_z_zs Zdn=%#x pattern=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, pattern, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqincw_z_zs
        IEM_INSTR_IMPL_A64__uqincw_z_zs(Zdn, pattern, imm4);
#else
        RT_NOREF(Zdn, pattern, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/440b8000: UQRSHL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqrshl_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqrshl_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uqrshl_z_p_zz
        IEM_INSTR_IMPL_A64__uqrshl_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/440f8000: UQRSHLR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqrshlr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqrshlr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uqrshlr_z_p_zz
        IEM_INSTR_IMPL_A64__uqrshlr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc20/c1e0d420: UQRSHR  <Zd>.H, { <Zn1>.S-<Zn2>.S }, #<const>
   Instruction Set: A64  Groups: mortlach_multi2_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uqrshr_z_mz2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uqrshr_z_mz2 Zd=%#x Zn=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqrshr_z_mz2
        IEM_INSTR_IMPL_A64__uqrshr_z_mz2(Zd, Zn, imm4);
#else
        RT_NOREF(Zd, Zn, imm4, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc60/c120d820: UQRSHR  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }, #<const>
   Instruction Set: A64  Groups: mortlach_multi4_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uqrshr_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const tsize      = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uqrshr_z_mz4 Zd=%#x Zn=%u imm5=%#x tsize=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm5, tsize));
#ifdef IEM_INSTR_IMPL_A64__uqrshr_z_mz4
        IEM_INSTR_IMPL_A64__uqrshr_z_mz4(Zd, Zn, imm5, tsize);
#else
        RT_NOREF(Zd, Zn, imm5, tsize, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0fc20/45b03800: UQRSHRN  <Zd>.H, { <Zn1>.S-<Zn2>.S }, #<const>
   Instruction Set: A64  Groups: sve_intx_multi_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqrshrn_z_mz2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc20)) == UINT32_C(0x45b03800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const imm4       = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
        {
            LogFlow(("%018x/%010x: uqrshrn_z_mz2 Zd=%#x Zn=%#x imm4=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm4));
#ifdef IEM_INSTR_IMPL_A64__uqrshrn_z_mz2
            IEM_INSTR_IMPL_A64__uqrshrn_z_mz2(Zd, Zn, imm4);
#else
            RT_NOREF(Zd, Zn, imm4, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc60/c120dc20: UQRSHRN  <Zd>.<T>, { <Zn1>.<Tb>-<Zn4>.<Tb> }, #<const>
   Instruction Set: A64  Groups: mortlach_multi4_qrshr, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uqrshrn_z_mz4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const imm5       = (uOpcode >> 16) & 0x0000001f;
    uint32_t const tsize      = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uqrshrn_z_mz4 Zd=%#x Zn=%u imm5=%#x tsize=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm5, tsize));
#ifdef IEM_INSTR_IMPL_A64__uqrshrn_z_mz4
        IEM_INSTR_IMPL_A64__uqrshrn_z_mz4(Zd, Zn, imm5, tsize);
#else
        RT_NOREF(Zd, Zn, imm5, tsize, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45203800: UQRSHRNB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqrshrnb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqrshrnb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__uqrshrnb_z_zi
        IEM_INSTR_IMPL_A64__uqrshrnb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45203c00: UQRSHRNT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqrshrnt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqrshrnt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__uqrshrnt_z_zi
        IEM_INSTR_IMPL_A64__uqrshrnt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/04078000: UQSHL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqshl_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqshl_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__uqshl_z_p_zi
        IEM_INSTR_IMPL_A64__uqshl_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44098000: UQSHL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqshl_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqshl_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uqshl_z_p_zz
        IEM_INSTR_IMPL_A64__uqshl_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/440d8000: UQSHLR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqshlr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqshlr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uqshlr_z_p_zz
        IEM_INSTR_IMPL_A64__uqshlr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45203000: UQSHRNB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqshrnb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqshrnb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__uqshrnb_z_zi
        IEM_INSTR_IMPL_A64__uqshrnb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/45203400: UQSHRNT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqshrnt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqshrnt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__uqshrnt_z_zi
        IEM_INSTR_IMPL_A64__uqshrnt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/441b8000: UQSUB  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary_sat, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqsub_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqsub_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uqsub_z_p_zz
        IEM_INSTR_IMPL_A64__uqsub_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fc000/2527c000: UQSUB  <Zdn>.<T>, <Zdn>.<T>, #<imm>{, <shift>}
   Instruction Set: A64  Groups: sve_int_arith_imm0, sve_wideimm_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqsub_z_zi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc000)) == UINT32_C(0x2527c000))
    {
        uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
        uint32_t const imm8       = (uOpcode >>  5) & 0x000000ff;
        uint32_t const sh         = (uOpcode >> 13) & 0x00000001;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqsub_z_zi Zdn=%#x imm8=%#x sh=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm8, sh, size));
#ifdef IEM_INSTR_IMPL_A64__uqsub_z_zi
            IEM_INSTR_IMPL_A64__uqsub_z_zi(Zdn, imm8, sh, size);
#else
            RT_NOREF(Zdn, imm8, sh, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04201c00: UQSUB  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_bin_cons_arit_0, sve_int_unpred_arit, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqsub_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqsub_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uqsub_z_zz
        IEM_INSTR_IMPL_A64__uqsub_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/441f8000: UQSUBR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary_sat, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqsubr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uqsubr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uqsubr_z_p_zz
        IEM_INSTR_IMPL_A64__uqsubr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa7fc00/45204800: UQXTNB  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_intx_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqxtnb_z_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45204800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
        uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqxtnb_z_zz Zd=%#x Zn=%#x tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__uqxtnb_z_zz
            IEM_INSTR_IMPL_A64__uqxtnb_z_zz(Zd, Zn, tszl, tszh);
#else
            RT_NOREF(Zd, Zn, tszl, tszh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa7fc00/45204c00: UQXTNT  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_intx_extract_narrow, sve_intx_narrowing, sve */
FNIEMOP_DEF_1(iemDecodeA64_uqxtnt_z_zz, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45204c00))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
        uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uqxtnt_z_zz Zd=%#x Zn=%#x tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__uqxtnt_z_zz
            IEM_INSTR_IMPL_A64__uqxtnt_z_zz(Zd, Zn, tszl, tszh);
#else
            RT_NOREF(Zd, Zn, tszl, tszh, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4400a000: URECPE  <Zd>.S, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_intx_pred_arith_unary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_urecpe_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: urecpe_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__urecpe_z_p_z_m
        IEM_INSTR_IMPL_A64__urecpe_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4402a000: URECPE  <Zd>.S, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_intx_pred_arith_unary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_urecpe_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: urecpe_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__urecpe_z_p_z_z
        IEM_INSTR_IMPL_A64__urecpe_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44158000: URHADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_urhadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: urhadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__urhadd_z_p_zz
        IEM_INSTR_IMPL_A64__urhadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe1/c120a221: URSHL  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_shift_sm, mortlach_multi_sve_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_urshl_mz_zzv_2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a221))
    {
        uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: urshl_mz_zzv_2x1 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__urshl_mz_zzv_2x1
            IEM_INSTR_IMPL_A64__urshl_mz_zzv_2x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30ffe3/c120aa21: URSHL  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi4_z_z_shift_sm, mortlach_multi_sve_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_urshl_mz_zzv_4x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120aa21))
    {
        uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: urshl_mz_zzv_4x1 Zdn=%u Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__urshl_mz_zzv_4x1
            IEM_INSTR_IMPL_A64__urshl_mz_zzv_4x1(Zdn, Zm, size);
#else
            RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff21ffe1/c120b221: URSHL  { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zdn1>.<T>-<Zdn2>.<T> }, { <Zm1>.<T>-<Zm2>.<T> }
   Instruction Set: A64  Groups: mortlach_multi2_z_z_shift_mm, mortlach_multi_sve_2c0, sme */
FNIEMOP_DEF_1(iemDecodeA64_urshl_mz_zzw_2x2, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: urshl_mz_zzw_2x2 Zdn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__urshl_mz_zzw_2x2
        IEM_INSTR_IMPL_A64__urshl_mz_zzw_2x2(Zdn, Zm, size);
#else
        RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff23ffe3/c120ba21: URSHL  { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zdn1>.<T>-<Zdn4>.<T> }, { <Zm1>.<T>-<Zm4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_shift_mm, mortlach_multi_sve_2d0, sme */
FNIEMOP_DEF_1(iemDecodeA64_urshl_mz_zzw_4x4, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: urshl_mz_zzw_4x4 Zdn=%u Zm=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__urshl_mz_zzw_4x4
        IEM_INSTR_IMPL_A64__urshl_mz_zzw_4x4(Zdn, Zm, size);
#else
        RT_NOREF(Zdn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44038000: URSHL  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_urshl_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: urshl_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__urshl_z_p_zz
        IEM_INSTR_IMPL_A64__urshl_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/44078000: URSHLR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_bin_pred_shift_sat_round, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_urshlr_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: urshlr_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__urshlr_z_p_zz
        IEM_INSTR_IMPL_A64__urshlr_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/040d8000: URSHR  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_bin_pred_shift_0, sve_int_pred_shift, sve */
FNIEMOP_DEF_1(iemDecodeA64_urshr_z_p_zi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >>  5) & 0x00000007;
    uint32_t const tszl       = (uOpcode >>  8) & 0x00000003;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: urshr_z_p_zi Zdn=%#x imm3=%u tszl=%u Pg=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, imm3, tszl, Pg, tszh));
#ifdef IEM_INSTR_IMPL_A64__urshr_z_p_zi
        IEM_INSTR_IMPL_A64__urshr_z_p_zi(Zdn, imm3, tszl, Pg, tszh);
#else
        RT_NOREF(Zdn, imm3, tszl, Pg, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4401a000: URSQRTE  <Zd>.S, <Pg>/M, <Zn>.S
   Instruction Set: A64  Groups: sve_intx_pred_arith_unary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_ursqrte_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ursqrte_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__ursqrte_z_p_z_m
        IEM_INSTR_IMPL_A64__ursqrte_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/4403a000: URSQRTE  <Zd>.S, <Pg>/Z, <Zn>.S
   Instruction Set: A64  Groups: sve_intx_pred_arith_unary, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_ursqrte_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: ursqrte_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__ursqrte_z_p_z_z
        IEM_INSTR_IMPL_A64__ursqrte_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500ec00: URSRA  <Zda>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_intx_sra, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_ursra_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ursra_z_zi Zda=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__ursra_z_zi
        IEM_INSTR_IMPL_A64__ursra_z_zi(Zda, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zda, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44807800: USDOT  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_intx_mixed_dot, sve_intx_muladd_unpred, sve */
FNIEMOP_DEF_1(iemDecodeA64_usdot_z_zzz_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
    {
        LogFlow(("%018x/%010x: usdot_z_zzz_s Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usdot_z_zzz_s
        IEM_INSTR_IMPL_A64__usdot_z_zzz_s(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/44a01800: USDOT  <Zda>.S, <Zn>.B, <Zm>.B[<imm>]
   Instruction Set: A64  Groups: sve_intx_mixed_dot_by_indexed_elem, sve_intx_by_indexed_elem, sve */
FNIEMOP_DEF_1(iemDecodeA64_usdot_z_zzzi_s, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 19) & 0x00000003;
    if ((IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/) && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
    {
        LogFlow(("%018x/%010x: usdot_z_zzzi_s Zda=%#x Zn=%#x Zm=%u i2=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm, i2));
#ifdef IEM_INSTR_IMPL_A64__usdot_z_zzzi_s
        IEM_INSTR_IMPL_A64__usdot_z_zzzi_s(Zda, Zn, Zm, i2);
#else
        RT_NOREF(Zda, Zn, Zm, i2, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1501028: USDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_usdot_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usdot_za_zzi_s2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usdot_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__usdot_za_zzi_s2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1509028: USDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_usdot_za_zzi_s4xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usdot_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usdot_za_zzi_s4xi
        IEM_INSTR_IMPL_A64__usdot_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1201408: USDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi2_z_za_mixed_dot_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_usdot_za_zzv_s2x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usdot_za_zzv_s2x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usdot_za_zzv_s2x1
        IEM_INSTR_IMPL_A64__usdot_za_zzv_s2x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c18/c1301408: USDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi4_z_za_mixed_dot_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_usdot_za_zzv_s4x1, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usdot_za_zzv_s4x1 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usdot_za_zzv_s4x1
        IEM_INSTR_IMPL_A64__usdot_za_zzv_s4x1(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c38/c1a01408: USDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_multi2_z_za_mixed_dot_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_usdot_za_zzw_s2x2, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usdot_za_zzw_s2x2 off3=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usdot_za_zzw_s2x2
        IEM_INSTR_IMPL_A64__usdot_za_zzw_s2x2(off3, Zn, Rv, Zm);
#else
        RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c78/c1a11408: USDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, { <Zm1>.B-<Zm4>.B }
   Instruction Set: A64  Groups: mortlach_multi4_z_za_mixed_dot_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_usdot_za_zzw_s4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1a11408))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: usdot_za_zzw_s4x4 off3=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usdot_za_zzw_s4x4
            IEM_INSTR_IMPL_A64__usdot_za_zzw_s4x4(off3, Zn, Rv, Zm);
#else
            RT_NOREF(off3, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4500a800: USHLLB  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_long, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_ushllb_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ushllb_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__ushllb_z_zi
        IEM_INSTR_IMPL_A64__ushllb_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffa0fc00/4500ac00: USHLLT  <Zd>.<T>, <Zn>.<Tb>, #<const>
   Instruction Set: A64  Groups: sve_intx_shift_long, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_ushllt_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000001;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: ushllt_z_zi Zd=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__ushllt_z_zi
        IEM_INSTR_IMPL_A64__ushllt_z_zi(Zd, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zd, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff0001c/c1000004: USMLALL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi1_mla_long_long_idx_s, mortlach_multi_indexed_1, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmlall_za_zzi_s, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const i4l        = (uOpcode >> 10) & 0x00000007;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const i4h        = (uOpcode >> 15) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usmlall_za_zzi_s off2=%u Zn=%#x i4l=%u Rv=%u i4h=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, i4l, Rv, i4h, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmlall_za_zzi_s
        IEM_INSTR_IMPL_A64__usmlall_za_zzi_s(off2, Zn, i4l, Rv, i4h, Zm);
#else
        RT_NOREF(off2, Zn, i4l, Rv, i4h, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1100020: USMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_mla_long_long_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmlall_za_zzi_s2xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usmlall_za_zzi_s2xi o1=%u i4l=%u Zn=%#x i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmlall_za_zzi_s2xi
        IEM_INSTR_IMPL_A64__usmlall_za_zzi_s2xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1108020: USMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_mla_long_long_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmlall_za_zzi_s4xi, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const i4l        = (uOpcode >>  1) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const i4h        = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usmlall_za_zzi_s4xi o1=%u i4l=%u Zn=%u i4h=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, i4l, Zn, i4h, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmlall_za_zzi_s4xi
        IEM_INSTR_IMPL_A64__usmlall_za_zzi_s4xi(o1, i4l, Zn, i4h, Rv, Zm);
#else
        RT_NOREF(o1, i4l, Zn, i4h, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1c/c1200404: USMLALL  ZA.S[<Wv>, <offs1>:<offs4>], <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi1_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmlall_za_zzv_s, uint32_t, uOpcode)
{
    uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usmlall_za_zzv_s off2=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmlall_za_zzv_s
        IEM_INSTR_IMPL_A64__usmlall_za_zzv_s(off2, Zn, Rv, Zm);
#else
        RT_NOREF(off2, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1e/c1200004: USMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_sm, mortlach_multi_array_1a, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmlall_za_zzv_s2x1, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usmlall_za_zzv_s2x1 o1=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmlall_za_zzv_s2x1
        IEM_INSTR_IMPL_A64__usmlall_za_zzv_s2x1(o1, Zn, Rv, Zm);
#else
        RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09c1e/c1300004: USMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_sm, mortlach_multi_array_1b, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmlall_za_zzv_s4x1, uint32_t, uOpcode)
{
    uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: usmlall_za_zzv_s4x1 o1=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmlall_za_zzv_s4x1
        IEM_INSTR_IMPL_A64__usmlall_za_zzv_s4x1(o1, Zn, Rv, Zm);
#else
        RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe19c3e/c1a00004: USMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx2}], { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_multi2_zz_za_mla_long_long_mm, mortlach_multi_array_2a, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmlall_za_zzw_s2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c3e)) == UINT32_C(0xc1a00004))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 17) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: usmlall_za_zzw_s2x2 o1=%u Zn=%#x Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmlall_za_zzw_s2x2
            IEM_INSTR_IMPL_A64__usmlall_za_zzw_s2x2(o1, Zn, Rv, Zm);
#else
            RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe39c7e/c1a10004: USMLALL  ZA.S[<Wv>, <offs1>:<offs4>{, VGx4}], { <Zn1>.B-<Zn4>.B }, { <Zm1>.B-<Zm4>.B }
   Instruction Set: A64  Groups: mortlach_multi4_zz_za_mla_long_long_mm, mortlach_multi_array_2b, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmlall_za_zzw_s4x4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe39c7e)) == UINT32_C(0xc1a10004))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 18) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: usmlall_za_zzw_s4x4 o1=%u Zn=%u Rv=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Zn, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmlall_za_zzw_s4x4
            IEM_INSTR_IMPL_A64__usmlall_za_zzw_s4x4(o1, Zn, Rv, Zm);
#else
            RT_NOREF(o1, Zn, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/45809800: USMMLA  <Zda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: sve_intx_mmla, sve_intx_constructive, sve */
FNIEMOP_DEF_1(iemDecodeA64_usmmla_z_zzz, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fI8mm /*FEAT_I8MM*/)
    {
        LogFlow(("%018x/%010x: usmmla_z_zzz Zda=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmmla_z_zzz
        IEM_INSTR_IMPL_A64__usmmla_z_zzz(Zda, Zn, Zm);
#else
        RT_NOREF(Zda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81008000: USMOP4A  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4a_za_zz_b1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81008000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: usmop4a_za_zz_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4a_za_zz_b1x1
            IEM_INSTR_IMPL_A64__usmop4a_za_zz_b1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81108000: USMOP4A  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4a_za_zz_b1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81108000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: usmop4a_za_zz_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4a_za_zz_b1x2
            IEM_INSTR_IMPL_A64__usmop4a_za_zz_b1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81008200: USMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4a_za_zz_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81008200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: usmop4a_za_zz_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4a_za_zz_b2x1
            IEM_INSTR_IMPL_A64__usmop4a_za_zz_b2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81108200: USMOP4A  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4a_za_zz_b2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81108200))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: usmop4a_za_zz_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4a_za_zz_b2x2
            IEM_INSTR_IMPL_A64__usmop4a_za_zz_b2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1c00008: USMOP4A  <ZAda>.D, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4a_za_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmop4a_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4a_za_zz_h1x1
        IEM_INSTR_IMPL_A64__usmop4a_za_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1d00008: USMOP4A  <ZAda>.D, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4a_za_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmop4a_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4a_za_zz_h1x2
        IEM_INSTR_IMPL_A64__usmop4a_za_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1c00208: USMOP4A  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4a_za_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmop4a_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4a_za_zz_h2x1
        IEM_INSTR_IMPL_A64__usmop4a_za_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1d00208: USMOP4A  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4a_za_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmop4a_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4a_za_zz_h2x2
        IEM_INSTR_IMPL_A64__usmop4a_za_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81008010: USMOP4S  <ZAda>.S, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4s_za_zz_b1x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81008010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: usmop4s_za_zz_b1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4s_za_zz_b1x1
            IEM_INSTR_IMPL_A64__usmop4s_za_zz_b1x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81108010: USMOP4S  <ZAda>.S, <Zn>.B, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4s_za_zz_b1x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81108010))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: usmop4s_za_zz_b1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4s_za_zz_b1x2
            IEM_INSTR_IMPL_A64__usmop4s_za_zz_b1x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81008210: USMOP4S  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4s_za_zz_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81008210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: usmop4s_za_zz_b2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4s_za_zz_b2x1
            IEM_INSTR_IMPL_A64__usmop4s_za_zz_b2x1(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe3c/81108210: USMOP4S  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, { <Zm1>.B-<Zm2>.B }
   Instruction Set: A64  Groups: mortlach_i8i32_prod4, mortlach2_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4s_za_zz_b2x2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x81108210))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
        uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/)
        {
            LogFlow(("%018x/%010x: usmop4s_za_zz_b2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4s_za_zz_b2x2
            IEM_INSTR_IMPL_A64__usmop4s_za_zz_b2x2(ZAda, Zn, Zm);
#else
            RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1c00018: USMOP4S  <ZAda>.D, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4s_za_zz_h1x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmop4s_za_zz_h1x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4s_za_zz_h1x1
        IEM_INSTR_IMPL_A64__usmop4s_za_zz_h1x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1d00018: USMOP4S  <ZAda>.D, <Zn>.H, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4s_za_zz_h1x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmop4s_za_zz_h1x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4s_za_zz_h1x2
        IEM_INSTR_IMPL_A64__usmop4s_za_zz_h1x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1c00218: USMOP4S  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4s_za_zz_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmop4s_za_zz_h2x1 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4s_za_zz_h2x1
        IEM_INSTR_IMPL_A64__usmop4s_za_zz_h2x1(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff1fe38/a1d00218: USMOP4S  <ZAda>.D, { <Zn1>.H-<Zn2>.H }, { <Zm1>.H-<Zm2>.H }
   Instruction Set: A64  Groups: mortlach_i16i64_prod4, mortlach2_64bit_prod4, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmop4s_za_zz_h2x2, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 17) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeMop4 /*FEAT_SME_MOP4*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmop4s_za_zz_h2x2 ZAda=%u Zn=%u Zm=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmop4s_za_zz_h2x2
        IEM_INSTR_IMPL_A64__usmop4s_za_zz_h2x2(ZAda, Zn, Zm);
#else
        RT_NOREF(ZAda, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a1800000: USMOPA  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmopa_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: usmopa_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmopa_za_pp_zz_32
        IEM_INSTR_IMPL_A64__usmopa_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/a1c00000: USMOPA  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmopa_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmopa_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmopa_za_pp_zz_64
        IEM_INSTR_IMPL_A64__usmopa_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0001c/a1800010: USMOPS  <ZAda>.S, <Pn>/M, <Pm>/M, <Zn>.B, <Zm>.B
   Instruction Set: A64  Groups: mortlach_i8i32_prod, mortlach_32bit_int_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmops_za_pp_zz_32, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: usmops_za_pp_zz_32 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmops_za_pp_zz_32
        IEM_INSTR_IMPL_A64__usmops_za_pp_zz_32(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe00018/a1c00010: USMOPS  <ZAda>.D, <Pn>/M, <Pm>/M, <Zn>.H, <Zm>.H
   Instruction Set: A64  Groups: mortlach_i16i64_prod, mortlach_64bit_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_usmops_za_pp_zz_64, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pn         = (uOpcode >> 10) & 0x00000007;
    uint32_t const Pm         = (uOpcode >> 13) & 0x00000007;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
    {
        LogFlow(("%018x/%010x: usmops_za_pp_zz_64 ZAda=%u Zn=%#x Pn=%u Pm=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, Zn, Pn, Pm, Zm));
#ifdef IEM_INSTR_IMPL_A64__usmops_za_pp_zz_64
        IEM_INSTR_IMPL_A64__usmops_za_pp_zz_64(ZAda, Zn, Pn, Pm, Zm);
#else
        RT_NOREF(ZAda, Zn, Pn, Pm, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/441d8000: USQADD  <Zdn>.<T>, <Pg>/M, <Zdn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_intx_pred_arith_binary_sat, sve_intx_predicated, sve */
FNIEMOP_DEF_1(iemDecodeA64_usqadd_z_p_zz, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: usqadd_z_p_zz Zdn=%#x Zm=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__usqadd_z_p_zz
        IEM_INSTR_IMPL_A64__usqadd_z_p_zz(Zdn, Zm, Pg, size);
#else
        RT_NOREF(Zdn, Zm, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4500e400: USRA  <Zda>.<T>, <Zn>.<T>, #<const>
   Instruction Set: A64  Groups: sve_intx_sra, sve_intx_acc, sve */
FNIEMOP_DEF_1(iemDecodeA64_usra_z_zi, uint32_t, uOpcode)
{
    uint32_t const Zda        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: usra_z_zi Zda=%#x Zn=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zda, Zn, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__usra_z_zi
        IEM_INSTR_IMPL_A64__usra_z_zi(Zda, Zn, imm3, tszl, tszh);
#else
        RT_NOREF(Zda, Zn, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/81408000: USTMOPA  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_i8i32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_ustmopa_za_zzzi_b2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: ustmopa_za_zzzi_b2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__ustmopa_za_zzzi_b2x1
        IEM_INSTR_IMPL_A64__ustmopa_za_zzzi_b2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45001800: USUBLB  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_usublb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: usublb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__usublb_z_zz
        IEM_INSTR_IMPL_A64__usublb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45001c00: USUBLT  <Zd>.<T>, <Zn>.<Tb>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_long, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_usublt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: usublt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__usublt_z_zz
        IEM_INSTR_IMPL_A64__usublt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45005800: USUBWB  <Zd>.<T>, <Zn>.<T>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_wide, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_usubwb_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: usubwb_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__usubwb_z_zz
        IEM_INSTR_IMPL_A64__usubwb_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/45005c00: USUBWT  <Zd>.<T>, <Zn>.<T>, <Zm>.<Tb>
   Instruction Set: A64  Groups: sve_intx_cons_arith_wide, sve_intx_cons_widening, sve */
FNIEMOP_DEF_1(iemDecodeA64_usubwt_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: usubwt_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__usubwt_z_zz
        IEM_INSTR_IMPL_A64__usubwt_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1508028: USVDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_usvdot_za_zzi_s4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1508028))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: usvdot_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__usvdot_za_zzi_s4xi
            IEM_INSTR_IMPL_A64__usvdot_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/81408008: UTMOPA  <ZAda>.S, { <Zn1>.H-<Zn2>.H }, <Zm>.H, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_i16i32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_utmopa_za32_zzzi_h2x1, uint32_t, uOpcode)
{
    uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
    uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
    uint32_t const K          = (uOpcode >> 12) & 0x00000001;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
    {
        LogFlow(("%018x/%010x: utmopa_za32_zzzi_h2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__utmopa_za32_zzzi_h2x1
        IEM_INSTR_IMPL_A64__utmopa_za32_zzzi_h2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
        RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0e00c/81608000: UTMOPA  <ZAda>.S, { <Zn1>.B-<Zn2>.B }, <Zm>.B, <Zk>[<index>]
   Instruction Set: A64  Groups: mortlach_i8i32_2in4ss_prod, mortlach2_ss_prod, sme */
FNIEMOP_DEF_1(iemDecodeA64_utmopa_za_zzzi_b2x1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x81608000))
    {
        uint32_t const ZAda       = (uOpcode >>  0) & 0x00000003;
        uint32_t const i2         = (uOpcode >>  4) & 0x00000003;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const Zk         = (uOpcode >> 10) & 0x00000003;
        uint32_t const K          = (uOpcode >> 12) & 0x00000001;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeTmop /*FEAT_SME_TMOP*/)
        {
            LogFlow(("%018x/%010x: utmopa_za_zzzi_b2x1 ZAda=%u i2=%u Zn=%#x Zk=%u K=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, ZAda, i2, Zn, Zk, K, Zm));
#ifdef IEM_INSTR_IMPL_A64__utmopa_za_zzzi_b2x1
            IEM_INSTR_IMPL_A64__utmopa_za_zzzi_b2x1(ZAda, i2, Zn, Zk, K, Zm);
#else
            RT_NOREF(ZAda, i2, Zn, Zk, K, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc01/c125e001: UUNPK  { <Zd1>.<T>-<Zd2>.<T> }, <Zn>.<Tb>
   Instruction Set: A64  Groups: mortlach_multi2_wide_int, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_uunpk_mz_z_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc01)) == UINT32_C(0xc125e001))
    {
        uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: uunpk_mz_z_2 Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__uunpk_mz_z_2
            IEM_INSTR_IMPL_A64__uunpk_mz_z_2(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc23/c135e001: UUNPK  { <Zd1>.<T>-<Zd4>.<T> }, { <Zn1>.<Tb>-<Zn2>.<Tb> }
   Instruction Set: A64  Groups: mortlach_multi4_wide_int, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_uunpk_mz_z_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc23)) == UINT32_C(0xc135e001))
    {
        uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: uunpk_mz_z_4 Zd=%u Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__uunpk_mz_z_4
            IEM_INSTR_IMPL_A64__uunpk_mz_z_4(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/05333800: UUNPKHI  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_perm_unpk, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_uunpkhi_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05333800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uunpkhi_z_z Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__uunpkhi_z_z
            IEM_INSTR_IMPL_A64__uunpkhi_z_z(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc00/05323800: UUNPKLO  <Zd>.<T>, <Zn>.<Tb>
   Instruction Set: A64  Groups: sve_int_perm_unpk, sve_perm_unpred_d, sve */
FNIEMOP_DEF_1(iemDecodeA64_uunpklo_z_z, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05323800))
    {
        uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
        uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uunpklo_z_z Zd=%#x Zn=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__uunpklo_z_z
            IEM_INSTR_IMPL_A64__uunpklo_z_z(Zd, Zn, size);
#else
            RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09038/c1500030: UVDOT  ZA.S[<Wv>, <offs>{, VGx2}], { <Zn1>.H-<Zn2>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi2_zza_idx_s, mortlach_multi_indexed_2, sme */
FNIEMOP_DEF_1(iemDecodeA64_uvdot_za32_zzi_2xi, uint32_t, uOpcode)
{
    uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  6) & 0x0000000f;
    uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
    uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uvdot_za32_zzi_2xi off3=%u Zn=%#x i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__uvdot_za32_zzi_2xi
        IEM_INSTR_IMPL_A64__uvdot_za32_zzi_2xi(off3, Zn, i2, Rv, Zm);
#else
        RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09878/c1d08818: UVDOT  ZA.D[<Wv>, <offs>{, VGx4}], { <Zn1>.H-<Zn4>.H }, <Zm>.H[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_d, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uvdot_za_zzi_d4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08818))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i1         = (uOpcode >> 10) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ && IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSmeI16I64 /*FEAT_SME_I16I64*/)
        {
            LogFlow(("%018x/%010x: uvdot_za_zzi_d4xi off3=%u Zn=%u i1=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i1, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__uvdot_za_zzi_d4xi
            IEM_INSTR_IMPL_A64__uvdot_za_zzi_d4xi(off3, Zn, i1, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i1, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fff09078/c1508030: UVDOT  ZA.S[<Wv>, <offs>{, VGx4}], { <Zn1>.B-<Zn4>.B }, <Zm>.B[<index>]
   Instruction Set: A64  Groups: mortlach_multi4_zza_idx_s, mortlach_multi_indexed_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uvdot_za_zzi_s4xi, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1508030))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
        uint32_t const i2         = (uOpcode >> 10) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        uint32_t const Zm         = (uOpcode >> 16) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
        {
            LogFlow(("%018x/%010x: uvdot_za_zzi_s4xi off3=%u Zn=%u i2=%u Rv=%u Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Zn, i2, Rv, Zm));
#ifdef IEM_INSTR_IMPL_A64__uvdot_za_zzi_s4xi
            IEM_INSTR_IMPL_A64__uvdot_za_zzi_s4xi(off3, Zn, i2, Rv, Zm);
#else
            RT_NOREF(off3, Zn, i2, Rv, Zm, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0411a000: UXTB  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_uxtb_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uxtb_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uxtb_z_p_z_m
        IEM_INSTR_IMPL_A64__uxtb_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0401a000: UXTB  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_uxtb_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: uxtb_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uxtb_z_p_z_z
        IEM_INSTR_IMPL_A64__uxtb_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0413a000: UXTH  <Zd>.<T>, <Pg>/M, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_uxth_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uxth_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uxth_z_p_z_m
        IEM_INSTR_IMPL_A64__uxth_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0403a000: UXTH  <Zd>.<T>, <Pg>/Z, <Zn>.<T>
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_uxth_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: uxth_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uxth_z_p_z_z
        IEM_INSTR_IMPL_A64__uxth_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0415a000: UXTW  <Zd>.D, <Pg>/M, <Zn>.D
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_uxtw_z_p_z_m, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uxtw_z_p_z_m Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uxtw_z_p_z_m
        IEM_INSTR_IMPL_A64__uxtw_z_p_z_m(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3fe000/0405a000: UXTW  <Zd>.D, <Pg>/Z, <Zn>.D
   Instruction Set: A64  Groups: sve_int_un_pred_arit_0, sve_int_pred_un, sve */
FNIEMOP_DEF_1(iemDecodeA64_uxtw_z_p_z_z, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Pg         = (uOpcode >> 10) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p2 /*FEAT_SVE2p2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p2 /*FEAT_SME2p2*/)
    {
        LogFlow(("%018x/%010x: uxtw_z_p_z_z Zd=%#x Zn=%#x Pg=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Pg, size));
#ifdef IEM_INSTR_IMPL_A64__uxtw_z_p_z_z
        IEM_INSTR_IMPL_A64__uxtw_z_p_z_z(Zd, Zn, Pg, size);
#else
        RT_NOREF(Zd, Zn, Pg, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30fe10/05204800: UZP1  <Pd>.<T>, <Pn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_pp, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_uzp1_p_pp, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30fe10)) == UINT32_C(0x05204800))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uzp1_p_pp Pd=%#x Pn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__uzp1_p_pp
            IEM_INSTR_IMPL_A64__uzp1_p_pp(Pd, Pn, Pm, size);
#else
            RT_NOREF(Pd, Pn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05206800: UZP1  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_zz, sve_perm_inter, sve */
FNIEMOP_DEF_1(iemDecodeA64_uzp1_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uzp1_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uzp1_z_zz
        IEM_INSTR_IMPL_A64__uzp1_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/05a00800: UZP1  <Zd>.Q, <Zn>.Q, <Zm>.Q
   Instruction Set: A64  Groups: sve_int_perm_bin_long_perm_zz, sve_perm_inter_long, sve */
FNIEMOP_DEF_1(iemDecodeA64_uzp1_z_zz_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: uzp1_z_zz_q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__uzp1_z_zz_q
        IEM_INSTR_IMPL_A64__uzp1_z_zz_q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30fe10/05204c00: UZP2  <Pd>.<T>, <Pn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_pp, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_uzp2_p_pp, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30fe10)) == UINT32_C(0x05204c00))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: uzp2_p_pp Pd=%#x Pn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__uzp2_p_pp
            IEM_INSTR_IMPL_A64__uzp2_p_pp(Pd, Pn, Pm, size);
#else
            RT_NOREF(Pd, Pn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05206c00: UZP2  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_zz, sve_perm_inter, sve */
FNIEMOP_DEF_1(iemDecodeA64_uzp2_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: uzp2_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uzp2_z_zz
        IEM_INSTR_IMPL_A64__uzp2_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/05a00c00: UZP2  <Zd>.Q, <Zn>.Q, <Zm>.Q
   Instruction Set: A64  Groups: sve_int_perm_bin_long_perm_zz, sve_perm_inter_long, sve */
FNIEMOP_DEF_1(iemDecodeA64_uzp2_z_zz_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: uzp2_z_zz_q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__uzp2_z_zz_q
        IEM_INSTR_IMPL_A64__uzp2_z_zz_q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc63/c136e002: UZP  { <Zd1>.<T>-<Zd4>.<T> }, { <Zn1>.<T>-<Zn4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_zip, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_uzp_mz_z_4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uzp_mz_z_4 Zd=%u Zn=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__uzp_mz_z_4
        IEM_INSTR_IMPL_A64__uzp_mz_z_4(Zd, Zn, size);
#else
        RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c137e002: UZP  { <Zd1>.Q-<Zd4>.Q }, { <Zn1>.Q-<Zn4>.Q }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_long_zip, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_uzp_mz_z_4q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uzp_mz_z_4q Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__uzp_mz_z_4q
        IEM_INSTR_IMPL_A64__uzp_mz_z_4q(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc01/c120d001: UZP  { <Zd1>.<T>-<Zd2>.<T> }, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_zip, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uzp_mz_zz_2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uzp_mz_zz_2 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uzp_mz_zz_2
        IEM_INSTR_IMPL_A64__uzp_mz_zz_2(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc01/c120d401: UZP  { <Zd1>.Q-<Zd2>.Q }, <Zn>.Q, <Zm>.Q
   Instruction Set: A64  Groups: mortlach_multi2_z_z_long_zip, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_uzp_mz_zz_2q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: uzp_mz_zz_2q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__uzp_mz_zz_2q
        IEM_INSTR_IMPL_A64__uzp_mz_zz_2q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4400e800: UZPQ1  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_binquads, sve_perm_quads_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_uzpq1_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: uzpq1_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uzpq1_z_zz
        IEM_INSTR_IMPL_A64__uzpq1_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4400ec00: UZPQ2  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_binquads, sve_perm_quads_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_uzpq2_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: uzpq2_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__uzpq2_z_zz
        IEM_INSTR_IMPL_A64__uzpq2_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec10/25200000: WHILEGE  <Pd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_while_rr, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilege_p_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sf         = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilege_p_p_rr Pd=%#x Rn=%#x sf=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, sf, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilege_p_p_rr
        IEM_INSTR_IMPL_A64__whilege_p_p_rr(Pd, Rn, sf, Rm, size);
#else
        RT_NOREF(Pd, Rn, sf, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20dc18/25204010: WHILEGE  <PNd>.<T>, <Xn>, <Xm>, <vl>
   Instruction Set: A64  Groups: sve_int_while_rr_pn, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilege_pn_rr, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const vl         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilege_pn_rr PNd=%u Rn=%#x vl=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, Rn, vl, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilege_pn_rr
        IEM_INSTR_IMPL_A64__whilege_pn_rr(PNd, Rn, vl, Rm, size);
#else
        RT_NOREF(PNd, Rn, vl, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc11/25205010: WHILEGE  { <Pd1>.<T>, <Pd2>.<T> }, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_while_rr_pair, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilege_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  1) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilege_pp_rr Pd=%u Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilege_pp_rr
        IEM_INSTR_IMPL_A64__whilege_pp_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec10/25200010: WHILEGT  <Pd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_while_rr, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilegt_p_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sf         = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilegt_p_p_rr Pd=%#x Rn=%#x sf=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, sf, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilegt_p_p_rr
        IEM_INSTR_IMPL_A64__whilegt_p_p_rr(Pd, Rn, sf, Rm, size);
#else
        RT_NOREF(Pd, Rn, sf, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20dc18/25204018: WHILEGT  <PNd>.<T>, <Xn>, <Xm>, <vl>
   Instruction Set: A64  Groups: sve_int_while_rr_pn, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilegt_pn_rr, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const vl         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilegt_pn_rr PNd=%u Rn=%#x vl=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, Rn, vl, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilegt_pn_rr
        IEM_INSTR_IMPL_A64__whilegt_pn_rr(PNd, Rn, vl, Rm, size);
#else
        RT_NOREF(PNd, Rn, vl, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc11/25205011: WHILEGT  { <Pd1>.<T>, <Pd2>.<T> }, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_while_rr_pair, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilegt_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  1) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilegt_pp_rr Pd=%u Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilegt_pp_rr
        IEM_INSTR_IMPL_A64__whilegt_pp_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec10/25200810: WHILEHI  <Pd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_while_rr, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilehi_p_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sf         = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilehi_p_p_rr Pd=%#x Rn=%#x sf=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, sf, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilehi_p_p_rr
        IEM_INSTR_IMPL_A64__whilehi_p_p_rr(Pd, Rn, sf, Rm, size);
#else
        RT_NOREF(Pd, Rn, sf, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20dc18/25204818: WHILEHI  <PNd>.<T>, <Xn>, <Xm>, <vl>
   Instruction Set: A64  Groups: sve_int_while_rr_pn, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilehi_pn_rr, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const vl         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilehi_pn_rr PNd=%u Rn=%#x vl=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, Rn, vl, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilehi_pn_rr
        IEM_INSTR_IMPL_A64__whilehi_pn_rr(PNd, Rn, vl, Rm, size);
#else
        RT_NOREF(PNd, Rn, vl, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc11/25205811: WHILEHI  { <Pd1>.<T>, <Pd2>.<T> }, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_while_rr_pair, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilehi_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  1) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilehi_pp_rr Pd=%u Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilehi_pp_rr
        IEM_INSTR_IMPL_A64__whilehi_pp_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec10/25200800: WHILEHS  <Pd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_while_rr, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilehs_p_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sf         = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilehs_p_p_rr Pd=%#x Rn=%#x sf=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, sf, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilehs_p_p_rr
        IEM_INSTR_IMPL_A64__whilehs_p_p_rr(Pd, Rn, sf, Rm, size);
#else
        RT_NOREF(Pd, Rn, sf, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20dc18/25204810: WHILEHS  <PNd>.<T>, <Xn>, <Xm>, <vl>
   Instruction Set: A64  Groups: sve_int_while_rr_pn, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilehs_pn_rr, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const vl         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilehs_pn_rr PNd=%u Rn=%#x vl=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, Rn, vl, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilehs_pn_rr
        IEM_INSTR_IMPL_A64__whilehs_pn_rr(PNd, Rn, vl, Rm, size);
#else
        RT_NOREF(PNd, Rn, vl, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc11/25205810: WHILEHS  { <Pd1>.<T>, <Pd2>.<T> }, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_while_rr_pair, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilehs_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  1) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilehs_pp_rr Pd=%u Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilehs_pp_rr
        IEM_INSTR_IMPL_A64__whilehs_pp_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec10/25200410: WHILELE  <Pd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_while_rr, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilele_p_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sf         = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilele_p_p_rr Pd=%#x Rn=%#x sf=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, sf, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilele_p_p_rr
        IEM_INSTR_IMPL_A64__whilele_p_p_rr(Pd, Rn, sf, Rm, size);
#else
        RT_NOREF(Pd, Rn, sf, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20dc18/25204418: WHILELE  <PNd>.<T>, <Xn>, <Xm>, <vl>
   Instruction Set: A64  Groups: sve_int_while_rr_pn, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilele_pn_rr, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const vl         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilele_pn_rr PNd=%u Rn=%#x vl=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, Rn, vl, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilele_pn_rr
        IEM_INSTR_IMPL_A64__whilele_pn_rr(PNd, Rn, vl, Rm, size);
#else
        RT_NOREF(PNd, Rn, vl, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc11/25205411: WHILELE  { <Pd1>.<T>, <Pd2>.<T> }, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_while_rr_pair, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilele_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  1) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilele_pp_rr Pd=%u Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilele_pp_rr
        IEM_INSTR_IMPL_A64__whilele_pp_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec10/25200c00: WHILELO  <Pd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_while_rr, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilelo_p_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sf         = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilelo_p_p_rr Pd=%#x Rn=%#x sf=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, sf, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilelo_p_p_rr
        IEM_INSTR_IMPL_A64__whilelo_p_p_rr(Pd, Rn, sf, Rm, size);
#else
        RT_NOREF(Pd, Rn, sf, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20dc18/25204c10: WHILELO  <PNd>.<T>, <Xn>, <Xm>, <vl>
   Instruction Set: A64  Groups: sve_int_while_rr_pn, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilelo_pn_rr, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const vl         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilelo_pn_rr PNd=%u Rn=%#x vl=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, Rn, vl, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilelo_pn_rr
        IEM_INSTR_IMPL_A64__whilelo_pn_rr(PNd, Rn, vl, Rm, size);
#else
        RT_NOREF(PNd, Rn, vl, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc11/25205c10: WHILELO  { <Pd1>.<T>, <Pd2>.<T> }, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_while_rr_pair, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilelo_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  1) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilelo_pp_rr Pd=%u Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilelo_pp_rr
        IEM_INSTR_IMPL_A64__whilelo_pp_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec10/25200c10: WHILELS  <Pd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_while_rr, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilels_p_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sf         = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilels_p_p_rr Pd=%#x Rn=%#x sf=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, sf, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilels_p_p_rr
        IEM_INSTR_IMPL_A64__whilels_p_p_rr(Pd, Rn, sf, Rm, size);
#else
        RT_NOREF(Pd, Rn, sf, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20dc18/25204c18: WHILELS  <PNd>.<T>, <Xn>, <Xm>, <vl>
   Instruction Set: A64  Groups: sve_int_while_rr_pn, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilels_pn_rr, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const vl         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilels_pn_rr PNd=%u Rn=%#x vl=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, Rn, vl, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilels_pn_rr
        IEM_INSTR_IMPL_A64__whilels_pn_rr(PNd, Rn, vl, Rm, size);
#else
        RT_NOREF(PNd, Rn, vl, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc11/25205c11: WHILELS  { <Pd1>.<T>, <Pd2>.<T> }, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_while_rr_pair, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilels_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  1) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilels_pp_rr Pd=%u Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilels_pp_rr
        IEM_INSTR_IMPL_A64__whilels_pp_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20ec10/25200400: WHILELT  <Pd>.<T>, <R><n>, <R><m>
   Instruction Set: A64  Groups: sve_int_while_rr, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilelt_p_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const sf         = (uOpcode >> 12) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilelt_p_p_rr Pd=%#x Rn=%#x sf=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, sf, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilelt_p_p_rr
        IEM_INSTR_IMPL_A64__whilelt_p_p_rr(Pd, Rn, sf, Rm, size);
#else
        RT_NOREF(Pd, Rn, sf, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20dc18/25204410: WHILELT  <PNd>.<T>, <Xn>, <Xm>, <vl>
   Instruction Set: A64  Groups: sve_int_while_rr_pn, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilelt_pn_rr, uint32_t, uOpcode)
{
    uint32_t const PNd        = (uOpcode >>  0) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const vl         = (uOpcode >> 13) & 0x00000001;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilelt_pn_rr PNd=%u Rn=%#x vl=%u Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, PNd, Rn, vl, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilelt_pn_rr
        IEM_INSTR_IMPL_A64__whilelt_pn_rr(PNd, Rn, vl, Rm, size);
#else
        RT_NOREF(PNd, Rn, vl, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc11/25205410: WHILELT  { <Pd1>.<T>, <Pd2>.<T> }, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_while_rr_pair, sve_while_pn, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilelt_pp_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  1) & 0x00000007;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/)
    {
        LogFlow(("%018x/%010x: whilelt_pp_rr Pd=%u Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilelt_pp_rr
        IEM_INSTR_IMPL_A64__whilelt_pp_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc10/25203010: WHILERW  <Pd>.<T>, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_whilenc, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilerw_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilerw_p_rr Pd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilerw_p_rr
        IEM_INSTR_IMPL_A64__whilerw_p_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc10/25203000: WHILEWR  <Pd>.<T>, <Xn>, <Xm>
   Instruction Set: A64  Groups: sve_int_whilenc, sve_cmpgpr, sve */
FNIEMOP_DEF_1(iemDecodeA64_whilewr_p_rr, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Rn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Rm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: whilewr_p_rr Pd=%#x Rn=%#x Rm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Rn, Rm, size));
#ifdef IEM_INSTR_IMPL_A64__whilewr_p_rr
        IEM_INSTR_IMPL_A64__whilewr_p_rr(Pd, Rn, Rm, size);
#else
        RT_NOREF(Pd, Rn, Rm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffe1f/25289000: WRFFR  <Pn>.B
   Instruction Set: A64  Groups: sve_int_wrffr, sve_pred_wrffr, sve */
FNIEMOP_DEF_1(iemDecodeA64_wrffr_f_p, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffe1f)) == UINT32_C(0x25289000))
    {
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/)
        {
            LogFlow(("%018x/%010x: wrffr_f_p Pn=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pn));
#ifdef IEM_INSTR_IMPL_A64__wrffr_f_p
            IEM_INSTR_IMPL_A64__wrffr_f_p(Pn);
#else
            RT_NOREF(Pn, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/04203400: XAR  <Zdn>.<T>, <Zdn>.<T>, <Zm>.<T>, #<const>
   Instruction Set: A64  Groups: sve_int_rotate_imm, sve_int_unpred_logical, sve */
FNIEMOP_DEF_1(iemDecodeA64_xar_z_zzi, uint32_t, uOpcode)
{
    uint32_t const Zdn        = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const imm3       = (uOpcode >> 16) & 0x00000007;
    uint32_t const tszl       = (uOpcode >> 19) & 0x00000003;
    uint32_t const tszh       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2 /*FEAT_SVE2*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: xar_z_zzi Zdn=%#x Zm=%#x imm3=%u tszl=%u tszh=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zdn, Zm, imm3, tszl, tszh));
#ifdef IEM_INSTR_IMPL_A64__xar_z_zzi
        IEM_INSTR_IMPL_A64__xar_z_zzi(Zdn, Zm, imm3, tszl, tszh);
#else
        RT_NOREF(Zdn, Zm, imm3, tszl, tszh, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9ff8/c00c0000: ZERO  ZA.D[<Wv>, <offs>, VGx2]
   Instruction Set: A64  Groups: mortlach_multi_zero, mortlach_multizero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za1_ri_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ff8)) == UINT32_C(0xc00c0000))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: zero_za1_ri_2 off3=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Rv));
#ifdef IEM_INSTR_IMPL_A64__zero_za1_ri_2
            IEM_INSTR_IMPL_A64__zero_za1_ri_2(off3, Rv);
#else
            RT_NOREF(off3, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9ff8/c00e0000: ZERO  ZA.D[<Wv>, <offs>, VGx4]
   Instruction Set: A64  Groups: mortlach_multi_zero, mortlach_multizero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za1_ri_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ff8)) == UINT32_C(0xc00e0000))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: zero_za1_ri_4 off3=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Rv));
#ifdef IEM_INSTR_IMPL_A64__zero_za1_ri_4
            IEM_INSTR_IMPL_A64__zero_za1_ri_4(off3, Rv);
#else
            RT_NOREF(off3, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9ff8/c00c8000: ZERO  ZA.D[<Wv>, <offs1>:<offs2>]
   Instruction Set: A64  Groups: mortlach_multi_zero, mortlach_multizero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za2_ri_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ff8)) == UINT32_C(0xc00c8000))
    {
        uint32_t const off3       = (uOpcode >>  0) & 0x00000007;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: zero_za2_ri_1 off3=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off3, Rv));
#ifdef IEM_INSTR_IMPL_A64__zero_za2_ri_1
            IEM_INSTR_IMPL_A64__zero_za2_ri_1(off3, Rv);
#else
            RT_NOREF(off3, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9ffc/c00d0000: ZERO  ZA.D[<Wv>, <offs1>:<offs2>, VGx2]
   Instruction Set: A64  Groups: mortlach_multi_zero, mortlach_multizero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za2_ri_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ffc)) == UINT32_C(0xc00d0000))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: zero_za2_ri_2 off2=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Rv));
#ifdef IEM_INSTR_IMPL_A64__zero_za2_ri_2
            IEM_INSTR_IMPL_A64__zero_za2_ri_2(off2, Rv);
#else
            RT_NOREF(off2, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9ffc/c00d8000: ZERO  ZA.D[<Wv>, <offs1>:<offs2>, VGx4]
   Instruction Set: A64  Groups: mortlach_multi_zero, mortlach_multizero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za2_ri_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ffc)) == UINT32_C(0xc00d8000))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: zero_za2_ri_4 off2=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Rv));
#ifdef IEM_INSTR_IMPL_A64__zero_za2_ri_4
            IEM_INSTR_IMPL_A64__zero_za2_ri_4(off2, Rv);
#else
            RT_NOREF(off2, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9ffc/c00e8000: ZERO  ZA.D[<Wv>, <offs1>:<offs4>]
   Instruction Set: A64  Groups: mortlach_multi_zero, mortlach_multizero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za4_ri_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ffc)) == UINT32_C(0xc00e8000))
    {
        uint32_t const off2       = (uOpcode >>  0) & 0x00000003;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: zero_za4_ri_1 off2=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, off2, Rv));
#ifdef IEM_INSTR_IMPL_A64__zero_za4_ri_1
            IEM_INSTR_IMPL_A64__zero_za4_ri_1(off2, Rv);
#else
            RT_NOREF(off2, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9ffe/c00f0000: ZERO  ZA.D[<Wv>, <offs1>:<offs4>, VGx2]
   Instruction Set: A64  Groups: mortlach_multi_zero, mortlach_multizero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za4_ri_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ffe)) == UINT32_C(0xc00f0000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: zero_za4_ri_2 o1=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Rv));
#ifdef IEM_INSTR_IMPL_A64__zero_za4_ri_2
            IEM_INSTR_IMPL_A64__zero_za4_ri_2(o1, Rv);
#else
            RT_NOREF(o1, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffff9ffe/c00f8000: ZERO  ZA.D[<Wv>, <offs1>:<offs4>, VGx4]
   Instruction Set: A64  Groups: mortlach_multi_zero, mortlach_multizero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za4_ri_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ffe)) == UINT32_C(0xc00f8000))
    {
        uint32_t const o1         = (uOpcode >>  0) & 0x00000001;
        uint32_t const Rv         = (uOpcode >> 13) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
        {
            LogFlow(("%018x/%010x: zero_za4_ri_4 o1=%u Rv=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, o1, Rv));
#ifdef IEM_INSTR_IMPL_A64__zero_za4_ri_4
            IEM_INSTR_IMPL_A64__zero_za4_ri_4(o1, Rv);
#else
            RT_NOREF(o1, Rv, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffff00/c0080000: ZERO  { <mask> }
   Instruction Set: A64  Groups: mortlach_zero_lvl2, mortlach_zero, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_za_i, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffff00)) == UINT32_C(0xc0080000))
    {
        uint32_t const imm8       = (uOpcode >>  0) & 0x000000ff;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: zero_za_i imm8=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, imm8));
#ifdef IEM_INSTR_IMPL_A64__zero_za_i
            IEM_INSTR_IMPL_A64__zero_za_i(imm8);
#else
            RT_NOREF(imm8, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffffffff/c0480001: ZERO  { ZT0 }
   Instruction Set: A64  Groups: mortlach_zero_zt_lvl2, mortlach_zero_zt, sme */
FNIEMOP_DEF_1(iemDecodeA64_zero_zt_i, uint32_t, uOpcode)
{
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: zero_zt_i\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode));
#ifdef IEM_INSTR_IMPL_A64__zero_zt_i
        IEM_INSTR_IMPL_A64__zero_zt_i();
#else
        RT_NOREF(pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30fe10/05204000: ZIP1  <Pd>.<T>, <Pn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_pp, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_zip1_p_pp, uint32_t, uOpcode)
{
    uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
    uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
    uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: zip1_p_pp Pd=%#x Pn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__zip1_p_pp
        IEM_INSTR_IMPL_A64__zip1_p_pp(Pd, Pn, Pm, size);
#else
        RT_NOREF(Pd, Pn, Pm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05206000: ZIP1  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_zz, sve_perm_inter, sve */
FNIEMOP_DEF_1(iemDecodeA64_zip1_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: zip1_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__zip1_z_zz
        IEM_INSTR_IMPL_A64__zip1_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/05a00000: ZIP1  <Zd>.Q, <Zn>.Q, <Zm>.Q
   Instruction Set: A64  Groups: sve_int_perm_bin_long_perm_zz, sve_perm_inter_long, sve */
FNIEMOP_DEF_1(iemDecodeA64_zip1_z_zz_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: zip1_z_zz_q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__zip1_z_zz_q
        IEM_INSTR_IMPL_A64__zip1_z_zz_q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff30fe10/05204400: ZIP2  <Pd>.<T>, <Pn>.<T>, <Pm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_pp, sve_perm_predicates, sve */
FNIEMOP_DEF_1(iemDecodeA64_zip2_p_pp, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30fe10)) == UINT32_C(0x05204400))
    {
        uint32_t const Pd         = (uOpcode >>  0) & 0x0000000f;
        uint32_t const Pn         = (uOpcode >>  5) & 0x0000000f;
        uint32_t const Pm         = (uOpcode >> 16) & 0x0000000f;
        uint32_t const size       = (uOpcode >> 22) & 0x00000003;
        if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
        {
            LogFlow(("%018x/%010x: zip2_p_pp Pd=%#x Pn=%#x Pm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Pd, Pn, Pm, size));
#ifdef IEM_INSTR_IMPL_A64__zip2_p_pp
            IEM_INSTR_IMPL_A64__zip2_p_pp(Pd, Pn, Pm, size);
#else
            RT_NOREF(Pd, Pn, Pm, size, pVCpu, uOpcode);
            return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
        }
        Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
        IEMOP_RAISE_INVALID_OPCODE_RET();
    }
    Log(("Invalid instruction %%#x at %%x\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/05206400: ZIP2  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_bin_perm_zz, sve_perm_inter, sve */
FNIEMOP_DEF_1(iemDecodeA64_zip2_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve /*FEAT_SVE*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme /*FEAT_SME*/)
    {
        LogFlow(("%018x/%010x: zip2_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__zip2_z_zz
        IEM_INSTR_IMPL_A64__zip2_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/05a00400: ZIP2  <Zd>.Q, <Zn>.Q, <Zm>.Q
   Instruction Set: A64  Groups: sve_int_perm_bin_long_perm_zz, sve_perm_inter_long, sve */
FNIEMOP_DEF_1(iemDecodeA64_zip2_z_zz_q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fF64mm /*FEAT_F64MM*/)
    {
        LogFlow(("%018x/%010x: zip2_z_zz_q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__zip2_z_zz_q
        IEM_INSTR_IMPL_A64__zip2_z_zz_q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff3ffc63/c136e000: ZIP  { <Zd1>.<T>-<Zd4>.<T> }, { <Zn1>.<T>-<Zn4>.<T> }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_zip, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_zip_mz_z_4, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: zip_mz_z_4 Zd=%u Zn=%u size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, size));
#ifdef IEM_INSTR_IMPL_A64__zip_mz_z_4
        IEM_INSTR_IMPL_A64__zip_mz_z_4(Zd, Zn, size);
#else
        RT_NOREF(Zd, Zn, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* fffffc63/c137e000: ZIP  { <Zd1>.Q-<Zd4>.Q }, { <Zn1>.Q-<Zn4>.Q }
   Instruction Set: A64  Groups: mortlach_multi4_z_z_long_zip, mortlach_multi_sve_4, sme */
FNIEMOP_DEF_1(iemDecodeA64_zip_mz_z_4q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  2) & 0x00000007;
    uint32_t const Zn         = (uOpcode >>  7) & 0x00000007;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: zip_mz_z_4q Zd=%u Zn=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn));
#ifdef IEM_INSTR_IMPL_A64__zip_mz_z_4q
        IEM_INSTR_IMPL_A64__zip_mz_z_4q(Zd, Zn);
#else
        RT_NOREF(Zd, Zn, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc01/c120d000: ZIP  { <Zd1>.<T>-<Zd2>.<T> }, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: mortlach_multi2_z_z_zip, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_zip_mz_zz_2, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: zip_mz_zz_2 Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__zip_mz_zz_2
        IEM_INSTR_IMPL_A64__zip_mz_zz_2(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc01/c120d400: ZIP  { <Zd1>.Q-<Zd2>.Q }, <Zn>.Q, <Zm>.Q
   Instruction Set: A64  Groups: mortlach_multi2_z_z_long_zip, mortlach_multi_sve_3, sme */
FNIEMOP_DEF_1(iemDecodeA64_zip_mz_zz_2q, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  1) & 0x0000000f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2 /*FEAT_SME2*/)
    {
        LogFlow(("%018x/%010x: zip_mz_zz_2q Zd=%#x Zn=%#x Zm=%#x\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm));
#ifdef IEM_INSTR_IMPL_A64__zip_mz_zz_2q
        IEM_INSTR_IMPL_A64__zip_mz_zz_2q(Zd, Zn, Zm);
#else
        RT_NOREF(Zd, Zn, Zm, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4400e000: ZIPQ1  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_binquads, sve_perm_quads_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_zipq1_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: zipq1_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__zipq1_z_zz
        IEM_INSTR_IMPL_A64__zipq1_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ff20fc00/4400e400: ZIPQ2  <Zd>.<T>, <Zn>.<T>, <Zm>.<T>
   Instruction Set: A64  Groups: sve_int_perm_binquads, sve_perm_quads_b, sve */
FNIEMOP_DEF_1(iemDecodeA64_zipq2_z_zz, uint32_t, uOpcode)
{
    uint32_t const Zd         = (uOpcode >>  0) & 0x0000001f;
    uint32_t const Zn         = (uOpcode >>  5) & 0x0000001f;
    uint32_t const Zm         = (uOpcode >> 16) & 0x0000001f;
    uint32_t const size       = (uOpcode >> 22) & 0x00000003;
    if (IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSve2p1 /*FEAT_SVE2p1*/ || IEM_GET_GUEST_CPU_FEATURES(pVCpu)->fSme2p1 /*FEAT_SME2p1*/)
    {
        LogFlow(("%018x/%010x: zipq2_z_zz Zd=%#x Zn=%#x Zm=%#x size=%u\n", pVCpu->cpum.GstCtx.Pc.u64, uOpcode, Zd, Zn, Zm, size));
#ifdef IEM_INSTR_IMPL_A64__zipq2_z_zz
        IEM_INSTR_IMPL_A64__zipq2_z_zz(Zd, Zn, Zm, size);
#else
        RT_NOREF(Zd, Zn, Zm, size, pVCpu, uOpcode);
        return VERR_IEM_INSTR_NOT_IMPLEMENTED;
#endif
    }
    Log(("Invalid instruction %%#x at %%x (cond)\n", uOpcode, pVCpu->cpum.GstCtx.Pc.u64));
    IEMOP_RAISE_INVALID_OPCODE_RET();
}

/* ffe0fc00/80000000 level 2
   mask=0x100210 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_80000000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmop4a_za_zz_s1x1,
        iemDecodeA64_fmop4s_za_zz_s1x1,
        iemDecodeA64_fmop4a_za_zz_s2x1,
        iemDecodeA64_fmop4s_za_zz_s2x1,
        iemDecodeA64_fmop4a_za_zz_s1x2,
        iemDecodeA64_fmop4s_za_zz_s1x2,
        iemDecodeA64_fmop4a_za_zz_s2x2,
        iemDecodeA64_fmop4s_za_zz_s2x2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100210 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0000000 level 2
   ffe0fc00/a0000400 level 2
   ffe0fc00/a0000800 level 2
   ffe0fc00/a0000c00 level 2
   ffe0fc00/a0001000 level 2
   ffe0fc00/a0001400 level 2
   ffe0fc00/a0001800 level 2
   ffe0fc00/a0001c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0000000))
        return iemDecodeA64_ld1b_mz_p_br_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0000001))
        return iemDecodeA64_ldnt1b_mz_p_br_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/c0020000 level 3
   ffeffc00/c0022000 level 3
   ffeffc00/c0024000 level 3
   ffeffc00/c0026000 level 3
   ffeffc00/c002a000 level 3
   ffeffc00/c002c000 level 3
   ffeffc00/c002e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_c0020000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0020000))
        return iemDecodeA64_mova_z_p_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0020200))
        return iemDecodeA64_movaz_z_rza_b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/c0060000 level 3
   ffeffc00/c0062000 level 3
   ffeffc00/c0064000 level 3
   ffeffc00/c0066000 level 3
   ffeffc00/c006a000 level 3
   ffeffc00/c006c000 level 3
   ffeffc00/c006e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_c0060000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0060000))
        return iemDecodeA64_mova_mz2_za_b1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0060200))
        return iemDecodeA64_movaz_mz2_za_b1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0000000 level 2
   mask=0xf0000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0000000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_b,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ffeffc00_c0020000_3,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_mova_za2_z_b1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc00_c0060000_3,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_zero_za_i,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_zero_za1_ri_2,
        iemDecodeA64_zero_za2_ri_2,
        iemDecodeA64_zero_za1_ri_4,
        iemDecodeA64_zero_za4_ri_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x0/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00000000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80000000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0000000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fe01/c0000400 level 3
   ffe3fe01/c0000401 level 3
   ffe3fe01/c0000600 level 3
   ffe3fe01/c0000601 level 3
   ffe3fe01/c0002400 level 3
   ffe3fe01/c0002401 level 3
   ffe3fe01/c0002600 level 3
   ffe3fe01/c0002601 level 3
   ffe3fe01/c0004400 level 3
   ffe3fe01/c0004401 level 3
   ffe3fe01/c0004600 level 3
   ffe3fe01/c0004601 level 3
   ffe3fe01/c0006400 level 3
   ffe3fe01/c0006401 level 3
   ffe3fe01/c0006600 level 3
   ffe3fe01/c0006601 level 3
   ffe3fe01/c0008400 level 3
   ffe3fe01/c0008401 level 3
   ffe3fe01/c0008600 level 3
   ffe3fe01/c0008601 level 3
   ffe3fe01/c000a400 level 3
   ffe3fe01/c000a401 level 3
   ffe3fe01/c000a600 level 3
   ffe3fe01/c000a601 level 3
   ffe3fe01/c000c400 level 3
   ffe3fe01/c000c401 level 3
   ffe3fe01/c000c600 level 3
   ffe3fe01/c000c601 level 3
   ffe3fe01/c000e400 level 3
   ffe3fe01/c000e401 level 3
   ffe3fe01/c000e600 level 3
   ffe3fe01/c000e601 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fe01_c0000400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0000000))
        return iemDecodeA64_mova_za_p_rz_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1c7c)) == UINT32_C(0xc0040400))
        return iemDecodeA64_mova_za4_z_b1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fe01/c0020400 level 3
   ffe3fe01/c0022400 level 3
   ffe3fe01/c0024400 level 3
   ffe3fe01/c0026400 level 3
   ffe3fe01/c0028400 level 3
   ffe3fe01/c002a400 level 3
   ffe3fe01/c002c400 level 3
   ffe3fe01/c002e400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fe01_c0020400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0020000))
        return iemDecodeA64_mova_z_p_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f83)) == UINT32_C(0xc0060400))
        return iemDecodeA64_mova_mz4_za_b1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0000400 level 2
   ffe0fc00/c0002400 level 2
   ffe0fc00/c0004400 level 2
   ffe0fc00/c0006400 level 2
   ffe0fc00/c0008400 level 2
   ffe0fc00/c000a400 level 2
   ffe0fc00/c000c400 level 2
   ffe0fc00/c000e400 level 2
   mask=0x30201 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%12 (0x2) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0000400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe3fe01_c0000400_3,
        iemDecodeA64_ffe3fe01_c0000400_3,
        iemDecodeA64_ffe3fe01_c0000400_3,
        iemDecodeA64_ffe3fe01_c0000400_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe3fe01_c0020400_3,
        iemDecodeA64_mova_z_p_rza_b,
        iemDecodeA64_movaz_mz4_za_b1,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00030201 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 14) & UINT32_C(0x0000000c)) /* bit 16 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00000400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0000000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0000400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fe01/c0000800 level 3
   ffe3fe01/c0000801 level 3
   ffe3fe01/c0000a00 level 3
   ffe3fe01/c0000a01 level 3
   ffe3fe01/c0002800 level 3
   ffe3fe01/c0002801 level 3
   ffe3fe01/c0002a00 level 3
   ffe3fe01/c0002a01 level 3
   ffe3fe01/c0004800 level 3
   ffe3fe01/c0004801 level 3
   ffe3fe01/c0004a00 level 3
   ffe3fe01/c0004a01 level 3
   ffe3fe01/c0006800 level 3
   ffe3fe01/c0006801 level 3
   ffe3fe01/c0006a00 level 3
   ffe3fe01/c0006a01 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fe01_c0000800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0000000))
        return iemDecodeA64_mova_za_p_rz_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff9c38)) == UINT32_C(0xc0040800))
        return iemDecodeA64_mova_za_mz2_1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fe01/c0020800 level 3
   ffe3fe01/c0022800 level 3
   ffe3fe01/c0024800 level 3
   ffe3fe01/c0026800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fe01_c0020800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0020000))
        return iemDecodeA64_mova_z_p_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff9f01)) == UINT32_C(0xc0060800))
        return iemDecodeA64_mova_mz_za2_1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0000800 level 2
   ffe0fc00/c0002800 level 2
   ffe0fc00/c0004800 level 2
   ffe0fc00/c0006800 level 2
   mask=0x30201 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%12 (0x2) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0000800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe3fe01_c0000800_3,
        iemDecodeA64_ffe3fe01_c0000800_3,
        iemDecodeA64_ffe3fe01_c0000800_3,
        iemDecodeA64_ffe3fe01_c0000800_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe3fe01_c0020800_3,
        iemDecodeA64_mova_z_p_rza_b,
        iemDecodeA64_movaz_mz_za2_1,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00030201 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 14) & UINT32_C(0x0000000c)) /* bit 16 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00000800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0000000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0000800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fe01/c0000c00 level 3
   ffe3fe01/c0000c01 level 3
   ffe3fe01/c0000e00 level 3
   ffe3fe01/c0000e01 level 3
   ffe3fe01/c0002c00 level 3
   ffe3fe01/c0002c01 level 3
   ffe3fe01/c0002e00 level 3
   ffe3fe01/c0002e01 level 3
   ffe3fe01/c0004c00 level 3
   ffe3fe01/c0004c01 level 3
   ffe3fe01/c0004e00 level 3
   ffe3fe01/c0004e01 level 3
   ffe3fe01/c0006c00 level 3
   ffe3fe01/c0006c01 level 3
   ffe3fe01/c0006e00 level 3
   ffe3fe01/c0006e01 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fe01_c0000c00_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0000000))
        return iemDecodeA64_mova_za_p_rz_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff9c78)) == UINT32_C(0xc0040c00))
        return iemDecodeA64_mova_za_mz4_1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fe01/c0020c00 level 3
   ffe3fe01/c0022c00 level 3
   ffe3fe01/c0024c00 level 3
   ffe3fe01/c0026c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fe01_c0020c00_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0020000))
        return iemDecodeA64_mova_z_p_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff9f03)) == UINT32_C(0xc0060c00))
        return iemDecodeA64_mova_mz_za4_1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0000c00 level 2
   ffe0fc00/c0002c00 level 2
   ffe0fc00/c0004c00 level 2
   ffe0fc00/c0006c00 level 2
   mask=0x30201 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%12 (0x2) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0000c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe3fe01_c0000c00_3,
        iemDecodeA64_ffe3fe01_c0000c00_3,
        iemDecodeA64_ffe3fe01_c0000c00_3,
        iemDecodeA64_ffe3fe01_c0000c00_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe3fe01_c0020c00_3,
        iemDecodeA64_mova_z_p_rza_b,
        iemDecodeA64_movaz_mz_za4_1,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00030201 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 14) & UINT32_C(0x0000000c)) /* bit 16 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00000c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0000000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0000c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c0001000 level 2
   ffe0fc00/c0001400 level 2
   ffe0fc00/c0001800 level 2
   ffe0fc00/c0001c00 level 2
   ffe0fc00/c0003000 level 2
   ffe0fc00/c0003400 level 2
   ffe0fc00/c0003800 level 2
   ffe0fc00/c0003c00 level 2
   ffe0fc00/c0005000 level 2
   ffe0fc00/c0005400 level 2
   ffe0fc00/c0005800 level 2
   ffe0fc00/c0005c00 level 2
   ffe0fc00/c0007000 level 2
   ffe0fc00/c0007400 level 2
   ffe0fc00/c0007800 level 2
   ffe0fc00/c0007c00 level 2
   ffe0fc00/c0008800 level 2
   ffe0fc00/c0008c00 level 2
   ffe0fc00/c0009000 level 2
   ffe0fc00/c0009400 level 2
   ffe0fc00/c0009800 level 2
   ffe0fc00/c0009c00 level 2
   ffe0fc00/c000a800 level 2
   ffe0fc00/c000ac00 level 2
   ffe0fc00/c000b000 level 2
   ffe0fc00/c000b400 level 2
   ffe0fc00/c000b800 level 2
   ffe0fc00/c000bc00 level 2
   ffe0fc00/c000c800 level 2
   ffe0fc00/c000cc00 level 2
   ffe0fc00/c000d000 level 2
   ffe0fc00/c000d400 level 2
   ffe0fc00/c000d800 level 2
   ffe0fc00/c000dc00 level 2
   ffe0fc00/c000e800 level 2
   ffe0fc00/c000ec00 level 2
   ffe0fc00/c000f000 level 2
   ffe0fc00/c000f400 level 2
   ffe0fc00/c000f800 level 2
   ffe0fc00/c000fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0001000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0000000))
        return iemDecodeA64_mova_za_p_rz_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0020000))
        return iemDecodeA64_mova_z_p_rza_b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00001000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00001000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0000000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00001400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00001400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0000000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00001800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00001800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0000000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00001c00 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00001c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0000000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0002000 level 2
   ffe0fc00/a0002400 level 2
   ffe0fc00/a0002800 level 2
   ffe0fc00/a0002c00 level 2
   ffe0fc00/a0003000 level 2
   ffe0fc00/a0003400 level 2
   ffe0fc00/a0003800 level 2
   ffe0fc00/a0003c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0002000))
        return iemDecodeA64_ld1h_mz_p_br_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0002001))
        return iemDecodeA64_ldnt1h_mz_p_br_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0002000 level 2
   ffe0fc00/c0004000 level 2
   ffe0fc00/c0006000 level 2
   mask=0xf0000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%38 (0x6) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0002000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_b,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ffeffc00_c0020000_3,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_mova_za2_z_b1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc00_c0060000_3,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_zero_za1_ri_2,
        iemDecodeA64_zero_za2_ri_2,
        iemDecodeA64_zero_za1_ri_4,
        iemDecodeA64_zero_za4_ri_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x2000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00002000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0002000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0002000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x2400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00002400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0002000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0000400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x2800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00002800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0002000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0000800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x2c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00002c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0002000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0000c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00003000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00003000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0002000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00003400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00003400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0002000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00003800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00003800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0002000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00003c00 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00003c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0002000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0004000 level 2
   ffe0fc00/a0004400 level 2
   ffe0fc00/a0004800 level 2
   ffe0fc00/a0004c00 level 2
   ffe0fc00/a0005000 level 2
   ffe0fc00/a0005400 level 2
   ffe0fc00/a0005800 level 2
   ffe0fc00/a0005c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0004000))
        return iemDecodeA64_ld1w_mz_p_br_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0004001))
        return iemDecodeA64_ldnt1w_mz_p_br_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00004000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0004000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0002000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00004400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0004000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0000400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00004800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0004000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0000800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00004c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0004000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0000c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00005000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00005000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0004000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00005400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00005400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0004000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00005800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00005800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0004000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00005c00 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00005c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0004000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0006000 level 2
   ffe0fc00/a0006400 level 2
   ffe0fc00/a0006800 level 2
   ffe0fc00/a0006c00 level 2
   ffe0fc00/a0007000 level 2
   ffe0fc00/a0007400 level 2
   ffe0fc00/a0007800 level 2
   ffe0fc00/a0007c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0006000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0006000))
        return iemDecodeA64_ld1d_mz_p_br_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0006001))
        return iemDecodeA64_ldnt1d_mz_p_br_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x6000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00006000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0006000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0002000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x6400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00006400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0006000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0000400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x6800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00006800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0006000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0000800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x6c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00006c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0006000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0000c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00007000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00007000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0006000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00007400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00007400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0006000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00007800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00007800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0006000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x7c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00007c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_STXRB_SR32_ldstexclr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_STXRH_SR32_ldstexclr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXR_SR32_ldstexclr,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0006000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_STXR_SR64_ldstexclr,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/80008000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_80008000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80008000))
        return iemDecodeA64_smop4a_za_zz_b1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80108000))
        return iemDecodeA64_smop4a_za_zz_b1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fe1c/a0008000 level 3
   ffe1fe1c/a0008004 level 3
   ffe1fe1c/a0008008 level 3
   ffe1fe1c/a000800c level 3
   ffe1fe1c/a0008010 level 3
   ffe1fe1c/a0008014 level 3
   ffe1fe1c/a0008018 level 3
   ffe1fe1c/a000801c level 3
   ffe1fe1c/a0008200 level 3
   ffe1fe1c/a0008204 level 3
   ffe1fe1c/a0008208 level 3
   ffe1fe1c/a000820c level 3
   ffe1fe1c/a0008210 level 3
   ffe1fe1c/a0008214 level 3
   ffe1fe1c/a0008218 level 3
   ffe1fe1c/a000821c level 3
   ffe1fe1c/a0018000 level 3
   ffe1fe1c/a0018004 level 3
   ffe1fe1c/a0018008 level 3
   ffe1fe1c/a001800c level 3
   ffe1fe1c/a0018010 level 3
   ffe1fe1c/a0018014 level 3
   ffe1fe1c/a0018018 level 3
   ffe1fe1c/a001801c level 3
   ffe1fe1c/a0018200 level 3
   ffe1fe1c/a0018204 level 3
   ffe1fe1c/a0018208 level 3
   ffe1fe1c/a001820c level 3
   ffe1fe1c/a0018210 level 3
   ffe1fe1c/a0018214 level 3
   ffe1fe1c/a0018218 level 3
   ffe1fe1c/a001821c level 3
   ffe0fc00/a0008400 level 2
   ffe0fc00/a0008800 level 2
   ffe0fc00/a0008c00 level 2
   ffe0fc00/a0009000 level 2
   ffe0fc00/a0009400 level 2
   ffe0fc00/a0009800 level 2
   ffe0fc00/a0009c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_a0008000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa0008000))
        return iemDecodeA64_ld1b_mz_p_br_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa0008001))
        return iemDecodeA64_ldnt1b_mz_p_br_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fe1c/c0008000 level 3
   mask=0x1e0000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_c0008000_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_b,
        iemDecodeA64_mova_z_p_rza_b,
        iemDecodeA64_mova_za2_z_b1,
        iemDecodeA64_mova_mz2_za_b1,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_zero_za2_ri_1,
        iemDecodeA64_zero_za4_ri_1,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/00008000 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_80008000_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008000_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/c0008004 level 3
   mask=0x1e0000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%31 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_c0008004_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_b,
        iemDecodeA64_mova_z_p_rza_b,
        iemDecodeA64_mova_za2_z_b1,
        iemDecodeA64_mova_mz2_za_b1,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_zero_za2_ri_1,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/00008004 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008004_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008004_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/80008008 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_80008008_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80008008))
        return iemDecodeA64_smop4a_za32_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80108008))
        return iemDecodeA64_smop4a_za32_zz_h1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fe1c/c0008008 level 3
   ffe1fe1c/c000800c level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_c0008008_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0000000))
        return iemDecodeA64_mova_za_p_rz_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0020000))
        return iemDecodeA64_mova_z_p_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0060000))
        return iemDecodeA64_mova_mz2_za_b1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e1fe1c/00008008 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008008_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_80008008_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008008_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/0000800c level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_0000800c_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008008_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/80008010 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_80008010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80008010))
        return iemDecodeA64_smop4s_za_zz_b1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80108010))
        return iemDecodeA64_smop4s_za_zz_b1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fe1c/c0008010 level 3
   ffe1fe1c/c0008014 level 3
   ffe1fe1c/c0008018 level 3
   ffe1fe1c/c000801c level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_c0008010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0020000))
        return iemDecodeA64_mova_z_p_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0060000))
        return iemDecodeA64_mova_mz2_za_b1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e1fe1c/00008010 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_80008010_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008010_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/00008014 level 2
   07e1fe1c/0000801c level 2
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008014_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008010_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/80008018 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_80008018_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80008018))
        return iemDecodeA64_smop4s_za32_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80108018))
        return iemDecodeA64_smop4s_za32_zz_h1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e1fe1c/00008018 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008018_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_80008018_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008010_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/80008200 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_80008200_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80008200))
        return iemDecodeA64_smop4a_za_zz_b2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80108200))
        return iemDecodeA64_smop4a_za_zz_b2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fe1c/c0008200 level 3
   ffe1fe1c/c0008204 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_c0008200_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0000000))
        return iemDecodeA64_mova_za_p_rz_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1c38)) == UINT32_C(0xc0040000))
        return iemDecodeA64_mova_za2_z_b1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0020200))
        return iemDecodeA64_movaz_z_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0060200))
        return iemDecodeA64_movaz_mz2_za_b1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e1fe1c/00008200 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008200_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_80008200_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008200_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/00008204 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008204_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008200_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/80008208 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_80008208_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80008208))
        return iemDecodeA64_smop4a_za32_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80108208))
        return iemDecodeA64_smop4a_za32_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fe1c/c0008208 level 3
   ffe1fe1c/c000820c level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_c0008208_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0000000))
        return iemDecodeA64_mova_za_p_rz_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0020200))
        return iemDecodeA64_movaz_z_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0060200))
        return iemDecodeA64_movaz_mz2_za_b1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e1fe1c/00008208 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008208_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_80008208_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008208_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/0000820c level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_0000820c_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008208_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/80008210 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_80008210_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80008210))
        return iemDecodeA64_smop4s_za_zz_b2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80108210))
        return iemDecodeA64_smop4s_za_zz_b2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fe1c/c0008210 level 3
   ffe1fe1c/c0008214 level 3
   ffe1fe1c/c0008218 level 3
   ffe1fe1c/c000821c level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_c0008210_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0020200))
        return iemDecodeA64_movaz_z_rza_b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0060200))
        return iemDecodeA64_movaz_mz2_za_b1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e1fe1c/00008210 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008210_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_80008210_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008210_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/00008214 level 2
   07e1fe1c/0000821c level 2
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008214_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008210_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/80008218 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_80008218_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80008218))
        return iemDecodeA64_smop4s_za32_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe3c)) == UINT32_C(0x80108218))
        return iemDecodeA64_smop4s_za32_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e1fe1c/00008218 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00008218_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_80008218_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0008210_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe1c/c0018000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe1c_c0018000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff9ffc)) == UINT32_C(0xc00d8000))
        return iemDecodeA64_zero_za2_ri_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff9ffe)) == UINT32_C(0xc00f8000))
        return iemDecodeA64_zero_za4_ri_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e1fe1c/00018000 level 2
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00018000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe1fe1c_c0018000_3,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/00018004 level 2
   07e1fe1c/00018008 level 2
   07e1fe1c/0001800c level 2
   07e1fe1c/00018200 level 2
   07e1fe1c/00018204 level 2
   07e1fe1c/00018208 level 2
   07e1fe1c/0001820c level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00018004_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e1fe1c/00018010 level 2
   07e1fe1c/00018014 level 2
   07e1fe1c/00018018 level 2
   07e1fe1c/0001801c level 2
   07e1fe1c/00018210 level 2
   07e1fe1c/00018214 level 2
   07e1fe1c/00018218 level 2
   07e1fe1c/0001821c level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e1fe1c_00018010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x8000/0x1021c
   mask=0x1021c entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%47 (0xf) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00008000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07e1fe1c_00008000_2,
        iemDecodeA64_07e1fe1c_00008004_2,
        iemDecodeA64_07e1fe1c_00008008_2,
        iemDecodeA64_07e1fe1c_0000800c_2,
        iemDecodeA64_07e1fe1c_00008010_2,
        iemDecodeA64_07e1fe1c_00008014_2,
        iemDecodeA64_07e1fe1c_00008018_2,
        iemDecodeA64_07e1fe1c_00008014_2,
        iemDecodeA64_07e1fe1c_00008200_2,
        iemDecodeA64_07e1fe1c_00008204_2,
        iemDecodeA64_07e1fe1c_00008208_2,
        iemDecodeA64_07e1fe1c_0000820c_2,
        iemDecodeA64_07e1fe1c_00008210_2,
        iemDecodeA64_07e1fe1c_00008214_2,
        iemDecodeA64_07e1fe1c_00008218_2,
        iemDecodeA64_07e1fe1c_00008214_2,
        iemDecodeA64_07e1fe1c_00018000_2,
        iemDecodeA64_07e1fe1c_00018004_2,
        iemDecodeA64_07e1fe1c_00018004_2,
        iemDecodeA64_07e1fe1c_00018004_2,
        iemDecodeA64_07e1fe1c_00018010_2,
        iemDecodeA64_07e1fe1c_00018010_2,
        iemDecodeA64_07e1fe1c_00018010_2,
        iemDecodeA64_07e1fe1c_00018010_2,
        iemDecodeA64_07e1fe1c_00018004_2,
        iemDecodeA64_07e1fe1c_00018004_2,
        iemDecodeA64_07e1fe1c_00018004_2,
        iemDecodeA64_07e1fe1c_00018004_2,
        iemDecodeA64_07e1fe1c_00018010_2,
        iemDecodeA64_07e1fe1c_00018010_2,
        iemDecodeA64_07e1fe1c_00018010_2,
        iemDecodeA64_07e1fe1c_00018010_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x0001021c -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000007)) /* bit  2 L 3 -> 0 */
                        | ((uOpcode >>  6) & UINT32_C(0x00000008)) /* bit  9 L 1 -> 3 */
                        | ((uOpcode >> 12) & UINT32_C(0x00000010)) /* bit 16 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x8400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00008400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0000400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00008800 level 1
   07e0fc00/00009800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00008800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00008c00 level 1
   07e0fc00/00009c00 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00008c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00009000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00009000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00009400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00009400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe1fe1c_a0008000_3,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a000a000 level 2
   ffe0fc00/a000a400 level 2
   ffe0fc00/a000a800 level 2
   ffe0fc00/a000ac00 level 2
   ffe0fc00/a000b000 level 2
   ffe0fc00/a000b400 level 2
   ffe0fc00/a000b800 level 2
   ffe0fc00/a000bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a000a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa000a000))
        return iemDecodeA64_ld1h_mz_p_br_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa000a001))
        return iemDecodeA64_ldnt1h_mz_p_br_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c000a000 level 2
   ffe0fc00/c000c000 level 2
   ffe0fc00/c000e000 level 2
   mask=0xf0000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%38 (0x6) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c000a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_b,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ffeffc00_c0020000_3,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_mova_za2_z_b1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc00_c0060000_3,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_zero_za2_ri_1,
        iemDecodeA64_zero_za2_ri_4,
        iemDecodeA64_zero_za4_ri_1,
        iemDecodeA64_zero_za4_ri_4,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xa000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c000a000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xa400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0000400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000a800 level 1
   07e0fc00/0000b800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000ac00 level 1
   07e0fc00/0000bc00 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000b000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000b400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a000c000 level 2
   ffe0fc00/a000c400 level 2
   ffe0fc00/a000c800 level 2
   ffe0fc00/a000cc00 level 2
   ffe0fc00/a000d000 level 2
   ffe0fc00/a000d400 level 2
   ffe0fc00/a000d800 level 2
   ffe0fc00/a000dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a000c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa000c000))
        return iemDecodeA64_ld1w_mz_p_br_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa000c001))
        return iemDecodeA64_ldnt1w_mz_p_br_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000c000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c000a000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000c000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0000400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000c800 level 1
   07e0fc00/0000d800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000c000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000cc00 level 1
   07e0fc00/0000dc00 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000c000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000d000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000c000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000d400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000c000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a000e000 level 2
   ffe0fc00/a000e400 level 2
   ffe0fc00/a000e800 level 2
   ffe0fc00/a000ec00 level 2
   ffe0fc00/a000f000 level 2
   ffe0fc00/a000f400 level 2
   ffe0fc00/a000f800 level 2
   ffe0fc00/a000fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a000e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa000e000))
        return iemDecodeA64_ld1d_mz_p_br_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa000e001))
        return iemDecodeA64_ldnt1d_mz_p_br_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xe000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000e000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c000a000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xe400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000e000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0000400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000e800 level 1
   07e0fc00/0000f800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000e000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000ec00 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000e000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000f000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000e000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0000f400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000e000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xfc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0000fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_UDF_only_perm_undef,
        iemDecodeA64_STLXRB_SR32_ldstexclr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_STLXRH_SR32_ldstexclr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLXR_SR32_ldstexclr,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a000e000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0001000_2,
        iemDecodeA64_STLXR_SR64_ldstexclr,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/80200000 level 2
   mask=0x100208 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_80200000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmop4a_za32_z8z8_b1x1,
        iemDecodeA64_fmop4a_za16_z8z8_b1x1,
        iemDecodeA64_fmop4a_za32_z8z8_b2x1,
        iemDecodeA64_fmop4a_za16_z8z8_b2x1,
        iemDecodeA64_fmop4a_za32_z8z8_b1x2,
        iemDecodeA64_fmop4a_za16_z8z8_b1x2,
        iemDecodeA64_fmop4a_za32_z8z8_b2x2,
        iemDecodeA64_fmop4a_za16_z8z8_b2x2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100208 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000001)) /* bit  3 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0200000 level 2
   dfe0fc00/80200400 level 2
   ffe0fc00/a0200800 level 2
   dfe0fc00/80200c00 level 2
   ffe0fc00/a0201000 level 2
   dfe0fc00/80201400 level 2
   ffe0fc00/a0201800 level 2
   dfe0fc00/80201c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0200000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0200000))
        return iemDecodeA64_st1b_mz_p_br_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0200001))
        return iemDecodeA64_stnt1b_mz_p_br_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x200000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00200000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDADDB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDADDH_32_memop,
        iemDecodeA64_ffe0fc00_80200000_2,
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0200000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDADD_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDADD_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/88200400 level 2
   dfe0fc00/88200c00 level 2
   dfe0fc00/88201400 level 2
   dfe0fc00/88201c00 level 2
   dfe0fc00/88202400 level 2
   dfe0fc00/88202c00 level 2
   dfe0fc00/88203400 level 2
   dfe0fc00/88203c00 level 2
   dfe0fc00/88204400 level 2
   dfe0fc00/88204c00 level 2
   dfe0fc00/88205400 level 2
   dfe0fc00/88205c00 level 2
   dfe0fc00/88206400 level 2
   dfe0fc00/88206c00 level 2
   dfe0fc00/88207400 level 2
   dfe0fc00/88207c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_88200400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa8000000))
        return iemDecodeA64_STNP_64_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x88200000))
        return iemDecodeA64_STXP_SP32_ldstexclp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/c8200400 level 2
   dfe0fc00/c8200c00 level 2
   dfe0fc00/c8201400 level 2
   dfe0fc00/c8201c00 level 2
   dfe0fc00/c8202400 level 2
   dfe0fc00/c8202c00 level 2
   dfe0fc00/c8203400 level 2
   dfe0fc00/c8203c00 level 2
   dfe0fc00/c8204400 level 2
   dfe0fc00/c8204c00 level 2
   dfe0fc00/c8205400 level 2
   dfe0fc00/c8205c00 level 2
   dfe0fc00/c8206400 level 2
   dfe0fc00/c8206c00 level 2
   dfe0fc00/c8207400 level 2
   dfe0fc00/c8207c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c8200400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe8000000))
        return iemDecodeA64_STTNP_64_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xc8200000))
        return iemDecodeA64_STXP_SP64_ldstexclp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/d8200400 level 2
   dfe0fc00/d8201400 level 2
   dfe0fc00/d8202400 level 2
   dfe0fc00/d8203400 level 2
   dfe0fc00/d8204400 level 2
   dfe0fc00/d8205400 level 2
   dfe0fc00/d8206400 level 2
   dfe0fc00/d8207400 level 2
   dfe0fc00/d8208400 level 2
   dfe0fc00/d8209400 level 2
   dfe0fc00/d820a400 level 2
   dfe0fc00/d820b400 level 2
   dfe0fc00/d820c400 level 2
   dfe0fc00/d820d400 level 2
   dfe0fc00/d820e400 level 2
   dfe0fc00/d820f400 level 2
   dfe0fc00/d8602400 level 2
   dfe0fc00/d8603400 level 2
   dfe0fc00/d8604400 level 2
   dfe0fc00/d8605400 level 2
   dfe0fc00/d8606400 level 2
   dfe0fc00/d8607400 level 2
   dfe0fc00/d8608400 level 2
   dfe0fc00/d8609400 level 2
   dfe0fc00/d860a400 level 2
   dfe0fc00/d860b400 level 2
   dfe0fc00/d860c400 level 2
   dfe0fc00/d860d400 level 2
   dfe0fc00/d860e400 level 2
   dfe0fc00/d860f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_d8200400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xd8000000))
        return iemDecodeA64_PRFM_P_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa00c00)) == UINT32_C(0xf8200400))
        return iemDecodeA64_LDRAA_64_ldst_pac(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00200400 level 1
   07e0fc00/00201400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00200400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0200000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00200800 level 1
   07e0fc00/00201800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00200800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0200000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/d8200c00 level 2
   dfe0fc00/d8201c00 level 2
   dfe0fc00/d8202c00 level 2
   dfe0fc00/d8203c00 level 2
   dfe0fc00/d8204c00 level 2
   dfe0fc00/d8205c00 level 2
   dfe0fc00/d8206c00 level 2
   dfe0fc00/d8207c00 level 2
   dfe0fc00/d8208c00 level 2
   dfe0fc00/d8209c00 level 2
   dfe0fc00/d820ac00 level 2
   dfe0fc00/d820bc00 level 2
   dfe0fc00/d820cc00 level 2
   dfe0fc00/d820dc00 level 2
   dfe0fc00/d820ec00 level 2
   dfe0fc00/d820fc00 level 2
   dfe0fc00/d8602c00 level 2
   dfe0fc00/d8603c00 level 2
   dfe0fc00/d8604c00 level 2
   dfe0fc00/d8605c00 level 2
   dfe0fc00/d8606c00 level 2
   dfe0fc00/d8607c00 level 2
   dfe0fc00/d8608c00 level 2
   dfe0fc00/d8609c00 level 2
   dfe0fc00/d860ac00 level 2
   dfe0fc00/d860bc00 level 2
   dfe0fc00/d860cc00 level 2
   dfe0fc00/d860dc00 level 2
   dfe0fc00/d860ec00 level 2
   dfe0fc00/d860fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_d8200c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xd8000000))
        return iemDecodeA64_PRFM_P_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa00c00)) == UINT32_C(0xf8200c00))
        return iemDecodeA64_LDRAA_64W_ldst_pac(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00200c00 level 1
   07e0fc00/00201c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00200c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0200000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00201000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00201000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDCLRB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDCLRH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0200000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDCLR_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDCLR_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0202000 level 2
   dfe0fc00/80202400 level 2
   ffe0fc00/a0202800 level 2
   dfe0fc00/80202c00 level 2
   ffe0fc00/a0203000 level 2
   dfe0fc00/80203400 level 2
   ffe0fc00/a0203800 level 2
   dfe0fc00/80203c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0202000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0202000))
        return iemDecodeA64_st1h_mz_p_br_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0202001))
        return iemDecodeA64_stnt1h_mz_p_br_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00202000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00202000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDEORB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDEORH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0202000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDEOR_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDEOR_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00202400 level 1
   07e0fc00/00203400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00202400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0202000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00202800 level 1
   07e0fc00/00203800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00202800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0202000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00202c00 level 1
   07e0fc00/00203c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00202c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0202000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00203000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00203000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSETB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSETH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0202000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSET_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSET_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0204000 level 2
   dfe0fc00/80204400 level 2
   ffe0fc00/a0204800 level 2
   dfe0fc00/80204c00 level 2
   ffe0fc00/a0205000 level 2
   dfe0fc00/80205400 level 2
   ffe0fc00/a0205800 level 2
   dfe0fc00/80205c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0204000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0204000))
        return iemDecodeA64_st1w_mz_p_br_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0204001))
        return iemDecodeA64_stnt1w_mz_p_br_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00204000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00204000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMAXB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMAXH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0204000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMAX_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMAX_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00204400 level 1
   07e0fc00/00205400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00204400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0204000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00204800 level 1
   07e0fc00/00205800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00204800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0204000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00204c00 level 1
   07e0fc00/00205c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00204c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0204000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00205000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00205000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMINB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMINH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0204000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMIN_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMIN_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0206000 level 2
   dfe0fc00/80206400 level 2
   ffe0fc00/a0206800 level 2
   dfe0fc00/80206c00 level 2
   ffe0fc00/a0207000 level 2
   dfe0fc00/80207400 level 2
   ffe0fc00/a0207800 level 2
   dfe0fc00/80207c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0206000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0206000))
        return iemDecodeA64_st1d_mz_p_br_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e001)) == UINT32_C(0xa0206001))
        return iemDecodeA64_stnt1d_mz_p_br_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00206000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00206000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMAXB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMAXH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0206000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMAX_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMAX_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00206400 level 1
   07e0fc00/00207400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00206400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0206000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/38206800 level 2
   ffe0fc00/38207800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_38206800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x38200800))
        return iemDecodeA64_STRB_32B_ldst_regoff(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0ec00)) == UINT32_C(0x38206800))
        return iemDecodeA64_STRB_32BL_ldst_regoff(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00206800 level 1
   07e0fc00/00207800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00206800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_ffe0fc00_38206800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0206000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00206c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00206c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0206000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00207000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00207000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMINB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMINH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0206000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMIN_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMIN_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/08207c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_08207c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x28000000))
        return iemDecodeA64_STNP_32_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x08207c00))
        return iemDecodeA64_CASP_CP32_comswappr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00207c00 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%56 (0x9) multi-if=%31 (0x5) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00207c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_dfe0fc00_08207c00_2,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CASP_CP64_comswappr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0206000_2,
        iemDecodeA64_dfe0fc00_88200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8200400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/80208000 level 2
   mask=0x100210 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_80208000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sumop4a_za_zz_b1x1,
        iemDecodeA64_sumop4s_za_zz_b1x1,
        iemDecodeA64_sumop4a_za_zz_b2x1,
        iemDecodeA64_sumop4s_za_zz_b2x1,
        iemDecodeA64_sumop4a_za_zz_b1x2,
        iemDecodeA64_sumop4s_za_zz_b1x2,
        iemDecodeA64_sumop4a_za_zz_b2x2,
        iemDecodeA64_sumop4s_za_zz_b2x2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100210 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0208000 level 2
   dfe0fc00/80208400 level 2
   ffe0fc00/a0208800 level 2
   dfe0fc00/80208c00 level 2
   ffe0fc00/a0209000 level 2
   dfe0fc00/80209400 level 2
   ffe0fc00/a0209800 level 2
   dfe0fc00/80209c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0208000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa0208000))
        return iemDecodeA64_st1b_mz_p_br_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa0208001))
        return iemDecodeA64_stnt1b_mz_p_br_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x208000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00208000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_SWPB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_SWPH_32_memop,
        iemDecodeA64_ffe0fc00_80208000_2,
        iemDecodeA64_STLXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0208000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_SWP_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STLXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_SWP_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/88208400 level 2
   dfe0fc00/88208c00 level 2
   dfe0fc00/88209400 level 2
   dfe0fc00/88209c00 level 2
   dfe0fc00/8820a400 level 2
   dfe0fc00/8820ac00 level 2
   dfe0fc00/8820b400 level 2
   dfe0fc00/8820bc00 level 2
   dfe0fc00/8820c000 level 2
   dfe0fc00/8820c400 level 2
   dfe0fc00/8820cc00 level 2
   dfe0fc00/8820d000 level 2
   dfe0fc00/8820d400 level 2
   dfe0fc00/8820dc00 level 2
   dfe0fc00/8820e000 level 2
   dfe0fc00/8820e400 level 2
   dfe0fc00/8820ec00 level 2
   dfe0fc00/8820f000 level 2
   dfe0fc00/8820f400 level 2
   dfe0fc00/8820fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_88208400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa8000000))
        return iemDecodeA64_STNP_64_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x88208000))
        return iemDecodeA64_STLXP_SP32_ldstexclp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/c8208400 level 2
   dfe0fc00/c8208c00 level 2
   dfe0fc00/c8209400 level 2
   dfe0fc00/c8209c00 level 2
   dfe0fc00/c820a400 level 2
   dfe0fc00/c820ac00 level 2
   dfe0fc00/c820b400 level 2
   dfe0fc00/c820bc00 level 2
   dfe0fc00/c820c000 level 2
   dfe0fc00/c820c400 level 2
   dfe0fc00/c820cc00 level 2
   dfe0fc00/c820d000 level 2
   dfe0fc00/c820d400 level 2
   dfe0fc00/c820dc00 level 2
   dfe0fc00/c820e000 level 2
   dfe0fc00/c820e400 level 2
   dfe0fc00/c820ec00 level 2
   dfe0fc00/c820f000 level 2
   dfe0fc00/c820f400 level 2
   dfe0fc00/c820fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c8208400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe8000000))
        return iemDecodeA64_STTNP_64_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xc8208000))
        return iemDecodeA64_STLXP_SP64_ldstexclp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00208400 level 1
   07e0fc00/00209400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00208400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0208000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00208800 level 1
   07e0fc00/00209800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00208800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0208000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STLXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00208c00 level 1
   07e0fc00/00209c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00208c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0208000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00209000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00209000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWCLR_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSCLR_64_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0208000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STLXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_ST64B_64L_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a020a000 level 2
   dfe0fc00/8020a400 level 2
   ffe0fc00/a020a800 level 2
   dfe0fc00/8020ac00 level 2
   ffe0fc00/a020b000 level 2
   dfe0fc00/8020b400 level 2
   ffe0fc00/a020b800 level 2
   dfe0fc00/8020bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a020a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa020a000))
        return iemDecodeA64_st1h_mz_p_br_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa020a001))
        return iemDecodeA64_stnt1h_mz_p_br_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0020a000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSWP_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSSWP_64_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a020a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STLXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_ST64BV0_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020a400 level 1
   07e0fc00/0020b400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a020a000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020a800 level 1
   07e0fc00/0020b800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a020a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STLXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020ac00 level 1
   07e0fc00/0020bc00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a020a000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020b000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSET_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSSET_64_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a020a000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STLXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_ST64BV_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/8020c000 level 2
   dfe0fc00/8020c400 level 2
   ffe0fc00/a020c800 level 2
   dfe0fc00/8020cc00 level 2
   dfe0fc00/8020d000 level 2
   dfe0fc00/8020d400 level 2
   ffe0fc00/a020d800 level 2
   dfe0fc00/8020dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_8020c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa020c000))
        return iemDecodeA64_st1w_mz_p_br_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa020c001))
        return iemDecodeA64_stnt1w_mz_p_br_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0020c000 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%62 (0xa) multi-if=%19 (0x3) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8020c000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020c400 level 1
   07e0fc00/0020d400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8020c000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020c800 level 1
   07e0fc00/0020d800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_8020c000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STLXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020cc00 level 1
   07e0fc00/0020dc00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8020c000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/d820d000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_d820d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xd8000000))
        return iemDecodeA64_PRFM_P_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xf83fd000))
        return iemDecodeA64_LD64B_64L_memop(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0020d000 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8020c000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d820d000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/8020e000 level 2
   dfe0fc00/8020e400 level 2
   ffe0fc00/a020e800 level 2
   dfe0fc00/8020ec00 level 2
   dfe0fc00/8020f000 level 2
   dfe0fc00/8020f400 level 2
   ffe0fc00/a020f800 level 2
   dfe0fc00/8020fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_8020e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa020e000))
        return iemDecodeA64_st1d_mz_p_br_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e003)) == UINT32_C(0xa020e001))
        return iemDecodeA64_stnt1d_mz_p_br_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0020e000 level 1
   07e0fc00/0020f000 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%62 (0xa) multi-if=%19 (0x3) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8020e000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020e400 level 1
   07e0fc00/0020f400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8020e000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020e800 level 1
   07e0fc00/0020f800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_STRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLXP_SP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_8020e000_2,
        iemDecodeA64_STNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_STLXP_SP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_STTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_STR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0020ec00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8020e000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/0820fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_0820fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x28000000))
        return iemDecodeA64_STNP_32_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0820fc00))
        return iemDecodeA64_CASPL_CP32_comswappr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0020fc00 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%56 (0x9) multi-if=%31 (0x5) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0020fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_dfe0fc00_0820fc00_2,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CASPL_CP64_comswappr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8020e000_2,
        iemDecodeA64_dfe0fc00_88208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1b_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8208400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0400000 level 2
   ffe0fc00/a0400400 level 2
   ffe0fc00/a0400800 level 2
   ffe0fc00/a0400c00 level 2
   ffe0fc00/a0401000 level 2
   ffe0fc00/a0401400 level 2
   ffe0fc00/a0401800 level 2
   ffe0fc00/a0401c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0400000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0400000))
        return iemDecodeA64_ld1b_mz_p_bi_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0400001))
        return iemDecodeA64_ldnt1b_mz_p_bi_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc01/c0400001 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc01_c0400001_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0400000))
        return iemDecodeA64_mova_za_p_rz_h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xc0480001))
        return iemDecodeA64_zero_zt_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc01/c0420000 level 3
   ffe7fc01/c0420001 level 3
   ffe7fd20/c0422000 level 3
   ffe7fd20/c0422020 level 3
   ffe7fd20/c0422100 level 3
   ffe7fd20/c0422120 level 3
   ffeefc00/c0424000 level 3
   ffeefc00/c0426000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc01_c0420000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0420000))
        return iemDecodeA64_mova_z_p_rza_h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0420200))
        return iemDecodeA64_movaz_z_rza_h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc01/c0440000 level 3
   ffe7fc01/c0440001 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc01_c0440000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1c38)) == UINT32_C(0xc0440000))
        return iemDecodeA64_mova_za2_z_h1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8fe0)) == UINT32_C(0xc04c03e0))
        return iemDecodeA64_movt_r_zt(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc01/c0460000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc01_c0460000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0460000))
        return iemDecodeA64_mova_mz2_za_h1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0460200))
        return iemDecodeA64_movaz_mz2_za_h1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8fe0)) == UINT32_C(0xc04e03e0))
        return iemDecodeA64_movt_zt_r(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0400000 level 2
   mask=0x70001 entries=0x10 children=0xa valid=%62 (0xa) leaf=%25 (0x4) multi-if=%38 (0x6) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0400000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_ffe7fc01_c0400001_3,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc01_c0420000_3,
        iemDecodeA64_ffe7fc01_c0420000_3,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe7fc01_c0440000_3,
        iemDecodeA64_ffe7fc01_c0440000_3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe7fc01_c0460000_3,
        iemDecodeA64_movt_zt_r,
        iemDecodeA64_movt_zt_z,
        iemDecodeA64_movt_zt_z,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00070001 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x0000000e)) /* bit 16 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00400000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_ftmopa_za_zzzi_s2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0400000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fe01/c0400400 level 3
   ffe3fe01/c0400401 level 3
   ffe3fe01/c0400600 level 3
   ffe3fe01/c0400601 level 3
   ffe3fe01/c0402400 level 3
   ffe3fe01/c0402401 level 3
   ffe3fe01/c0402600 level 3
   ffe3fe01/c0402601 level 3
   ffe3fe01/c0404400 level 3
   ffe3fe01/c0404401 level 3
   ffe3fe01/c0404600 level 3
   ffe3fe01/c0404601 level 3
   ffe3fe01/c0406400 level 3
   ffe3fe01/c0406401 level 3
   ffe3fe01/c0406600 level 3
   ffe3fe01/c0406601 level 3
   ffe3fe01/c0408400 level 3
   ffe3fe01/c0408401 level 3
   ffe3fe01/c0408600 level 3
   ffe3fe01/c0408601 level 3
   ffe3fe01/c040a400 level 3
   ffe3fe01/c040a401 level 3
   ffe3fe01/c040a600 level 3
   ffe3fe01/c040a601 level 3
   ffe3fe01/c040c400 level 3
   ffe3fe01/c040c401 level 3
   ffe3fe01/c040c600 level 3
   ffe3fe01/c040c601 level 3
   ffe3fe01/c040e400 level 3
   ffe3fe01/c040e401 level 3
   ffe3fe01/c040e600 level 3
   ffe3fe01/c040e601 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fe01_c0400400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0400000))
        return iemDecodeA64_mova_za_p_rz_h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1c7c)) == UINT32_C(0xc0440400))
        return iemDecodeA64_mova_za4_z_h1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fe01/c0420400 level 3
   ffe3fe01/c0422400 level 3
   ffe3fe01/c0424400 level 3
   ffe3fe01/c0426400 level 3
   ffe3fe01/c0428400 level 3
   ffe3fe01/c042a400 level 3
   ffe3fe01/c042c400 level 3
   ffe3fe01/c042e400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fe01_c0420400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0420000))
        return iemDecodeA64_mova_z_p_rza_h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f83)) == UINT32_C(0xc0460400))
        return iemDecodeA64_mova_mz4_za_h1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0400400 level 2
   ffe0fc00/c0402400 level 2
   ffe0fc00/c0404400 level 2
   ffe0fc00/c0406400 level 2
   ffe0fc00/c0408400 level 2
   ffe0fc00/c040a400 level 2
   ffe0fc00/c040c400 level 2
   ffe0fc00/c040e400 level 2
   mask=0x30201 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%12 (0x2) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0400400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe3fe01_c0400400_3,
        iemDecodeA64_ffe3fe01_c0400400_3,
        iemDecodeA64_ffe3fe01_c0400400_3,
        iemDecodeA64_ffe3fe01_c0400400_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe3fe01_c0420400_3,
        iemDecodeA64_mova_z_p_rza_h,
        iemDecodeA64_movaz_mz4_za_h1,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00030201 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 14) & UINT32_C(0x0000000c)) /* bit 16 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00400400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_ftmopa_za_zzzi_s2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0400000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c0400800 level 2
   ffe0fc00/c0400c00 level 2
   ffe0fc00/c0401400 level 2
   ffe0fc00/c0401800 level 2
   ffe0fc00/c0401c00 level 2
   ffe0fc00/c0402800 level 2
   ffe0fc00/c0402c00 level 2
   ffe0fc00/c0403400 level 2
   ffe0fc00/c0403800 level 2
   ffe0fc00/c0403c00 level 2
   ffe0fc00/c0404800 level 2
   ffe0fc00/c0404c00 level 2
   ffe0fc00/c0405400 level 2
   ffe0fc00/c0405800 level 2
   ffe0fc00/c0405c00 level 2
   ffe0fc00/c0406800 level 2
   ffe0fc00/c0406c00 level 2
   ffe0fc00/c0407400 level 2
   ffe0fc00/c0407800 level 2
   ffe0fc00/c0407c00 level 2
   ffe0fc00/c0408800 level 2
   ffe0fc00/c0408c00 level 2
   ffe0fc00/c0409000 level 2
   ffe0fc00/c0409400 level 2
   ffe0fc00/c0409800 level 2
   ffe0fc00/c0409c00 level 2
   ffe0fc00/c040a800 level 2
   ffe0fc00/c040ac00 level 2
   ffe0fc00/c040b000 level 2
   ffe0fc00/c040b400 level 2
   ffe0fc00/c040b800 level 2
   ffe0fc00/c040bc00 level 2
   ffe0fc00/c040c800 level 2
   ffe0fc00/c040cc00 level 2
   ffe0fc00/c040d000 level 2
   ffe0fc00/c040d400 level 2
   ffe0fc00/c040d800 level 2
   ffe0fc00/c040dc00 level 2
   ffe0fc00/c040e800 level 2
   ffe0fc00/c040ec00 level 2
   ffe0fc00/c040f000 level 2
   ffe0fc00/c040f400 level 2
   ffe0fc00/c040f800 level 2
   ffe0fc00/c040fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0400800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0400000))
        return iemDecodeA64_mova_za_p_rz_h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0420000))
        return iemDecodeA64_mova_z_p_rza_h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00400800 level 1
   07e0fc00/00401800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00400800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRH_32_ldst_unpriv,
        iemDecodeA64_ftmopa_za_zzzi_s2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0400000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00400c00 level 1
   07e0fc00/00401c00 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00400c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_ftmopa_za_zzzi_s2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0400000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3ff80/c0401380 level 3
   ffe3ff80/c0403380 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3ff80_c0401380_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0400000))
        return iemDecodeA64_mova_za_p_rz_h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8fe0)) == UINT32_C(0xc04c03e0))
        return iemDecodeA64_movt_r_zt(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0401000 level 2
   ffe0fc00/c0403000 level 2
   mask=0x30380 entries=0x20 children=0xe valid=%44 (0xe) leaf=%41 (0xd) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0401000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_ffe3ff80_c0401380_3,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_mova_z_p_rza_h,
        iemDecodeA64_mova_z_p_rza_h,
        iemDecodeA64_mova_z_p_rza_h,
        iemDecodeA64_mova_z_p_rza_h,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_movt_zt_r,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_movt_zt_z,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x00030380 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  7) & UINT32_C(0x00000007)) /* bit  7 L 3 -> 0 */
                        | ((uOpcode >> 13) & UINT32_C(0x00000018)) /* bit 16 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x401000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00401000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_ftmopa_za_zzzi_s2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0400000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00401400 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00401400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_ftmopa_za_zzzi_s2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0400000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0402000 level 2
   ffe0fc00/a0402400 level 2
   ffe0fc00/a0402800 level 2
   ffe0fc00/a0402c00 level 2
   ffe0fc00/a0403000 level 2
   ffe0fc00/a0403400 level 2
   ffe0fc00/a0403800 level 2
   ffe0fc00/a0403c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0402000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0402000))
        return iemDecodeA64_ld1h_mz_p_bi_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0402001))
        return iemDecodeA64_ldnt1h_mz_p_bi_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fd20/c0462000 level 3
   ffe7fd20/c0462020 level 3
   ffeefc00/c0464000 level 3
   ffeefc00/c0466000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fd20_c0462000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0460000))
        return iemDecodeA64_mova_mz2_za_h1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0460200))
        return iemDecodeA64_movaz_mz2_za_h1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0402000 level 2
   mask=0x70120 entries=0x20 children=0xf valid=%47 (0xf) leaf=%28 (0x9) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0402000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe7fc01_c0420000_3,
        iemDecodeA64_ffe7fc01_c0420000_3,
        iemDecodeA64_ffe7fc01_c0420000_3,
        iemDecodeA64_ffe7fc01_c0420000_3,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_mova_za2_z_h1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_mova_za2_z_h1,
        iemDecodeA64_movt_r_zt,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe7fd20_c0462000_3,
        iemDecodeA64_ffe7fd20_c0462000_3,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_movt_zt_r,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_movt_zt_z,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x00070120 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  5) & UINT32_C(0x00000001)) /* bit  5 L 1 -> 0 */
                        | ((uOpcode >>  7) & UINT32_C(0x00000002)) /* bit  8 L 1 -> 1 */
                        | ((uOpcode >> 14) & UINT32_C(0x0000001c)) /* bit 16 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x402000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00402000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0402000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0402000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x402400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00402400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0402000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00402800 level 1
   07e0fc00/00403800 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00402800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0402000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00402c00 level 1
   07e0fc00/00403c00 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00402c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0402000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x403000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00403000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0402000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00403400 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00403400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0402000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0404000 level 2
   ffe0fc00/a0404400 level 2
   ffe0fc00/a0404800 level 2
   ffe0fc00/a0404c00 level 2
   ffe0fc00/a0405000 level 2
   ffe0fc00/a0405400 level 2
   ffe0fc00/a0405800 level 2
   ffe0fc00/a0405c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0404000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0404000))
        return iemDecodeA64_ld1w_mz_p_bi_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0404001))
        return iemDecodeA64_ldnt1w_mz_p_bi_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0404000 level 2
   ffe0fc00/c0406000 level 2
   mask=0xe0000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0404000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_ffe7fc01_c0420000_3,
        iemDecodeA64_mova_za2_z_h1,
        iemDecodeA64_ffe7fd20_c0462000_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_movt_r_zt,
        iemDecodeA64_movt_zt_r,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x000e0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000007)) /* bit 17 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x404000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00404000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0404000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0404000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x404400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00404400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0404000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00404800 level 1
   07e0fc00/00405800 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00404800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0404000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00404c00 level 1
   07e0fc00/00405c00 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00404c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0404000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c0405000 level 2
   ffe0fc00/c0407000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0405000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0400000))
        return iemDecodeA64_mova_za_p_rz_h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0420000))
        return iemDecodeA64_mova_z_p_rza_h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8fe0)) == UINT32_C(0xc04c03e0))
        return iemDecodeA64_movt_r_zt(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8fe0)) == UINT32_C(0xc04e03e0))
        return iemDecodeA64_movt_zt_r(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x405000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00405000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0404000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0405000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00405400 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00405400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0404000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0406000 level 2
   ffe0fc00/a0406400 level 2
   ffe0fc00/a0406800 level 2
   ffe0fc00/a0406c00 level 2
   ffe0fc00/a0407000 level 2
   ffe0fc00/a0407400 level 2
   ffe0fc00/a0407800 level 2
   ffe0fc00/a0407c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0406000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0406000))
        return iemDecodeA64_ld1d_mz_p_bi_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0406001))
        return iemDecodeA64_ldnt1d_mz_p_bi_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x406000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00406000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0406000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0404000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x406400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00406400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0406000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00406800 level 1
   07e0fc00/00407800 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00406800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0406000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00406c00 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00406c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0406000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x407000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00407000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0406000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0405000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00407400 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00407400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0406000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x407c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00407c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDXRB_LR32_ldstexclr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LDXRH_LR32_ldstexclr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXR_LR32_ldstexclr,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0406000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_LDXR_LR64_ldstexclr,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/80408000 level 2
   ffe0fc00/80408400 level 2
   ffe0fc00/80408800 level 2
   ffe0fc00/80408c00 level 2
   ffe0fc00/80409000 level 2
   ffe0fc00/80409400 level 2
   ffe0fc00/80409800 level 2
   ffe0fc00/80409c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_80408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x80408000))
        return iemDecodeA64_stmopa_za_zzzi_b2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x80408008))
        return iemDecodeA64_stmopa_za32_zzzi_h2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a0408000 level 2
   ffe0fc00/a0408400 level 2
   ffe0fc00/a0408800 level 2
   ffe0fc00/a0408c00 level 2
   ffe0fc00/a0409000 level 2
   ffe0fc00/a0409400 level 2
   ffe0fc00/a0409800 level 2
   ffe0fc00/a0409c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa0408000))
        return iemDecodeA64_ld1b_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa0408001))
        return iemDecodeA64_ldnt1b_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0408000 level 2
   ffe0fc00/c040a000 level 2
   ffe0fc00/c040c000 level 2
   ffe0fc00/c040e000 level 2
   mask=0x60200 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0408000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_za_p_rz_h,
        iemDecodeA64_mova_z_p_rza_h,
        iemDecodeA64_movaz_z_rza_h,
        iemDecodeA64_mova_za2_z_h1,
        iemDecodeA64_mova_za2_z_h1,
        iemDecodeA64_mova_mz2_za_h1,
        iemDecodeA64_movaz_mz2_za_h1,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00060200 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 16) & UINT32_C(0x00000006)) /* bit 17 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x408000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00408000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0408000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x408400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00408400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_80408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0408000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x408800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x409800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00408800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRH_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_80408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0408000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x408c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x409c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00408c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_80408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0408000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x409000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00409000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0408000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x409400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00409400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_80408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0408000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a040a000 level 2
   ffe0fc00/a040a400 level 2
   ffe0fc00/a040a800 level 2
   ffe0fc00/a040ac00 level 2
   ffe0fc00/a040b000 level 2
   ffe0fc00/a040b400 level 2
   ffe0fc00/a040b800 level 2
   ffe0fc00/a040bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a040a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa040a000))
        return iemDecodeA64_ld1h_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa040a001))
        return iemDecodeA64_ldnt1h_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x40a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040a000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x40a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040a000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040a800 level 1
   07e0fc00/0040b800 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040a000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040ac00 level 1
   07e0fc00/0040bc00 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040a000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040b000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040a000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040b400 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040a000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a040c000 level 2
   ffe0fc00/a040c400 level 2
   ffe0fc00/a040c800 level 2
   ffe0fc00/a040cc00 level 2
   ffe0fc00/a040d000 level 2
   ffe0fc00/a040d400 level 2
   ffe0fc00/a040d800 level 2
   ffe0fc00/a040dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a040c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa040c000))
        return iemDecodeA64_ld1w_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa040c001))
        return iemDecodeA64_ldnt1w_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x40c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040c000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x40c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040c000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040c800 level 1
   07e0fc00/0040d800 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040c000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040cc00 level 1
   07e0fc00/0040dc00 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040c000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040d000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040c000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040d400 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040c000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a040e000 level 2
   ffe0fc00/a040e400 level 2
   ffe0fc00/a040e800 level 2
   ffe0fc00/a040ec00 level 2
   ffe0fc00/a040f000 level 2
   ffe0fc00/a040f400 level 2
   ffe0fc00/a040f800 level 2
   ffe0fc00/a040fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a040e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa040e000))
        return iemDecodeA64_ld1d_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa040e001))
        return iemDecodeA64_ldnt1d_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x40e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040e000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x40e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040e000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040e800 level 1
   07e0fc00/0040f800 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRH_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040e000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTR_64_ldst_unpriv,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040ec00 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040e000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040f000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURH_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040e000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUR_64_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0040f400 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpost,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040e000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x40fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0040fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDAXRB_LR32_ldstexclr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LDAXRH_LR32_ldstexclr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_immpre,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDAXR_LR32_ldstexclr,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a040e000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0400800_2,
        iemDecodeA64_LDAXR_LR64_ldstexclr,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/80600000 level 2
   ffe0fc00/80600400 level 2
   ffe0fc00/80600800 level 2
   ffe0fc00/80600c00 level 2
   ffe0fc00/80601000 level 2
   ffe0fc00/80601400 level 2
   ffe0fc00/80601800 level 2
   ffe0fc00/80601c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_80600000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x80600000))
        return iemDecodeA64_ftmopa_za32_z8z8zi_b2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00e)) == UINT32_C(0x80600008))
        return iemDecodeA64_ftmopa_za16_z8z8zi_b2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a0600000 level 2
   ffe0fc00/a0600400 level 2
   ffe0fc00/a0600800 level 2
   ffe0fc00/a0600c00 level 2
   ffe0fc00/a0601000 level 2
   ffe0fc00/a0601400 level 2
   ffe0fc00/a0601800 level 2
   ffe0fc00/a0601c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0600000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0600000))
        return iemDecodeA64_st1b_mz_p_bi_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0600001))
        return iemDecodeA64_stnt1b_mz_p_bi_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x600000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00600000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDADDLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDADDLH_32_memop,
        iemDecodeA64_ffe0fc00_80600000_2,
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0600000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDADDL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDADDL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00600400 level 1
   07e0fc00/00601400 level 1
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00600400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0fc00_80600000_2,
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0600000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRAA_64_ldst_pac,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x600800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x601800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00600800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_regoff,
        iemDecodeA64_ffe0fc00_80600000_2,
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0600000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00600c00 level 1
   07e0fc00/00601c00 level 1
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00600c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0fc00_80600000_2,
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0600000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRAA_64W_ldst_pac,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x601000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00601000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDCLRLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDCLRLH_32_memop,
        iemDecodeA64_ffe0fc00_80600000_2,
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0600000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDCLRL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDCLRL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0602000 level 2
   dfe0fc00/80602400 level 2
   ffe0fc00/a0602800 level 2
   dfe0fc00/80602c00 level 2
   ffe0fc00/a0603000 level 2
   dfe0fc00/80603400 level 2
   ffe0fc00/a0603800 level 2
   dfe0fc00/80603c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0602000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0602000))
        return iemDecodeA64_st1h_mz_p_bi_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0602001))
        return iemDecodeA64_stnt1h_mz_p_bi_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00602000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00602000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDEORLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDEORLH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0602000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDEORL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDEORL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/88602400 level 2
   dfe0fc00/88602c00 level 2
   dfe0fc00/88603400 level 2
   dfe0fc00/88603c00 level 2
   dfe0fc00/88604400 level 2
   dfe0fc00/88604c00 level 2
   dfe0fc00/88605400 level 2
   dfe0fc00/88605c00 level 2
   dfe0fc00/88606400 level 2
   dfe0fc00/88606c00 level 2
   dfe0fc00/88607400 level 2
   dfe0fc00/88607c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_88602400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa8400000))
        return iemDecodeA64_LDNP_64_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8000)) == UINT32_C(0x887f0000))
        return iemDecodeA64_LDXP_LP32_ldstexclp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/c8602400 level 2
   dfe0fc00/c8602c00 level 2
   dfe0fc00/c8603400 level 2
   dfe0fc00/c8603c00 level 2
   dfe0fc00/c8604400 level 2
   dfe0fc00/c8604c00 level 2
   dfe0fc00/c8605400 level 2
   dfe0fc00/c8605c00 level 2
   dfe0fc00/c8606400 level 2
   dfe0fc00/c8606c00 level 2
   dfe0fc00/c8607400 level 2
   dfe0fc00/c8607c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c8602400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe8400000))
        return iemDecodeA64_LDTNP_64_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8000)) == UINT32_C(0xc87f0000))
        return iemDecodeA64_LDXP_LP64_ldstexclp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00602400 level 1
   07e0fc00/00603400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00602400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0602000_2,
        iemDecodeA64_dfe0fc00_88602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00602800 level 1
   07e0fc00/00603800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00602800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0602000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00602c00 level 1
   07e0fc00/00603c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00602c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0602000_2,
        iemDecodeA64_dfe0fc00_88602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00603000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00603000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSETLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSETLH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0602000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSETL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSETL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0604000 level 2
   dfe0fc00/80604400 level 2
   ffe0fc00/a0604800 level 2
   dfe0fc00/80604c00 level 2
   ffe0fc00/a0605000 level 2
   dfe0fc00/80605400 level 2
   ffe0fc00/a0605800 level 2
   dfe0fc00/80605c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0604000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0604000))
        return iemDecodeA64_st1w_mz_p_bi_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0604001))
        return iemDecodeA64_stnt1w_mz_p_bi_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00604000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00604000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMAXLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMAXLH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0604000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMAXL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMAXL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00604400 level 1
   07e0fc00/00605400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00604400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0604000_2,
        iemDecodeA64_dfe0fc00_88602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00604800 level 1
   07e0fc00/00605800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00604800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0604000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00604c00 level 1
   07e0fc00/00605c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00604c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0604000_2,
        iemDecodeA64_dfe0fc00_88602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00605000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00605000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMINLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMINLH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0604000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMINL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMINL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0606000 level 2
   dfe0fc00/80606400 level 2
   ffe0fc00/a0606800 level 2
   dfe0fc00/80606c00 level 2
   ffe0fc00/a0607000 level 2
   dfe0fc00/80607400 level 2
   ffe0fc00/a0607800 level 2
   dfe0fc00/80607c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0606000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0606000))
        return iemDecodeA64_st1d_mz_p_bi_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e001)) == UINT32_C(0xa0606001))
        return iemDecodeA64_stnt1d_mz_p_bi_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00606000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00606000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMAXLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMAXLH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0606000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMAXL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMAXL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00606400 level 1
   07e0fc00/00607400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00606400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0606000_2,
        iemDecodeA64_dfe0fc00_88602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/38606800 level 2
   ffe0fc00/38607800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_38606800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x38600800))
        return iemDecodeA64_LDRB_32B_ldst_regoff(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0ec00)) == UINT32_C(0x38606800))
        return iemDecodeA64_LDRB_32BL_ldst_regoff(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00606800 level 1
   07e0fc00/00607800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00606800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_ffe0fc00_38606800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0606000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00606c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00606c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0606000_2,
        iemDecodeA64_dfe0fc00_88602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00607000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00607000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMINLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMINLH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0606000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMINL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMINL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/08607c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_08607c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x28400000))
        return iemDecodeA64_LDNP_32_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x08607c00))
        return iemDecodeA64_CASPA_CP32_comswappr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00607c00 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%56 (0x9) multi-if=%31 (0x5) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00607c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_dfe0fc00_08607c00_2,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CASPA_CP64_comswappr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_ffe0fc00_a0606000_2,
        iemDecodeA64_dfe0fc00_88602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8602400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a0608000 level 2
   ffe0fc00/a0608800 level 2
   ffe0fc00/a0609800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0608000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa0608000))
        return iemDecodeA64_st1b_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa0608001))
        return iemDecodeA64_stnt1b_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00608000 level 1
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%72 (0x17) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00608000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_SWPLB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_SWPLH_32_memop,
        iemDecodeA64_sutmopa_za_zzzi_b2x1,
        iemDecodeA64_LDAXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0608000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_SWPL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDAXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_SWPL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/80608400 level 2
   dfe0fc00/80608c00 level 2
   dfe0fc00/80609000 level 2
   dfe0fc00/80609400 level 2
   dfe0fc00/80609c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_80608400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x80608000))
        return iemDecodeA64_sutmopa_za_zzzi_b2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa0608000))
        return iemDecodeA64_st1b_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa0608001))
        return iemDecodeA64_stnt1b_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/88608400 level 2
   dfe0fc00/88608c00 level 2
   dfe0fc00/88609000 level 2
   dfe0fc00/88609400 level 2
   dfe0fc00/88609c00 level 2
   dfe0fc00/8860a000 level 2
   dfe0fc00/8860a400 level 2
   dfe0fc00/8860ac00 level 2
   dfe0fc00/8860b000 level 2
   dfe0fc00/8860b400 level 2
   dfe0fc00/8860bc00 level 2
   dfe0fc00/8860c000 level 2
   dfe0fc00/8860c400 level 2
   dfe0fc00/8860cc00 level 2
   dfe0fc00/8860d000 level 2
   dfe0fc00/8860d400 level 2
   dfe0fc00/8860dc00 level 2
   dfe0fc00/8860e000 level 2
   dfe0fc00/8860e400 level 2
   dfe0fc00/8860ec00 level 2
   dfe0fc00/8860f000 level 2
   dfe0fc00/8860f400 level 2
   dfe0fc00/8860fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_88608400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa8400000))
        return iemDecodeA64_LDNP_64_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8000)) == UINT32_C(0x887f8000))
        return iemDecodeA64_LDAXP_LP32_ldstexclp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/c8608400 level 2
   dfe0fc00/c8608c00 level 2
   dfe0fc00/c8609000 level 2
   dfe0fc00/c8609400 level 2
   dfe0fc00/c8609c00 level 2
   dfe0fc00/c860a000 level 2
   dfe0fc00/c860a400 level 2
   dfe0fc00/c860ac00 level 2
   dfe0fc00/c860b000 level 2
   dfe0fc00/c860b400 level 2
   dfe0fc00/c860bc00 level 2
   dfe0fc00/c860c000 level 2
   dfe0fc00/c860c400 level 2
   dfe0fc00/c860cc00 level 2
   dfe0fc00/c860d000 level 2
   dfe0fc00/c860d400 level 2
   dfe0fc00/c860dc00 level 2
   dfe0fc00/c860e000 level 2
   dfe0fc00/c860e400 level 2
   dfe0fc00/c860ec00 level 2
   dfe0fc00/c860f000 level 2
   dfe0fc00/c860f400 level 2
   dfe0fc00/c860fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c8608400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe8400000))
        return iemDecodeA64_LDTNP_64_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff8000)) == UINT32_C(0xc87f8000))
        return iemDecodeA64_LDAXP_LP64_ldstexclp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00608400 level 1
   07e0fc00/00609400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00608400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_80608400_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00608800 level 1
   07e0fc00/00609800 level 1
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%72 (0x17) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00608800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_regoff,
        iemDecodeA64_sutmopa_za_zzzi_b2x1,
        iemDecodeA64_LDAXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0608000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDAXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00608c00 level 1
   07e0fc00/00609c00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00608c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_80608400_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/18609000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_18609000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x18000000))
        return iemDecodeA64_LDR_32_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x38609000))
        return iemDecodeA64_RCWCLRL_64_memop(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/58609000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_58609000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x58000000))
        return iemDecodeA64_LDR_64_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x78609000))
        return iemDecodeA64_RCWSCLRL_64_memop(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00609000 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%50 (0x8) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00609000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_dfe0fc00_18609000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_dfe0fc00_58609000_2,
        iemDecodeA64_dfe0fc00_80608400_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/1860a000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_1860a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x18000000))
        return iemDecodeA64_LDR_32_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x3860a000))
        return iemDecodeA64_RCWSWPL_64_memop(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/5860a000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_5860a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x58000000))
        return iemDecodeA64_LDR_64_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7860a000))
        return iemDecodeA64_RCWSSWPL_64_memop(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/8060a000 level 2
   dfe0fc00/8060a400 level 2
   ffe0fc00/a060a800 level 2
   dfe0fc00/8060ac00 level 2
   dfe0fc00/8060b000 level 2
   dfe0fc00/8060b400 level 2
   ffe0fc00/a060b800 level 2
   dfe0fc00/8060bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_8060a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa060a000))
        return iemDecodeA64_st1h_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa060a001))
        return iemDecodeA64_stnt1h_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0060a000 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%50 (0x8) multi-if=%31 (0x5) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_dfe0fc00_1860a000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_dfe0fc00_5860a000_2,
        iemDecodeA64_dfe0fc00_8060a000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060a400 level 1
   07e0fc00/0060b400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060a000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060a800 level 1
   07e0fc00/0060b800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDAXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_8060a000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDAXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060ac00 level 1
   07e0fc00/0060bc00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060a000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/1860b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_1860b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x18000000))
        return iemDecodeA64_LDR_32_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x3860b000))
        return iemDecodeA64_RCWSETL_64_memop(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/5860b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_5860b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x58000000))
        return iemDecodeA64_LDR_64_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7860b000))
        return iemDecodeA64_RCWSSETL_64_memop(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0060b000 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%50 (0x8) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_dfe0fc00_1860b000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_dfe0fc00_5860b000_2,
        iemDecodeA64_dfe0fc00_8060a000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/8060c000 level 2
   dfe0fc00/8060c400 level 2
   ffe0fc00/a060c800 level 2
   dfe0fc00/8060cc00 level 2
   dfe0fc00/8060d000 level 2
   dfe0fc00/8060d400 level 2
   ffe0fc00/a060d800 level 2
   dfe0fc00/8060dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_8060c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa060c000))
        return iemDecodeA64_st1w_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa060c001))
        return iemDecodeA64_stnt1w_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0060c000 level 1
   07e0fc00/0060d000 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%62 (0xa) multi-if=%19 (0x3) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060c000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060c400 level 1
   07e0fc00/0060d400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060c000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060c800 level 1
   07e0fc00/0060d800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDAXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_8060c000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDAXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060cc00 level 1
   07e0fc00/0060dc00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060c000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/8060e000 level 2
   dfe0fc00/8060e400 level 2
   ffe0fc00/a060e800 level 2
   dfe0fc00/8060ec00 level 2
   dfe0fc00/8060f000 level 2
   dfe0fc00/8060f400 level 2
   ffe0fc00/a060f800 level 2
   dfe0fc00/8060fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_8060e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa060e000))
        return iemDecodeA64_st1d_mz_p_bi_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e003)) == UINT32_C(0xa060e001))
        return iemDecodeA64_stnt1d_mz_p_bi_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0060e000 level 1
   07e0fc00/0060f000 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%62 (0xa) multi-if=%19 (0x3) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060e000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060e400 level 1
   07e0fc00/0060f400 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060e000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060e800 level 1
   07e0fc00/0060f800 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDAXP_LP32_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_8060e000_2,
        iemDecodeA64_LDNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_32_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_LDAXP_LP64_ldstexclp,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_LDTNP_64_ldstnapair_offs,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDR_64_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0060ec00 level 1
   mask=0xd8000000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%56 (0x9) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDNP_32_ldstnapair_offs,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060e000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/0860fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_0860fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x28400000))
        return iemDecodeA64_LDNP_32_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0860fc00))
        return iemDecodeA64_CASPAL_CP32_comswappr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0060fc00 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%56 (0x9) multi-if=%31 (0x5) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0060fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_dfe0fc00_0860fc00_2,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CASPAL_CP64_comswappr,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_8060e000_2,
        iemDecodeA64_dfe0fc00_88608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1h_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8608400_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8200c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/80800000 level 2
   ffe0fc00/80800400 level 2
   ffe0fc00/80800800 level 2
   ffe0fc00/80800c00 level 2
   ffe0fc00/80801000 level 2
   ffe0fc00/80801400 level 2
   ffe0fc00/80801800 level 2
   ffe0fc00/80801c00 level 2
   ffe0fc00/80802000 level 2
   ffe0fc00/80802400 level 2
   ffe0fc00/80802800 level 2
   ffe0fc00/80802c00 level 2
   ffe0fc00/80803000 level 2
   ffe0fc00/80803400 level 2
   ffe0fc00/80803800 level 2
   ffe0fc00/80803c00 level 2
   ffe0fc00/80804000 level 2
   ffe0fc00/80804400 level 2
   ffe0fc00/80804800 level 2
   ffe0fc00/80804c00 level 2
   ffe0fc00/80805000 level 2
   ffe0fc00/80805400 level 2
   ffe0fc00/80805800 level 2
   ffe0fc00/80805c00 level 2
   ffe0fc00/80806000 level 2
   ffe0fc00/80806400 level 2
   ffe0fc00/80806800 level 2
   ffe0fc00/80806c00 level 2
   ffe0fc00/80807000 level 2
   ffe0fc00/80807400 level 2
   ffe0fc00/80807800 level 2
   ffe0fc00/80807c00 level 2
   ffe0fc00/80808000 level 2
   ffe0fc00/80808400 level 2
   ffe0fc00/80808800 level 2
   ffe0fc00/80808c00 level 2
   ffe0fc00/80809000 level 2
   ffe0fc00/80809400 level 2
   ffe0fc00/80809800 level 2
   ffe0fc00/80809c00 level 2
   ffe0fc00/8080a000 level 2
   ffe0fc00/8080a400 level 2
   ffe0fc00/8080a800 level 2
   ffe0fc00/8080ac00 level 2
   ffe0fc00/8080b000 level 2
   ffe0fc00/8080b400 level 2
   ffe0fc00/8080b800 level 2
   ffe0fc00/8080bc00 level 2
   ffe0fc00/8080c000 level 2
   ffe0fc00/8080c400 level 2
   ffe0fc00/8080c800 level 2
   ffe0fc00/8080cc00 level 2
   ffe0fc00/8080d000 level 2
   ffe0fc00/8080d400 level 2
   ffe0fc00/8080d800 level 2
   ffe0fc00/8080dc00 level 2
   ffe0fc00/8080e000 level 2
   ffe0fc00/8080e400 level 2
   ffe0fc00/8080e800 level 2
   ffe0fc00/8080ec00 level 2
   ffe0fc00/8080f000 level 2
   ffe0fc00/8080f400 level 2
   ffe0fc00/8080f800 level 2
   ffe0fc00/8080fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_80800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x80800000))
        return iemDecodeA64_fmopa_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x80800008))
        return iemDecodeA64_bmopa_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x80800010))
        return iemDecodeA64_fmops_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x80800018))
        return iemDecodeA64_bmops_za_pp_zz_32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a0800000 level 2
   ffe0fc00/a0800400 level 2
   ffe0fc00/a0800800 level 2
   ffe0fc00/a0800c00 level 2
   ffe0fc00/a0801000 level 2
   ffe0fc00/a0801400 level 2
   ffe0fc00/a0801800 level 2
   ffe0fc00/a0801c00 level 2
   ffe0fc00/a0802000 level 2
   ffe0fc00/a0802400 level 2
   ffe0fc00/a0802800 level 2
   ffe0fc00/a0802c00 level 2
   ffe0fc00/a0803000 level 2
   ffe0fc00/a0803400 level 2
   ffe0fc00/a0803800 level 2
   ffe0fc00/a0803c00 level 2
   ffe0fc00/a0804000 level 2
   ffe0fc00/a0804400 level 2
   ffe0fc00/a0804800 level 2
   ffe0fc00/a0804c00 level 2
   ffe0fc00/a0805000 level 2
   ffe0fc00/a0805400 level 2
   ffe0fc00/a0805800 level 2
   ffe0fc00/a0805c00 level 2
   ffe0fc00/a0806000 level 2
   ffe0fc00/a0806400 level 2
   ffe0fc00/a0806800 level 2
   ffe0fc00/a0806c00 level 2
   ffe0fc00/a0807000 level 2
   ffe0fc00/a0807400 level 2
   ffe0fc00/a0807800 level 2
   ffe0fc00/a0807c00 level 2
   ffe0fc00/a0808000 level 2
   ffe0fc00/a0808400 level 2
   ffe0fc00/a0808800 level 2
   ffe0fc00/a0808c00 level 2
   ffe0fc00/a0809000 level 2
   ffe0fc00/a0809400 level 2
   ffe0fc00/a0809800 level 2
   ffe0fc00/a0809c00 level 2
   ffe0fc00/a080a000 level 2
   ffe0fc00/a080a400 level 2
   ffe0fc00/a080a800 level 2
   ffe0fc00/a080ac00 level 2
   ffe0fc00/a080b000 level 2
   ffe0fc00/a080b400 level 2
   ffe0fc00/a080b800 level 2
   ffe0fc00/a080bc00 level 2
   ffe0fc00/a080c000 level 2
   ffe0fc00/a080c400 level 2
   ffe0fc00/a080c800 level 2
   ffe0fc00/a080cc00 level 2
   ffe0fc00/a080d000 level 2
   ffe0fc00/a080d400 level 2
   ffe0fc00/a080d800 level 2
   ffe0fc00/a080dc00 level 2
   ffe0fc00/a080e000 level 2
   ffe0fc00/a080e400 level 2
   ffe0fc00/a080e800 level 2
   ffe0fc00/a080ec00 level 2
   ffe0fc00/a080f000 level 2
   ffe0fc00/a080f400 level 2
   ffe0fc00/a080f800 level 2
   ffe0fc00/a080fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa0800000))
        return iemDecodeA64_smopa_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa0800008))
        return iemDecodeA64_smopa_za32_pp_zz_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa0800010))
        return iemDecodeA64_smops_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa0800018))
        return iemDecodeA64_smops_za32_pp_zz_16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fe00/c0800000 level 3
   ffe7fe00/c0800200 level 3
   ffe7fe00/c0802000 level 3
   ffe7fe00/c0802200 level 3
   ffeffc00/c0804000 level 3
   ffeffc00/c0806000 level 3
   ffeffc00/c0808000 level 3
   ffeffc00/c080a000 level 3
   ffeffc00/c080c000 level 3
   ffeffc00/c080e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fe00_c0800000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0800000))
        return iemDecodeA64_mova_za_p_rz_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff001c)) == UINT32_C(0xc0900000))
        return iemDecodeA64_addha_za_pp_z_32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fe00/c0830000 level 3
   ffe7fe00/c0830200 level 3
   ffe1fc14/c0811010 level 3
   ffe7fe00/c0832000 level 3
   ffe7fe00/c0832200 level 3
   ffe1fc14/c0813010 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fe00_c0830000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffcc23)) == UINT32_C(0xc08b0000))
        return iemDecodeA64_luti4_mz4_ztmz2_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffcc2c)) == UINT32_C(0xc09b0000))
        return iemDecodeA64_luti4_mz4_ztmz2_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0800000 level 2
   ffe0fc00/c0802000 level 2
   mask=0x70200 entries=0x10 children=0xc valid=%75 (0xc) leaf=%50 (0x8) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0800000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fe00_c0800000_3,
        iemDecodeA64_ffe7fe00_c0800000_3,
        iemDecodeA64_addva_za_pp_z_32,
        iemDecodeA64_addva_za_pp_z_32,
        iemDecodeA64_mova_z_p_rza_w,
        iemDecodeA64_movaz_z_rza_w,
        iemDecodeA64_ffe7fe00_c0830000_3,
        iemDecodeA64_ffe7fe00_c0830000_3,
        iemDecodeA64_mova_za2_z_w1,
        iemDecodeA64_mova_za2_z_w1,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_mova_mz2_za_w1,
        iemDecodeA64_movaz_mz2_za_w1,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00070200 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x0000000e)) /* bit 16 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x800000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x802000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00800000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSB_64_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSH_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDURSW_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0800000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFUM_P_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fc14/c0800400 level 3
   ffe3fc14/c0802400 level 3
   ffe3fc14/c0804400 level 3
   ffe3fc14/c0806400 level 3
   ffe3fc14/c0808400 level 3
   ffe3fc14/c080a400 level 3
   ffe3fc14/c080c400 level 3
   ffe3fc14/c080e400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc14_c0800400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0800000))
        return iemDecodeA64_mova_za_p_rz_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff001c)) == UINT32_C(0xc0900000))
        return iemDecodeA64_addha_za_pp_z_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1c7c)) == UINT32_C(0xc0840400))
        return iemDecodeA64_mova_za4_z_w1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fc14/c0820400 level 3
   ffe3fc14/c0820404 level 3
   ffe3fc14/c0820410 level 3
   ffe3fc14/c0820414 level 3
   ffe3fc14/c0822400 level 3
   ffe3fc14/c0822404 level 3
   ffe3fc14/c0822410 level 3
   ffe3fc14/c0822414 level 3
   ffe3fc14/c0824400 level 3
   ffe3fc14/c0824404 level 3
   ffe3fc14/c0824410 level 3
   ffe3fc14/c0824414 level 3
   ffe3fc14/c0826400 level 3
   ffe3fc14/c0826404 level 3
   ffe3fc14/c0826410 level 3
   ffe3fc14/c0826414 level 3
   ffe3fc14/c0828400 level 3
   ffe3fc14/c0828404 level 3
   ffe3fc14/c0828410 level 3
   ffe3fc14/c0828414 level 3
   ffe3fc14/c082a400 level 3
   ffe3fc14/c082a404 level 3
   ffe3fc14/c082a410 level 3
   ffe3fc14/c082a414 level 3
   ffe3fc14/c082c400 level 3
   ffe3fc14/c082c404 level 3
   ffe3fc14/c082c410 level 3
   ffe3fc14/c082c414 level 3
   ffe3fc14/c082e400 level 3
   ffe3fc14/c082e404 level 3
   ffe3fc14/c082e410 level 3
   ffe3fc14/c082e414 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc14_c0820400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0820000))
        return iemDecodeA64_mova_z_p_rza_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f83)) == UINT32_C(0xc0860400))
        return iemDecodeA64_mova_mz4_za_w1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f83)) == UINT32_C(0xc0860600))
        return iemDecodeA64_movaz_mz4_za_w1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0800400 level 2
   ffe0fc00/c0802400 level 2
   ffe0fc00/c0804400 level 2
   ffe0fc00/c0806400 level 2
   ffe0fc00/c0808400 level 2
   ffe0fc00/c080a400 level 2
   ffe0fc00/c080c400 level 2
   ffe0fc00/c080e400 level 2
   mask=0x30014 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%12 (0x2) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0800400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe3fc14_c0800400_3,
        iemDecodeA64_mova_za_p_rz_w,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_addva_za_pp_z_32,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe3fc14_c0820400_3,
        iemDecodeA64_ffe3fc14_c0820400_3,
        iemDecodeA64_ffe3fc14_c0820400_3,
        iemDecodeA64_ffe3fc14_c0820400_3,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00030014 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000001)) /* bit  2 L 1 -> 0 */
                        | ((uOpcode >>  3) & UINT32_C(0x00000002)) /* bit  4 L 1 -> 1 */
                        | ((uOpcode >> 14) & UINT32_C(0x0000000c)) /* bit 16 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x800400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x802400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x804400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x806400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x808400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80a400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80c400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00800400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_64_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_64_ldst_immpost,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0800400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c0800800 level 2
   ffe0fc00/c0800c00 level 2
   ffe0fc00/c0801400 level 2
   ffe0fc00/c0801800 level 2
   ffe0fc00/c0801c00 level 2
   ffe0fc00/c0802800 level 2
   ffe0fc00/c0802c00 level 2
   ffe0fc00/c0803400 level 2
   ffe0fc00/c0803800 level 2
   ffe0fc00/c0803c00 level 2
   ffe0fc00/c0804800 level 2
   ffe0fc00/c0804c00 level 2
   ffe0fc00/c0805400 level 2
   ffe0fc00/c0805800 level 2
   ffe0fc00/c0805c00 level 2
   ffe0fc00/c0806800 level 2
   ffe0fc00/c0806c00 level 2
   ffe0fc00/c0807400 level 2
   ffe0fc00/c0807800 level 2
   ffe0fc00/c0807c00 level 2
   ffe0fc00/c0808800 level 2
   ffe0fc00/c0808c00 level 2
   ffe0fc00/c0809400 level 2
   ffe0fc00/c0809800 level 2
   ffe0fc00/c0809c00 level 2
   ffe0fc00/c080a800 level 2
   ffe0fc00/c080ac00 level 2
   ffe0fc00/c080b400 level 2
   ffe0fc00/c080b800 level 2
   ffe0fc00/c080bc00 level 2
   ffe0fc00/c080c800 level 2
   ffe0fc00/c080cc00 level 2
   ffe0fc00/c080d400 level 2
   ffe0fc00/c080d800 level 2
   ffe0fc00/c080dc00 level 2
   ffe0fc00/c080e800 level 2
   ffe0fc00/c080ec00 level 2
   ffe0fc00/c080f400 level 2
   ffe0fc00/c080f800 level 2
   ffe0fc00/c080fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0800800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0800000))
        return iemDecodeA64_mova_za_p_rz_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff001c)) == UINT32_C(0xc0900000))
        return iemDecodeA64_addha_za_pp_z_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff001c)) == UINT32_C(0xc0910000))
        return iemDecodeA64_addva_za_pp_z_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0820000))
        return iemDecodeA64_mova_z_p_rza_w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x800800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x801800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x802800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x803800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x804800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x805800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x806800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x807800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x808800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x809800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80b800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80e800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00800800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRSB_64_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRSH_64_ldst_unpriv,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDTRSW_64_ldst_unpriv,
        iemDecodeA64_ffe0fc00_c0800800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x800c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x801c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x802c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x803c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x804c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x805c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x806c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x808c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x809c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80ac00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80bc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80cc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80dc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00800c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_64_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_64_ldst_immpre,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0800800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc14/c0801000 level 3
   ffe1fc14/c0803000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc14_c0801000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0800000))
        return iemDecodeA64_mova_za_p_rz_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff001c)) == UINT32_C(0xc0900000))
        return iemDecodeA64_addha_za_pp_z_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0820000))
        return iemDecodeA64_mova_z_p_rza_w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fc14/c0801004 level 3
   ffe1fc14/c0803004 level 3
   fffcfc00/c0805000 level 3
   fffcfc00/c0807000 level 3
   fffcfc00/c0809000 level 3
   fffcfc00/c080b000 level 3
   fffcfc00/c080d000 level 3
   fffcfc00/c080f000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc14_c0801004_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0800000))
        return iemDecodeA64_mova_za_p_rz_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0820000))
        return iemDecodeA64_mova_z_p_rza_w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fc14/c0811000 level 3
   ffe1fc14/c0813000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc14_c0811000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff001c)) == UINT32_C(0xc0910000))
        return iemDecodeA64_addva_za_pp_z_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffcc23)) == UINT32_C(0xc08b0000))
        return iemDecodeA64_luti4_mz4_ztmz2_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffcc2c)) == UINT32_C(0xc09b0000))
        return iemDecodeA64_luti4_mz4_ztmz2_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0801000 level 2
   ffe0fc00/c0803000 level 2
   mask=0x10014 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%50 (0x4) multi-if=%50 (0x4) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0801000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe1fc14_c0801000_3,
        iemDecodeA64_ffe1fc14_c0801004_3,
        iemDecodeA64_mova_z_p_rza_w,
        iemDecodeA64_mova_z_p_rza_w,
        iemDecodeA64_ffe1fc14_c0811000_3,
        iemDecodeA64_luti4_mz4_ztmz2_1,
        iemDecodeA64_ffe7fe00_c0830000_3,
        iemDecodeA64_luti4_mz4_ztmz2_1,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00010014 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000001)) /* bit  2 L 1 -> 0 */
                        | ((uOpcode >>  3) & UINT32_C(0x00000002)) /* bit  4 L 1 -> 1 */
                        | ((uOpcode >> 14) & UINT32_C(0x00000004)) /* bit 16 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x801000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x803000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00801000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSB_64_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSH_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDURSW_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFUM_P_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x801400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x803400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x805400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x807400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x809400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80b400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00801400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_64_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_64_ldst_immpost,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_ldst_immpost,
        iemDecodeA64_ffe0fc00_c0800800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/c0824000 level 3
   ffeffc00/c0826000 level 3
   ffeffc00/c0828000 level 3
   ffeffc00/c082a000 level 3
   ffeffc00/c082c000 level 3
   ffeffc00/c082e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_c0824000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0820000))
        return iemDecodeA64_mova_z_p_rza_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0820200))
        return iemDecodeA64_movaz_z_rza_w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/c0864000 level 3
   ffeffc00/c0866000 level 3
   ffeffc00/c0868000 level 3
   ffeffc00/c086a000 level 3
   ffeffc00/c086c000 level 3
   ffeffc00/c086e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_c0864000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0860000))
        return iemDecodeA64_mova_mz2_za_w1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0860200))
        return iemDecodeA64_movaz_mz2_za_w1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/c08a4000 level 3
   ffeffc00/c08b4000 level 3
   ffeffc00/c08a6000 level 3
   ffeffc00/c08b6000 level 3
   ffeffc00/c08ac000 level 3
   ffeffc00/c08bc000 level 3
   ffeffc00/c08ae000 level 3
   ffeffc00/c08be000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_c08a4000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffe4c01)) == UINT32_C(0xc08a4000))
        return iemDecodeA64_luti4_mz2_ztz_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffe4c08)) == UINT32_C(0xc09a4000))
        return iemDecodeA64_luti4_mz2_ztz_8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/c08c4000 level 3
   ffeffc00/c08d4000 level 3
   ffeffc00/c08e4000 level 3
   ffeffc00/c08f4000 level 3
   ffeffc00/c08c6000 level 3
   ffeffc00/c08d6000 level 3
   ffeffc00/c08e6000 level 3
   ffeffc00/c08f6000 level 3
   ffeffc00/c08cc000 level 3
   ffeffc00/c08dc000 level 3
   ffeffc00/c08ec000 level 3
   ffeffc00/c08fc000 level 3
   ffeffc00/c08ce000 level 3
   ffeffc00/c08de000 level 3
   ffeffc00/c08ee000 level 3
   ffeffc00/c08fe000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_c08c4000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc4c01)) == UINT32_C(0xc08c4000))
        return iemDecodeA64_luti2_mz2_ztz_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc4c08)) == UINT32_C(0xc09c4000))
        return iemDecodeA64_luti2_mz2_ztz_8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0804000 level 2
   ffe0fc00/c0806000 level 2
   ffe0fc00/c080c000 level 2
   ffe0fc00/c080e000 level 2
   mask=0xf0000 entries=0x10 children=0xb valid=%69 (0xb) leaf=%12 (0x2) multi-if=%56 (0x9) reuse=%31 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0804000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fe00_c0800000_3,
        iemDecodeA64_addva_za_pp_z_32,
        iemDecodeA64_ffeffc00_c0824000_3,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_mova_za2_z_w1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc00_c0864000_3,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffeffc00_c08a4000_3,
        iemDecodeA64_ffeffc00_c08a4000_3,
        iemDecodeA64_ffeffc00_c08c4000_3,
        iemDecodeA64_ffeffc00_c08c4000_3,
        iemDecodeA64_ffeffc00_c08c4000_3,
        iemDecodeA64_ffeffc00_c08c4000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x804000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x806000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80c000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00804000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSB_64_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSH_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDURSW_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0804000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFUM_P_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffcfc00/c0905000 level 3
   fffcfc00/c0907000 level 3
   fffcfc00/c0909000 level 3
   fffcfc00/c090b000 level 3
   fffcfc00/c090d000 level 3
   fffcfc00/c090f000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fffcfc00_c0905000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff001c)) == UINT32_C(0xc0900000))
        return iemDecodeA64_addha_za_pp_z_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff001c)) == UINT32_C(0xc0910000))
        return iemDecodeA64_addva_za_pp_z_32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0805000 level 2
   ffe0fc00/c0807000 level 2
   ffe0fc00/c080d000 level 2
   ffe0fc00/c080f000 level 2
   mask=0x1c0000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0805000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe1fc14_c0801004_3,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_luti4_mz2_ztz_1,
        iemDecodeA64_luti2_mz2_ztz_1,
        iemDecodeA64_fffcfc00_c0905000_3,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_luti4_mz2_ztz_8,
        iemDecodeA64_luti2_mz2_ztz_8,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x805000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x807000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80d000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00805000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSB_64_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSH_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDURSW_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0805000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFUM_P_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x807c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00807c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STLLRB_SL32_ldstord,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_64_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_STLLRH_SL32_ldstord,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_64_ldst_immpre,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_STLLR_SL32_ldstord,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0800800_2,
        iemDecodeA64_STLLR_SL64_ldstord,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/c08a8000 level 3
   ffeffc00/c08b8000 level 3
   ffeffc00/c08aa000 level 3
   ffeffc00/c08ba000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_c08a8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffecc03)) == UINT32_C(0xc08a8000))
        return iemDecodeA64_luti4_mz4_ztz_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffecc0c)) == UINT32_C(0xc09a8000))
        return iemDecodeA64_luti4_mz4_ztz_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/c08c8000 level 3
   ffeffc00/c08d8000 level 3
   ffeffc00/c08e8000 level 3
   ffeffc00/c08f8000 level 3
   ffeffc00/c08ca000 level 3
   ffeffc00/c08da000 level 3
   ffeffc00/c08ea000 level 3
   ffeffc00/c08fa000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_c08c8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffccc03)) == UINT32_C(0xc08c8000))
        return iemDecodeA64_luti2_mz4_ztz_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffccc0c)) == UINT32_C(0xc09c8000))
        return iemDecodeA64_luti2_mz4_ztz_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0808000 level 2
   ffe0fc00/c080a000 level 2
   mask=0xf0000 entries=0x10 children=0xb valid=%69 (0xb) leaf=%12 (0x2) multi-if=%56 (0x9) reuse=%44 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0808000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fe00_c0800000_3,
        iemDecodeA64_addva_za_pp_z_32,
        iemDecodeA64_ffeffc00_c0824000_3,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_mova_za2_z_w1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc00_c0864000_3,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffeffc00_c08a8000_3,
        iemDecodeA64_ffeffc00_c08a8000_3,
        iemDecodeA64_ffeffc00_c08c8000_3,
        iemDecodeA64_ffeffc00_c08c8000_3,
        iemDecodeA64_ffeffc00_c08c8000_3,
        iemDecodeA64_ffeffc00_c08c8000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x808000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00808000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSB_64_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSH_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDURSW_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0808000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFUM_P_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c0809000 level 2
   ffe0fc00/c080b000 level 2
   mask=0x1c0000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0809000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe1fc14_c0801004_3,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_luti4_mz4_ztz_1,
        iemDecodeA64_luti2_mz4_ztz_1,
        iemDecodeA64_fffcfc00_c0905000_3,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_luti4_mz4_ztz_4,
        iemDecodeA64_luti2_mz4_ztz_4,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x809000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x80b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00809000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSB_64_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSH_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDURSW_64_ldst_unscaled,
        iemDecodeA64_ffe0fc00_c0809000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFUM_P_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x80fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0080fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STLRB_SL32_ldstord,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_64_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_STLRH_SL32_ldstord,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_64_ldst_immpre,
        iemDecodeA64_ffe0fc00_80800000_2,
        iemDecodeA64_STLR_SL32_ldstord,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0800000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_ldst_immpre,
        iemDecodeA64_ffe0fc00_c0800800_2,
        iemDecodeA64_STLR_SL64_ldstord,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/80a00000 level 2
   ffe0fc00/80a00400 level 2
   ffe0fc00/80a00800 level 2
   ffe0fc00/80a00c00 level 2
   ffe0fc00/80a01000 level 2
   ffe0fc00/80a01400 level 2
   ffe0fc00/80a01800 level 2
   ffe0fc00/80a01c00 level 2
   ffe0fc00/80a02000 level 2
   ffe0fc00/80a02400 level 2
   ffe0fc00/80a02800 level 2
   ffe0fc00/80a02c00 level 2
   ffe0fc00/80a03000 level 2
   ffe0fc00/80a03400 level 2
   ffe0fc00/80a03800 level 2
   ffe0fc00/80a03c00 level 2
   ffe0fc00/80a04000 level 2
   ffe0fc00/80a04400 level 2
   ffe0fc00/80a04800 level 2
   ffe0fc00/80a04c00 level 2
   ffe0fc00/80a05000 level 2
   ffe0fc00/80a05400 level 2
   ffe0fc00/80a05800 level 2
   ffe0fc00/80a05c00 level 2
   ffe0fc00/80a06000 level 2
   ffe0fc00/80a06400 level 2
   ffe0fc00/80a06800 level 2
   ffe0fc00/80a06c00 level 2
   ffe0fc00/80a07000 level 2
   ffe0fc00/80a07400 level 2
   ffe0fc00/80a07800 level 2
   ffe0fc00/80a07c00 level 2
   ffe0fc00/80a08000 level 2
   ffe0fc00/80a08400 level 2
   ffe0fc00/80a08800 level 2
   ffe0fc00/80a08c00 level 2
   ffe0fc00/80a09000 level 2
   ffe0fc00/80a09400 level 2
   ffe0fc00/80a09800 level 2
   ffe0fc00/80a09c00 level 2
   ffe0fc00/80a0a000 level 2
   ffe0fc00/80a0a400 level 2
   ffe0fc00/80a0a800 level 2
   ffe0fc00/80a0ac00 level 2
   ffe0fc00/80a0b000 level 2
   ffe0fc00/80a0b400 level 2
   ffe0fc00/80a0b800 level 2
   ffe0fc00/80a0bc00 level 2
   ffe0fc00/80a0c000 level 2
   ffe0fc00/80a0c400 level 2
   ffe0fc00/80a0c800 level 2
   ffe0fc00/80a0cc00 level 2
   ffe0fc00/80a0d400 level 2
   ffe0fc00/80a0d800 level 2
   ffe0fc00/80a0dc00 level 2
   ffe0fc00/80a0e400 level 2
   ffe0fc00/80a0e800 level 2
   ffe0fc00/80a0ec00 level 2
   ffe0fc00/80a0f400 level 2
   ffe0fc00/80a0f800 level 2
   ffe0fc00/80a0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_80a00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x80a00000))
        return iemDecodeA64_fmopa_za32_pp_z8z8_8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001e)) == UINT32_C(0x80a00008))
        return iemDecodeA64_fmopa_za16_pp_z8z8_8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a0a00000 level 2
   ffe0fc00/a0a00400 level 2
   ffe0fc00/a0a00800 level 2
   ffe0fc00/a0a00c00 level 2
   ffe0fc00/a0a01000 level 2
   ffe0fc00/a0a01400 level 2
   ffe0fc00/a0a01800 level 2
   ffe0fc00/a0a01c00 level 2
   ffe0fc00/a0a02000 level 2
   ffe0fc00/a0a02400 level 2
   ffe0fc00/a0a02800 level 2
   ffe0fc00/a0a02c00 level 2
   ffe0fc00/a0a03000 level 2
   ffe0fc00/a0a03400 level 2
   ffe0fc00/a0a03800 level 2
   ffe0fc00/a0a03c00 level 2
   ffe0fc00/a0a04000 level 2
   ffe0fc00/a0a04400 level 2
   ffe0fc00/a0a04800 level 2
   ffe0fc00/a0a04c00 level 2
   ffe0fc00/a0a05000 level 2
   ffe0fc00/a0a05400 level 2
   ffe0fc00/a0a05800 level 2
   ffe0fc00/a0a05c00 level 2
   ffe0fc00/a0a06000 level 2
   ffe0fc00/a0a06400 level 2
   ffe0fc00/a0a06800 level 2
   ffe0fc00/a0a06c00 level 2
   ffe0fc00/a0a07000 level 2
   ffe0fc00/a0a07400 level 2
   ffe0fc00/a0a07800 level 2
   ffe0fc00/a0a07c00 level 2
   ffe0fc00/a0a08000 level 2
   ffe0fc00/a0a08400 level 2
   ffe0fc00/a0a08800 level 2
   ffe0fc00/a0a08c00 level 2
   ffe0fc00/a0a09000 level 2
   ffe0fc00/a0a09400 level 2
   ffe0fc00/a0a09800 level 2
   ffe0fc00/a0a09c00 level 2
   ffe0fc00/a0a0a000 level 2
   ffe0fc00/a0a0a400 level 2
   ffe0fc00/a0a0a800 level 2
   ffe0fc00/a0a0ac00 level 2
   ffe0fc00/a0a0b000 level 2
   ffe0fc00/a0a0b400 level 2
   ffe0fc00/a0a0b800 level 2
   ffe0fc00/a0a0bc00 level 2
   ffe0fc00/a0a0c000 level 2
   ffe0fc00/a0a0c400 level 2
   ffe0fc00/a0a0c800 level 2
   ffe0fc00/a0a0cc00 level 2
   ffe0fc00/a0a0d400 level 2
   ffe0fc00/a0a0d800 level 2
   ffe0fc00/a0a0dc00 level 2
   ffe0fc00/a0a0e400 level 2
   ffe0fc00/a0a0e800 level 2
   ffe0fc00/a0a0ec00 level 2
   ffe0fc00/a0a0f400 level 2
   ffe0fc00/a0a0f800 level 2
   ffe0fc00/a0a0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0a00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa0a00000))
        return iemDecodeA64_sumopa_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa0a00010))
        return iemDecodeA64_sumops_za_pp_zz_32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00a00000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDADDAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDADDAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDADDA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDADDA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a00400 level 1
   07e0fc00/00a01400 level 1
   07e0fc00/00a02400 level 1
   07e0fc00/00a03400 level 1
   07e0fc00/00a04400 level 1
   07e0fc00/00a05400 level 1
   07e0fc00/00a06400 level 1
   07e0fc00/00a07400 level 1
   07e0fc00/00a08400 level 1
   07e0fc00/00a09400 level 1
   07e0fc00/00a0a400 level 1
   07e0fc00/00a0b400 level 1
   07e0fc00/00a0c400 level 1
   07e0fc00/00a0d400 level 1
   07e0fc00/00a0e400 level 1
   07e0fc00/00a0f400 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRAB_64_ldst_pac,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/f8a00800 level 2
   ffe0fc00/f8a01800 level 2
   ffe0fc00/f8a02800 level 2
   ffe0fc00/f8a03800 level 2
   ffe0fc00/f8a04800 level 2
   ffe0fc00/f8a05800 level 2
   ffe0fc00/f8a06800 level 2
   ffe0fc00/f8a07800 level 2
   ffe0fc00/f8a08800 level 2
   ffe0fc00/f8a09800 level 2
   ffe0fc00/f8a0a800 level 2
   ffe0fc00/f8a0b800 level 2
   ffe0fc00/f8a0c800 level 2
   ffe0fc00/f8a0d800 level 2
   ffe0fc00/f8a0e800 level 2
   ffe0fc00/f8a0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_f8a00800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xf8a00800))
        return iemDecodeA64_PRFM_P_ldst_regoff(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xf8a00800))
        return iemDecodeA64_RPRFM_R_ldst_regoff(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xa00800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa01800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa02800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa03800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa04800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa05800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa08800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa09800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa0a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa0b800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa0c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa0d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa0e800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa0f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_64B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_64_ldst_regoff,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_ffe0fc00_f8a00800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a00c00 level 1
   07e0fc00/00a01c00 level 1
   07e0fc00/00a02c00 level 1
   07e0fc00/00a03c00 level 1
   07e0fc00/00a04c00 level 1
   07e0fc00/00a05c00 level 1
   07e0fc00/00a06c00 level 1
   07e0fc00/00a08c00 level 1
   07e0fc00/00a09c00 level 1
   07e0fc00/00a0ac00 level 1
   07e0fc00/00a0bc00 level 1
   07e0fc00/00a0cc00 level 1
   07e0fc00/00a0dc00 level 1
   07e0fc00/00a0ec00 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRAB_64W_ldst_pac,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a01000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDCLRAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDCLRAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDCLRA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDCLRA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a02000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDEORAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDEORAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDEORA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDEORA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a03000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSETAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSETAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSETA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSETA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a04000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMAXAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMAXAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMAXA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMAXA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a05000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMINAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMINAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMINA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMINA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a06000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMAXAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMAXAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMAXA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMAXA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/38a06800 level 2
   ffe0fc00/38a07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_38a06800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x38a00800))
        return iemDecodeA64_LDRSB_64B_ldst_regoff(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0ec00)) == UINT32_C(0x38a06800))
        return iemDecodeA64_LDRSB_64BL_ldst_regoff(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xa06800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xa07800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_ffe0fc00_38a06800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_64_ldst_regoff,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_ldst_regoff,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_ffe0fc00_f8a00800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a07000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMINAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMINAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMINA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMINA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xa07c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CASB_C32_comswap,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_CASH_C32_comswap,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_CAS_C32_comswap,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_CAS_C64_comswap,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRAB_64W_ldst_pac,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a08000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_SWPAB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_SWPAH_32_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_SWPA_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_SWPA_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a09000 level 1
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWCLRA_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSCLRA_64_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a0a000 level 1
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSWPA_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSSWPA_64_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a0b000 level 1
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSETA_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSSETA_64_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00a0c000 level 1
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDAPRB_32L_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDAPRH_32L_memop,
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDAPR_32L_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDAPR_64L_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/80a0d000 level 2
   dfe0fc00/80a0e000 level 2
   dfe0fc00/80a0f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_80a0d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x80a00000))
        return iemDecodeA64_fmopa_za32_pp_z8z8_8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa0a00000))
        return iemDecodeA64_sumopa_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa0a00010))
        return iemDecodeA64_sumops_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001e)) == UINT32_C(0x80a00008))
        return iemDecodeA64_fmopa_za16_pp_z8z8_8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00a0d000 level 1
   07e0fc00/00a0e000 level 1
   07e0fc00/00a0f000 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%81 (0xd) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_80a0d000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xa0fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00a0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CASLB_C32_comswap,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_CASLH_C32_comswap,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0fc00_80a00000_2,
        iemDecodeA64_CASL_C32_comswap,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0a00000_2,
        iemDecodeA64_STP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_CASL_C64_comswap,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1w_za_p_rrr,
        iemDecodeA64_STTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRAB_64W_ldst_pac,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffedfc38/c0c00000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc38_c0c00000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c00000))
        return iemDecodeA64_mova_za_p_rz_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0018)) == UINT32_C(0xc0d00000))
        return iemDecodeA64_addha_za_pp_z_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c20000))
        return iemDecodeA64_mova_z_p_rza_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c20200))
        return iemDecodeA64_movaz_z_rza_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffedfc38/c0c10000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc38_c0c10000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c10000))
        return iemDecodeA64_mova_za_p_rz_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0018)) == UINT32_C(0xc0d10000))
        return iemDecodeA64_addva_za_pp_z_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c30000))
        return iemDecodeA64_mova_z_p_rza_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c30200))
        return iemDecodeA64_movaz_z_rza_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffedfc38/c0c40000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc38_c0c40000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1c38)) == UINT32_C(0xc0c40000))
        return iemDecodeA64_mova_za2_z_d1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0c60000))
        return iemDecodeA64_mova_mz2_za_d1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0c60200))
        return iemDecodeA64_movaz_mz2_za_d1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1fe0fc38/00c00000 level 2
   mask=0xe00d0000 entries=0x40 children=0x1f valid=%48 (0x1f) leaf=%44 (0x1c) multi-if=%5 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_00c00000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_ffedfc38_c0c00000_3,
        iemDecodeA64_ffedfc38_c0c10000_3,
        iemDecodeA64_ffedfc38_c0c40000_3,
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xe00d0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000038)) /* bit 29 L 3 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffdfe38/c0c00008 level 4 */
FNIEMOP_DEF_1(iemDecodeA64_fffdfe38_c0c00008_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c00000))
        return iemDecodeA64_mova_za_p_rz_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c20000))
        return iemDecodeA64_mova_z_p_rza_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffdfe38/c0c10008 level 4 */
FNIEMOP_DEF_1(iemDecodeA64_fffdfe38_c0c10008_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c10000))
        return iemDecodeA64_mova_za_p_rz_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c30000))
        return iemDecodeA64_mova_z_p_rza_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7ff0fe38/40c00008 level 3
   mask=0x800d0000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%31 (0x5) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7ff0fe38_40c00008_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fffdfe38_c0c00008_4,
        iemDecodeA64_fffdfe38_c0c10008_4,
        iemDecodeA64_mova_mz2_za_d1,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x800d0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffdfe38/c0c00208 level 4 */
FNIEMOP_DEF_1(iemDecodeA64_fffdfe38_c0c00208_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c00000))
        return iemDecodeA64_mova_za_p_rz_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c20200))
        return iemDecodeA64_movaz_z_rza_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffdfe38/c0c10208 level 4 */
FNIEMOP_DEF_1(iemDecodeA64_fffdfe38_c0c10208_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c10000))
        return iemDecodeA64_mova_za_p_rz_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c30200))
        return iemDecodeA64_movaz_z_rza_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7ff0fe38/40c00208 level 3
   mask=0x800d0000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%31 (0x5) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7ff0fe38_40c00208_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fffdfe38_c0c00208_4,
        iemDecodeA64_fffdfe38_c0c10208_4,
        iemDecodeA64_movaz_mz2_za_d1,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x800d0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1fe0fc38/00c00008 level 2
   mask=0x60100200 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_00c00008_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmop4a_za_zz_d1x1,
        iemDecodeA64_fmop4a_za_zz_d2x1,
        iemDecodeA64_fmop4a_za_zz_d1x2,
        iemDecodeA64_fmop4a_za_zz_d2x2,
        iemDecodeA64_smop4a_za_zz_h1x1,
        iemDecodeA64_smop4a_za_zz_h2x1,
        iemDecodeA64_smop4a_za_zz_h1x2,
        iemDecodeA64_smop4a_za_zz_h2x2,
        iemDecodeA64_7ff0fe38_40c00008_3,
        iemDecodeA64_7ff0fe38_40c00208_3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x60100200 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 19) & UINT32_C(0x00000002)) /* bit 20 L 1 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000000c)) /* bit 29 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe7fc38/80c00010 level 3
   dfe7fc38/80c10010 level 3
   dfe7fc38/80c20010 level 3
   dfe7fc38/80c30010 level 3
   dfe7fc38/80c40010 level 3
   dfe7fc38/80c50010 level 3
   dfe7fc38/80c60010 level 3
   dfe7fc38/80c70010 level 3
   dfe7fc38/80c00030 level 3
   dfe7fc38/80c10030 level 3
   dfe7fc38/80c20030 level 3
   dfe7fc38/80c30030 level 3
   dfe7fc38/80c40030 level 3
   dfe7fc38/80c50030 level 3
   dfe7fc38/80c60030 level 3
   dfe7fc38/80c70030 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_dfe7fc38_80c00010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0x80c00010))
        return iemDecodeA64_fmops_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa0c00010))
        return iemDecodeA64_smops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe7fc38/c0c20010 level 3
   dfe7fc38/c0c20030 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_dfe7fc38_c0c20010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffe0c00)) == UINT32_C(0xc0ca0000))
        return iemDecodeA64_luti4_z_ztz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c20000))
        return iemDecodeA64_mova_z_p_rza_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c20200))
        return iemDecodeA64_movaz_z_rza_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe7fc38/c0c30010 level 3
   dfe7fc38/c0c30030 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_dfe7fc38_c0c30010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffe0c00)) == UINT32_C(0xc0ca0000))
        return iemDecodeA64_luti4_z_ztz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c30000))
        return iemDecodeA64_mova_z_p_rza_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c30200))
        return iemDecodeA64_movaz_z_rza_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe7fc38/c0c60010 level 3
   dfe7fc38/c0c60030 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_dfe7fc38_c0c60010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0c00)) == UINT32_C(0xc0cc0000))
        return iemDecodeA64_luti2_z_ztz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0c60000))
        return iemDecodeA64_mova_mz2_za_d1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0c60200))
        return iemDecodeA64_movaz_mz2_za_d1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1fe0fc38/00c00010 level 2
   1fe0fc38/00c00030 level 2
   mask=0xc0070000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%9 (0x3) multi-if=%34 (0xb) reuse=%22 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_00c00010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_dfe7fc38_80c00010_3,
        iemDecodeA64_dfe7fc38_80c00010_3,
        iemDecodeA64_dfe7fc38_80c00010_3,
        iemDecodeA64_dfe7fc38_80c00010_3,
        iemDecodeA64_dfe7fc38_80c00010_3,
        iemDecodeA64_dfe7fc38_80c00010_3,
        iemDecodeA64_dfe7fc38_80c00010_3,
        iemDecodeA64_dfe7fc38_80c00010_3,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_dfe7fc38_c0c20010_3,
        iemDecodeA64_dfe7fc38_c0c30010_3,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_dfe7fc38_c0c60010_3,
        iemDecodeA64_luti2_z_ztz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xc0070000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fe38/00c00018 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe38_00c00018_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0x80c00018))
        return iemDecodeA64_fmop4s_za_zz_d1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0x80d00018))
        return iemDecodeA64_fmop4s_za_zz_d1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fe38/00c00218 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe38_00c00218_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0x80c00218))
        return iemDecodeA64_fmop4s_za_zz_d2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0x80d00218))
        return iemDecodeA64_fmop4s_za_zz_d2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fe38/20c00018 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe38_20c00018_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0c00018))
        return iemDecodeA64_smop4s_za_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0d00018))
        return iemDecodeA64_smop4s_za_zz_h1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fe38/20c00218 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe38_20c00218_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0c00218))
        return iemDecodeA64_smop4s_za_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0d00218))
        return iemDecodeA64_smop4s_za_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fe38/40c00018 level 3
   mask=0x1d0000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%44 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe38_40c00018_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_z_p_rza_d,
        iemDecodeA64_mova_z_p_rza_q,
        iemDecodeA64_mova_mz2_za_d1,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001d0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000e)) /* bit 18 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fe38/40c00218 level 3
   mask=0x1d0000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%44 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe38_40c00218_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_movaz_z_rza_d,
        iemDecodeA64_movaz_z_rza_q,
        iemDecodeA64_movaz_mz2_za_d1,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001d0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000e)) /* bit 18 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1fe0fc38/00c00018 level 2
   mask=0x60000200 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%0 (0x0) multi-if=%50 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_00c00018_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_7fe0fe38_00c00018_3,
        iemDecodeA64_7fe0fe38_00c00218_3,
        iemDecodeA64_7fe0fe38_20c00018_3,
        iemDecodeA64_7fe0fe38_20c00218_3,
        iemDecodeA64_7fe0fe38_40c00018_3,
        iemDecodeA64_7fe0fe38_40c00218_3,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x60000200 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000006)) /* bit 29 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff2fc38/c0c00020 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff2fc38_c0c00020_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0c00)) == UINT32_C(0xc0cc0000))
        return iemDecodeA64_luti2_z_ztz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c00000))
        return iemDecodeA64_mova_za_p_rz_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c10000))
        return iemDecodeA64_mova_za_p_rz_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffefe38/c0c20020 level 4
   ffecfc10/c0c01010 level 3
   ffecfc10/c0c03010 level 3
   ffecfc10/c0c05010 level 3
   ffecfc10/c0c07010 level 3
   ffecfc10/c0c09010 level 3
   ffecfc10/c0c0b010 level 3
   ffecfc10/c0c0d010 level 3
   ffecfc10/c0c0f010 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fffefe38_c0c20020_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c20000))
        return iemDecodeA64_mova_z_p_rza_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c30000))
        return iemDecodeA64_mova_z_p_rza_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffefe38/c0c20220 level 4 */
FNIEMOP_DEF_1(iemDecodeA64_fffefe38_c0c20220_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c20200))
        return iemDecodeA64_movaz_z_rza_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c30200))
        return iemDecodeA64_movaz_z_rza_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff2fc38/c0c20020 level 3
   mask=0xc0200 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%75 (0x6) multi-if=%25 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_fff2fc38_c0c20020_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fffefe38_c0c20020_4,
        iemDecodeA64_fffefe38_c0c20220_4,
        iemDecodeA64_mova_mz2_za_d1,
        iemDecodeA64_movaz_mz2_za_d1,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x000c0200 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff2fc38/c0d00020 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff2fc38_c0d00020_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0018)) == UINT32_C(0xc0d00000))
        return iemDecodeA64_addha_za_pp_z_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0018)) == UINT32_C(0xc0d10000))
        return iemDecodeA64_addva_za_pp_z_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1fe0fc38/00c00020 level 2
   mask=0xe0120000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_00c00020_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_fmopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_smopa_za_pp_zz_64,
        iemDecodeA64_fff2fc38_c0c00020_3,
        iemDecodeA64_fff2fc38_c0c20020_3,
        iemDecodeA64_fff2fc38_c0d00020_3,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xe0120000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000001)) /* bit 17 L 1 -> 0 */
                        | ((uOpcode >> 19) & UINT32_C(0x00000002)) /* bit 20 L 1 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001c)) /* bit 29 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fedfc38/40c00028 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fedfc38_40c00028_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c00000))
        return iemDecodeA64_mova_za_p_rz_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c20000))
        return iemDecodeA64_mova_z_p_rza_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c20200))
        return iemDecodeA64_movaz_z_rza_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fedfc38/40c10028 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fedfc38_40c10028_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c10000))
        return iemDecodeA64_mova_za_p_rz_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c30000))
        return iemDecodeA64_mova_z_p_rza_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c30200))
        return iemDecodeA64_movaz_z_rza_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fedfc38/40c40028 level 3
   3fedfc38/00c40038 level 3
   ffeffc00/c0c62000 level 3
   ffeffc00/c0c64000 level 3
   ffeffc00/c0c66000 level 3
   ffeffc00/c0c68000 level 3
   ffeffc00/c0c6a000 level 3
   ffeffc00/c0c6c000 level 3
   ffeffc00/c0c6e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fedfc38_40c40028_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0c60000))
        return iemDecodeA64_mova_mz2_za_d1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f01)) == UINT32_C(0xc0c60200))
        return iemDecodeA64_movaz_mz2_za_d1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1fe0fc38/00c00028 level 2
   mask=0x600d0000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%9 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_00c00028_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_7fedfc38_40c00028_3,
        iemDecodeA64_7fedfc38_40c10028_3,
        iemDecodeA64_7fedfc38_40c40028_3,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_ld1d_za_p_rrr,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x600d0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000018)) /* bit 29 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fedfc38/00c00038 level 3
   ffeffc00/c0c22000 level 3
   ffeffc00/c0c24000 level 3
   ffeffc00/c0c26000 level 3
   ffeffc00/c0c28000 level 3
   ffeffc00/c0c2a000 level 3
   ffeffc00/c0c2c000 level 3
   ffeffc00/c0c2e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fedfc38_00c00038_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c20000))
        return iemDecodeA64_mova_z_p_rza_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c20200))
        return iemDecodeA64_movaz_z_rza_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fedfc38/00c10038 level 3
   ffeffc00/c0c32000 level 3
   ffeffc00/c0c34000 level 3
   ffeffc00/c0c36000 level 3
   ffeffc00/c0c38000 level 3
   ffeffc00/c0c3a000 level 3
   ffeffc00/c0c3c000 level 3
   ffeffc00/c0c3e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fedfc38_00c10038_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0200)) == UINT32_C(0xc0c30000))
        return iemDecodeA64_mova_z_p_rza_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1e00)) == UINT32_C(0xc0c30200))
        return iemDecodeA64_movaz_z_rza_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1fe0fc38/00c00038 level 2
   mask=0x200d0000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%25 (0x4) multi-if=%19 (0x3) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_00c00038_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_3fedfc38_00c00038_3,
        iemDecodeA64_3fedfc38_00c10038_3,
        iemDecodeA64_7fedfc38_40c40028_3,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x200d0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000008)) /* bit 29 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1fe0fc38/08c00000 level 2
   1fe0fc38/08c00008 level 2
   1fe0fc38/08c00010 level 2
   1fe0fc38/08c00018 level 2
   1fe0fc38/08c00020 level 2
   1fe0fc38/08c00028 level 2
   1fe0fc38/08c00030 level 2
   1fe0fc38/08c00038 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_08c00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x28c00000))
        return iemDecodeA64_LDP_32_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x68c00000))
        return iemDecodeA64_LDPSW_64_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa8c00000))
        return iemDecodeA64_LDP_64_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe8c00000))
        return iemDecodeA64_LDTP_64_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1fe0fc38/10c00000 level 2
   1fe0fc38/10c00008 level 2
   1fe0fc38/10c00010 level 2
   1fe0fc38/10c00018 level 2
   1fe0fc38/10c00020 level 2
   1fe0fc38/10c00028 level 2
   1fe0fc38/10c00030 level 2
   1fe0fc38/10c00038 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_10c00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x9f000000)) == UINT32_C(0x10000000))
        return iemDecodeA64_ADR_only_pcreladdr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0x9f000000)) == UINT32_C(0x90000000))
        return iemDecodeA64_ADRP_only_pcreladdr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1fe0fc38/18c00000 level 2
   1fe0fc38/18c00008 level 2
   1fe0fc38/18c00010 level 2
   1fe0fc38/18c00018 level 2
   1fe0fc38/18c00020 level 2
   1fe0fc38/18c00028 level 2
   1fe0fc38/18c00030 level 2
   1fe0fc38/18c00038 level 2
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1fe0fc38_18c00000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_LDURSB_32_ldst_unscaled,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_LDURSH_32_ldst_unscaled,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc00000/0x18000038
   mask=0x18000038 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%50 (0x10) reuse=%69 (0x16) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_1fe0fc38_00c00000_2,
        iemDecodeA64_1fe0fc38_00c00008_2,
        iemDecodeA64_1fe0fc38_00c00010_2,
        iemDecodeA64_1fe0fc38_00c00018_2,
        iemDecodeA64_1fe0fc38_00c00020_2,
        iemDecodeA64_1fe0fc38_00c00028_2,
        iemDecodeA64_1fe0fc38_00c00010_2,
        iemDecodeA64_1fe0fc38_00c00038_2,
        iemDecodeA64_1fe0fc38_08c00000_2,
        iemDecodeA64_1fe0fc38_08c00000_2,
        iemDecodeA64_1fe0fc38_08c00000_2,
        iemDecodeA64_1fe0fc38_08c00000_2,
        iemDecodeA64_1fe0fc38_08c00000_2,
        iemDecodeA64_1fe0fc38_08c00000_2,
        iemDecodeA64_1fe0fc38_08c00000_2,
        iemDecodeA64_1fe0fc38_08c00000_2,
        iemDecodeA64_1fe0fc38_10c00000_2,
        iemDecodeA64_1fe0fc38_10c00000_2,
        iemDecodeA64_1fe0fc38_10c00000_2,
        iemDecodeA64_1fe0fc38_10c00000_2,
        iemDecodeA64_1fe0fc38_10c00000_2,
        iemDecodeA64_1fe0fc38_10c00000_2,
        iemDecodeA64_1fe0fc38_10c00000_2,
        iemDecodeA64_1fe0fc38_10c00000_2,
        iemDecodeA64_1fe0fc38_18c00000_2,
        iemDecodeA64_1fe0fc38_18c00000_2,
        iemDecodeA64_1fe0fc38_18c00000_2,
        iemDecodeA64_1fe0fc38_18c00000_2,
        iemDecodeA64_1fe0fc38_18c00000_2,
        iemDecodeA64_1fe0fc38_18c00000_2,
        iemDecodeA64_1fe0fc38_18c00000_2,
        iemDecodeA64_1fe0fc38_18c00000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x18000038 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000018)) /* bit 27 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/80c00400 level 2
   ffe0fc00/80c00800 level 2
   ffe0fc00/80c00c00 level 2
   ffe0fc00/80c01000 level 2
   ffe0fc00/80c01400 level 2
   ffe0fc00/80c01800 level 2
   ffe0fc00/80c01c00 level 2
   ffe0fc00/80c02000 level 2
   ffe0fc00/80c02400 level 2
   ffe0fc00/80c02800 level 2
   ffe0fc00/80c02c00 level 2
   ffe0fc00/80c03000 level 2
   ffe0fc00/80c03400 level 2
   ffe0fc00/80c03800 level 2
   ffe0fc00/80c03c00 level 2
   ffe0fc00/80c04000 level 2
   ffe0fc00/80c04400 level 2
   ffe0fc00/80c04800 level 2
   ffe0fc00/80c04c00 level 2
   ffe0fc00/80c05000 level 2
   ffe0fc00/80c05400 level 2
   ffe0fc00/80c05800 level 2
   ffe0fc00/80c05c00 level 2
   ffe0fc00/80c06000 level 2
   ffe0fc00/80c06400 level 2
   ffe0fc00/80c06800 level 2
   ffe0fc00/80c06c00 level 2
   ffe0fc00/80c07000 level 2
   ffe0fc00/80c07400 level 2
   ffe0fc00/80c07800 level 2
   ffe0fc00/80c07c00 level 2
   ffe0fc00/80c08000 level 2
   ffe0fc00/80c08400 level 2
   ffe0fc00/80c08800 level 2
   ffe0fc00/80c08c00 level 2
   ffe0fc00/80c09000 level 2
   ffe0fc00/80c09400 level 2
   ffe0fc00/80c09800 level 2
   ffe0fc00/80c09c00 level 2
   ffe0fc00/80c0a000 level 2
   ffe0fc00/80c0a400 level 2
   ffe0fc00/80c0a800 level 2
   ffe0fc00/80c0ac00 level 2
   ffe0fc00/80c0b000 level 2
   ffe0fc00/80c0b400 level 2
   ffe0fc00/80c0b800 level 2
   ffe0fc00/80c0bc00 level 2
   ffe0fc00/80c0c000 level 2
   ffe0fc00/80c0c400 level 2
   ffe0fc00/80c0c800 level 2
   ffe0fc00/80c0cc00 level 2
   ffe0fc00/80c0d000 level 2
   ffe0fc00/80c0d400 level 2
   ffe0fc00/80c0d800 level 2
   ffe0fc00/80c0dc00 level 2
   ffe0fc00/80c0e000 level 2
   ffe0fc00/80c0e400 level 2
   ffe0fc00/80c0e800 level 2
   ffe0fc00/80c0ec00 level 2
   ffe0fc00/80c0f000 level 2
   ffe0fc00/80c0f400 level 2
   ffe0fc00/80c0f800 level 2
   ffe0fc00/80c0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_80c00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0x80c00000))
        return iemDecodeA64_fmopa_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0x80c00010))
        return iemDecodeA64_fmops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a0c00400 level 2
   ffe0fc00/a0c00800 level 2
   ffe0fc00/a0c00c00 level 2
   ffe0fc00/a0c01000 level 2
   ffe0fc00/a0c01400 level 2
   ffe0fc00/a0c01800 level 2
   ffe0fc00/a0c01c00 level 2
   ffe0fc00/a0c02000 level 2
   ffe0fc00/a0c02400 level 2
   ffe0fc00/a0c02800 level 2
   ffe0fc00/a0c02c00 level 2
   ffe0fc00/a0c03000 level 2
   ffe0fc00/a0c03400 level 2
   ffe0fc00/a0c03800 level 2
   ffe0fc00/a0c03c00 level 2
   ffe0fc00/a0c04000 level 2
   ffe0fc00/a0c04400 level 2
   ffe0fc00/a0c04800 level 2
   ffe0fc00/a0c04c00 level 2
   ffe0fc00/a0c05000 level 2
   ffe0fc00/a0c05400 level 2
   ffe0fc00/a0c05800 level 2
   ffe0fc00/a0c05c00 level 2
   ffe0fc00/a0c06000 level 2
   ffe0fc00/a0c06400 level 2
   ffe0fc00/a0c06800 level 2
   ffe0fc00/a0c06c00 level 2
   ffe0fc00/a0c07000 level 2
   ffe0fc00/a0c07400 level 2
   ffe0fc00/a0c07800 level 2
   ffe0fc00/a0c07c00 level 2
   ffe0fc00/a0c08000 level 2
   ffe0fc00/a0c08400 level 2
   ffe0fc00/a0c08800 level 2
   ffe0fc00/a0c08c00 level 2
   ffe0fc00/a0c09000 level 2
   ffe0fc00/a0c09400 level 2
   ffe0fc00/a0c09800 level 2
   ffe0fc00/a0c09c00 level 2
   ffe0fc00/a0c0a000 level 2
   ffe0fc00/a0c0a400 level 2
   ffe0fc00/a0c0a800 level 2
   ffe0fc00/a0c0ac00 level 2
   ffe0fc00/a0c0b000 level 2
   ffe0fc00/a0c0b400 level 2
   ffe0fc00/a0c0b800 level 2
   ffe0fc00/a0c0bc00 level 2
   ffe0fc00/a0c0c000 level 2
   ffe0fc00/a0c0c400 level 2
   ffe0fc00/a0c0c800 level 2
   ffe0fc00/a0c0cc00 level 2
   ffe0fc00/a0c0d000 level 2
   ffe0fc00/a0c0d400 level 2
   ffe0fc00/a0c0d800 level 2
   ffe0fc00/a0c0dc00 level 2
   ffe0fc00/a0c0e000 level 2
   ffe0fc00/a0c0e400 level 2
   ffe0fc00/a0c0e800 level 2
   ffe0fc00/a0c0ec00 level 2
   ffe0fc00/a0c0f000 level 2
   ffe0fc00/a0c0f400 level 2
   ffe0fc00/a0c0f800 level 2
   ffe0fc00/a0c0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0c00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa0c00000))
        return iemDecodeA64_smopa_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa0c00010))
        return iemDecodeA64_smops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc00/c0c00400 level 3
   ffe3fc10/c0c00800 level 3
   ffe3fc10/c0c00c00 level 3
   ffe3fc10/c0c01400 level 3
   ffe3fc10/c0c01800 level 3
   ffe3fc10/c0c01c00 level 3
   ffeffc00/c0c02000 level 3
   ffe7fc00/c0c02400 level 3
   ffe3fc10/c0c02800 level 3
   ffe3fc10/c0c02c00 level 3
   ffe3fc10/c0c03400 level 3
   ffe3fc10/c0c03800 level 3
   ffe3fc10/c0c03c00 level 3
   ffeffc00/c0c04000 level 3
   ffe7fc00/c0c04400 level 3
   ffe3fc10/c0c04800 level 3
   ffe3fc10/c0c04c00 level 3
   ffe3fc10/c0c05400 level 3
   ffe3fc10/c0c05800 level 3
   ffe3fc10/c0c05c00 level 3
   ffeffc00/c0c06000 level 3
   ffe7fc00/c0c06400 level 3
   ffe3fc10/c0c06800 level 3
   ffe3fc10/c0c06c00 level 3
   ffe3fc10/c0c07400 level 3
   ffe3fc10/c0c07800 level 3
   ffe3fc10/c0c07c00 level 3
   ffeffc00/c0c08000 level 3
   ffe7fc00/c0c08400 level 3
   ffe3fc10/c0c08800 level 3
   ffe3fc10/c0c08c00 level 3
   ffe3fc10/c0c09400 level 3
   ffe3fc10/c0c09800 level 3
   ffe3fc10/c0c09c00 level 3
   ffeffc00/c0c0a000 level 3
   ffe7fc00/c0c0a400 level 3
   ffe3fc10/c0c0a800 level 3
   ffe3fc10/c0c0ac00 level 3
   ffe3fc10/c0c0b400 level 3
   ffe3fc10/c0c0b800 level 3
   ffe3fc10/c0c0bc00 level 3
   ffeffc00/c0c0c000 level 3
   ffe7fc00/c0c0c400 level 3
   ffe3fc10/c0c0c800 level 3
   ffe3fc10/c0c0cc00 level 3
   ffe3fc10/c0c0d400 level 3
   ffe3fc10/c0c0d800 level 3
   ffe3fc10/c0c0dc00 level 3
   ffeffc00/c0c0e000 level 3
   ffe7fc00/c0c0e400 level 3
   ffe3fc10/c0c0e800 level 3
   ffe3fc10/c0c0ec00 level 3
   ffe3fc10/c0c0f400 level 3
   ffe3fc10/c0c0f800 level 3
   ffe3fc10/c0c0fc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc00_c0c00400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c00000))
        return iemDecodeA64_mova_za_p_rz_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0018)) == UINT32_C(0xc0d00000))
        return iemDecodeA64_addha_za_pp_z_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc00/c0c10400 level 3
   ffe3fc10/c0c10800 level 3
   ffe3fc10/c0c10c00 level 3
   ffe3fc10/c0c11400 level 3
   ffe3fc10/c0c11800 level 3
   ffe3fc10/c0c11c00 level 3
   ffeffc00/c0c12000 level 3
   ffe7fc00/c0c12400 level 3
   ffe3fc10/c0c12800 level 3
   ffe3fc10/c0c12c00 level 3
   ffe3fc10/c0c13400 level 3
   ffe3fc10/c0c13800 level 3
   ffe3fc10/c0c13c00 level 3
   ffeffc00/c0c14000 level 3
   ffe7fc00/c0c14400 level 3
   ffe3fc10/c0c14800 level 3
   ffe3fc10/c0c14c00 level 3
   ffe3fc10/c0c15400 level 3
   ffe3fc10/c0c15800 level 3
   ffe3fc10/c0c15c00 level 3
   ffeffc00/c0c16000 level 3
   ffe7fc00/c0c16400 level 3
   ffe3fc10/c0c16800 level 3
   ffe3fc10/c0c16c00 level 3
   ffe3fc10/c0c17400 level 3
   ffe3fc10/c0c17800 level 3
   ffe3fc10/c0c17c00 level 3
   ffeffc00/c0c18000 level 3
   ffe7fc00/c0c18400 level 3
   ffe3fc10/c0c18800 level 3
   ffe3fc10/c0c18c00 level 3
   ffe3fc10/c0c19400 level 3
   ffe3fc10/c0c19800 level 3
   ffe3fc10/c0c19c00 level 3
   ffeffc00/c0c1a000 level 3
   ffe7fc00/c0c1a400 level 3
   ffe3fc10/c0c1a800 level 3
   ffe3fc10/c0c1ac00 level 3
   ffe3fc10/c0c1b400 level 3
   ffe3fc10/c0c1b800 level 3
   ffe3fc10/c0c1bc00 level 3
   ffeffc00/c0c1c000 level 3
   ffe7fc00/c0c1c400 level 3
   ffe3fc10/c0c1c800 level 3
   ffe3fc10/c0c1cc00 level 3
   ffe3fc10/c0c1d400 level 3
   ffe3fc10/c0c1d800 level 3
   ffe3fc10/c0c1dc00 level 3
   ffeffc00/c0c1e000 level 3
   ffe7fc00/c0c1e400 level 3
   ffe3fc10/c0c1e800 level 3
   ffe3fc10/c0c1ec00 level 3
   ffe3fc10/c0c1f400 level 3
   ffe3fc10/c0c1f800 level 3
   ffe3fc10/c0c1fc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc00_c0c10400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0010)) == UINT32_C(0xc0c10000))
        return iemDecodeA64_mova_za_p_rz_q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0018)) == UINT32_C(0xc0d10000))
        return iemDecodeA64_addva_za_pp_z_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc00/c0c60400 level 3
   ffe7fc00/c0c62400 level 3
   ffe7fc00/c0c64400 level 3
   ffe7fc00/c0c66400 level 3
   ffe7fc00/c0c68400 level 3
   ffe7fc00/c0c6a400 level 3
   ffe7fc00/c0c6c400 level 3
   ffe7fc00/c0c6e400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc00_c0c60400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff1f03)) == UINT32_C(0xc0c60400))
        return iemDecodeA64_mova_mz4_za_d1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff1f03)) == UINT32_C(0xc0c60600))
        return iemDecodeA64_movaz_mz4_za_d1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c0c00400 level 2
   ffe0fc00/c0c02400 level 2
   ffe0fc00/c0c04400 level 2
   ffe0fc00/c0c06400 level 2
   ffe0fc00/c0c08400 level 2
   ffe0fc00/c0c0a400 level 2
   ffe0fc00/c0c0c400 level 2
   ffe0fc00/c0c0e400 level 2
   mask=0x70000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%38 (0x3) multi-if=%38 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0c00400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fc00_c0c00400_3,
        iemDecodeA64_ffe7fc00_c0c10400_3,
        iemDecodeA64_mova_z_p_rza_d,
        iemDecodeA64_mova_z_p_rza_q,
        iemDecodeA64_mova_za4_z_d1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffe7fc00_c0c60400_3,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc00400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc02400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc04400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc06400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc08400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0a400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0c400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_80c00400_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0c00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c0c00400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c0c00800 level 2
   ffe0fc00/c0c00c00 level 2
   ffe0fc00/c0c01400 level 2
   ffe0fc00/c0c01800 level 2
   ffe0fc00/c0c01c00 level 2
   ffe0fc00/c0c02800 level 2
   ffe0fc00/c0c02c00 level 2
   ffe0fc00/c0c03400 level 2
   ffe0fc00/c0c03800 level 2
   ffe0fc00/c0c03c00 level 2
   ffe0fc00/c0c04800 level 2
   ffe0fc00/c0c04c00 level 2
   ffe0fc00/c0c05400 level 2
   ffe0fc00/c0c05800 level 2
   ffe0fc00/c0c05c00 level 2
   ffe0fc00/c0c06800 level 2
   ffe0fc00/c0c06c00 level 2
   ffe0fc00/c0c07400 level 2
   ffe0fc00/c0c07800 level 2
   ffe0fc00/c0c07c00 level 2
   ffe0fc00/c0c08800 level 2
   ffe0fc00/c0c08c00 level 2
   ffe0fc00/c0c09400 level 2
   ffe0fc00/c0c09800 level 2
   ffe0fc00/c0c09c00 level 2
   ffe0fc00/c0c0a800 level 2
   ffe0fc00/c0c0ac00 level 2
   ffe0fc00/c0c0b400 level 2
   ffe0fc00/c0c0b800 level 2
   ffe0fc00/c0c0bc00 level 2
   ffe0fc00/c0c0c800 level 2
   ffe0fc00/c0c0cc00 level 2
   ffe0fc00/c0c0d400 level 2
   ffe0fc00/c0c0d800 level 2
   ffe0fc00/c0c0dc00 level 2
   ffe0fc00/c0c0e800 level 2
   ffe0fc00/c0c0ec00 level 2
   ffe0fc00/c0c0f400 level 2
   ffe0fc00/c0c0f800 level 2
   ffe0fc00/c0c0fc00 level 2
   mask=0x30010 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0c00800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fc00_c0c00400_3,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ffe7fc00_c0c10400_3,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_mova_z_p_rza_d,
        iemDecodeA64_mova_z_p_rza_d,
        iemDecodeA64_mova_z_p_rza_q,
        iemDecodeA64_mova_z_p_rza_q,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00030010 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x00000006)) /* bit 16 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc00800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc01800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc02800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc03800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc04800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc05800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc06800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc07800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc08800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc09800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0b800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0e800/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRSB_32_ldst_unpriv,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDTRSH_32_ldst_unpriv,
        iemDecodeA64_ffe0fc00_80c00400_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0c00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c0c00800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc00c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc01c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc02c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc03c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc04c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc05c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc06c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc08c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc09c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0ac00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0bc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0cc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0dc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_80c00400_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0c00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c0c00800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffecfc10/c0c01000 level 3
   ffecfc10/c0c03000 level 3
   ffecfc10/c0c05000 level 3
   ffecfc10/c0c07000 level 3
   ffecfc10/c0c09000 level 3
   ffecfc10/c0c0b000 level 3
   ffecfc10/c0c0d000 level 3
   ffecfc10/c0c0f000 level 3
   mask=0x130000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffecfc10_c0c01000_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mova_za_p_rz_d,
        iemDecodeA64_mova_za_p_rz_q,
        iemDecodeA64_mova_z_p_rza_d,
        iemDecodeA64_mova_z_p_rza_q,
        iemDecodeA64_addha_za_pp_z_64,
        iemDecodeA64_addva_za_pp_z_64,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00130000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c0c01000 level 2
   ffe0fc00/c0c03000 level 2
   ffe0fc00/c0c05000 level 2
   ffe0fc00/c0c07000 level 2
   ffe0fc00/c0c09000 level 2
   ffe0fc00/c0c0b000 level 2
   ffe0fc00/c0c0d000 level 2
   ffe0fc00/c0c0f000 level 2
   mask=0xc0010 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0c01000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffecfc10_c0c01000_3,
        iemDecodeA64_fffefe38_c0c20020_4,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x000c0010 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc01000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc03000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc05000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc07000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc09000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0b000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0d000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSH_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80c00400_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0c00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c0c01000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc01400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc03400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc05400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc07400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc09400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0b400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_32_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_32_ldst_immpost,
        iemDecodeA64_ffe0fc00_80c00400_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0c00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c0c00800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c0c02000 level 2
   ffe0fc00/c0c04000 level 2
   ffe0fc00/c0c06000 level 2
   ffe0fc00/c0c08000 level 2
   ffe0fc00/c0c0a000 level 2
   ffe0fc00/c0c0c000 level 2
   ffe0fc00/c0c0e000 level 2
   mask=0xf0000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%44 (0x7) multi-if=%31 (0x5) reuse=%31 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c0c02000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fc00_c0c00400_3,
        iemDecodeA64_ffe7fc00_c0c10400_3,
        iemDecodeA64_3fedfc38_00c00038_3,
        iemDecodeA64_3fedfc38_00c10038_3,
        iemDecodeA64_mova_za2_z_d1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_7fedfc38_40c40028_3,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti4_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
        iemDecodeA64_luti2_z_ztz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc02000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc04000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc06000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc08000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0a000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0c000/0xf8000000
   --decoder-hint1 0x7e0fc00/0xc0e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSB_32_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDURSH_32_ldst_unscaled,
        iemDecodeA64_ffe0fc00_80c00400_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0c00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c0c02000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc07c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDLARB_LR32_ldstord,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LDLARH_LR32_ldstord,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_80c00400_2,
        iemDecodeA64_LDLAR_LR32_ldstord,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0c00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c0c00800_2,
        iemDecodeA64_LDLAR_LR64_ldstord,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xc0fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00c0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDARB_LR32_ldstord,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_32_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LDARH_LR32_ldstord,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_32_ldst_immpre,
        iemDecodeA64_ffe0fc00_80c00400_2,
        iemDecodeA64_LDAR_LR32_ldstord,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0c00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c0c00800_2,
        iemDecodeA64_LDAR_LR64_ldstord,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_ld1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fe38/a0e00008 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fe38_a0e00008_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0e00008))
        return iemDecodeA64_sumop4a_za_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0f00008))
        return iemDecodeA64_sumop4a_za_zz_h1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fe38/a0e00018 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fe38_a0e00018_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0e00018))
        return iemDecodeA64_sumop4s_za_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0f00018))
        return iemDecodeA64_sumop4s_za_zz_h1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fe38/a0e00208 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fe38_a0e00208_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0e00208))
        return iemDecodeA64_sumop4a_za_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0f00208))
        return iemDecodeA64_sumop4a_za_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fe38/a0e00218 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fe38_a0e00218_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0e00218))
        return iemDecodeA64_sumop4s_za_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa0f00218))
        return iemDecodeA64_sumop4s_za_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a0e00000 level 2
   mask=0x238 entries=0x10 children=0xc valid=%75 (0xc) leaf=%50 (0x8) multi-if=%25 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a0e00000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sumopa_za_pp_zz_64,
        iemDecodeA64_ffe0fe38_a0e00008_3,
        iemDecodeA64_sumops_za_pp_zz_64,
        iemDecodeA64_ffe0fe38_a0e00018_3,
        iemDecodeA64_sumopa_za_pp_zz_64,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_sumops_za_pp_zz_64,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sumopa_za_pp_zz_64,
        iemDecodeA64_ffe0fe38_a0e00208_3,
        iemDecodeA64_sumops_za_pp_zz_64,
        iemDecodeA64_ffe0fe38_a0e00218_3,
        iemDecodeA64_sumopa_za_pp_zz_64,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_sumops_za_pp_zz_64,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00000238 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >>  6) & UINT32_C(0x00000008)) /* bit  9 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0xe00000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDADDALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDADDALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_ffe0fc00_a0e00000_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDADDAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDADDAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/80e00400 level 2
   ffe0fc00/a0e00800 level 2
   dfe0fc00/80e00c00 level 2
   ffe0fc00/a0e01000 level 2
   dfe0fc00/80e01400 level 2
   ffe0fc00/a0e01800 level 2
   dfe0fc00/80e01c00 level 2
   ffe0fc00/a0e02000 level 2
   dfe0fc00/80e02400 level 2
   ffe0fc00/a0e02800 level 2
   dfe0fc00/80e02c00 level 2
   ffe0fc00/a0e03000 level 2
   dfe0fc00/80e03400 level 2
   ffe0fc00/a0e03800 level 2
   dfe0fc00/80e03c00 level 2
   ffe0fc00/a0e04000 level 2
   dfe0fc00/80e04400 level 2
   ffe0fc00/a0e04800 level 2
   dfe0fc00/80e04c00 level 2
   ffe0fc00/a0e05000 level 2
   dfe0fc00/80e05400 level 2
   ffe0fc00/a0e05800 level 2
   dfe0fc00/80e05c00 level 2
   ffe0fc00/a0e06000 level 2
   dfe0fc00/80e06400 level 2
   ffe0fc00/a0e06800 level 2
   dfe0fc00/80e06c00 level 2
   ffe0fc00/a0e07000 level 2
   dfe0fc00/80e07400 level 2
   ffe0fc00/a0e07800 level 2
   dfe0fc00/80e07c00 level 2
   ffe0fc00/a0e08000 level 2
   dfe0fc00/80e08400 level 2
   ffe0fc00/a0e08800 level 2
   dfe0fc00/80e08c00 level 2
   ffe0fc00/a0e09000 level 2
   dfe0fc00/80e09400 level 2
   ffe0fc00/a0e09800 level 2
   dfe0fc00/80e09c00 level 2
   ffe0fc00/a0e0a000 level 2
   dfe0fc00/80e0a400 level 2
   ffe0fc00/a0e0a800 level 2
   dfe0fc00/80e0ac00 level 2
   ffe0fc00/a0e0b000 level 2
   dfe0fc00/80e0b400 level 2
   ffe0fc00/a0e0b800 level 2
   dfe0fc00/80e0bc00 level 2
   dfe0fc00/80e0c000 level 2
   dfe0fc00/80e0c400 level 2
   ffe0fc00/a0e0c800 level 2
   dfe0fc00/80e0cc00 level 2
   dfe0fc00/80e0d000 level 2
   dfe0fc00/80e0d400 level 2
   ffe0fc00/a0e0d800 level 2
   dfe0fc00/80e0dc00 level 2
   dfe0fc00/80e0e000 level 2
   dfe0fc00/80e0e400 level 2
   ffe0fc00/a0e0e800 level 2
   dfe0fc00/80e0ec00 level 2
   dfe0fc00/80e0f000 level 2
   dfe0fc00/80e0f400 level 2
   ffe0fc00/a0e0f800 level 2
   dfe0fc00/80e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_80e00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa0e00000))
        return iemDecodeA64_sumopa_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa0e00010))
        return iemDecodeA64_sumops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/d8e00400 level 2
   dfe0fc00/d8e01400 level 2
   dfe0fc00/d8e02400 level 2
   dfe0fc00/d8e03400 level 2
   dfe0fc00/d8e04400 level 2
   dfe0fc00/d8e05400 level 2
   dfe0fc00/d8e06400 level 2
   dfe0fc00/d8e07400 level 2
   dfe0fc00/d8e08400 level 2
   dfe0fc00/d8e09400 level 2
   dfe0fc00/d8e0a400 level 2
   dfe0fc00/d8e0b400 level 2
   dfe0fc00/d8e0c400 level 2
   dfe0fc00/d8e0d400 level 2
   dfe0fc00/d8e0e400 level 2
   dfe0fc00/d8e0f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_d8e00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xd8000000))
        return iemDecodeA64_PRFM_P_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa00c00)) == UINT32_C(0xf8a00400))
        return iemDecodeA64_LDRAB_64_ldst_pac(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00e00400 level 1
   07e0fc00/00e01400 level 1
   07e0fc00/00e02400 level 1
   07e0fc00/00e03400 level 1
   07e0fc00/00e04400 level 1
   07e0fc00/00e05400 level 1
   07e0fc00/00e06400 level 1
   07e0fc00/00e07400 level 1
   07e0fc00/00e08400 level 1
   07e0fc00/00e09400 level 1
   07e0fc00/00e0a400 level 1
   07e0fc00/00e0b400 level 1
   07e0fc00/00e0c400 level 1
   07e0fc00/00e0d400 level 1
   07e0fc00/00e0e400 level 1
   07e0fc00/00e0f400 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8e00400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e00800 level 1
   07e0fc00/00e01800 level 1
   07e0fc00/00e02800 level 1
   07e0fc00/00e03800 level 1
   07e0fc00/00e04800 level 1
   07e0fc00/00e05800 level 1
   07e0fc00/00e08800 level 1
   07e0fc00/00e09800 level 1
   07e0fc00/00e0a800 level 1
   07e0fc00/00e0b800 level 1
   07e0fc00/00e0c800 level 1
   07e0fc00/00e0d800 level 1
   07e0fc00/00e0e800 level 1
   07e0fc00/00e0f800 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSB_32B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/d8e00c00 level 2
   dfe0fc00/d8e01c00 level 2
   dfe0fc00/d8e02c00 level 2
   dfe0fc00/d8e03c00 level 2
   dfe0fc00/d8e04c00 level 2
   dfe0fc00/d8e05c00 level 2
   dfe0fc00/d8e06c00 level 2
   dfe0fc00/d8e07c00 level 2
   dfe0fc00/d8e08c00 level 2
   dfe0fc00/d8e09c00 level 2
   dfe0fc00/d8e0ac00 level 2
   dfe0fc00/d8e0bc00 level 2
   dfe0fc00/d8e0cc00 level 2
   dfe0fc00/d8e0dc00 level 2
   dfe0fc00/d8e0ec00 level 2
   dfe0fc00/d8e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_d8e00c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xd8000000))
        return iemDecodeA64_PRFM_P_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa00c00)) == UINT32_C(0xf8a00c00))
        return iemDecodeA64_LDRAB_64W_ldst_pac(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00e00c00 level 1
   07e0fc00/00e01c00 level 1
   07e0fc00/00e02c00 level 1
   07e0fc00/00e03c00 level 1
   07e0fc00/00e04c00 level 1
   07e0fc00/00e05c00 level 1
   07e0fc00/00e06c00 level 1
   07e0fc00/00e08c00 level 1
   07e0fc00/00e09c00 level 1
   07e0fc00/00e0ac00 level 1
   07e0fc00/00e0bc00 level 1
   07e0fc00/00e0cc00 level 1
   07e0fc00/00e0dc00 level 1
   07e0fc00/00e0ec00 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8e00c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e01000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDCLRALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDCLRALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDCLRAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDCLRAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e02000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDEORALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDEORALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDEORAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDEORAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e03000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSETALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSETALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSETAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSETAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e04000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMAXALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMAXALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMAXAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMAXAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e05000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMINALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDSMINALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMINAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDSMINAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e06000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMAXALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMAXALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMAXAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMAXAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/38e06800 level 2
   ffe0fc00/38e07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_38e06800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x38e00800))
        return iemDecodeA64_LDRSB_32B_ldst_regoff(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0ec00)) == UINT32_C(0x38e06800))
        return iemDecodeA64_LDRSB_32BL_ldst_regoff(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00e06800 level 1
   07e0fc00/00e07800 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_ffe0fc00_38e06800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDRSH_32_ldst_regoff,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e07000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMINALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDUMINALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMINAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDUMINAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/08e07c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_08e07c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x28c00000))
        return iemDecodeA64_LDP_32_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x08e07c00))
        return iemDecodeA64_CASAB_C32_comswap(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/48e07c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_48e07c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x68c00000))
        return iemDecodeA64_LDPSW_64_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x48e07c00))
        return iemDecodeA64_CASAH_C32_comswap(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/88e07c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_88e07c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa8c00000))
        return iemDecodeA64_LDP_64_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x88e07c00))
        return iemDecodeA64_CASA_C32_comswap(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/c8e07c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c8e07c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe8c00000))
        return iemDecodeA64_LDTP_64_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xc8e07c00))
        return iemDecodeA64_CASA_C64_comswap(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00e07c00 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%50 (0x8) multi-if=%38 (0x6) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_dfe0fc00_08e07c00_2,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_dfe0fc00_48e07c00_2,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_dfe0fc00_88e07c00_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8e07c00_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8e00c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e08000 level 1
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_SWPALB_32_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_SWPALH_32_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_SWPAL_32_memop,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_SWPAL_64_memop,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e09000 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWCLRAL_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSCLRAL_64_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e0a000 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSWPAL_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSSWPAL_64_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e0b000 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSETAL_64_memop,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_RCWSSETAL_64_memop,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/00e0c000 level 1
   07e0fc00/00e0d000 level 1
   07e0fc00/00e0e000 level 1
   07e0fc00/00e0f000 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%81 (0xd) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDP_32_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDPSW_64_ldstpair_post,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_LDP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_post,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_PRFM_P_loadlit,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/08e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_08e0fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x28c00000))
        return iemDecodeA64_LDP_32_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x08e0fc00))
        return iemDecodeA64_CASALB_C32_comswap(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/48e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_48e0fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x68c00000))
        return iemDecodeA64_LDPSW_64_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x48e0fc00))
        return iemDecodeA64_CASALH_C32_comswap(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/88e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_88e0fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa8c00000))
        return iemDecodeA64_LDP_64_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x88e0fc00))
        return iemDecodeA64_CASAL_C32_comswap(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/c8e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c8e0fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe8c00000))
        return iemDecodeA64_LDTP_64_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xc8e0fc00))
        return iemDecodeA64_CASAL_C64_comswap(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/00e0fc00 level 1
   mask=0xd8000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%50 (0x8) multi-if=%38 (0x6) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_00e0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_dfe0fc00_08e0fc00_2,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_32_loadlit,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_dfe0fc00_48e0fc00_2,
        iemDecodeA64_ADR_only_pcreladdr,
        iemDecodeA64_LDR_64_loadlit,
        iemDecodeA64_dfe0fc00_80e00400_2,
        iemDecodeA64_dfe0fc00_88e0fc00_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_LDRSW_64_loadlit,
        iemDecodeA64_st1d_za_p_rrr,
        iemDecodeA64_dfe0fc00_c8e0fc00_2,
        iemDecodeA64_ADRP_only_pcreladdr,
        iemDecodeA64_dfe0fc00_d8e00c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81000000 level 2
   mask=0x100218 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%100 (0x10) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81000000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfmop4a_za32_zz_h1x1,
        iemDecodeA64_fmop4a_za_zz_h1x1,
        iemDecodeA64_bfmop4s_za32_zz_h1x1,
        iemDecodeA64_fmop4s_za_zz_h1x1,
        iemDecodeA64_bfmop4a_za32_zz_h2x1,
        iemDecodeA64_fmop4a_za_zz_h2x1,
        iemDecodeA64_bfmop4s_za32_zz_h2x1,
        iemDecodeA64_fmop4s_za_zz_h2x1,
        iemDecodeA64_bfmop4a_za32_zz_h1x2,
        iemDecodeA64_fmop4a_za_zz_h1x2,
        iemDecodeA64_bfmop4s_za32_zz_h1x2,
        iemDecodeA64_fmop4s_za_zz_h1x2,
        iemDecodeA64_bfmop4a_za32_zz_h2x2,
        iemDecodeA64_fmop4a_za_zz_h2x2,
        iemDecodeA64_bfmop4s_za32_zz_h2x2,
        iemDecodeA64_fmop4s_za_zz_h2x2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100218 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >>  7) & UINT32_C(0x00000004)) /* bit  9 L 1 -> 2 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1000000 level 2
   ffe0fc00/a1000400 level 2
   ffe0fc00/a1000800 level 2
   ffe0fc00/a1000c00 level 2
   ffe0fc00/a1001000 level 2
   ffe0fc00/a1001400 level 2
   ffe0fc00/a1001800 level 2
   ffe0fc00/a1001c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1000000))
        return iemDecodeA64_ld1b_mzx_p_br_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1000008))
        return iemDecodeA64_ldnt1b_mzx_p_br_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc1c/c1100000 level 3
   fff0fc1c/c1100004 level 3
   fff0fc1c/c1100400 level 3
   fff0fc1c/c1100404 level 3
   fff0fc1c/c1100800 level 3
   fff0fc1c/c1100804 level 3
   fff0fc1c/c1100c00 level 3
   fff0fc1c/c1100c04 level 3
   fff0fc1c/c1102000 level 3
   fff0fc1c/c1102004 level 3
   fff0fc1c/c1102400 level 3
   fff0fc1c/c1102404 level 3
   fff0fc1c/c1102800 level 3
   fff0fc1c/c1102804 level 3
   fff0fc1c/c1102c00 level 3
   fff0fc1c/c1102c04 level 3
   fff0fc1c/c1104000 level 3
   fff0fc1c/c1104004 level 3
   fff0fc1c/c1104400 level 3
   fff0fc1c/c1104404 level 3
   fff0fc1c/c1104800 level 3
   fff0fc1c/c1104804 level 3
   fff0fc1c/c1104c00 level 3
   fff0fc1c/c1104c04 level 3
   fff0fc1c/c1106000 level 3
   fff0fc1c/c1106004 level 3
   fff0fc1c/c1106400 level 3
   fff0fc1c/c1106404 level 3
   fff0fc1c/c1106800 level 3
   fff0fc1c/c1106804 level 3
   fff0fc1c/c1106c00 level 3
   fff0fc1c/c1106c04 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc1c_c1100000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09038)) == UINT32_C(0xc1100000))
        return iemDecodeA64_smlall_za_zzi_s2xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09038)) == UINT32_C(0xc1100020))
        return iemDecodeA64_usmlall_za_zzi_s2xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc1c/c1100010 level 3
   fff0fc1c/c1100014 level 3
   fff0fc1c/c1100410 level 3
   fff0fc1c/c1100414 level 3
   fff0fc1c/c1100810 level 3
   fff0fc1c/c1100814 level 3
   fff0fc1c/c1100c10 level 3
   fff0fc1c/c1100c14 level 3
   fff0fc1c/c1102010 level 3
   fff0fc1c/c1102014 level 3
   fff0fc1c/c1102410 level 3
   fff0fc1c/c1102414 level 3
   fff0fc1c/c1102810 level 3
   fff0fc1c/c1102814 level 3
   fff0fc1c/c1102c10 level 3
   fff0fc1c/c1102c14 level 3
   fff0fc1c/c1104010 level 3
   fff0fc1c/c1104014 level 3
   fff0fc1c/c1104410 level 3
   fff0fc1c/c1104414 level 3
   fff0fc1c/c1104810 level 3
   fff0fc1c/c1104814 level 3
   fff0fc1c/c1104c10 level 3
   fff0fc1c/c1104c14 level 3
   fff0fc1c/c1106010 level 3
   fff0fc1c/c1106014 level 3
   fff0fc1c/c1106410 level 3
   fff0fc1c/c1106414 level 3
   fff0fc1c/c1106810 level 3
   fff0fc1c/c1106814 level 3
   fff0fc1c/c1106c10 level 3
   fff0fc1c/c1106c14 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc1c_c1100010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09038)) == UINT32_C(0xc1100010))
        return iemDecodeA64_umlall_za_zzi_s2xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09038)) == UINT32_C(0xc1100030))
        return iemDecodeA64_sumlall_za_zzi_s2xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1000000 level 2
   ffe0fc00/c1000400 level 2
   ffe0fc00/c1000800 level 2
   ffe0fc00/c1000c00 level 2
   ffe0fc00/c1002000 level 2
   ffe0fc00/c1002400 level 2
   ffe0fc00/c1002800 level 2
   ffe0fc00/c1002c00 level 2
   ffe0fc00/c1004000 level 2
   ffe0fc00/c1004400 level 2
   ffe0fc00/c1004800 level 2
   ffe0fc00/c1004c00 level 2
   ffe0fc00/c1006000 level 2
   ffe0fc00/c1006400 level 2
   ffe0fc00/c1006800 level 2
   ffe0fc00/c1006c00 level 2
   mask=0x10001c entries=0x10 children=0xe valid=%88 (0xe) leaf=%62 (0xa) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1000000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzi_s,
        iemDecodeA64_usmlall_za_zzi_s,
        iemDecodeA64_smlsll_za_zzi_s,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_umlall_za_zzi_s,
        iemDecodeA64_sumlall_za_zzi_s,
        iemDecodeA64_umlsll_za_zzi_s,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fff0fc1c_c1100000_3,
        iemDecodeA64_fff0fc1c_c1100000_3,
        iemDecodeA64_smlsll_za_zzi_s2xi,
        iemDecodeA64_smlsll_za_zzi_s2xi,
        iemDecodeA64_fff0fc1c_c1100010_3,
        iemDecodeA64_fff0fc1c_c1100010_3,
        iemDecodeA64_umlsll_za_zzi_s2xi,
        iemDecodeA64_umlsll_za_zzi_s2xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x0010001c -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000007)) /* bit  2 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1000000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01000000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81000000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1000000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_ldr_za_ri,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1000400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01000400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFP_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFP_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFP_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1000000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFP_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1000800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01000800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STILP_32SE_ldiappstilp,
        iemDecodeA64_ffe0fc00_a1000000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STILP_64SS_ldiappstilp,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1000c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01000c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1000000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_GCSSTR_64_ldst_gcs,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fc30/c1001000 level 3
   fff0fc30/c1001020 level 3
   fff0fc30/c1001400 level 3
   fff0fc30/c1001420 level 3
   fff0fc30/c1001800 level 3
   fff0fc30/c1001820 level 3
   fff0fc30/c1001c00 level 3
   fff0fc30/c1001c20 level 3
   fff0fc30/c1003000 level 3
   fff0fc30/c1003020 level 3
   fff0fc30/c1003400 level 3
   fff0fc30/c1003420 level 3
   fff0fc30/c1003800 level 3
   fff0fc30/c1003820 level 3
   fff0fc30/c1003c00 level 3
   fff0fc30/c1003c20 level 3
   fff0fc30/c1005000 level 3
   fff0fc30/c1005020 level 3
   fff0fc30/c1005400 level 3
   fff0fc30/c1005420 level 3
   fff0fc30/c1005800 level 3
   fff0fc30/c1005820 level 3
   fff0fc30/c1005c00 level 3
   fff0fc30/c1005c20 level 3
   fff0fc30/c1007000 level 3
   fff0fc30/c1007020 level 3
   fff0fc30/c1007400 level 3
   fff0fc30/c1007420 level 3
   fff0fc30/c1007800 level 3
   fff0fc30/c1007820 level 3
   fff0fc30/c1007c00 level 3
   fff0fc30/c1007c20 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc30_c1001000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000000))
        return iemDecodeA64_smlall_za_zzi_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000004))
        return iemDecodeA64_usmlall_za_zzi_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000008))
        return iemDecodeA64_smlsll_za_zzi_s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc30/c1001010 level 3
   fff0fc30/c1001030 level 3
   fff0fc30/c1001410 level 3
   fff0fc30/c1001430 level 3
   fff0fc30/c1001810 level 3
   fff0fc30/c1001830 level 3
   fff0fc30/c1001c10 level 3
   fff0fc30/c1001c30 level 3
   fff0fc30/c1003010 level 3
   fff0fc30/c1003030 level 3
   fff0fc30/c1003410 level 3
   fff0fc30/c1003430 level 3
   fff0fc30/c1003810 level 3
   fff0fc30/c1003830 level 3
   fff0fc30/c1003c10 level 3
   fff0fc30/c1003c30 level 3
   fff0fc30/c1005010 level 3
   fff0fc30/c1005030 level 3
   fff0fc30/c1005410 level 3
   fff0fc30/c1005430 level 3
   fff0fc30/c1005810 level 3
   fff0fc30/c1005830 level 3
   fff0fc30/c1005c10 level 3
   fff0fc30/c1005c30 level 3
   fff0fc30/c1007010 level 3
   fff0fc30/c1007030 level 3
   fff0fc30/c1007410 level 3
   fff0fc30/c1007430 level 3
   fff0fc30/c1007810 level 3
   fff0fc30/c1007830 level 3
   fff0fc30/c1007c10 level 3
   fff0fc30/c1007c30 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc30_c1001010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000010))
        return iemDecodeA64_umlall_za_zzi_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000014))
        return iemDecodeA64_sumlall_za_zzi_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000018))
        return iemDecodeA64_umlsll_za_zzi_s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1001000 level 2
   ffe0fc00/c1001400 level 2
   ffe0fc00/c1001800 level 2
   ffe0fc00/c1001c00 level 2
   ffe0fc00/c1003000 level 2
   ffe0fc00/c1003400 level 2
   ffe0fc00/c1003800 level 2
   ffe0fc00/c1003c00 level 2
   ffe0fc00/c1005000 level 2
   ffe0fc00/c1005400 level 2
   ffe0fc00/c1005800 level 2
   ffe0fc00/c1005c00 level 2
   ffe0fc00/c1007000 level 2
   ffe0fc00/c1007400 level 2
   ffe0fc00/c1007800 level 2
   ffe0fc00/c1007c00 level 2
   mask=0x100030 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%50 (0x4) multi-if=%50 (0x4) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1001000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff0fc30_c1001000_3,
        iemDecodeA64_fff0fc30_c1001010_3,
        iemDecodeA64_fff0fc30_c1001000_3,
        iemDecodeA64_fff0fc30_c1001010_3,
        iemDecodeA64_fmla_za_zzi_h2xi,
        iemDecodeA64_fmls_za_zzi_h2xi,
        iemDecodeA64_bfmla_za_zzi_h2xi,
        iemDecodeA64_bfmls_za_zzi_h2xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100030 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000003)) /* bit  4 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1001000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01001000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1000000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1001400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01001400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPWT_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPWT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPWT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1000000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPWT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1001800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01001800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STILP_32S_ldiappstilp,
        iemDecodeA64_ffe0fc00_a1000000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STILP_64S_ldiappstilp,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1001c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01001c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1000000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_GCSSTTR_64_ldst_gcs,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1002000 level 2
   ffe0fc00/a1002400 level 2
   ffe0fc00/a1002800 level 2
   ffe0fc00/a1002c00 level 2
   ffe0fc00/a1003000 level 2
   ffe0fc00/a1003400 level 2
   ffe0fc00/a1003800 level 2
   ffe0fc00/a1003c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1002000))
        return iemDecodeA64_ld1h_mzx_p_br_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1002008))
        return iemDecodeA64_ldnt1h_mzx_p_br_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1002000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01002000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1002000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_ldr_za_ri,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1002400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01002400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPRT_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPRT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPRT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1002000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPRT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1002800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1002c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01002800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1002000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1003000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01003000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1002000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1003400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01003400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPT_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1002000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1003800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1003c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01003800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1002000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1004000 level 2
   ffe0fc00/a1004400 level 2
   ffe0fc00/a1004800 level 2
   ffe0fc00/a1004c00 level 2
   ffe0fc00/a1005000 level 2
   ffe0fc00/a1005400 level 2
   ffe0fc00/a1005800 level 2
   ffe0fc00/a1005c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1004000))
        return iemDecodeA64_ld1w_mzx_p_br_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1004008))
        return iemDecodeA64_ldnt1w_mzx_p_br_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1004000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01004000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1004000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_ldr_za_ri,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1004400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01004400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1004000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1004800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1004c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01004800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1004000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1005000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01005000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1004000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1005400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01005400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1004000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1005800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1005c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01005800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1004000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1006000 level 2
   ffe0fc00/a1006400 level 2
   ffe0fc00/a1006800 level 2
   ffe0fc00/a1006c00 level 2
   ffe0fc00/a1007000 level 2
   ffe0fc00/a1007400 level 2
   ffe0fc00/a1007800 level 2
   ffe0fc00/a1007c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1006000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1006000))
        return iemDecodeA64_ld1d_mzx_p_br_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1006008))
        return iemDecodeA64_ldnt1d_mzx_p_br_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1006000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01006000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1006000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_ldr_za_ri,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1006400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01006400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPRTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPRTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPRTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1006000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPRTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1006800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1006c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01006800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1006000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1000000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1007000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01007000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1006000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1007400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01007400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1006000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1007800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01007800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1006000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1007c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01007c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STTXR_SR32_ldstexclr_unpriv,
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1006000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1001000_2,
        iemDecodeA64_STTXR_SR64_ldstexclr_unpriv,
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81008000 level 2
   mask=0x100218 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%100 (0x10) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81008000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_usmop4a_za_zz_b1x1,
        iemDecodeA64_umop4a_za32_zz_h1x1,
        iemDecodeA64_usmop4s_za_zz_b1x1,
        iemDecodeA64_umop4s_za32_zz_h1x1,
        iemDecodeA64_usmop4a_za_zz_b2x1,
        iemDecodeA64_umop4a_za32_zz_h2x1,
        iemDecodeA64_usmop4s_za_zz_b2x1,
        iemDecodeA64_umop4s_za32_zz_h2x1,
        iemDecodeA64_usmop4a_za_zz_b1x2,
        iemDecodeA64_umop4a_za32_zz_h1x2,
        iemDecodeA64_usmop4s_za_zz_b1x2,
        iemDecodeA64_umop4s_za32_zz_h1x2,
        iemDecodeA64_usmop4a_za_zz_b2x2,
        iemDecodeA64_umop4a_za32_zz_h2x2,
        iemDecodeA64_usmop4s_za_zz_b2x2,
        iemDecodeA64_umop4s_za32_zz_h2x2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100218 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >>  7) & UINT32_C(0x00000004)) /* bit  9 L 1 -> 2 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1008000 level 2
   ffe0fc00/a1008400 level 2
   ffe0fc00/a1008800 level 2
   ffe0fc00/a1008c00 level 2
   ffe0fc00/a1009000 level 2
   ffe0fc00/a1009400 level 2
   ffe0fc00/a1009800 level 2
   ffe0fc00/a1009c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa1008000))
        return iemDecodeA64_ld1b_mzx_p_br_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa1008008))
        return iemDecodeA64_ldnt1b_mzx_p_br_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc1c/c1108000 level 3
   fff0fc1c/c1108004 level 3
   fff0fc1c/c1108400 level 3
   fff0fc1c/c1108404 level 3
   fff0fc1c/c1108800 level 3
   fff0fc1c/c1108804 level 3
   fff0fc1c/c1108c00 level 3
   fff0fc1c/c1108c04 level 3
   fff0fc1c/c110a000 level 3
   fff0fc1c/c110a004 level 3
   fff0fc1c/c110a400 level 3
   fff0fc1c/c110a404 level 3
   fff0fc1c/c110a800 level 3
   fff0fc1c/c110a804 level 3
   fff0fc1c/c110ac00 level 3
   fff0fc1c/c110ac04 level 3
   fff0fc1c/c110c000 level 3
   fff0fc1c/c110c004 level 3
   fff0fc1c/c110c400 level 3
   fff0fc1c/c110c404 level 3
   fff0fc1c/c110c800 level 3
   fff0fc1c/c110c804 level 3
   fff0fc1c/c110cc00 level 3
   fff0fc1c/c110cc04 level 3
   fff0fc1c/c110e000 level 3
   fff0fc1c/c110e004 level 3
   fff0fc1c/c110e400 level 3
   fff0fc1c/c110e404 level 3
   fff0fc1c/c110e800 level 3
   fff0fc1c/c110e804 level 3
   fff0fc1c/c110ec00 level 3
   fff0fc1c/c110ec04 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc1c_c1108000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1108000))
        return iemDecodeA64_smlall_za_zzi_s4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1108020))
        return iemDecodeA64_usmlall_za_zzi_s4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1108040))
        return iemDecodeA64_fmlall_za32_z8z8i_4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc1c/c1108010 level 3
   fff0fc1c/c1108014 level 3
   fff0fc1c/c1108410 level 3
   fff0fc1c/c1108414 level 3
   fff0fc1c/c1108810 level 3
   fff0fc1c/c1108814 level 3
   fff0fc1c/c1108c10 level 3
   fff0fc1c/c1108c14 level 3
   fff0fc1c/c110a010 level 3
   fff0fc1c/c110a014 level 3
   fff0fc1c/c110a410 level 3
   fff0fc1c/c110a414 level 3
   fff0fc1c/c110a810 level 3
   fff0fc1c/c110a814 level 3
   fff0fc1c/c110ac10 level 3
   fff0fc1c/c110ac14 level 3
   fff0fc1c/c110c010 level 3
   fff0fc1c/c110c014 level 3
   fff0fc1c/c110c410 level 3
   fff0fc1c/c110c414 level 3
   fff0fc1c/c110c810 level 3
   fff0fc1c/c110c814 level 3
   fff0fc1c/c110cc10 level 3
   fff0fc1c/c110cc14 level 3
   fff0fc1c/c110e010 level 3
   fff0fc1c/c110e014 level 3
   fff0fc1c/c110e410 level 3
   fff0fc1c/c110e414 level 3
   fff0fc1c/c110e810 level 3
   fff0fc1c/c110e814 level 3
   fff0fc1c/c110ec10 level 3
   fff0fc1c/c110ec14 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc1c_c1108010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1108010))
        return iemDecodeA64_umlall_za_zzi_s4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1108030))
        return iemDecodeA64_sumlall_za_zzi_s4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1008000 level 2
   ffe0fc00/c1008400 level 2
   ffe0fc00/c1008800 level 2
   ffe0fc00/c1008c00 level 2
   ffe0fc00/c100a000 level 2
   ffe0fc00/c100a400 level 2
   ffe0fc00/c100a800 level 2
   ffe0fc00/c100ac00 level 2
   ffe0fc00/c100c000 level 2
   ffe0fc00/c100c400 level 2
   ffe0fc00/c100c800 level 2
   ffe0fc00/c100cc00 level 2
   ffe0fc00/c100e000 level 2
   ffe0fc00/c100e400 level 2
   ffe0fc00/c100e800 level 2
   ffe0fc00/c100ec00 level 2
   mask=0x10001c entries=0x10 children=0xe valid=%88 (0xe) leaf=%62 (0xa) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1008000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzi_s,
        iemDecodeA64_usmlall_za_zzi_s,
        iemDecodeA64_smlsll_za_zzi_s,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_umlall_za_zzi_s,
        iemDecodeA64_sumlall_za_zzi_s,
        iemDecodeA64_umlsll_za_zzi_s,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fff0fc1c_c1108000_3,
        iemDecodeA64_fff0fc1c_c1108000_3,
        iemDecodeA64_smlsll_za_zzi_s4xi,
        iemDecodeA64_smlsll_za_zzi_s4xi,
        iemDecodeA64_fff0fc1c_c1108010_3,
        iemDecodeA64_fff0fc1c_c1108010_3,
        iemDecodeA64_umlsll_za_zzi_s4xi,
        iemDecodeA64_umlsll_za_zzi_s4xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x0010001c -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000007)) /* bit  2 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1008000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01008000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81008000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1008000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_ldr_zt_br,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1008400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01008400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1008000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1008800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1008c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01008800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1008000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fc18/c1009000 level 3
   fff0fc18/c1009400 level 3
   fff0fc18/c1009800 level 3
   fff0fc18/c1009c00 level 3
   fff0fc18/c100b000 level 3
   fff0fc18/c100b400 level 3
   fff0fc18/c100b800 level 3
   fff0fc18/c100bc00 level 3
   fff0fc18/c100d000 level 3
   fff0fc18/c100d400 level 3
   fff0fc18/c100d800 level 3
   fff0fc18/c100dc00 level 3
   fff0fc18/c100f000 level 3
   fff0fc18/c100f400 level 3
   fff0fc18/c100f800 level 3
   fff0fc18/c100fc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc18_c1009000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000000))
        return iemDecodeA64_smlall_za_zzi_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000004))
        return iemDecodeA64_usmlall_za_zzi_s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc18/c1009010 level 3
   fff0fc18/c1009410 level 3
   fff0fc18/c1009810 level 3
   fff0fc18/c1009c10 level 3
   fff0fc18/c100b010 level 3
   fff0fc18/c100b410 level 3
   fff0fc18/c100b810 level 3
   fff0fc18/c100bc10 level 3
   fff0fc18/c100d010 level 3
   fff0fc18/c100d410 level 3
   fff0fc18/c100d810 level 3
   fff0fc18/c100dc10 level 3
   fff0fc18/c100f010 level 3
   fff0fc18/c100f410 level 3
   fff0fc18/c100f810 level 3
   fff0fc18/c100fc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc18_c1009010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000010))
        return iemDecodeA64_umlall_za_zzi_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0001c)) == UINT32_C(0xc1000014))
        return iemDecodeA64_sumlall_za_zzi_s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc18/c1109000 level 3
   fff0fc18/c1109008 level 3
   fff0fc18/c1109400 level 3
   fff0fc18/c1109408 level 3
   fff0fc18/c1109800 level 3
   fff0fc18/c1109808 level 3
   fff0fc18/c1109c00 level 3
   fff0fc18/c1109c08 level 3
   fff0fc18/c110b000 level 3
   fff0fc18/c110b008 level 3
   fff0fc18/c110b400 level 3
   fff0fc18/c110b408 level 3
   fff0fc18/c110b800 level 3
   fff0fc18/c110b808 level 3
   fff0fc18/c110bc00 level 3
   fff0fc18/c110bc08 level 3
   fff0fc18/c110d000 level 3
   fff0fc18/c110d008 level 3
   fff0fc18/c110d400 level 3
   fff0fc18/c110d408 level 3
   fff0fc18/c110d800 level 3
   fff0fc18/c110d808 level 3
   fff0fc18/c110dc00 level 3
   fff0fc18/c110dc08 level 3
   fff0fc18/c110f000 level 3
   fff0fc18/c110f008 level 3
   fff0fc18/c110f400 level 3
   fff0fc18/c110f408 level 3
   fff0fc18/c110f800 level 3
   fff0fc18/c110f808 level 3
   fff0fc18/c110fc00 level 3
   fff0fc18/c110fc08 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc18_c1109000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09070)) == UINT32_C(0xc1109000))
        return iemDecodeA64_fmla_za_zzi_h4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09070)) == UINT32_C(0xc1109020))
        return iemDecodeA64_bfmla_za_zzi_h4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09070)) == UINT32_C(0xc1109040))
        return iemDecodeA64_fdot_za_z8z8i_4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc18/c1109010 level 3
   fff0fc18/c1109018 level 3
   fff0fc18/c1109410 level 3
   fff0fc18/c1109418 level 3
   fff0fc18/c1109810 level 3
   fff0fc18/c1109818 level 3
   fff0fc18/c1109c10 level 3
   fff0fc18/c1109c18 level 3
   fff0fc18/c110b010 level 3
   fff0fc18/c110b018 level 3
   fff0fc18/c110b410 level 3
   fff0fc18/c110b418 level 3
   fff0fc18/c110b810 level 3
   fff0fc18/c110b818 level 3
   fff0fc18/c110bc10 level 3
   fff0fc18/c110bc18 level 3
   fff0fc18/c110d010 level 3
   fff0fc18/c110d018 level 3
   fff0fc18/c110d410 level 3
   fff0fc18/c110d418 level 3
   fff0fc18/c110d810 level 3
   fff0fc18/c110d818 level 3
   fff0fc18/c110dc10 level 3
   fff0fc18/c110dc18 level 3
   fff0fc18/c110f010 level 3
   fff0fc18/c110f018 level 3
   fff0fc18/c110f410 level 3
   fff0fc18/c110f418 level 3
   fff0fc18/c110f810 level 3
   fff0fc18/c110f818 level 3
   fff0fc18/c110fc10 level 3
   fff0fc18/c110fc18 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc18_c1109010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09070)) == UINT32_C(0xc1109010))
        return iemDecodeA64_fmls_za_zzi_h4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09070)) == UINT32_C(0xc1109030))
        return iemDecodeA64_bfmls_za_zzi_h4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1009000 level 2
   ffe0fc00/c1009400 level 2
   ffe0fc00/c1009800 level 2
   ffe0fc00/c1009c00 level 2
   ffe0fc00/c100b000 level 2
   ffe0fc00/c100b400 level 2
   ffe0fc00/c100b800 level 2
   ffe0fc00/c100bc00 level 2
   ffe0fc00/c100d000 level 2
   ffe0fc00/c100d400 level 2
   ffe0fc00/c100d800 level 2
   ffe0fc00/c100dc00 level 2
   ffe0fc00/c100f000 level 2
   ffe0fc00/c100f400 level 2
   ffe0fc00/c100f800 level 2
   ffe0fc00/c100fc00 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%25 (0x2) multi-if=%75 (0x6) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1009000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff0fc18_c1009000_3,
        iemDecodeA64_smlsll_za_zzi_s,
        iemDecodeA64_fff0fc18_c1009010_3,
        iemDecodeA64_umlsll_za_zzi_s,
        iemDecodeA64_fff0fc18_c1109000_3,
        iemDecodeA64_fff0fc18_c1109000_3,
        iemDecodeA64_fff0fc18_c1109010_3,
        iemDecodeA64_fff0fc18_c1109010_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1009000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01009000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1008000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1009400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01009400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPWTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1008000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1009800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1009c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01009800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1008000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a100a000 level 2
   ffe0fc00/a100a400 level 2
   ffe0fc00/a100a800 level 2
   ffe0fc00/a100ac00 level 2
   ffe0fc00/a100b000 level 2
   ffe0fc00/a100b400 level 2
   ffe0fc00/a100b800 level 2
   ffe0fc00/a100bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a100a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa100a000))
        return iemDecodeA64_ld1h_mzx_p_br_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa100a008))
        return iemDecodeA64_ldnt1h_mzx_p_br_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a100a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPRTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a100a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x100ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a100a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a100a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a100a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100b800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x100bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a100a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a100c000 level 2
   ffe0fc00/a100c400 level 2
   ffe0fc00/a100c800 level 2
   ffe0fc00/a100cc00 level 2
   ffe0fc00/a100d000 level 2
   ffe0fc00/a100d400 level 2
   ffe0fc00/a100d800 level 2
   ffe0fc00/a100dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a100c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa100c000))
        return iemDecodeA64_ld1w_mzx_p_br_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa100c008))
        return iemDecodeA64_ldnt1w_mzx_p_br_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a100c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a100c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x100cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a100c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a100c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPWTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a100c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x100dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a100c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a100e000 level 2
   ffe0fc00/a100e400 level 2
   ffe0fc00/a100e800 level 2
   ffe0fc00/a100ec00 level 2
   ffe0fc00/a100f000 level 2
   ffe0fc00/a100f400 level 2
   ffe0fc00/a100f800 level 2
   ffe0fc00/a100fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a100e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa100e000))
        return iemDecodeA64_ld1d_mzx_p_br_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa100e008))
        return iemDecodeA64_ldnt1d_mzx_p_br_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a100e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPRTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPRTN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPRTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a100e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPRTN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100e800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x100ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a100e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1008000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_STLURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_STLURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_STLUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a100e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STLUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFPTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFPTN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFPTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a100e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFPTN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a100e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x100fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0100fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_STLTXR_SR32_ldstexclr_unpriv,
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a100e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1009000_2,
        iemDecodeA64_STLTXR_SR64_ldstexclr_unpriv,
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81200000 level 2
   mask=0x100218 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%100 (0x10) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81200000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmop4a_za32_zz_h1x1,
        iemDecodeA64_bfmop4a_za_zz_h1x1,
        iemDecodeA64_fmop4s_za32_zz_h1x1,
        iemDecodeA64_bfmop4s_za_zz_h1x1,
        iemDecodeA64_fmop4a_za32_zz_h2x1,
        iemDecodeA64_bfmop4a_za_zz_h2x1,
        iemDecodeA64_fmop4s_za32_zz_h2x1,
        iemDecodeA64_bfmop4s_za_zz_h2x1,
        iemDecodeA64_fmop4a_za32_zz_h1x2,
        iemDecodeA64_bfmop4a_za_zz_h1x2,
        iemDecodeA64_fmop4s_za32_zz_h1x2,
        iemDecodeA64_bfmop4s_za_zz_h1x2,
        iemDecodeA64_fmop4a_za32_zz_h2x2,
        iemDecodeA64_bfmop4a_za_zz_h2x2,
        iemDecodeA64_fmop4s_za32_zz_h2x2,
        iemDecodeA64_bfmop4s_za_zz_h2x2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100218 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >>  7) & UINT32_C(0x00000004)) /* bit  9 L 1 -> 2 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1200000 level 2
   ffe0fc00/a1200400 level 2
   ffe0fc00/a1200800 level 2
   ffe0fc00/a1200c00 level 2
   ffe0fc00/a1201000 level 2
   ffe0fc00/a1201400 level 2
   ffe0fc00/a1201800 level 2
   ffe0fc00/a1201c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1200000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1200000))
        return iemDecodeA64_st1b_mzx_p_br_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1200008))
        return iemDecodeA64_stnt1b_mzx_p_br_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1200000 level 2
   ffe0fc00/c1202000 level 2
   ffe0fc00/c1204000 level 2
   ffe0fc00/c1206000 level 2
   mask=0x10001e entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1200000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzv_2x1,
        iemDecodeA64_fmlall_za32_z8z8v_2x1,
        iemDecodeA64_usmlall_za_zzv_s2x1,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_smlsll_za_zzv_2x1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlall_za_zzv_2x1,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_sumlall_za_zzv_s2x1,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_umlsll_za_zzv_2x1,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_smlall_za_zzv_4x1,
        iemDecodeA64_fmlall_za32_z8z8v_4x1,
        iemDecodeA64_usmlall_za_zzv_s4x1,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_smlsll_za_zzv_4x1,
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_umlall_za_zzv_4x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_sumlall_za_zzv_s4x1,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_umlsll_za_zzv_4x1,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x0010001e -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  1) & UINT32_C(0x0000000f)) /* bit  1 L 4 -> 0 */
                        | ((uOpcode >> 16) & UINT32_C(0x00000010)) /* bit 20 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1200000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01200000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81200000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1200000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZGM_64bulk_ldsttags,
        iemDecodeA64_str_za_ri,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1200400 level 2
   ffe0fc00/c1202400 level 2
   ffe0fc00/c1204400 level 2
   ffe0fc00/c1206400 level 2
   mask=0x10001c entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1200400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzv_1,
        iemDecodeA64_usmlall_za_zzv_s,
        iemDecodeA64_smlsll_za_zzv_1,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_umlall_za_zzv_1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_umlsll_za_zzv_1,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmlall_za32_z8z8v_1,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x0010001c -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000007)) /* bit  2 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1200400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01200400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDTADD_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDTADD_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1200000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1200800 level 2
   ffe0fc00/c1202800 level 2
   ffe0fc00/c1204800 level 2
   ffe0fc00/c1206800 level 2
   mask=0x10001c entries=0x10 children=0xa valid=%62 (0xa) leaf=%62 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1200800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_zzv_2x1,
        iemDecodeA64_fmlal_za_z8z8v_2x1,
        iemDecodeA64_fmlsl_za_zzv_2x1,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfmlal_za_zzv_2x1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_bfmlsl_za_zzv_2x1,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmlal_za_zzv_4x1,
        iemDecodeA64_fmlal_za_z8z8v_4x1,
        iemDecodeA64_fmlsl_za_zzv_4x1,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_bfmlal_za_zzv_4x1,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_bfmlsl_za_zzv_4x1,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x0010001c -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000007)) /* bit  2 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1200800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01200800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWCAS_C64_rcwcomswap,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSCAS_C64_rcwcomswap,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1200000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1200c00 level 2
   ffe0fc00/c1202c00 level 2
   ffe0fc00/c1204c00 level 2
   ffe0fc00/c1206c00 level 2
   mask=0x100018 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1200c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_zzv_1,
        iemDecodeA64_fmlsl_za_zzv_1,
        iemDecodeA64_bfmlal_za_zzv_1,
        iemDecodeA64_bfmlsl_za_zzv_1,
        iemDecodeA64_fmlal_za_z8z8v_1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1200c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01200c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWCASP_C64_rcwcomswappr,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSCASP_C64_rcwcomswappr,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1200000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1201000 level 2
   ffe0fc00/c1203000 level 2
   ffe0fc00/c1205000 level 2
   ffe0fc00/c1207000 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1201000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fdot_za_zzv_2x1,
        iemDecodeA64_fdot_za_z8z8v_2x1,
        iemDecodeA64_bfdot_za_zzv_2x1,
        iemDecodeA64_fdot_za32_z8z8v_2x1,
        iemDecodeA64_fdot_za_zzv_4x1,
        iemDecodeA64_fdot_za_z8z8v_4x1,
        iemDecodeA64_bfdot_za_zzv_4x1,
        iemDecodeA64_fdot_za32_z8z8v_4x1,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1201000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01201000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDCLRP_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1200000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1201400 level 2
   ffe0fc00/c1203400 level 2
   ffe0fc00/c1205400 level 2
   ffe0fc00/c1207400 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1201400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sdot_za_zzv_2x1,
        iemDecodeA64_usdot_za_zzv_s2x1,
        iemDecodeA64_udot_za_zzv_2x1,
        iemDecodeA64_sudot_za_zzv_s2x1,
        iemDecodeA64_sdot_za_zzv_4x1,
        iemDecodeA64_usdot_za_zzv_s4x1,
        iemDecodeA64_udot_za_zzv_4x1,
        iemDecodeA64_sudot_za_zzv_s4x1,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1201400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01201400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDTCLR_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDTCLR_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1200000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1201800 level 2
   ffe0fc00/c1203800 level 2
   ffe0fc00/c1205800 level 2
   ffe0fc00/c1207800 level 2
   ffe0fc00/c1601800 level 2
   ffe0fc00/c1603800 level 2
   ffe0fc00/c1605800 level 2
   ffe0fc00/c1607800 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1201800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmla_za_zzv_2x1,
        iemDecodeA64_fmls_za_zzv_2x1,
        iemDecodeA64_add_za_zzv_2x1,
        iemDecodeA64_sub_za_zzv_2x1,
        iemDecodeA64_fmla_za_zzv_4x1,
        iemDecodeA64_fmls_za_zzv_4x1,
        iemDecodeA64_add_za_zzv_4x1,
        iemDecodeA64_sub_za_zzv_4x1,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1201800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01201800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1200000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1201c00 level 2
   ffe0fc00/c1203c00 level 2
   ffe0fc00/c1205c00 level 2
   ffe0fc00/c1207c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1201c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1201c00))
        return iemDecodeA64_fmla_za_zzv_2x1_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1201c08))
        return iemDecodeA64_fmls_za_zzv_2x1_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1301c00))
        return iemDecodeA64_fmla_za_zzv_4x1_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1301c08))
        return iemDecodeA64_fmls_za_zzv_4x1_16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1201c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01201c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1200000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1202000 level 2
   ffe0fc00/a1202400 level 2
   ffe0fc00/a1202800 level 2
   ffe0fc00/a1202c00 level 2
   ffe0fc00/a1203000 level 2
   ffe0fc00/a1203400 level 2
   ffe0fc00/a1203800 level 2
   ffe0fc00/a1203c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1202000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1202000))
        return iemDecodeA64_st1h_mzx_p_br_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1202008))
        return iemDecodeA64_stnt1h_mzx_p_br_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1202000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01202000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1202000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_za_ri,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1202400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01202400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1202000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1202800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01202800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1202000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1202c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01202c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1202000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1203000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01203000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDSETP_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1202000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1203400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01203400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDTSET_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDTSET_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1202000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1203800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01203800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1202000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1203c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01203c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1202000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1204000 level 2
   ffe0fc00/a1204400 level 2
   ffe0fc00/a1204800 level 2
   ffe0fc00/a1204c00 level 2
   ffe0fc00/a1205000 level 2
   ffe0fc00/a1205400 level 2
   ffe0fc00/a1205800 level 2
   ffe0fc00/a1205c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1204000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1204000))
        return iemDecodeA64_st1w_mzx_p_br_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1204008))
        return iemDecodeA64_stnt1w_mzx_p_br_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1204000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01204000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1204000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_za_ri,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1204400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01204400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1204000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1204800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01204800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1204000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1204c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01204c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1204000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1205000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01205000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1204000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1205400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01205400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1204000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1205800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01205800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1204000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1205c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01205c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1204000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1206000 level 2
   ffe0fc00/a1206400 level 2
   ffe0fc00/a1206800 level 2
   ffe0fc00/a1206c00 level 2
   ffe0fc00/a1207000 level 2
   ffe0fc00/a1207400 level 2
   ffe0fc00/a1207800 level 2
   ffe0fc00/a1207c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1206000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1206000))
        return iemDecodeA64_st1d_mzx_p_br_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e008)) == UINT32_C(0xa1206008))
        return iemDecodeA64_stnt1d_mzx_p_br_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1206000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01206000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1206000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_za_ri,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1206400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01206400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1206000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1206800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01206800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1206000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1206c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01206c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1206000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1200c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1207000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01207000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1206000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1207400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01207400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1206000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1207800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01207800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1206000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1207c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01207c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1206000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81208000 level 2
   mask=0x100210 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81208000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_umop4a_za_zz_b1x1,
        iemDecodeA64_umop4s_za_zz_b1x1,
        iemDecodeA64_umop4a_za_zz_b2x1,
        iemDecodeA64_umop4s_za_zz_b2x1,
        iemDecodeA64_umop4a_za_zz_b1x2,
        iemDecodeA64_umop4s_za_zz_b1x2,
        iemDecodeA64_umop4a_za_zz_b2x2,
        iemDecodeA64_umop4s_za_zz_b2x2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100210 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1208000 level 2
   ffe0fc00/a1208400 level 2
   ffe0fc00/a1208800 level 2
   ffe0fc00/a1208c00 level 2
   ffe0fc00/a1209000 level 2
   ffe0fc00/a1209400 level 2
   ffe0fc00/a1209800 level 2
   ffe0fc00/a1209c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1208000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa1208000))
        return iemDecodeA64_st1b_mzx_p_br_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa1208008))
        return iemDecodeA64_stnt1b_mzx_p_br_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1208000 level 2
   ffe0fc00/c1208400 level 2
   ffe0fc00/c1208800 level 2
   ffe0fc00/c1208c00 level 2
   ffe0fc00/c1209000 level 2
   ffe0fc00/c1209400 level 2
   ffe0fc00/c1209800 level 2
   ffe0fc00/c1209c00 level 2
   ffe0fc00/c1608000 level 2
   ffe0fc00/c1608400 level 2
   ffe0fc00/c1608800 level 2
   ffe0fc00/c1608c00 level 2
   ffe0fc00/c1609000 level 2
   ffe0fc00/c1609400 level 2
   ffe0fc00/c1609800 level 2
   ffe0fc00/c1609c00 level 2
   dfe0fc00/c1a08000 level 2
   ffe0fc00/c1a08400 level 2
   dfe0fc00/c1a08800 level 2
   dfe0fc00/c1a08c00 level 2
   ffe0fc00/c1a09000 level 2
   dfe0fc00/c1a09400 level 2
   dfe0fc00/c1a09800 level 2
   dfe0fc00/c1a09c00 level 2
   ffe0fc00/c1e08400 level 2
   ffe0fc00/c1e09000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1208000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21e021)) == UINT32_C(0xc1208000))
        return iemDecodeA64_sel_mz_p_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23e063)) == UINT32_C(0xc1218000))
        return iemDecodeA64_sel_mz_p_zz_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1208000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01208000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_SWPP_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81208000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1208000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_zt_br,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1208400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01208400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_SWPT_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_SWPT_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1208000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1208800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1209800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01208800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1208000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1208c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1209c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01208c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1208000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1209000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01209000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWCLRP_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSCLRP_128_memop_128,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1208000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1209400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01209400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1208000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a120a000 level 2
   ffe0fc00/a120a400 level 2
   3fe0fc04/2120a800 level 2
   ffe0fc00/a120ac00 level 2
   5fe0fc04/0120b000 level 2
   ffe0fc00/a120b400 level 2
   ffe0fc00/a120bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a120a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa120a000))
        return iemDecodeA64_st1h_mzx_p_br_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa120a008))
        return iemDecodeA64_stnt1h_mzx_p_br_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0ff21/c120a100 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0ff21_c120a100_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a100))
        return iemDecodeA64_fmax_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a180))
        return iemDecodeA64_fscale_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe1)) == UINT32_C(0xc120a100))
        return iemDecodeA64_bfmax_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe1)) == UINT32_C(0xc120a180))
        return iemDecodeA64_bfscale_mz_zzv_2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0ff21/c120a101 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0ff21_c120a101_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a101))
        return iemDecodeA64_fmin_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe1)) == UINT32_C(0xc120a101))
        return iemDecodeA64_bfmin_mz_zzv_2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0ff21/c120a120 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0ff21_c120a120_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a120))
        return iemDecodeA64_fmaxnm_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe1)) == UINT32_C(0xc120a120))
        return iemDecodeA64_bfmaxnm_mz_zzv_2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0ff21/c120a121 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0ff21_c120a121_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe1)) == UINT32_C(0xc120a121))
        return iemDecodeA64_fminnm_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe1)) == UINT32_C(0xc120a121))
        return iemDecodeA64_bfminnm_mz_zzv_2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c120a000 level 2
   mask=0x321 entries=0x10 children=0xb valid=%69 (0xb) leaf=%44 (0x7) multi-if=%25 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzv_2x1,
        iemDecodeA64_umax_mz_zzv_2x1,
        iemDecodeA64_smin_mz_zzv_2x1,
        iemDecodeA64_umin_mz_zzv_2x1,
        iemDecodeA64_ffe0ff21_c120a100_3,
        iemDecodeA64_ffe0ff21_c120a101_3,
        iemDecodeA64_ffe0ff21_c120a120_3,
        iemDecodeA64_ffe0ff21_c120a121_3,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_srshl_mz_zzv_2x1,
        iemDecodeA64_urshl_mz_zzv_2x1,
        iemDecodeA64_add_mz_zzv_2x1,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00000321 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  4) & UINT32_C(0x00000002)) /* bit  5 L 1 -> 1 */
                        | ((uOpcode >>  6) & UINT32_C(0x0000000c)) /* bit  8 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWSWPP_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSSWPP_128_memop_128,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120a000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzv_2x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0ff25/0120a900 level 3
   3fe0ff25/0120a904 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0ff25_0120a900_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a900))
        return iemDecodeA64_fmax_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a980))
        return iemDecodeA64_fscale_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe3)) == UINT32_C(0xc120a900))
        return iemDecodeA64_bfmax_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe3)) == UINT32_C(0xc120a980))
        return iemDecodeA64_bfscale_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0ff25/0120a901 level 3
   3fe0ff25/0120a905 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0ff25_0120a901_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a901))
        return iemDecodeA64_fmin_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe3)) == UINT32_C(0xc120a901))
        return iemDecodeA64_bfmin_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0ff25/0120a920 level 3
   3fe0ff25/0120a924 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0ff25_0120a920_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a920))
        return iemDecodeA64_fmaxnm_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe3)) == UINT32_C(0xc120a920))
        return iemDecodeA64_bfmaxnm_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0ff25/0120a921 level 3
   3fe0ff25/0120a925 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0ff25_0120a921_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a921))
        return iemDecodeA64_fminnm_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0ffe3)) == UINT32_C(0xc120a921))
        return iemDecodeA64_bfminnm_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fc04/0120a800 level 2
   3fe0fc04/0120a804 level 2
   mask=0x321 entries=0x10 children=0xb valid=%69 (0xb) leaf=%44 (0x7) multi-if=%25 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fc04_0120a800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzv_4x1,
        iemDecodeA64_umax_mz_zzv_4x1,
        iemDecodeA64_smin_mz_zzv_4x1,
        iemDecodeA64_umin_mz_zzv_4x1,
        iemDecodeA64_3fe0ff25_0120a900_3,
        iemDecodeA64_3fe0ff25_0120a901_3,
        iemDecodeA64_3fe0ff25_0120a920_3,
        iemDecodeA64_3fe0ff25_0120a921_3,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_srshl_mz_zzv_4x1,
        iemDecodeA64_urshl_mz_zzv_4x1,
        iemDecodeA64_add_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00000321 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  4) & UINT32_C(0x00000002)) /* bit  5 L 1 -> 1 */
                        | ((uOpcode >>  6) & UINT32_C(0x0000000c)) /* bit  8 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0fc04/1120a800 level 2
   3fe0fc04/1120a804 level 2
   3fe0fc08/1120b800 level 2
   3fe0fc08/1120b808 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fc04_1120a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x11000000))
        return iemDecodeA64_ADD_32_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x51000000))
        return iemDecodeA64_SUB_32_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x91000000))
        return iemDecodeA64_ADD_64_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xd1000000))
        return iemDecodeA64_SUB_64_addsub_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fc04/2920a800 level 2
   3fe0fc04/2920a804 level 2
   3fe0fc08/2920b800 level 2
   3fe0fc08/2920b808 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fc04_2920a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x29000000))
        return iemDecodeA64_STP_32_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x69000000))
        return iemDecodeA64_STGP_64_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9000000))
        return iemDecodeA64_STP_64_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9000000))
        return iemDecodeA64_STTP_64_ldstpair_off(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fc04/3120a800 level 2
   3fe0fc04/3120a804 level 2
   3fe0fc08/3120b800 level 2
   3fe0fc08/3120b808 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fc04_3120a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x31000000))
        return iemDecodeA64_ADDS_32S_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x71000000))
        return iemDecodeA64_SUBS_32S_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xb1000000))
        return iemDecodeA64_ADDS_64S_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xf1000000))
        return iemDecodeA64_SUBS_64S_addsub_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fc04/3920a800 level 2
   3fe0fc04/3920a804 level 2
   3fe0fc08/3920b800 level 2
   3fe0fc08/3920b808 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fc04_3920a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x39000000))
        return iemDecodeA64_STRB_32_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x79000000))
        return iemDecodeA64_STRH_32_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xb9000000))
        return iemDecodeA64_STR_32_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xf9000000))
        return iemDecodeA64_STR_64_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120a800/0x38000004
   mask=0x38000004 entries=0x10 children=0xd valid=%81 (0xd) leaf=%12 (0x2) multi-if=%56 (0x9) reuse=%38 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_3fe0fc04_0120a800_2,
        iemDecodeA64_3fe0fc04_0120a800_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe0fc04_1120a800_2,
        iemDecodeA64_3fe0fc04_1120a800_2,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_ffe0fc00_a120a000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_3fe0fc04_2920a800_2,
        iemDecodeA64_3fe0fc04_2920a800_2,
        iemDecodeA64_3fe0fc04_3120a800_2,
        iemDecodeA64_3fe0fc04_3120a800_2,
        iemDecodeA64_3fe0fc04_3920a800_2,
        iemDecodeA64_3fe0fc04_3920a800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x38000004 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000001)) /* bit  2 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe0fc04/0920b000 level 2
   5fe0fc04/0920b004 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc04_0920b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x29000000))
        return iemDecodeA64_STP_32_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9000000))
        return iemDecodeA64_STP_64_ldstpair_off(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fc04/1120b000 level 2
   5fe0fc04/1120b004 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc04_1120b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x11000000))
        return iemDecodeA64_ADD_32_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x31000000))
        return iemDecodeA64_ADDS_32S_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x91000000))
        return iemDecodeA64_ADD_64_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xb1000000))
        return iemDecodeA64_ADDS_64S_addsub_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fc04/1920b000 level 2
   5fe0fc04/1920b004 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc04_1920b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x39000000))
        return iemDecodeA64_STRB_32_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xb9000000))
        return iemDecodeA64_STR_32_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1920b000))
        return iemDecodeA64_RCWSETP_128_memop_128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fd65/4120b020 level 3
   5fe0fd65/4120b024 level 3
   ffe0fde1/c160b020 level 3
   f7e0fde5/c1a0b020 level 3
   f7e0fde5/c1a0b024 level 3
   77e0fde9/41e0b020 level 3
   77e0fde9/41e0b028 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fd65_4120b020_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b020))
        return iemDecodeA64_smin_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b220))
        return iemDecodeA64_srshl_mz_zzw_2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fd65/4120b021 level 3
   5fe0fd65/4120b025 level 3
   ffe0fde1/c160b021 level 3
   f7e0fde5/c1a0b021 level 3
   f7e0fde5/c1a0b025 level 3
   77e0fde9/41e0b021 level 3
   77e0fde9/41e0b029 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fd65_4120b021_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b021))
        return iemDecodeA64_umin_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b221))
        return iemDecodeA64_urshl_mz_zzw_2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fd65/4120b100 level 3
   5fe0fd65/4120b104 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fd65_4120b100_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b100))
        return iemDecodeA64_fmax_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b180))
        return iemDecodeA64_fscale_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe1ffe1)) == UINT32_C(0xc120b100))
        return iemDecodeA64_bfmax_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe1ffe1)) == UINT32_C(0xc120b180))
        return iemDecodeA64_bfscale_mz_zzw_2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fd65/4120b101 level 3
   5fe0fd65/4120b105 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fd65_4120b101_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b101))
        return iemDecodeA64_fmin_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe1ffe1)) == UINT32_C(0xc120b101))
        return iemDecodeA64_bfmin_mz_zzw_2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fd65/4120b120 level 3
   5fe0fd65/4120b124 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fd65_4120b120_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b120))
        return iemDecodeA64_fmaxnm_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe1ffe1)) == UINT32_C(0xc120b120))
        return iemDecodeA64_bfmaxnm_mz_zzw_2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fd65/4120b121 level 3
   5fe0fd65/4120b125 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fd65_4120b121_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21ffe1)) == UINT32_C(0xc120b121))
        return iemDecodeA64_fminnm_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe1ffe1)) == UINT32_C(0xc120b121))
        return iemDecodeA64_bfminnm_mz_zzw_2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fc04/4120b000 level 2
   5fe0fc04/4120b004 level 2
   mask=0x161 entries=0x10 children=0xa valid=%62 (0xa) leaf=%25 (0x4) multi-if=%38 (0x6) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc04_4120b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzw_2x2,
        iemDecodeA64_umax_mz_zzw_2x2,
        iemDecodeA64_5fe0fd65_4120b020_3,
        iemDecodeA64_5fe0fd65_4120b021_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_5fe0fd65_4120b100_3,
        iemDecodeA64_5fe0fd65_4120b101_3,
        iemDecodeA64_5fe0fd65_4120b120_3,
        iemDecodeA64_5fe0fd65_4120b121_3,
        iemDecodeA64_famax_mz_zzw_2x2,
        iemDecodeA64_famin_mz_zzw_2x2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00000161 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  4) & UINT32_C(0x00000006)) /* bit  5 L 2 -> 1 */
                        | ((uOpcode >>  5) & UINT32_C(0x00000008)) /* bit  8 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe0fc04/4920b000 level 2
   5fe0fc04/4920b004 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc04_4920b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x69000000))
        return iemDecodeA64_STGP_64_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9000000))
        return iemDecodeA64_STTP_64_ldstpair_off(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fc04/5120b000 level 2
   5fe0fc04/5120b004 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc04_5120b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x51000000))
        return iemDecodeA64_SUB_32_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x71000000))
        return iemDecodeA64_SUBS_32S_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xd1000000))
        return iemDecodeA64_SUB_64_addsub_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xf1000000))
        return iemDecodeA64_SUBS_64S_addsub_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fc04/5920b000 level 2
   5fe0fc04/5920b004 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc04_5920b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x79000000))
        return iemDecodeA64_STRH_32_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xf9000000))
        return iemDecodeA64_STR_64_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5920b000))
        return iemDecodeA64_RCWSSETP_128_memop_128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120b000/0x58000004
   mask=0x58000004 entries=0x10 children=0xf valid=%94 (0xf) leaf=%0 (0x0) multi-if=%81 (0xd) reuse=%50 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_a120a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_5fe0fc04_0920b000_2,
        iemDecodeA64_5fe0fc04_0920b000_2,
        iemDecodeA64_5fe0fc04_1120b000_2,
        iemDecodeA64_5fe0fc04_1120b000_2,
        iemDecodeA64_5fe0fc04_1920b000_2,
        iemDecodeA64_5fe0fc04_1920b000_2,
        iemDecodeA64_5fe0fc04_4120b000_2,
        iemDecodeA64_5fe0fc04_4120b000_2,
        iemDecodeA64_5fe0fc04_4920b000_2,
        iemDecodeA64_5fe0fc04_4920b000_2,
        iemDecodeA64_5fe0fc04_5120b000_2,
        iemDecodeA64_5fe0fc04_5120b000_2,
        iemDecodeA64_5fe0fc04_5920b000_2,
        iemDecodeA64_5fe0fc04_5920b000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x58000004 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000001)) /* bit  2 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzw_2x2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0fd69/0120b820 level 3
   3fe0fd69/0120b828 level 3
   ffe0fde1/c160b820 level 3
   7fe0fde3/41a0b820 level 3
   7fe0fde3/41e0b820 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fd69_0120b820_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b820))
        return iemDecodeA64_smin_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120ba20))
        return iemDecodeA64_srshl_mz_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fd69/0120b821 level 3
   3fe0fd69/0120b829 level 3
   ffe0fde1/c160b821 level 3
   7fe0fd63/41a0b821 level 3
   7fe0fd63/41e0b821 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fd69_0120b821_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b821))
        return iemDecodeA64_umin_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120ba21))
        return iemDecodeA64_urshl_mz_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fd69/0120b900 level 3
   3fe0fd69/0120b908 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fd69_0120b900_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b900))
        return iemDecodeA64_fmax_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b980))
        return iemDecodeA64_fscale_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe3ffe3)) == UINT32_C(0xc120b900))
        return iemDecodeA64_bfmax_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe3ffe3)) == UINT32_C(0xc120b980))
        return iemDecodeA64_bfscale_mz_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fd69/0120b901 level 3
   3fe0fd69/0120b909 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fd69_0120b901_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b901))
        return iemDecodeA64_fmin_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe3ffe3)) == UINT32_C(0xc120b901))
        return iemDecodeA64_bfmin_mz_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fd69/0120b920 level 3
   3fe0fd69/0120b928 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fd69_0120b920_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b920))
        return iemDecodeA64_fmaxnm_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe3ffe3)) == UINT32_C(0xc120b920))
        return iemDecodeA64_bfmaxnm_mz_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fd69/0120b921 level 3
   3fe0fd69/0120b929 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fd69_0120b921_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff23ffe3)) == UINT32_C(0xc120b921))
        return iemDecodeA64_fminnm_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe3ffe3)) == UINT32_C(0xc120b921))
        return iemDecodeA64_bfminnm_mz_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fc08/0120b800 level 2
   3fe0fc08/0120b808 level 2
   mask=0x161 entries=0x10 children=0xa valid=%62 (0xa) leaf=%25 (0x4) multi-if=%38 (0x6) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fc08_0120b800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzw_4x4,
        iemDecodeA64_umax_mz_zzw_4x4,
        iemDecodeA64_3fe0fd69_0120b820_3,
        iemDecodeA64_3fe0fd69_0120b821_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_3fe0fd69_0120b900_3,
        iemDecodeA64_3fe0fd69_0120b901_3,
        iemDecodeA64_3fe0fd69_0120b920_3,
        iemDecodeA64_3fe0fd69_0120b921_3,
        iemDecodeA64_famax_mz_zzw_4x4,
        iemDecodeA64_famin_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00000161 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  4) & UINT32_C(0x00000006)) /* bit  5 L 2 -> 1 */
                        | ((uOpcode >>  5) & UINT32_C(0x00000008)) /* bit  8 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120b800/0x38000008
   mask=0x38000008 entries=0x10 children=0xe valid=%88 (0xe) leaf=%25 (0x4) multi-if=%50 (0x8) reuse=%56 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_3fe0fc08_0120b800_2,
        iemDecodeA64_3fe0fc08_0120b800_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe0fc04_1120a800_2,
        iemDecodeA64_3fe0fc04_1120a800_2,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_st1h_mzx_p_br_4x4,
        iemDecodeA64_stnt1h_mzx_p_br_4x4,
        iemDecodeA64_3fe0fc04_2920a800_2,
        iemDecodeA64_3fe0fc04_2920a800_2,
        iemDecodeA64_3fe0fc04_3120a800_2,
        iemDecodeA64_3fe0fc04_3120a800_2,
        iemDecodeA64_3fe0fc04_3920a800_2,
        iemDecodeA64_3fe0fc04_3920a800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x38000008 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000001)) /* bit  3 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120a000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a120c000 level 2
   ffe0fc00/a120c400 level 2
   ffe0fc00/a120c800 level 2
   ffe0fc00/a120cc00 level 2
   ffe0fc00/a120d000 level 2
   ffe0fc00/a120d400 level 2
   ffe0fc00/a120d800 level 2
   ffe0fc00/a120dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a120c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa120c000))
        return iemDecodeA64_st1w_mzx_p_br_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa120c008))
        return iemDecodeA64_stnt1w_mzx_p_br_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c120c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120c000))
        return iemDecodeA64_fclamp_mz_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc01)) == UINT32_C(0xc120c000))
        return iemDecodeA64_bfclamp_mz_zz_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120c000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120c400 level 2
   ffe0fc00/c160c400 level 2
   dfe0fc00/c1a0c400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120c400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120c400))
        return iemDecodeA64_sclamp_mz_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120c401))
        return iemDecodeA64_uclamp_mz_zz_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120c400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc03)) == UINT32_C(0xc120c800))
        return iemDecodeA64_fclamp_mz_zz_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc03)) == UINT32_C(0xc120c800))
        return iemDecodeA64_bfclamp_mz_zz_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120c800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120cc00 level 2
   ffe0fc00/c160cc00 level 2
   dfe0fc00/c1a0cc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120cc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc03)) == UINT32_C(0xc120cc00))
        return iemDecodeA64_sclamp_mz_zz_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc03)) == UINT32_C(0xc120cc01))
        return iemDecodeA64_uclamp_mz_zz_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120cc00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120d000 level 2
   ffe0fc00/c160d000 level 2
   dfe0fc00/c1a0d000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120d000))
        return iemDecodeA64_zip_mz_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120d001))
        return iemDecodeA64_uzp_mz_zz_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120d000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120d400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120d400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc01)) == UINT32_C(0xc120d400))
        return iemDecodeA64_zip_mz_zz_2q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc01)) == UINT32_C(0xc120d401))
        return iemDecodeA64_uzp_mz_zz_2q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120d400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120d800 level 2
   ffe0fc00/c160d800 level 2
   dfe0fc00/c1a0d800 level 2
   7fe0fc00/41e0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc60)) == UINT32_C(0xc120d800))
        return iemDecodeA64_sqrshr_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc60)) == UINT32_C(0xc120d820))
        return iemDecodeA64_uqrshr_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc60)) == UINT32_C(0xc120d840))
        return iemDecodeA64_sqrshru_z_mz4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120d800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120dc00 level 2
   ffe0fc00/c160dc00 level 2
   dfe0fc00/c1a0dc00 level 2
   7fe0fc00/41e0dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120dc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc60)) == UINT32_C(0xc120dc00))
        return iemDecodeA64_sqrshrn_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc60)) == UINT32_C(0xc120dc20))
        return iemDecodeA64_uqrshrn_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc60)) == UINT32_C(0xc120dc40))
        return iemDecodeA64_sqrshrun_z_mz4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a120c000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120dc00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc01/a120e000 level 2
   ffe0fc01/a120e001 level 2
   ffe0fc00/a120e400 level 2
   ffe0fc00/a120e800 level 2
   ffe0fc00/a120ec00 level 2
   ffe0fc00/a120f000 level 2
   ffe0fc00/a120f400 level 2
   ffe0fc00/a120f800 level 2
   ffe0fc00/a120fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc01_a120e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa120e000))
        return iemDecodeA64_st1d_mzx_p_br_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0xa120e008))
        return iemDecodeA64_stnt1d_mzx_p_br_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc21/c133e000 level 3
   fff7fc21/c133e001 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc21_c133e000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc133e000))
        return iemDecodeA64_sqcvt_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc133e040))
        return iemDecodeA64_sqcvtn_z_mz4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc21/c133e020 level 3
   fff7fc21/c133e021 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc21_c133e020_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc133e020))
        return iemDecodeA64_uqcvt_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc133e060))
        return iemDecodeA64_uqcvtn_z_mz4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc21/c136e000 level 3
   fff7fc01/c176e000 level 3
   fff7fc01/c1b6e000 level 3
   7ff3fc01/41f2e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc21_c136e000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc63)) == UINT32_C(0xc136e000))
        return iemDecodeA64_zip_mz_z_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffc63)) == UINT32_C(0xc136e002))
        return iemDecodeA64_uzp_mz_z_4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc21/c137e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc21_c137e000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc137e000))
        return iemDecodeA64_zip_mz_z_4q(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc63)) == UINT32_C(0xc137e002))
        return iemDecodeA64_uzp_mz_z_4q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc01/c120e000 level 2
   mask=0x170020 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%62 (0x14) multi-if=%12 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc01_c120e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fcvt_z_mz2,
        iemDecodeA64_fcvtn_z_mz2,
        iemDecodeA64_fcvtzs_mz_z_2,
        iemDecodeA64_fcvtzu_mz_z_2,
        iemDecodeA64_scvtf_mz_z_2,
        iemDecodeA64_ucvtf_mz_z_2,
        iemDecodeA64_sqcvt_z_mz2,
        iemDecodeA64_uqcvt_z_mz2,
        iemDecodeA64_fcvt_z8_mz2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_sunpk_mz_z_2,
        iemDecodeA64_sunpk_mz_z_2,
        iemDecodeA64_f1cvt_mz2_z8,
        iemDecodeA64_f1cvt_mz2_z8,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fcvtzs_mz_z_4,
        iemDecodeA64_fcvtzu_mz_z_4,
        iemDecodeA64_scvtf_mz_z_4,
        iemDecodeA64_ucvtf_mz_z_4,
        iemDecodeA64_fff7fc21_c133e000_3,
        iemDecodeA64_fff7fc21_c133e020_3,
        iemDecodeA64_fcvt_z8_mz4,
        iemDecodeA64_fcvtn_z8_mz4,
        iemDecodeA64_sunpk_mz_z_4,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_fff7fc21_c136e000_3,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_fff7fc21_c137e000_3,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x00170020 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  5) & UINT32_C(0x00000001)) /* bit  5 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x0000000e)) /* bit 16 L 3 -> 1 */
                        | ((uOpcode >> 16) & UINT32_C(0x00000010)) /* bit 20 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc01/c120e001 level 2
   mask=0x170020 entries=0x20 children=0xe valid=%44 (0xe) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc01_c120e001_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fcvt_z_mz2,
        iemDecodeA64_fcvtn_z_mz2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_sqcvt_z_mz2,
        iemDecodeA64_uqcvt_z_mz2,
        iemDecodeA64_fcvt_z8_mz2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_uunpk_mz_z_2,
        iemDecodeA64_uunpk_mz_z_2,
        iemDecodeA64_f1cvtl_mz2_z8,
        iemDecodeA64_f1cvtl_mz2_z8,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_fff7fc21_c133e000_3,
        iemDecodeA64_fff7fc21_c133e020_3,
        iemDecodeA64_fcvt_z8_mz4,
        iemDecodeA64_fcvtn_z8_mz4,
        iemDecodeA64_uunpk_mz_z_4,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x00170020 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  5) & UINT32_C(0x00000001)) /* bit  5 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x0000000e)) /* bit 16 L 3 -> 1 */
                        | ((uOpcode >> 16) & UINT32_C(0x00000010)) /* bit 20 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120e000/0xf8000001
   mask=0xf8000001 entries=0x40 children=0x24 valid=%56 (0x24) leaf=%50 (0x20) multi-if=%3 (0x2) reuse=%2 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ffe0fc01_a120e000_2,
        iemDecodeA64_ffe0fc01_a120e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc01_c120e000_2,
        iemDecodeA64_ffe0fc01_c120e001_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8000001 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21fc21)) == UINT32_C(0xc120e400))
        return iemDecodeA64_fmul_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23fc63)) == UINT32_C(0xc121e400))
        return iemDecodeA64_fmul_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe1fc21)) == UINT32_C(0xc120e400))
        return iemDecodeA64_bfmul_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe3fc63)) == UINT32_C(0xc121e400))
        return iemDecodeA64_bfmul_mz_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc01_a120e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120e400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c120e800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c120e800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21fc21)) == UINT32_C(0xc120e800))
        return iemDecodeA64_fmul_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff21fc63)) == UINT32_C(0xc121e800))
        return iemDecodeA64_fmul_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe1fc21)) == UINT32_C(0xc120e800))
        return iemDecodeA64_bfmul_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe1fc63)) == UINT32_C(0xc121e800))
        return iemDecodeA64_bfmul_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x120e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc01_a120e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120e800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0120ec00 level 1
   07e0fc00/0120fc00 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc01_a120e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0120f000 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc01_a120e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0120f400 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc01_a120e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0120f800 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0120f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_STRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_STRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc01_a120e000_2,
        iemDecodeA64_STP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_STR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_STR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81400000 level 2
   ffe0fc00/81400400 level 2
   ffe0fc00/81400800 level 2
   ffe0fc00/81400c00 level 2
   ffe0fc00/81401000 level 2
   ffe0fc00/81401400 level 2
   ffe0fc00/81401800 level 2
   ffe0fc00/81401c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81400000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x81400000))
        return iemDecodeA64_bftmopa_za32_zzzi_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00e)) == UINT32_C(0x81400008))
        return iemDecodeA64_ftmopa_za_zzzi_h2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a1400000 level 2
   ffe0fc00/a1400400 level 2
   ffe0fc00/a1400800 level 2
   ffe0fc00/a1400c00 level 2
   ffe0fc00/a1401000 level 2
   ffe0fc00/a1401400 level 2
   ffe0fc00/a1401800 level 2
   ffe0fc00/a1401c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1400000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1400000))
        return iemDecodeA64_ld1b_mzx_p_bi_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1400008))
        return iemDecodeA64_ldnt1b_mzx_p_bi_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1400000 level 2
   ffe0fc00/c1400400 level 2
   ffe0fc00/c1400800 level 2
   ffe0fc00/c1400c00 level 2
   ffe0fc00/c1402000 level 2
   ffe0fc00/c1402400 level 2
   ffe0fc00/c1402800 level 2
   ffe0fc00/c1402c00 level 2
   ffe0fc00/c1404000 level 2
   ffe0fc00/c1404400 level 2
   ffe0fc00/c1404800 level 2
   ffe0fc00/c1404c00 level 2
   ffe0fc00/c1406000 level 2
   ffe0fc00/c1406400 level 2
   ffe0fc00/c1406800 level 2
   ffe0fc00/c1406c00 level 2
   mask=0x100038 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%56 (0x9) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1400000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmla_za_zzi_s2xi,
        iemDecodeA64_fvdot_za_zzi_2xi,
        iemDecodeA64_fmls_za_zzi_s2xi,
        iemDecodeA64_bfvdot_za_zzi_2xi,
        iemDecodeA64_svdot_za32_zzi_2xi,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_uvdot_za32_zzi_2xi,
        iemDecodeA64_fdot_za32_z8z8i_2xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100038 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1400000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01400000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81400000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1400000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1400400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01400400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFM_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFM_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81400000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFM_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1400000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFM_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1400800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01400800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81400000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDIAPP_32LE_ldiappstilp,
        iemDecodeA64_ffe0fc00_a1400000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDIAPP_64LS_ldiappstilp,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1400c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01400c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81400000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1400000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1401000 level 2
   ffe0fc00/c1401400 level 2
   ffe0fc00/c1401800 level 2
   ffe0fc00/c1401c00 level 2
   ffe0fc00/c1403000 level 2
   ffe0fc00/c1403400 level 2
   ffe0fc00/c1403800 level 2
   ffe0fc00/c1403c00 level 2
   ffe0fc00/c1405000 level 2
   ffe0fc00/c1405400 level 2
   ffe0fc00/c1405800 level 2
   ffe0fc00/c1405c00 level 2
   ffe0fc00/c1407000 level 2
   ffe0fc00/c1407400 level 2
   ffe0fc00/c1407800 level 2
   ffe0fc00/c1407c00 level 2
   mask=0x100038 entries=0x10 children=0xa valid=%62 (0xa) leaf=%62 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1401000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sdot_za32_zzi_2xi,
        iemDecodeA64_fdot_za_zzi_2xi,
        iemDecodeA64_udot_za32_zzi_2xi,
        iemDecodeA64_bfdot_za_zzi_2xi,
        iemDecodeA64_sdot_za_zzi_s2xi,
        iemDecodeA64_usdot_za_zzi_s2xi,
        iemDecodeA64_udot_za_zzi_s2xi,
        iemDecodeA64_sudot_za_zzi_s2xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100038 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1401000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01401000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81400000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1400000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1401400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01401400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMWT_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMWT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81400000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMWT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1400000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMWT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1401800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01401800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81400000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDIAPP_32L_ldiappstilp,
        iemDecodeA64_ffe0fc00_a1400000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDIAPP_64L_ldiappstilp,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1401c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01401c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81400000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1400000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1402000 level 2
   ffe0fc00/a1402400 level 2
   ffe0fc00/a1402800 level 2
   ffe0fc00/a1402c00 level 2
   ffe0fc00/a1403000 level 2
   ffe0fc00/a1403400 level 2
   ffe0fc00/a1403800 level 2
   ffe0fc00/a1403c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1402000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1402000))
        return iemDecodeA64_ld1h_mzx_p_bi_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1402008))
        return iemDecodeA64_ldnt1h_mzx_p_bi_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1402000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01402000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1402000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1402400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01402400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMRT_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMRT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMRT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1402000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMRT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1402800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1402c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01402800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1402000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1403000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01403000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1402000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1403400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01403400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMT_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1402000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1403800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1403c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01403800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1402000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1404000 level 2
   ffe0fc00/a1404400 level 2
   ffe0fc00/a1404800 level 2
   ffe0fc00/a1404c00 level 2
   ffe0fc00/a1405000 level 2
   ffe0fc00/a1405400 level 2
   ffe0fc00/a1405800 level 2
   ffe0fc00/a1405c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1404000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1404000))
        return iemDecodeA64_ld1w_mzx_p_bi_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1404008))
        return iemDecodeA64_ldnt1w_mzx_p_bi_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1404000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01404000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1404000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1404400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01404400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1404000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1404800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1404c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01404800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1404000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1405000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01405000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1404000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1405400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01405400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1404000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1405800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1405c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01405800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1404000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1406000 level 2
   ffe0fc00/a1406400 level 2
   ffe0fc00/a1406800 level 2
   ffe0fc00/a1406c00 level 2
   ffe0fc00/a1407000 level 2
   ffe0fc00/a1407400 level 2
   ffe0fc00/a1407800 level 2
   ffe0fc00/a1407c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1406000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1406000))
        return iemDecodeA64_ld1d_mzx_p_bi_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1406008))
        return iemDecodeA64_ldnt1d_mzx_p_bi_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1406000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01406000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1406000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1406400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01406400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMRTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMRTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMRTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1406000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMRTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1406800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1406c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01406800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1406000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1400000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1407000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01407000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1406000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1407400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01407400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1406000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1407800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01407800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1406000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1407c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01407c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDTXR_LR32_ldstexclr_unpriv,
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1406000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1401000_2,
        iemDecodeA64_LDTXR_LR64_ldstexclr_unpriv,
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81408000 level 2
   ffe0fc00/81408400 level 2
   ffe0fc00/81408800 level 2
   ffe0fc00/81408c00 level 2
   ffe0fc00/81409000 level 2
   ffe0fc00/81409400 level 2
   ffe0fc00/81409800 level 2
   ffe0fc00/81409c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x81408000))
        return iemDecodeA64_ustmopa_za_zzzi_b2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x81408008))
        return iemDecodeA64_utmopa_za32_zzzi_h2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a1408000 level 2
   ffe0fc00/a1408400 level 2
   ffe0fc00/a1408800 level 2
   ffe0fc00/a1408c00 level 2
   ffe0fc00/a1409000 level 2
   ffe0fc00/a1409400 level 2
   ffe0fc00/a1409800 level 2
   ffe0fc00/a1409c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa1408000))
        return iemDecodeA64_ld1b_mzx_p_bi_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa1408008))
        return iemDecodeA64_ldnt1b_mzx_p_bi_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1408000 level 2
   ffe0fc00/c1408400 level 2
   ffe0fc00/c1408800 level 2
   ffe0fc00/c1408c00 level 2
   ffe0fc00/c140a000 level 2
   ffe0fc00/c140a400 level 2
   ffe0fc00/c140a800 level 2
   ffe0fc00/c140ac00 level 2
   ffe0fc00/c140c000 level 2
   ffe0fc00/c140c400 level 2
   ffe0fc00/c140c800 level 2
   ffe0fc00/c140cc00 level 2
   ffe0fc00/c140e000 level 2
   ffe0fc00/c140e400 level 2
   ffe0fc00/c140e800 level 2
   ffe0fc00/c140ec00 level 2
   mask=0x100038 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%56 (0x9) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1408000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmla_za_zzi_s4xi,
        iemDecodeA64_fdot_za32_z8z8i_4xi,
        iemDecodeA64_fmls_za_zzi_s4xi,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_svdot_za_zzi_s4xi,
        iemDecodeA64_usvdot_za_zzi_s4xi,
        iemDecodeA64_uvdot_za_zzi_s4xi,
        iemDecodeA64_suvdot_za_zzi_s4xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100038 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1408000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01408000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1408000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1408400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01408400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1408000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1408800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1408c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01408800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1408000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1409000 level 2
   ffe0fc00/c1409400 level 2
   ffe0fc00/c1409800 level 2
   ffe0fc00/c1409c00 level 2
   ffe0fc00/c140b000 level 2
   ffe0fc00/c140b400 level 2
   ffe0fc00/c140b800 level 2
   ffe0fc00/c140bc00 level 2
   ffe0fc00/c140d000 level 2
   ffe0fc00/c140d400 level 2
   ffe0fc00/c140d800 level 2
   ffe0fc00/c140dc00 level 2
   ffe0fc00/c140f000 level 2
   ffe0fc00/c140f400 level 2
   ffe0fc00/c140f800 level 2
   ffe0fc00/c140fc00 level 2
   mask=0x100078 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1409000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmlall_za32_z8z8i_1,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_sdot_za32_zzi_4xi,
        iemDecodeA64_fdot_za_zzi_4xi,
        iemDecodeA64_udot_za32_zzi_4xi,
        iemDecodeA64_bfdot_za_zzi_4xi,
        iemDecodeA64_sdot_za_zzi_s4xi,
        iemDecodeA64_usdot_za_zzi_s4xi,
        iemDecodeA64_udot_za_zzi_s4xi,
        iemDecodeA64_sudot_za_zzi_s4xi,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x00100078 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x0000000f)) /* bit  3 L 4 -> 0 */
                        | ((uOpcode >> 16) & UINT32_C(0x00000010)) /* bit 20 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1409000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01409000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1408000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1409400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01409400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMWTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1408000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1409800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1409c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01409800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81408000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1408000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a140a000 level 2
   ffe0fc00/a140a400 level 2
   ffe0fc00/a140a800 level 2
   ffe0fc00/a140ac00 level 2
   ffe0fc00/a140b000 level 2
   ffe0fc00/a140b400 level 2
   ffe0fc00/a140b800 level 2
   ffe0fc00/a140bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a140a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa140a000))
        return iemDecodeA64_ld1h_mzx_p_bi_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa140a008))
        return iemDecodeA64_ldnt1h_mzx_p_bi_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a140a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMRTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a140a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x140ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a140a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a140a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a140a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140b800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x140bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a140a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a140c000 level 2
   ffe0fc00/a140c400 level 2
   ffe0fc00/a140c800 level 2
   ffe0fc00/a140cc00 level 2
   ffe0fc00/a140d000 level 2
   ffe0fc00/a140d400 level 2
   ffe0fc00/a140d800 level 2
   ffe0fc00/a140dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a140c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa140c000))
        return iemDecodeA64_ld1w_mzx_p_bi_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa140c008))
        return iemDecodeA64_ldnt1w_mzx_p_bi_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a140c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a140c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x140cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a140c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a140c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMWTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a140c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x140dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a140c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a140e000 level 2
   ffe0fc00/a140e400 level 2
   ffe0fc00/a140e800 level 2
   ffe0fc00/a140ec00 level 2
   ffe0fc00/a140f000 level 2
   ffe0fc00/a140f400 level 2
   ffe0fc00/a140f800 level 2
   ffe0fc00/a140fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a140e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa140e000))
        return iemDecodeA64_ld1d_mzx_p_bi_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa140e008))
        return iemDecodeA64_ldnt1d_mzx_p_bi_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a140e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMRTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMRTN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMRTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a140e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMRTN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140e800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x140ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a140e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1408000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDAPURB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDAPURH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_LDAPUR_32_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a140e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDAPUR_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_CPYFMTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_CPYFMTN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_CPYFMTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a140e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_CPYFMTN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a140e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x140fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0140fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_LDATXR_LR32_ldstexclr_unpriv,
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a140e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1409000_2,
        iemDecodeA64_LDATXR_LR64_ldstexclr_unpriv,
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81600000 level 2
   ffe0fc00/81600400 level 2
   ffe0fc00/81600800 level 2
   ffe0fc00/81600c00 level 2
   ffe0fc00/81601000 level 2
   ffe0fc00/81601400 level 2
   ffe0fc00/81601800 level 2
   ffe0fc00/81601c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81600000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e00c)) == UINT32_C(0x81600000))
        return iemDecodeA64_ftmopa_za32_zzzi_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e00e)) == UINT32_C(0x81600008))
        return iemDecodeA64_bftmopa_za_zzzi_h2x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a1600000 level 2
   ffe0fc00/a1600400 level 2
   ffe0fc00/a1600800 level 2
   ffe0fc00/a1600c00 level 2
   ffe0fc00/a1601000 level 2
   ffe0fc00/a1601400 level 2
   ffe0fc00/a1601800 level 2
   ffe0fc00/a1601c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1600000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1600000))
        return iemDecodeA64_st1b_mzx_p_bi_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1600008))
        return iemDecodeA64_stnt1b_mzx_p_bi_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1600000 level 2
   ffe0fc00/c1602000 level 2
   ffe0fc00/c1604000 level 2
   ffe0fc00/c1606000 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1600000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzv_2x1,
        iemDecodeA64_smlsll_za_zzv_2x1,
        iemDecodeA64_umlall_za_zzv_2x1,
        iemDecodeA64_umlsll_za_zzv_2x1,
        iemDecodeA64_smlall_za_zzv_4x1,
        iemDecodeA64_smlsll_za_zzv_4x1,
        iemDecodeA64_umlall_za_zzv_4x1,
        iemDecodeA64_umlsll_za_zzv_4x1,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1600000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01600000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81600000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1600000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1600400 level 2
   ffe0fc00/c1602400 level 2
   ffe0fc00/c1604400 level 2
   ffe0fc00/c1606400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1600400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffb09c1c)) == UINT32_C(0xc1200400))
        return iemDecodeA64_smlall_za_zzv_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffb09c1c)) == UINT32_C(0xc1200408))
        return iemDecodeA64_smlsll_za_zzv_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffb09c1c)) == UINT32_C(0xc1200410))
        return iemDecodeA64_umlall_za_zzv_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffb09c1c)) == UINT32_C(0xc1200418))
        return iemDecodeA64_umlsll_za_zzv_1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1600400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01600400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDTADDL_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDTADDL_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81600000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1600000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1600800 level 2
   ffe0fc00/c1602800 level 2
   ffe0fc00/c1604800 level 2
   ffe0fc00/c1606800 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1600800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlal_za_zzv_2x1,
        iemDecodeA64_smlsl_za_zzv_2x1,
        iemDecodeA64_umlal_za_zzv_2x1,
        iemDecodeA64_umlsl_za_zzv_2x1,
        iemDecodeA64_smlal_za_zzv_4x1,
        iemDecodeA64_smlsl_za_zzv_4x1,
        iemDecodeA64_umlal_za_zzv_4x1,
        iemDecodeA64_umlsl_za_zzv_4x1,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1600800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01600800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWCASL_C64_rcwcomswap,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSCASL_C64_rcwcomswap,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81600000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1600000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1600c00 level 2
   ffe0fc00/c1602c00 level 2
   ffe0fc00/c1604c00 level 2
   ffe0fc00/c1606c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1600c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1600c00))
        return iemDecodeA64_smlal_za_zzv_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1600c08))
        return iemDecodeA64_smlsl_za_zzv_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1600c10))
        return iemDecodeA64_umlal_za_zzv_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1600c18))
        return iemDecodeA64_umlsl_za_zzv_1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1600c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01600c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWCASPL_C64_rcwcomswappr,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSCASPL_C64_rcwcomswappr,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81600000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1600000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1601000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01601000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDCLRPL_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81600000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1600000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1601400 level 2
   ffe0fc00/c1603400 level 2
   ffe0fc00/c1605400 level 2
   ffe0fc00/c1607400 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1601400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sdot_za_zzv_2x1,
        iemDecodeA64_sdot_za32_zzv_2x1,
        iemDecodeA64_udot_za_zzv_2x1,
        iemDecodeA64_udot_za32_zzv_2x1,
        iemDecodeA64_sdot_za_zzv_4x1,
        iemDecodeA64_sdot_za32_zzv_4x1,
        iemDecodeA64_udot_za_zzv_4x1,
        iemDecodeA64_udot_za32_zzv_4x1,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1601400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01601400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDTCLRL_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDTCLRL_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81600000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1600000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1601400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1601800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01601800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81600000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1600000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1601c00 level 2
   ffe0fc00/c1603c00 level 2
   ffe0fc00/c1605c00 level 2
   ffe0fc00/c1607c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1601c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1601c00))
        return iemDecodeA64_bfmla_za_zzv_2x1_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1601c08))
        return iemDecodeA64_bfmls_za_zzv_2x1_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1701c00))
        return iemDecodeA64_bfmla_za_zzv_4x1_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09c18)) == UINT32_C(0xc1701c08))
        return iemDecodeA64_bfmls_za_zzv_4x1_16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1601c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01601c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_ffe0fc00_81600000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1600000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1601c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1602000 level 2
   ffe0fc00/a1602400 level 2
   ffe0fc00/a1602800 level 2
   ffe0fc00/a1602c00 level 2
   ffe0fc00/a1603000 level 2
   ffe0fc00/a1603400 level 2
   ffe0fc00/a1603800 level 2
   ffe0fc00/a1603c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1602000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1602000))
        return iemDecodeA64_st1h_mzx_p_bi_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1602008))
        return iemDecodeA64_stnt1h_mzx_p_bi_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1602000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01602000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1602000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1602400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01602400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1602000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1602800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01602800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1602000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1602c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01602c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1602000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1603000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01603000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDSETPL_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1602000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1603400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01603400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_LDTSETL_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_LDTSETL_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1602000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1601400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1603800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01603800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1602000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1603c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01603c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1602000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1601c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1604000 level 2
   ffe0fc00/a1604400 level 2
   ffe0fc00/a1604800 level 2
   ffe0fc00/a1604c00 level 2
   ffe0fc00/a1605000 level 2
   ffe0fc00/a1605400 level 2
   ffe0fc00/a1605800 level 2
   ffe0fc00/a1605c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1604000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1604000))
        return iemDecodeA64_st1w_mzx_p_bi_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1604008))
        return iemDecodeA64_stnt1w_mzx_p_bi_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1604000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01604000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1604000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1604400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01604400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1604000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1604800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01604800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1604000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1604c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01604c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1604000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01605000 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01605000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1604000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1605400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01605400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1604000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1601400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1605800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01605800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1604000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1605c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01605c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1604000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1601c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1606000 level 2
   ffe0fc00/a1606400 level 2
   ffe0fc00/a1606800 level 2
   ffe0fc00/a1606c00 level 2
   ffe0fc00/a1607000 level 2
   ffe0fc00/a1607400 level 2
   ffe0fc00/a1607800 level 2
   ffe0fc00/a1607c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1606000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1606000))
        return iemDecodeA64_st1d_mzx_p_bi_2x8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e008)) == UINT32_C(0xa1606008))
        return iemDecodeA64_stnt1d_mzx_p_bi_2x8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1606000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01606000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1606000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1606400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01606400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1606000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1606800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01606800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1606000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1606c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01606c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1606000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1600c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01607000 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01607000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1606000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1607400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01607400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1606000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1601400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1607800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01607800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1606000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1201800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1607c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01607c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1606000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1601c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a1608000 level 2
   ffe0fc00/a1608400 level 2
   ffe0fc00/a1608800 level 2
   ffe0fc00/a1608c00 level 2
   ffe0fc00/a1609000 level 2
   ffe0fc00/a1609400 level 2
   ffe0fc00/a1609800 level 2
   ffe0fc00/a1609c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1608000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa1608000))
        return iemDecodeA64_st1b_mzx_p_bi_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa1608008))
        return iemDecodeA64_stnt1b_mzx_p_bi_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1608000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01608000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_SWPPL_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_utmopa_za_zzzi_b2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1608000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1608400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01608400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_SWPTL_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_SWPTL_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_utmopa_za_zzzi_b2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1608000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1608800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1609800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01608800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_utmopa_za_zzzi_b2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1608000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1608c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1609c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01608c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_utmopa_za_zzzi_b2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1608000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1609000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01609000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWCLRPL_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSCLRPL_128_memop_128,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_utmopa_za_zzzi_b2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1608000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1609400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01609400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_utmopa_za_zzzi_b2x1,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1608000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a160a000 level 2
   ffe0fc00/a160a400 level 2
   ffe0fc00/a160a800 level 2
   ffe0fc00/a160ac00 level 2
   ffe0fc00/a160b000 level 2
   ffe0fc00/a160b400 level 2
   ffe0fc00/a160b800 level 2
   ffe0fc00/a160bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a160a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa160a000))
        return iemDecodeA64_st1h_mzx_p_bi_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa160a008))
        return iemDecodeA64_stnt1h_mzx_p_bi_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c160a000 level 2
   f7e0fc40/c1a0a000 level 2
   2fe0fc18/01e0a000 level 2
   2fe0fc18/01e0a008 level 2
   2fe0fc18/01e0a010 level 2
   2fe0fc18/01e0a018 level 2
   mask=0x3a1 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c160a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzv_2x1,
        iemDecodeA64_umax_mz_zzv_2x1,
        iemDecodeA64_smin_mz_zzv_2x1,
        iemDecodeA64_umin_mz_zzv_2x1,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmax_mz_zzv_2x1,
        iemDecodeA64_fmin_mz_zzv_2x1,
        iemDecodeA64_fmaxnm_mz_zzv_2x1,
        iemDecodeA64_fminnm_mz_zzv_2x1,
        iemDecodeA64_fscale_mz_zzv_2x1,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_srshl_mz_zzv_2x1,
        iemDecodeA64_urshl_mz_zzv_2x1,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_add_mz_zzv_2x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x000003a1 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  4) & UINT32_C(0x00000002)) /* bit  5 L 1 -> 1 */
                        | ((uOpcode >>  5) & UINT32_C(0x0000001c)) /* bit  7 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWSWPPL_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSSWPPL_128_memop_128,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c160a000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzv_2x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c160a800 level 2
   f7e0fc04/c1a0a800 level 2
   f7e0fc04/c1a0a804 level 2
   5fe0fc10/41e0a810 level 2
   mask=0x3a1 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c160a800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzv_4x1,
        iemDecodeA64_umax_mz_zzv_4x1,
        iemDecodeA64_smin_mz_zzv_4x1,
        iemDecodeA64_umin_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmax_mz_zzv_4x1,
        iemDecodeA64_fmin_mz_zzv_4x1,
        iemDecodeA64_fmaxnm_mz_zzv_4x1,
        iemDecodeA64_fminnm_mz_zzv_4x1,
        iemDecodeA64_fscale_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_srshl_mz_zzv_4x1,
        iemDecodeA64_urshl_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_add_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x000003a1 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  4) & UINT32_C(0x00000002)) /* bit  5 L 1 -> 1 */
                        | ((uOpcode >>  5) & UINT32_C(0x0000001c)) /* bit  7 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160a800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c160a800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c160b000 level 2
   f7e0fc04/c1a0b000 level 2
   f7e0fc04/c1a0b004 level 2
   77e0fc08/41e0b000 level 2
   77e0fc08/41e0b008 level 2
   mask=0x1e1 entries=0x20 children=0xb valid=%34 (0xb) leaf=%28 (0x9) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c160b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzw_2x2,
        iemDecodeA64_umax_mz_zzw_2x2,
        iemDecodeA64_5fe0fd65_4120b020_3,
        iemDecodeA64_5fe0fd65_4120b021_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fmax_mz_zzw_2x2,
        iemDecodeA64_fmin_mz_zzw_2x2,
        iemDecodeA64_fmaxnm_mz_zzw_2x2,
        iemDecodeA64_fminnm_mz_zzw_2x2,
        iemDecodeA64_famax_mz_zzw_2x2,
        iemDecodeA64_famin_mz_zzw_2x2,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fscale_mz_zzw_2x2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x000001e1 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  4) & UINT32_C(0x0000001e)) /* bit  5 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_RCWSETPL_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_RCWSSETPL_128_memop_128,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c160b000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzw_2x2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c160b800 level 2
   mask=0x1e1 entries=0x20 children=0xb valid=%34 (0xb) leaf=%28 (0x9) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c160b800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzw_4x4,
        iemDecodeA64_umax_mz_zzw_4x4,
        iemDecodeA64_3fe0fd69_0120b820_3,
        iemDecodeA64_3fe0fd69_0120b821_3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fmax_mz_zzw_4x4,
        iemDecodeA64_fmin_mz_zzw_4x4,
        iemDecodeA64_fmaxnm_mz_zzw_4x4,
        iemDecodeA64_fminnm_mz_zzw_4x4,
        iemDecodeA64_famax_mz_zzw_4x4,
        iemDecodeA64_famin_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fscale_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x000001e1 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  4) & UINT32_C(0x0000001e)) /* bit  5 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c160b800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160a000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a160c000 level 2
   ffe0fc00/a160c400 level 2
   ffe0fc00/a160c800 level 2
   ffe0fc00/a160cc00 level 2
   ffe0fc00/a160d000 level 2
   ffe0fc00/a160d400 level 2
   ffe0fc00/a160d800 level 2
   ffe0fc00/a160dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a160c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa160c000))
        return iemDecodeA64_st1w_mzx_p_bi_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa160c008))
        return iemDecodeA64_stnt1w_mzx_p_bi_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_fclamp_mz_zz_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120c400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_fclamp_mz_zz_4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120cc00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120d000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0160d400 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120d800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160c000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120dc00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a160e000 level 2
   ffe0fc00/a160e400 level 2
   ffe0fc00/a160e800 level 2
   ffe0fc00/a160ec00 level 2
   ffe0fc00/a160f000 level 2
   ffe0fc00/a160f400 level 2
   ffe0fc00/a160f800 level 2
   ffe0fc00/a160fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a160e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa160e000))
        return iemDecodeA64_st1d_mzx_p_bi_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e00c)) == UINT32_C(0xa160e008))
        return iemDecodeA64_stnt1d_mzx_p_bi_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc01/c160e000 level 3
   fff7fc01/c160e001 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc01_c160e000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc160e000))
        return iemDecodeA64_bfcvt_z_mz2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0xc160e020))
        return iemDecodeA64_bfcvtn_z_mz2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc01/c173e000 level 3
   fff7fc01/c173e001 level 3
   7ff3fc01/41f3e000 level 3
   7ff3fc01/41f3e001 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc01_c173e000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc173e000))
        return iemDecodeA64_sqcvtu_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc173e040))
        return iemDecodeA64_sqcvtun_z_mz4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c160e000 level 2
   mask=0x170001 entries=0x20 children=0xf valid=%47 (0xf) leaf=%31 (0xa) multi-if=%16 (0x5) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c160e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff7fc01_c160e000_3,
        iemDecodeA64_fff7fc01_c160e000_3,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_sqcvtu_z_mz2,
        iemDecodeA64_sqcvtu_z_mz2,
        iemDecodeA64_bfcvt_z8_mz2,
        iemDecodeA64_bfcvt_z8_mz2,
        iemDecodeA64_sunpk_mz_z_2,
        iemDecodeA64_uunpk_mz_z_2,
        iemDecodeA64_bf1cvt_mz2_z8,
        iemDecodeA64_bf1cvtl_mz2_z8,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_fff7fc01_c173e000_3,
        iemDecodeA64_fff7fc01_c173e000_3,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_sunpk_mz_z_4,
        iemDecodeA64_uunpk_mz_z_4,
        iemDecodeA64_fff7fc21_c136e000_3,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x00170001 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x0000000e)) /* bit 16 L 3 -> 1 */
                        | ((uOpcode >> 16) & UINT32_C(0x00000010)) /* bit 20 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c160e000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c160e400 level 2
   dfe0fc00/c1a0e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c160e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21fc21)) == UINT32_C(0xc120e400))
        return iemDecodeA64_fmul_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23fc63)) == UINT32_C(0xc121e400))
        return iemDecodeA64_fmul_mz_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c160e400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c160e800 level 2
   dfe0fc00/c1a0e800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c160e800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21fc21)) == UINT32_C(0xc120e800))
        return iemDecodeA64_fmul_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff21fc63)) == UINT32_C(0xc121e800))
        return iemDecodeA64_fmul_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x160e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c160e800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0160ec00 level 1
   07e0fc00/0160fc00 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0160f000 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_LDG_64Loffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0160f400 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0160f800 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0160f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ADD_32_addsub_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_off,
        iemDecodeA64_ADDS_32S_addsub_imm,
        iemDecodeA64_LDRB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SUB_32_addsub_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_off,
        iemDecodeA64_SUBS_32S_addsub_imm,
        iemDecodeA64_LDRH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADD_64_addsub_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a160e000_2,
        iemDecodeA64_LDP_64_ldstpair_off,
        iemDecodeA64_ADDS_64S_addsub_imm,
        iemDecodeA64_LDR_32_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUB_64_addsub_imm,
        iemDecodeA64_STZG_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_64_ldstpair_off,
        iemDecodeA64_SUBS_64S_addsub_imm,
        iemDecodeA64_LDR_64_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81800000 level 2
   ffe0fc00/81800400 level 2
   ffe0fc00/81800800 level 2
   ffe0fc00/81801000 level 2
   ffe0fc00/81801400 level 2
   ffe0fc00/81801800 level 2
   ffe0fc00/81801c00 level 2
   ffe0fc00/81802000 level 2
   ffe0fc00/81802400 level 2
   ffe0fc00/81803000 level 2
   ffe0fc00/81803400 level 2
   ffe0fc00/81803800 level 2
   ffe0fc00/81803c00 level 2
   ffe0fc00/81804000 level 2
   ffe0fc00/81804400 level 2
   ffe0fc00/81804800 level 2
   ffe0fc00/81804c00 level 2
   ffe0fc00/81805000 level 2
   ffe0fc00/81805400 level 2
   ffe0fc00/81805800 level 2
   ffe0fc00/81805c00 level 2
   ffe0fc00/81806000 level 2
   ffe0fc00/81806400 level 2
   ffe0fc00/81806800 level 2
   ffe0fc00/81806c00 level 2
   ffe0fc00/81807000 level 2
   ffe0fc00/81807400 level 2
   ffe0fc00/81807800 level 2
   ffe0fc00/81807c00 level 2
   ffe0fc00/81808000 level 2
   ffe0fc00/81808400 level 2
   ffe0fc00/81809000 level 2
   ffe0fc00/81809400 level 2
   ffe0fc00/8180a000 level 2
   ffe0fc00/8180a400 level 2
   ffe0fc00/8180b000 level 2
   ffe0fc00/8180b400 level 2
   ffe0fc00/8180c000 level 2
   ffe0fc00/8180c400 level 2
   ffe0fc00/8180d000 level 2
   ffe0fc00/8180d400 level 2
   ffe0fc00/8180e000 level 2
   ffe0fc00/8180e400 level 2
   ffe0fc00/8180f000 level 2
   ffe0fc00/8180f400 level 2
   ffe0fc00/8180fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x81800000))
        return iemDecodeA64_bfmopa_za32_pp_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x81800010))
        return iemDecodeA64_bfmops_za32_pp_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001e)) == UINT32_C(0x81800008))
        return iemDecodeA64_fmopa_za_pp_zz_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001e)) == UINT32_C(0x81800018))
        return iemDecodeA64_fmops_za_pp_zz_16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a1800000 level 2
   ffe0fc00/a1800400 level 2
   ffe0fc00/a1800800 level 2
   ffe0fc00/a1801000 level 2
   ffe0fc00/a1801400 level 2
   ffe0fc00/a1801800 level 2
   ffe0fc00/a1801c00 level 2
   ffe0fc00/a1802000 level 2
   ffe0fc00/a1802400 level 2
   ffe0fc00/a1803000 level 2
   ffe0fc00/a1803400 level 2
   ffe0fc00/a1803800 level 2
   ffe0fc00/a1803c00 level 2
   ffe0fc00/a1804000 level 2
   ffe0fc00/a1804400 level 2
   ffe0fc00/a1804800 level 2
   ffe0fc00/a1804c00 level 2
   ffe0fc00/a1805000 level 2
   ffe0fc00/a1805400 level 2
   ffe0fc00/a1805800 level 2
   ffe0fc00/a1805c00 level 2
   ffe0fc00/a1806000 level 2
   ffe0fc00/a1806400 level 2
   ffe0fc00/a1806800 level 2
   ffe0fc00/a1806c00 level 2
   ffe0fc00/a1807000 level 2
   ffe0fc00/a1807400 level 2
   ffe0fc00/a1807800 level 2
   ffe0fc00/a1807c00 level 2
   ffe0fc00/a1808000 level 2
   ffe0fc00/a1808400 level 2
   ffe0fc00/a1809000 level 2
   ffe0fc00/a1809400 level 2
   ffe0fc00/a180a000 level 2
   ffe0fc00/a180a400 level 2
   ffe0fc00/a180b000 level 2
   ffe0fc00/a180b400 level 2
   ffe0fc00/a180c000 level 2
   ffe0fc00/a180c400 level 2
   ffe0fc00/a180d000 level 2
   ffe0fc00/a180d400 level 2
   ffe0fc00/a180e000 level 2
   ffe0fc00/a180e400 level 2
   ffe0fc00/a180f000 level 2
   ffe0fc00/a180f400 level 2
   ffe0fc00/a180fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa1800000))
        return iemDecodeA64_usmopa_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa1800008))
        return iemDecodeA64_umopa_za32_pp_zz_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa1800010))
        return iemDecodeA64_usmops_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa1800018))
        return iemDecodeA64_umops_za32_pp_zz_16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc18/c1900000 level 3
   fff0fc18/c1900400 level 3
   fff0fc18/c1902000 level 3
   fff0fc18/c1902400 level 3
   fff0fc18/c1904000 level 3
   fff0fc18/c1904400 level 3
   fff0fc18/c1906000 level 3
   fff0fc18/c1906400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc18_c1900000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09038)) == UINT32_C(0xc1900020))
        return iemDecodeA64_fmlall_za32_z8z8i_2xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09838)) == UINT32_C(0xc1900000))
        return iemDecodeA64_smlall_za_zzi_d2xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1800000 level 2
   ffe0fc00/c1800400 level 2
   ffe0fc00/c1802000 level 2
   ffe0fc00/c1802400 level 2
   ffe0fc00/c1804000 level 2
   ffe0fc00/c1804400 level 2
   ffe0fc00/c1806000 level 2
   ffe0fc00/c1806400 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%88 (0x7) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1800000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzi_d,
        iemDecodeA64_smlsll_za_zzi_d,
        iemDecodeA64_umlall_za_zzi_d,
        iemDecodeA64_umlsll_za_zzi_d,
        iemDecodeA64_fff0fc18_c1900000_3,
        iemDecodeA64_smlsll_za_zzi_d2xi,
        iemDecodeA64_umlall_za_zzi_d2xi,
        iemDecodeA64_umlsll_za_zzi_d2xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1800000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1802000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01800000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDAPURSB_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_LDAPURSW_64_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1800000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1800400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01800400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFE_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFE_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_CPYFE_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1800000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_CPYFE_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1800800 level 2
   ffe0fc00/c1804800 level 2
   ffe0fc00/c1804c00 level 2
   ffe0fc00/c1806800 level 2
   ffe0fc00/c1806c00 level 2
   mask=0x10001c entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1800800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzi_d,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_smlsll_za_zzi_d,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_umlall_za_zzi_d,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_umlsll_za_zzi_d,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmlall_za32_z8z8i_2xi,
        iemDecodeA64_fmlall_za32_z8z8i_2xi,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x0010001c -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000007)) /* bit  2 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1800800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01800800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_STLR_32S_ldapstl_writeback,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1800800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_STLR_64S_ldapstl_writeback,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/81800c00 level 2
   dfe0fc00/81802800 level 2
   dfe0fc00/81802c00 level 2
   dfe0fc00/81808800 level 2
   dfe0fc00/81808c00 level 2
   dfe0fc00/81809800 level 2
   dfe0fc00/81809c00 level 2
   dfe0fc00/8180a800 level 2
   dfe0fc00/8180ac00 level 2
   dfe0fc00/8180b800 level 2
   dfe0fc00/8180bc00 level 2
   dfe0fc00/8180c800 level 2
   dfe0fc00/8180cc00 level 2
   dfe0fc00/8180d800 level 2
   dfe0fc00/8180dc00 level 2
   dfe0fc00/8180e800 level 2
   dfe0fc00/8180ec00 level 2
   dfe0fc00/8180f800 level 2
   mask=0x20000018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_81800c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfmopa_za32_pp_zz,
        iemDecodeA64_fmopa_za_pp_zz_16,
        iemDecodeA64_bfmops_za32_pp_zz,
        iemDecodeA64_fmops_za_pp_zz_16,
        iemDecodeA64_usmopa_za_pp_zz_32,
        iemDecodeA64_umopa_za32_pp_zz_16,
        iemDecodeA64_usmops_za_pp_zz_32,
        iemDecodeA64_umops_za32_pp_zz_16,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x20000018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000004)) /* bit 29 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/c1800c00 level 2
   dfe0fc00/c1802800 level 2
   dfe0fc00/c1802c00 level 2
   mask=0x100018 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c1800c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzi_d,
        iemDecodeA64_smlsll_za_zzi_d,
        iemDecodeA64_umlall_za_zzi_d,
        iemDecodeA64_umlsll_za_zzi_d,
        iemDecodeA64_fmlall_za32_z8z8i_2xi,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1800c00/0xd8000000
   --decoder-hint1 0x7e0fc00/0x1802800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x1802c00/0xd8000000
   mask=0xd8000000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%62 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01800c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81800c00_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_dfe0fc00_c1800c00_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1801000 level 2
   ffe0fc00/c1801400 level 2
   ffe0fc00/c1801800 level 2
   ffe0fc00/c1801c00 level 2
   ffe0fc00/c1803000 level 2
   ffe0fc00/c1803400 level 2
   ffe0fc00/c1803800 level 2
   ffe0fc00/c1803c00 level 2
   ffe0fc00/c1805000 level 2
   ffe0fc00/c1805400 level 2
   ffe0fc00/c1805800 level 2
   ffe0fc00/c1805c00 level 2
   ffe0fc00/c1807000 level 2
   ffe0fc00/c1807400 level 2
   ffe0fc00/c1807800 level 2
   ffe0fc00/c1807c00 level 2
   mask=0x100038 entries=0x10 children=0xe valid=%88 (0xe) leaf=%88 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1801000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_zzi_1,
        iemDecodeA64_fmlsl_za_zzi_1,
        iemDecodeA64_bfmlal_za_zzi_1,
        iemDecodeA64_bfmlsl_za_zzi_1,
        iemDecodeA64_fmlal_za_zzi_1,
        iemDecodeA64_fmlsl_za_zzi_1,
        iemDecodeA64_bfmlal_za_zzi_1,
        iemDecodeA64_bfmlsl_za_zzi_1,
        iemDecodeA64_fmlal_za_zzi_2xi,
        iemDecodeA64_fmlsl_za_zzi_2xi,
        iemDecodeA64_bfmlal_za_zzi_2xi,
        iemDecodeA64_bfmlsl_za_zzi_2xi,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_fmlal_za_z8z8i_2xi,
        iemDecodeA64_fmlal_za_z8z8i_2xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100038 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1801000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1803000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01801000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDAPURSB_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_LDAPURSW_64_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1801400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01801400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFEWT_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFEWT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_CPYFEWT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_CPYFEWT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1801800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1801c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1803800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1803c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%31 (0xa) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01801800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1802400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01802400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFERT_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFERT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_CPYFERT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1800000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_CPYFERT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1803400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01803400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFET_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFET_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_CPYFET_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_CPYFET_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1804000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1806000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01804000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDAPURSB_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_LDAPURSW_64_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1800000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1804400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01804400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFEWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFEWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFEWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1800000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFEWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1804800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1804c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1806800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1806c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%25 (0x8) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01804800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1800800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1805000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1807000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01805000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDAPURSB_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_LDAPURSW_64_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1805400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01805400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFEWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFEWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFEWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFEWTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1805800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1805c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1807800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%25 (0x8) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01805800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1806400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01806400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFERTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFERTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFERTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1800000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFERTWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1807400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01807400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFETWN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFETWN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFETWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFETWN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1807c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%31 (0xa) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01807c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_CASPT_CP64_comswappr_unpriv,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1801000_2,
        iemDecodeA64_CAST_C64_comswap_unpriv,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1808000 level 2
   ffe0fc00/c1808400 level 2
   ffe0fc00/c180a000 level 2
   ffe0fc00/c180a400 level 2
   ffe0fc00/c180c000 level 2
   ffe0fc00/c180c400 level 2
   ffe0fc00/c180e000 level 2
   ffe0fc00/c180e400 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1808000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzi_d,
        iemDecodeA64_smlsll_za_zzi_d,
        iemDecodeA64_umlall_za_zzi_d,
        iemDecodeA64_umlsll_za_zzi_d,
        iemDecodeA64_smlall_za_zzi_d4xi,
        iemDecodeA64_smlsll_za_zzi_d4xi,
        iemDecodeA64_umlall_za_zzi_d4xi,
        iemDecodeA64_umlsll_za_zzi_d4xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1808000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x180a000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x180c000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x180e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01808000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDAPURSB_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_LDAPURSW_64_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1808000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1808400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01808400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFERN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFERN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFERN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1808000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFERN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/c1808800 level 2
   dfe0fc00/c1808c00 level 2
   dfe0fc00/c180a800 level 2
   dfe0fc00/c180ac00 level 2
   dfe0fc00/c180c800 level 2
   dfe0fc00/c180cc00 level 2
   dfe0fc00/c180e800 level 2
   dfe0fc00/c180ec00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c1808800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0101c)) == UINT32_C(0xc1800000))
        return iemDecodeA64_smlall_za_zzi_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0101c)) == UINT32_C(0xc1800008))
        return iemDecodeA64_smlsll_za_zzi_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0101c)) == UINT32_C(0xc1800010))
        return iemDecodeA64_umlall_za_zzi_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0101c)) == UINT32_C(0xc1800018))
        return iemDecodeA64_umlsll_za_zzi_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1808800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x1808c00/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180a800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180ac00/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180c800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180cc00/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180e800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180ec00/0xd8000000
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01808800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81800c00_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_dfe0fc00_c1808800_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fc18/c1909000 level 3
   fff0fc18/c1909400 level 3
   fff0fc18/c190b000 level 3
   fff0fc18/c190b400 level 3
   fff0fc18/c190d000 level 3
   fff0fc18/c190d400 level 3
   fff0fc18/c190f000 level 3
   fff0fc18/c190f400 level 3
   fff0fc18/c190fc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc18_c1909000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09070)) == UINT32_C(0xc1909020))
        return iemDecodeA64_fmlal_za_z8z8i_4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1909000))
        return iemDecodeA64_fmlal_za_zzi_4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc18/c1909008 level 3
   fff0fc18/c1909408 level 3
   fff0fc18/c190b008 level 3
   fff0fc18/c190b408 level 3
   fff0fc18/c190d008 level 3
   fff0fc18/c190d408 level 3
   fff0fc18/c190f008 level 3
   fff0fc18/c190f408 level 3
   fff0fc18/c190fc08 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc18_c1909008_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09070)) == UINT32_C(0xc1909020))
        return iemDecodeA64_fmlal_za_z8z8i_4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1909008))
        return iemDecodeA64_fmlsl_za_zzi_4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1809000 level 2
   ffe0fc00/c1809400 level 2
   ffe0fc00/c180b000 level 2
   ffe0fc00/c180b400 level 2
   ffe0fc00/c180d000 level 2
   ffe0fc00/c180d400 level 2
   ffe0fc00/c180f000 level 2
   ffe0fc00/c180f400 level 2
   ffe0fc00/c180fc00 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%75 (0x6) multi-if=%25 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1809000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_zzi_1,
        iemDecodeA64_fmlsl_za_zzi_1,
        iemDecodeA64_bfmlal_za_zzi_1,
        iemDecodeA64_bfmlsl_za_zzi_1,
        iemDecodeA64_fff0fc18_c1909000_3,
        iemDecodeA64_fff0fc18_c1909008_3,
        iemDecodeA64_bfmlal_za_zzi_4xi,
        iemDecodeA64_bfmlsl_za_zzi_4xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1809000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x180b000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x180d000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x180f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01809000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDAPURSB_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_64_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_LDAPURSW_64_ldapstl_unscaled,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1809000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1809400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01809400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFEWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFEWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFEWTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1809000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFEWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/c1809800 level 2
   dfe0fc00/c1809c00 level 2
   dfe0fc00/c180b800 level 2
   dfe0fc00/c180bc00 level 2
   dfe0fc00/c180d800 level 2
   dfe0fc00/c180dc00 level 2
   dfe0fc00/c180f800 level 2
   mask=0x20100038 entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c1809800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_zzi_1,
        iemDecodeA64_fmlsl_za_zzi_1,
        iemDecodeA64_bfmlal_za_zzi_1,
        iemDecodeA64_bfmlsl_za_zzi_1,
        iemDecodeA64_fmlal_za_zzi_1,
        iemDecodeA64_fmlsl_za_zzi_1,
        iemDecodeA64_bfmlal_za_zzi_1,
        iemDecodeA64_bfmlsl_za_zzi_1,
        iemDecodeA64_fmlal_za_zzi_4xi,
        iemDecodeA64_fmlsl_za_zzi_4xi,
        iemDecodeA64_bfmlal_za_zzi_4xi,
        iemDecodeA64_bfmlsl_za_zzi_4xi,
        iemDecodeA64_fmlal_za_z8z8i_4xi,
        iemDecodeA64_fmlal_za_z8z8i_4xi,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x20100038 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000010)) /* bit 29 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1809800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x1809c00/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180b800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180bc00/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180d800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180dc00/0xd8000000
   --decoder-hint1 0x7e0fc00/0x180f800/0xd8000000
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%0 (0x0) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01809800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81800c00_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_dfe0fc00_c1809800_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x180a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0180a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFERTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFERTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFERTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1808000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFERTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x180b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0180b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFETRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFETRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFETRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1809000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFETRN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x180c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0180c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFEN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFEN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFEN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1808000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFEN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x180d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0180d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFEWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFEWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFEWTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1809000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFEWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x180e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0180e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFERTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFERTN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFERTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1808000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFERTN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x180f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0180f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CPYFETN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYFETN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_CPYFETN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1809000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYFETN_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x180fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%31 (0xa) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0180fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_CASPLT_CP64_comswappr_unpriv,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81800000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1800000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1809000_2,
        iemDecodeA64_CASLT_C64_comswap_unpriv,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/81a00000 level 2
   ffe0fc00/81a00400 level 2
   ffe0fc04/81a00800 level 2
   ffe0fc00/81a00c00 level 2
   ffe0fc00/81a01000 level 2
   ffe0fc00/81a01400 level 2
   ffe0fc00/81a01c00 level 2
   ffe0fc00/81a02000 level 2
   ffe0fc00/81a02400 level 2
   ffe0fc00/81a02800 level 2
   ffe0fc00/81a02c00 level 2
   ffe0fc00/81a03000 level 2
   ffe0fc00/81a03400 level 2
   ffe0fc00/81a03c00 level 2
   ffe0fc00/81a04800 level 2
   ffe0fc00/81a05400 level 2
   ffe0fc00/81a05c00 level 2
   ffe0fc00/81a06800 level 2
   ffe0fc00/81a07400 level 2
   ffe0fc00/81a07c00 level 2
   ffe0fc00/81a08400 level 2
   ffe0fc00/81a09000 level 2
   f7e0fc40/81a0a000 level 2
   f7e0fc40/81a0a040 level 2
   f7e0fc04/81a0a800 level 2
   f7e0fc04/81a0b000 level 2
   7fe0fc03/01a0b800 level 2
   7fe0fc03/01a0b801 level 2
   ffe0fc00/81a0e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_81a00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x81a00000))
        return iemDecodeA64_fmopa_za32_pp_zz_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x81a00010))
        return iemDecodeA64_fmops_za32_pp_zz_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001e)) == UINT32_C(0x81a00008))
        return iemDecodeA64_bfmopa_za_pp_zz_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001e)) == UINT32_C(0x81a00018))
        return iemDecodeA64_bfmops_za_pp_zz_16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a1a00000 level 2
   ffe0fc00/a1a00400 level 2
   ffe0fc04/a1a00800 level 2
   ffe0fc00/a1a00c00 level 2
   ffe0fc00/a1a01000 level 2
   ffe0fc00/a1a01400 level 2
   ffe0fc00/a1a01c00 level 2
   ffe0fc00/a1a02000 level 2
   ffe0fc00/a1a02400 level 2
   ffe0fc00/a1a02800 level 2
   ffe0fc00/a1a02c00 level 2
   ffe0fc00/a1a03000 level 2
   ffe0fc00/a1a03400 level 2
   ffe0fc00/a1a03c00 level 2
   ffe0fc00/a1a04800 level 2
   ffe0fc00/a1a05400 level 2
   ffe0fc00/a1a05c00 level 2
   ffe0fc00/a1a06800 level 2
   ffe0fc00/a1a07400 level 2
   ffe0fc00/a1a07c00 level 2
   ffe0fc00/a1a08400 level 2
   ffe0fc00/a1a09000 level 2
   7fe0fc03/21a0b800 level 2
   7fe0fc03/21a0b801 level 2
   7fe0fc03/21a0b802 level 2
   7fe0fc03/21a0b803 level 2
   ffe0fc00/a1a0e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a1a00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa1a00000))
        return iemDecodeA64_umopa_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa1a00010))
        return iemDecodeA64_umops_za_pp_zz_32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1a00000 level 2
   ffe0fc00/c1a02000 level 2
   dfe0fc00/c1a04000 level 2
   dfe0fc00/c1a06000 level 2
   mask=0x1003c entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1a00000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzw_2x2,
        iemDecodeA64_usmlall_za_zzw_s2x2,
        iemDecodeA64_smlsll_za_zzw_2x2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_umlall_za_zzw_2x2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_umlsll_za_zzw_2x2,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmlall_za32_z8z8w_2x2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_smlall_za_zzw_4x4,
        iemDecodeA64_usmlall_za_zzw_s4x4,
        iemDecodeA64_smlsll_za_zzw_4x4,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_umlall_za_zzw_4x4,
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_umlsll_za_zzw_4x4,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fmlall_za32_z8z8w_4x4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x0001003c -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x0000000f)) /* bit  2 L 4 -> 0 */
                        | ((uOpcode >> 12) & UINT32_C(0x00000010)) /* bit 16 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a00000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a00000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_STGM_64bulk_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a00400 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDTADDA_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDTADDA_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc04/c1a00800 level 2
   mask=0x10038 entries=0x10 children=0xa valid=%62 (0xa) leaf=%62 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc04_c1a00800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_zzw_2x2,
        iemDecodeA64_fmlsl_za_zzw_2x2,
        iemDecodeA64_bfmlal_za_zzw_2x2,
        iemDecodeA64_bfmlsl_za_zzw_2x2,
        iemDecodeA64_fmlal_za_z8z8w_2x2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmlal_za_zzw_4x4,
        iemDecodeA64_fmlsl_za_zzw_4x4,
        iemDecodeA64_bfmlal_za_zzw_4x4,
        iemDecodeA64_bfmlsl_za_zzw_4x4,
        iemDecodeA64_fmlal_za_z8z8w_4x4,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00010038 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 13) & UINT32_C(0x00000008)) /* bit 16 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a00800/0xf8000004
   mask=0xf8000004 entries=0x40 children=0x1d valid=%45 (0x1d) leaf=%41 (0x1a) multi-if=%3 (0x2) reuse=%3 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_RCWCASA_C64_rcwcomswap,
        iemDecodeA64_RCWCASA_C64_rcwcomswap,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_RCWSCASA_C64_rcwcomswap,
        iemDecodeA64_RCWSCASA_C64_rcwcomswap,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc04_c1a00800_2,
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_PRFM_P_ldst_pos,
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8000004 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000001)) /* bit  2 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a00c00 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_RCWCASPA_C64_rcwcomswappr,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_RCWSCASPA_C64_rcwcomswappr,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1a01000 level 2
   ffe0fc00/c1a03000 level 2
   mask=0x10038 entries=0x10 children=0xc valid=%75 (0xc) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1a01000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fdot_za_zzw_2x2,
        iemDecodeA64_fmla_za_zzw_2x2_16,
        iemDecodeA64_bfdot_za_zzw_2x2,
        iemDecodeA64_fmls_za_zzw_2x2_16,
        iemDecodeA64_fdot_za_z8z8w_2x2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fdot_za32_z8z8w_2x2,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fdot_za_zzw_4x4,
        iemDecodeA64_fmla_za_zzw_4x4_16,
        iemDecodeA64_bfdot_za_zzw_4x4,
        iemDecodeA64_fmls_za_zzw_4x4_16,
        iemDecodeA64_fdot_za_z8z8w_4x4,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_fdot_za32_z8z8w_4x4,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00010038 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 13) & UINT32_C(0x00000008)) /* bit 16 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a01000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDCLRPA_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a01000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1a01400 level 2
   ffe0fc00/c1a03400 level 2
   ffe0fc00/c1a05400 level 2
   ffe0fc00/c1a07400 level 2
   mask=0x10038 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1a01400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sdot_za_zzw_2x2,
        iemDecodeA64_usdot_za_zzw_s2x2,
        iemDecodeA64_udot_za_zzw_2x2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sdot_za_zzw_4x4,
        iemDecodeA64_usdot_za_zzw_s4x4,
        iemDecodeA64_udot_za_zzw_4x4,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00010038 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 13) & UINT32_C(0x00000008)) /* bit 16 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a01400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDTCLRA_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDTCLRA_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a01400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/81a01800 level 2
   dfe0fc00/81a03800 level 2
   dfe0fc00/81a04000 level 2
   dfe0fc00/81a04400 level 2
   dfe0fc00/81a04c00 level 2
   dfe0fc00/81a05000 level 2
   dfe0fc00/81a05800 level 2
   dfe0fc00/81a06000 level 2
   dfe0fc00/81a06400 level 2
   dfe0fc00/81a06c00 level 2
   dfe0fc00/81a07000 level 2
   dfe0fc00/81a07800 level 2
   dfe0fc00/81a08000 level 2
   dfe0fc00/81a08800 level 2
   dfe0fc00/81a08c00 level 2
   dfe0fc00/81a09400 level 2
   dfe0fc00/81a09800 level 2
   dfe0fc00/81a09c00 level 2
   dfe0fc00/81a0a400 level 2
   dfe0fc00/81a0ac00 level 2
   dfe0fc00/81a0b400 level 2
   dfe0fc00/81a0bc00 level 2
   dfe0fc00/81a0c000 level 2
   dfe0fc00/81a0c400 level 2
   dfe0fc00/81a0c800 level 2
   dfe0fc00/81a0cc00 level 2
   dfe0fc00/81a0d000 level 2
   dfe0fc00/81a0d400 level 2
   dfe0fc00/81a0d800 level 2
   dfe0fc00/81a0dc00 level 2
   dfe0fc00/81a0e400 level 2
   dfe0fc00/81a0e800 level 2
   dfe0fc00/81a0ec00 level 2
   dfe0fc00/81a0f000 level 2
   dfe0fc00/81a0f400 level 2
   dfe0fc00/81a0f800 level 2
   dfe0fc00/81a0fc00 level 2
   mask=0x2000001c entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_81a01800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmopa_za32_pp_zz_16,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bfmopa_za_pp_zz_16,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmops_za32_pp_zz_16,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_bfmops_za_pp_zz_16,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umopa_za_pp_zz_32,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_umops_za_pp_zz_32,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x2000001c -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000007)) /* bit  2 L 3 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000008)) /* bit 29 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/c1a01800 level 2
   dfe0fc00/c1a03800 level 2
   dfe0fc00/c1a05800 level 2
   dfe0fc00/c1a07800 level 2
   7fe0fc00/41e01800 level 2
   7fe0fc00/41e03800 level 2
   7fe0fc00/41e05800 level 2
   7fe0fc00/41e07800 level 2
   mask=0x10018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c1a01800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmla_za_zzw_2x2,
        iemDecodeA64_fmls_za_zzw_2x2,
        iemDecodeA64_add_za_zzw_2x2,
        iemDecodeA64_sub_za_zzw_2x2,
        iemDecodeA64_fmla_za_zzw_4x4,
        iemDecodeA64_fmls_za_zzw_4x4,
        iemDecodeA64_add_za_zzw_4x4,
        iemDecodeA64_sub_za_zzw_4x4,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00010018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 14) & UINT32_C(0x00000004)) /* bit 16 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/d9a01800 level 2
   dfe0fc00/d9a03800 level 2
   dfe0fc00/d9a05800 level 2
   dfe0fc00/d9a07800 level 2
   dfe0fc00/d9a08800 level 2
   dfe0fc00/d9a09800 level 2
   dfe0fc00/d9a0c800 level 2
   dfe0fc00/d9a0d800 level 2
   dfe0fc00/d9a0e800 level 2
   dfe0fc00/d9a0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_d9a01800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xf9800000))
        return iemDecodeA64_PRFM_P_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xd9a00800))
        return iemDecodeA64_ST2G_64Soffset_ldsttags(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a01800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x1a03800/0xd8000000
   mask=0xd8000000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%56 (0x9) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_dfe0fc00_c1a01800_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_dfe0fc00_d9a01800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1a01c00 level 2
   ffe0fc00/c1a03c00 level 2
   ffe0fc00/c1a05c00 level 2
   ffe0fc00/c1a07c00 level 2
   mask=0x50018 entries=0x10 children=0xc valid=%75 (0xc) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1a01c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_za_zw_2x2,
        iemDecodeA64_fsub_za_zw_2x2,
        iemDecodeA64_add_za_zw_2x2,
        iemDecodeA64_sub_za_zw_2x2,
        iemDecodeA64_fadd_za_zw_4x4,
        iemDecodeA64_fsub_za_zw_4x4,
        iemDecodeA64_add_za_zw_4x4,
        iemDecodeA64_sub_za_zw_4x4,
        iemDecodeA64_fadd_za_zw_2x2_16,
        iemDecodeA64_fsub_za_zw_2x2_16,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fadd_za_zw_4x4_16,
        iemDecodeA64_fsub_za_zw_4x4_16,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00050018 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 14) & UINT32_C(0x00000004)) /* bit 16 L 1 -> 2 */
                        | ((uOpcode >> 15) & UINT32_C(0x00000008)) /* bit 18 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a01c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1a03c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a01c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a02000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%31 (0xa) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a00000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a02400 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1a02800 level 2
   ffe0fc00/c1a04800 level 2
   ffe0fc00/c1a06800 level 2
   mask=0x1003c entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1a02800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_zzw_2x2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fmlsl_za_zzw_2x2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfmlal_za_zzw_2x2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_bfmlsl_za_zzw_2x2,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmlal_za_z8z8w_2x2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fmlal_za_zzw_4x4,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fmlsl_za_zzw_4x4,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfmlal_za_zzw_4x4,
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_bfmlsl_za_zzw_4x4,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fmlal_za_z8z8w_4x4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x0001003c -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x0000000f)) /* bit  2 L 4 -> 0 */
                        | ((uOpcode >> 12) & UINT32_C(0x00000010)) /* bit 16 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a02800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a02800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a02c00 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a03000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDSETPA_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a01000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a03400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDTSETA_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDTSETA_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ADDG_64_addsub_immtags,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a01400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SUBG_64_addsub_immtags,
        iemDecodeA64_ST2G_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a04000/0xd8000000
   --decoder-hint1 0x7e0fc00/0x1a06000/0xd8000000
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%0 (0x0) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a00000_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/d9a04400 level 2
   dfe0fc00/d9a06400 level 2
   dfe0fc00/d9a09400 level 2
   dfe0fc00/d9a0a400 level 2
   dfe0fc00/d9a0b400 level 2
   dfe0fc00/d9a0c400 level 2
   dfe0fc00/d9a0d400 level 2
   dfe0fc00/d9a0e400 level 2
   dfe0fc00/d9a0f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_d9a04400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xf9800000))
        return iemDecodeA64_PRFM_P_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xd9a00400))
        return iemDecodeA64_ST2G_64Spost_ldsttags(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01a04400 level 1
   07e0fc00/01a06400 level 1
   07e0fc00/01a0d400 level 1
   07e0fc00/01a0f400 level 1
   mask=0xd8000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a04800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1a06800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%28 (0x9) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a02800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/d9a04c00 level 2
   dfe0fc00/d9a06c00 level 2
   dfe0fc00/d9a08c00 level 2
   dfe0fc00/d9a09c00 level 2
   dfe0fc00/d9a0ac00 level 2
   dfe0fc00/d9a0bc00 level 2
   dfe0fc00/d9a0cc00 level 2
   dfe0fc00/d9a0dc00 level 2
   dfe0fc00/d9a0ec00 level 2
   dfe0fc00/d9a0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_d9a04c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xf9800000))
        return iemDecodeA64_PRFM_P_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xd9a00c00))
        return iemDecodeA64_ST2G_64Spre_ldsttags(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01a04c00 level 1
   07e0fc00/01a06c00 level 1
   07e0fc00/01a0ec00 level 1
   07e0fc00/01a0fc00 level 1
   mask=0xd8000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/c1a05000 level 2
   dfe0fc00/c1a07000 level 2
   mask=0x20010038 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c1a05000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fdot_za_zzw_2x2,
        iemDecodeA64_fmla_za_zzw_2x2_16,
        iemDecodeA64_bfdot_za_zzw_2x2,
        iemDecodeA64_fmls_za_zzw_2x2_16,
        iemDecodeA64_fdot_za_z8z8w_2x2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fdot_za32_z8z8w_2x2,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fdot_za_zzw_4x4,
        iemDecodeA64_fmla_za_zzw_4x4_16,
        iemDecodeA64_bfdot_za_zzw_4x4,
        iemDecodeA64_fmls_za_zzw_4x4_16,
        iemDecodeA64_fdot_za_z8z8w_4x4,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_fdot_za32_z8z8w_4x4,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x20010038 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 13) & UINT32_C(0x00000008)) /* bit 16 L 1 -> 3 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000010)) /* bit 29 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a05000/0xd8000000
   --decoder-hint1 0x7e0fc00/0x1a07000/0xd8000000
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%0 (0x0) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_dfe0fc00_c1a05000_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a05400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1a07400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%28 (0x9) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a01400_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_ST2G_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a05800/0xd8000000
   --decoder-hint1 0x7e0fc00/0x1a07800/0xd8000000
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_dfe0fc00_c1a01800_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a01800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a05c00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1a07c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%28 (0x9) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a01c00_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_ST2G_64Spre_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/19a08000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_19a08000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x39800000))
        return iemDecodeA64_LDRSB_64_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19a08000))
        return iemDecodeA64_SWPPA_128_memop_128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01a08000 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_dfe0fc00_19a08000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a08400 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_SWPTA_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SWPTA_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_ST2G_64Spost_ldsttags,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a08800 level 1
   07e0fc00/01a09800 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a01800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a08c00 level 1
   07e0fc00/01a09c00 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a09000 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%31 (0xa) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_RCWCLRPA_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_RCWSCLRPA_128_memop_128,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a09400 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc40/a1a0a000 level 2
   f7e0fc40/a1a0a040 level 2
   f7e0fc04/a1a0a800 level 2
   f7e0fc04/a1a0b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_a1a0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9800000))
        return iemDecodeA64_STP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa1a00000))
        return iemDecodeA64_umopa_za_pp_zz_32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0xa1a00010))
        return iemDecodeA64_umops_za_pp_zz_32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a0a000/0xf0000040
   mask=0xf0000040 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_RCWSWPPA_128_memop_128,
        iemDecodeA64_RCWSWPPA_128_memop_128,
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RCWSSWPPA_128_memop_128,
        iemDecodeA64_RCWSSWPPA_128_memop_128,
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_f7e0fc40_a1a0a000_2,
        iemDecodeA64_f7e0fc40_a1a0a000_2,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c160a000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_PRFM_P_ldst_pos,
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000040 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000001)) /* bit  6 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0a400 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzv_2x1,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a0a800/0xf0000004
   mask=0xf0000004 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_f7e0fc40_a1a0a000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c160a800_2,
        iemDecodeA64_ffe0fc00_c160a800_2,
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_PRFM_P_ldst_pos,
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000004 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000001)) /* bit  2 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0ac00 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzv_4x1,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a0b000/0xf0000004
   mask=0xf0000004 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_RCWSETPA_128_memop_128,
        iemDecodeA64_RCWSETPA_128_memop_128,
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RCWSSETPA_128_memop_128,
        iemDecodeA64_RCWSSETPA_128_memop_128,
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_f7e0fc40_a1a0a000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c160b000_2,
        iemDecodeA64_ffe0fc00_c160b000_2,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_PRFM_P_ldst_pos,
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000004 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000001)) /* bit  2 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0b400 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzw_2x2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc03/01a0b802 level 2
   7fe0fc03/01a0b803 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc03_01a0b802_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x81a00000))
        return iemDecodeA64_fmopa_za32_pp_zz_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001c)) == UINT32_C(0x81a00010))
        return iemDecodeA64_fmops_za32_pp_zz_16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc03/29a0b800 level 2
   7fe0fc03/29a0b801 level 2
   7fe0fc03/29a0b802 level 2
   7fe0fc03/29a0b803 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc03_29a0b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x29800000))
        return iemDecodeA64_STP_32_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9800000))
        return iemDecodeA64_STP_64_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc03/39a0b800 level 2
   7fe0fc03/39a0b801 level 2
   7fe0fc03/39a0b802 level 2
   7fe0fc03/39a0b803 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc03_39a0b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x39800000))
        return iemDecodeA64_LDRSB_64_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xb9800000))
        return iemDecodeA64_LDRSW_64_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc03/41a0b800 level 2
   7fe0fc03/41e0b800 level 2
   mask=0x1e0 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc03_41a0b800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smax_mz_zzw_4x4,
        iemDecodeA64_3fe0fd69_0120b820_3,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmax_mz_zzw_4x4,
        iemDecodeA64_fmaxnm_mz_zzw_4x4,
        iemDecodeA64_famax_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fscale_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000001e0 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  5) & UINT32_C(0x0000000f)) /* bit  5 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc03/41a0b801 level 2
   7fe0fc03/41e0b801 level 2
   mask=0x160 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc03_41a0b801_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_umax_mz_zzw_4x4,
        iemDecodeA64_3fe0fd69_0120b821_3,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmin_mz_zzw_4x4,
        iemDecodeA64_fminnm_mz_zzw_4x4,
        iemDecodeA64_famin_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00000160 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  5) & UINT32_C(0x00000003)) /* bit  5 L 2 -> 0 */
                        | ((uOpcode >>  6) & UINT32_C(0x00000004)) /* bit  8 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc03/69a0b800 level 2
   7fe0fc03/69a0b801 level 2
   7fe0fc03/69a0b802 level 2
   7fe0fc03/69a0b803 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc03_69a0b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x69800000))
        return iemDecodeA64_STGP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9800000))
        return iemDecodeA64_STTP_64_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc03/79a0b800 level 2
   7fe0fc03/79a0b801 level 2
   7fe0fc03/79a0b802 level 2
   7fe0fc03/79a0b803 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc03_79a0b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x79800000))
        return iemDecodeA64_LDRSH_64_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xf9800000))
        return iemDecodeA64_PRFM_P_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a0b800/0x78000003
   mask=0x78000003 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%6 (0x4) multi-if=%38 (0x18) reuse=%30 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_7fe0fc03_01a0b802_2,
        iemDecodeA64_7fe0fc03_01a0b802_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_7fe0fc03_29a0b800_2,
        iemDecodeA64_7fe0fc03_29a0b800_2,
        iemDecodeA64_7fe0fc03_29a0b800_2,
        iemDecodeA64_7fe0fc03_29a0b800_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_7fe0fc03_39a0b800_2,
        iemDecodeA64_7fe0fc03_39a0b800_2,
        iemDecodeA64_7fe0fc03_39a0b800_2,
        iemDecodeA64_7fe0fc03_39a0b800_2,
        iemDecodeA64_7fe0fc03_41a0b800_2,
        iemDecodeA64_7fe0fc03_41a0b801_2,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_ST2G_64Soffset_ldsttags,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_7fe0fc03_69a0b800_2,
        iemDecodeA64_7fe0fc03_69a0b800_2,
        iemDecodeA64_7fe0fc03_69a0b800_2,
        iemDecodeA64_7fe0fc03_69a0b800_2,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_7fe0fc03_79a0b800_2,
        iemDecodeA64_7fe0fc03_79a0b800_2,
        iemDecodeA64_7fe0fc03_79a0b800_2,
        iemDecodeA64_7fe0fc03_79a0b800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78000003 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000003)) /* bit  0 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0bc00 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_sqdmulh_mz_zzw_4x4,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0c000 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%56 (0x9) multi-if=%0 (0x0) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_fclamp_mz_zz_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0c400 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c120c400_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0c800 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_fclamp_mz_zz_4,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a01800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0cc00 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c120cc00_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0d000 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c120d000_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0d800 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c120d800_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a01800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0dc00 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c120dc00_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc01/c1a0e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc01_c1a0e000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc01)) == UINT32_C(0xc1a0e000))
        return iemDecodeA64_fcvt_mz2_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc21)) == UINT32_C(0xc1a8e000))
        return iemDecodeA64_frintn_mz_z_2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc01/c1b3e000 level 3
   fff7fc01/c1b3e001 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc01_c1b3e000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc133e000))
        return iemDecodeA64_sqcvt_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc133e020))
        return iemDecodeA64_uqcvt_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc133e040))
        return iemDecodeA64_sqcvtn_z_mz4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff7ffc60)) == UINT32_C(0xc133e060))
        return iemDecodeA64_uqcvtn_z_mz4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1a0e000 level 2
   mask=0x170001 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1a0e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff7fc01_c1a0e000_3,
        iemDecodeA64_fcvtl_mz2_z,
        iemDecodeA64_frintp_mz_z_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_frintm_mz_z_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_frinta_mz_z_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_sunpk_mz_z_2,
        iemDecodeA64_uunpk_mz_z_2,
        iemDecodeA64_f2cvt_mz2_z8,
        iemDecodeA64_f2cvtl_mz2_z8,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_frintn_mz_z_4,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_frintp_mz_z_4,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_frintm_mz_z_4,
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_fff7fc01_c1b3e000_3,
        iemDecodeA64_fff7fc01_c1b3e000_3,
        iemDecodeA64_frinta_mz_z_4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_sunpk_mz_z_4,
        iemDecodeA64_uunpk_mz_z_4,
        iemDecodeA64_fff7fc21_c136e000_3,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x00170001 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x0000000e)) /* bit 16 L 3 -> 1 */
                        | ((uOpcode >> 16) & UINT32_C(0x00000010)) /* bit 20 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1a0e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%25 (0x8) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_ffe0fc00_81a00000_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a1a00000_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c1a0e000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0e400 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c160e400_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a04400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0e800 level 1
   mask=0xd8000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_ffe0fc00_c160e800_2,
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a01800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0f000 level 1
   mask=0xd8000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%50 (0x8) multi-if=%0 (0x0) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_PRFM_P_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01a0f800 level 1
   mask=0xd8000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01a0f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_STP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_64_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STGP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_64_ldst_pos,
        iemDecodeA64_dfe0fc00_81a01800_2,
        iemDecodeA64_STP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDRSW_64_ldst_pos,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_dfe0fc00_d9a01800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/11c00000 level 2
   7fe0fc10/11c00800 level 2
   7fe0fc10/11c00810 level 2
   5fe0fc10/11c08800 level 2
   5fe0fc10/11c08810 level 2
   5fe0fc10/11c08c00 level 2
   5fe0fc10/11c08c10 level 2
   5fe0fc10/11c0a800 level 2
   5fe0fc10/11c0a810 level 2
   5fe0fc10/11c0ac00 level 2
   5fe0fc10/11c0ac10 level 2
   5fe0fc10/11c0c800 level 2
   5fe0fc10/11c0c810 level 2
   5fe0fc10/11c0cc00 level 2
   5fe0fc10/11c0cc10 level 2
   5fe0fc10/11c0e800 level 2
   5fe0fc10/11c0e810 level 2
   5fe0fc10/11c0ec00 level 2
   5fe0fc10/11c0ec10 level 2
   mask=0x800c0000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_11c00000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SMAX_32_minmax_imm,
        iemDecodeA64_UMAX_32U_minmax_imm,
        iemDecodeA64_SMIN_32_minmax_imm,
        iemDecodeA64_UMIN_32U_minmax_imm,
        iemDecodeA64_SMAX_64_minmax_imm,
        iemDecodeA64_UMAX_64U_minmax_imm,
        iemDecodeA64_SMIN_64_minmax_imm,
        iemDecodeA64_UMIN_64U_minmax_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x800c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000003)) /* bit 18 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fe18/21c00008 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe18_21c00008_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1c00008))
        return iemDecodeA64_usmop4a_za_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1d00008))
        return iemDecodeA64_usmop4a_za_zz_h1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fe18/21c00018 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe18_21c00018_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1c00018))
        return iemDecodeA64_usmop4s_za_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1d00018))
        return iemDecodeA64_usmop4s_za_zz_h1x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fe18/21c00208 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe18_21c00208_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1c00208))
        return iemDecodeA64_usmop4a_za_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1d00208))
        return iemDecodeA64_usmop4a_za_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fe18/21c00218 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe18_21c00218_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1c00218))
        return iemDecodeA64_usmop4s_za_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1d00218))
        return iemDecodeA64_usmop4s_za_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc00/21c00000 level 2
   mask=0x218 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%50 (0x4) multi-if=%50 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_21c00000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_usmopa_za_pp_zz_64,
        iemDecodeA64_7fe0fe18_21c00008_3,
        iemDecodeA64_usmops_za_pp_zz_64,
        iemDecodeA64_7fe0fe18_21c00018_3,
        iemDecodeA64_usmopa_za_pp_zz_64,
        iemDecodeA64_7fe0fe18_21c00208_3,
        iemDecodeA64_usmops_za_pp_zz_64,
        iemDecodeA64_7fe0fe18_21c00218_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00000218 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >>  7) & UINT32_C(0x00000004)) /* bit  9 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/29c00000 level 2
   7fe0fc10/29c00800 level 2
   7fe0fc10/29c00810 level 2
   7ff8fc00/29c00c00 level 2
   7ff8fc00/29c80c00 level 2
   7ff8fc00/29d00c00 level 2
   7ff8fc00/29d80c00 level 2
   7ff8fc00/29c02800 level 2
   7ff8fc00/29c82800 level 2
   7ff8fc00/29d02800 level 2
   7ff8fc00/29d82800 level 2
   7ff8fc00/29c02c00 level 2
   7ff8fc00/29c82c00 level 2
   7ff8fc00/29d02c00 level 2
   7ff8fc00/29d82c00 level 2
   7ff8fc00/29c04800 level 2
   7ff8fc00/29c84800 level 2
   7ff8fc00/29d04800 level 2
   7ff8fc00/29d84800 level 2
   7ff8fc00/29c04c00 level 2
   7ff8fc00/29c84c00 level 2
   7ff8fc00/29d04c00 level 2
   7ff8fc00/29d84c00 level 2
   7ff8fc00/29c06800 level 2
   7ff8fc00/29c86800 level 2
   7ff8fc00/29d06800 level 2
   7ff8fc00/29d86800 level 2
   7ff8fc00/29c06c00 level 2
   7ff8fc00/29c86c00 level 2
   7ff8fc00/29d06c00 level 2
   7ff8fc00/29d86c00 level 2
   5fe0fc10/09c08800 level 2
   5fe0fc10/09c08810 level 2
   5fe0fc10/09c08c00 level 2
   5fe0fc10/09c08c10 level 2
   5fe0fc10/09c0a800 level 2
   5fe0fc10/09c0a810 level 2
   5fe0fc10/09c0ac00 level 2
   5fe0fc10/09c0ac10 level 2
   7ff8fc00/29c0c400 level 2
   7ff8fc00/29c8c400 level 2
   7ff8fc00/29d0c400 level 2
   7ff8fc00/29d8c400 level 2
   5fe0fc10/09c0c800 level 2
   5fe0fc10/09c0c810 level 2
   5fe0fc10/09c0cc00 level 2
   5fe0fc10/09c0cc10 level 2
   7ff8fc00/29c0e400 level 2
   7ff8fc00/29c8e400 level 2
   7ff8fc00/29d0e400 level 2
   7ff8fc00/29d8e400 level 2
   5fe0fc10/09c0e800 level 2
   5fe0fc10/09c0e810 level 2
   5fe0fc10/09c0ec00 level 2
   5fe0fc10/09c0ec10 level 2
   7fe0fc18/29e00000 level 2
   7fe0fc18/29e00008 level 2
   7fe0fc18/29e00010 level 2
   7fe0fc18/29e00018 level 2
   7fe0fc00/29e01000 level 2
   7fe0fc00/29e01800 level 2
   7fe0fc00/29e01c00 level 2
   7fe0fc00/29e02000 level 2
   7fe0fc00/29e02800 level 2
   7fe0fc00/29e03000 level 2
   7fe0fc00/29e03800 level 2
   7fe0fc00/29e03c00 level 2
   7fe0fc00/29e04000 level 2
   7fe0fc00/29e04800 level 2
   7fe0fc00/29e05000 level 2
   7fe0fc00/29e05400 level 2
   7fe0fc00/29e05800 level 2
   7fe0fc00/29e05c00 level 2
   7fe0fc00/29e06000 level 2
   7fe0fc00/29e06800 level 2
   7fe0fc00/29e07000 level 2
   7fe0fc00/29e07400 level 2
   7fe0fc00/29e07800 level 2
   7fe0fc00/29e07c00 level 2
   5fe0fc10/09e0a800 level 2
   5fe0fc10/09e0a810 level 2
   77e0fc08/21e0b008 level 2
   7fe0fc03/29e0b800 level 2
   7fe0fc03/29e0b801 level 2
   7fe0fc03/29e0b802 level 2
   7fe0fc03/29e0b803 level 2
   7fe0fc00/29e0d400 level 2
   7fe0fc00/29e0d800 level 2
   7fe0fc00/29e0dc00 level 2
   7fe0fc00/29e0e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_29c00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x29c00000))
        return iemDecodeA64_LDP_32_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9c00000))
        return iemDecodeA64_LDP_64_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7ff0fc18/41d00000 level 3
   fff0fc18/c1d02000 level 3
   fff0fc18/c1d04000 level 3
   fff0fc18/c1d06000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7ff0fc18_41d00000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09030)) == UINT32_C(0xc1d00020))
        return iemDecodeA64_fdot_za_z8z8i_2xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09838)) == UINT32_C(0xc1d00000))
        return iemDecodeA64_fmla_za_zzi_d2xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7ff0fc18/41d00008 level 3
   fff0fc18/c1d02008 level 3
   fff0fc18/c1d04008 level 3
   fff0fc18/c1d06008 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7ff0fc18_41d00008_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09030)) == UINT32_C(0xc1d00020))
        return iemDecodeA64_fdot_za_z8z8i_2xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09838)) == UINT32_C(0xc1d00008))
        return iemDecodeA64_sdot_za_zzi_d2xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc00/41c00000 level 2
   ffe0fc00/c1c02000 level 2
   ffe0fc00/c1c04000 level 2
   ffe0fc00/c1c06000 level 2
   mask=0x100018 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_41c00000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7ff0fc18_41d00000_3,
        iemDecodeA64_7ff0fc18_41d00008_3,
        iemDecodeA64_fmls_za_zzi_d2xi,
        iemDecodeA64_udot_za_zzi_d2xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/69c00000 level 2
   7fe0fc10/69c00800 level 2
   7fe0fc10/69c00810 level 2
   7ff8fc00/69c00c00 level 2
   7ff8fc00/69c80c00 level 2
   7ff8fc00/69d00c00 level 2
   7ff8fc00/69d80c00 level 2
   7ff8fc00/69c02800 level 2
   7ff8fc00/69c82800 level 2
   7ff8fc00/69d02800 level 2
   7ff8fc00/69d82800 level 2
   7ff8fc00/69c02c00 level 2
   7ff8fc00/69c82c00 level 2
   7ff8fc00/69d02c00 level 2
   7ff8fc00/69d82c00 level 2
   7ff8fc00/69c04800 level 2
   7ff8fc00/69c84800 level 2
   7ff8fc00/69d04800 level 2
   7ff8fc00/69d84800 level 2
   7ff8fc00/69c04c00 level 2
   7ff8fc00/69c84c00 level 2
   7ff8fc00/69d04c00 level 2
   7ff8fc00/69d84c00 level 2
   7ff8fc00/69c06800 level 2
   7ff8fc00/69c86800 level 2
   7ff8fc00/69d06800 level 2
   7ff8fc00/69d86800 level 2
   7ff8fc00/69c06c00 level 2
   7ff8fc00/69c86c00 level 2
   7ff8fc00/69d06c00 level 2
   7ff8fc00/69d86c00 level 2
   5fe0fc10/49c08800 level 2
   5fe0fc10/49c08810 level 2
   5fe0fc10/49c08c00 level 2
   5fe0fc10/49c08c10 level 2
   5fe0fc10/49c0a800 level 2
   5fe0fc10/49c0a810 level 2
   5fe0fc10/49c0ac00 level 2
   5fe0fc10/49c0ac10 level 2
   7ff8fc00/69c0c400 level 2
   7ff8fc00/69c8c400 level 2
   7ff8fc00/69d0c400 level 2
   7ff8fc00/69d8c400 level 2
   5fe0fc10/49c0c800 level 2
   5fe0fc10/49c0c810 level 2
   5fe0fc10/49c0cc00 level 2
   5fe0fc10/49c0cc10 level 2
   7ff8fc00/69c0e400 level 2
   7ff8fc00/69c8e400 level 2
   7ff8fc00/69d0e400 level 2
   7ff8fc00/69d8e400 level 2
   5fe0fc10/49c0e800 level 2
   5fe0fc10/49c0e810 level 2
   5fe0fc10/49c0ec00 level 2
   5fe0fc10/49c0ec10 level 2
   7fe0fc18/69e00000 level 2
   7fe0fc18/69e00008 level 2
   7fe0fc18/69e00010 level 2
   7fe0fc18/69e00018 level 2
   7fe0fc00/69e01000 level 2
   7fe0fc00/69e01800 level 2
   7fe0fc00/69e01c00 level 2
   7fe0fc00/69e02000 level 2
   7fe0fc00/69e02800 level 2
   7fe0fc00/69e03000 level 2
   7fe0fc00/69e03800 level 2
   7fe0fc00/69e03c00 level 2
   7fe0fc00/69e04000 level 2
   7fe0fc00/69e04800 level 2
   7fe0fc00/69e05000 level 2
   7fe0fc00/69e05400 level 2
   7fe0fc00/69e05800 level 2
   7fe0fc00/69e05c00 level 2
   7fe0fc00/69e06000 level 2
   7fe0fc00/69e06800 level 2
   7fe0fc00/69e07000 level 2
   7fe0fc00/69e07400 level 2
   7fe0fc00/69e07800 level 2
   7fe0fc00/69e07c00 level 2
   5fe0fc10/49e0a800 level 2
   5fe0fc10/49e0a810 level 2
   7fe0fc03/69e0b800 level 2
   7fe0fc03/69e0b801 level 2
   7fe0fc03/69e0b802 level 2
   7fe0fc03/69e0b803 level 2
   7fe0fc00/69e0d400 level 2
   7fe0fc00/69e0d800 level 2
   7fe0fc00/69e0dc00 level 2
   7fe0fc00/69e0e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_69c00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x69c00000))
        return iemDecodeA64_LDPSW_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c00000/0x78000000
   mask=0x78000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%31 (0x5) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe0fc00_11c00000_2,
        iemDecodeA64_LDAPURSB_32_ldapstl_unscaled,
        iemDecodeA64_7fe0fc00_21c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc00_41c00000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_32_ldapstl_unscaled,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fc00/11c00400 level 2
   ffe0fc00/11c01000 level 2
   f7e0fc08/11c01800 level 2
   f7e0fc08/11c01808 level 2
   f7e0fc08/11c01c00 level 2
   f7e0fc08/11c01c08 level 2
   ffe0fc00/11c02000 level 2
   fff0fc00/11c02400 level 2
   ffe0fc00/11c03000 level 2
   f7e0fc08/11c03800 level 2
   f7e0fc08/11c03808 level 2
   f7e0fc08/11c03c00 level 2
   f7e0fc08/11c03c08 level 2
   ffe0fc00/11c04000 level 2
   fff0fc00/11c04400 level 2
   ffe0fc00/11c05000 level 2
   f7e0fc08/11c05800 level 2
   f7e0fc08/11c05808 level 2
   f7e0fc08/11c05c00 level 2
   f7e0fc08/11c05c08 level 2
   ffe0fc00/11c06000 level 2
   fff0fc00/11c06400 level 2
   ffe0fc00/11c07000 level 2
   f7e0fc08/11c07800 level 2
   f7e0fc08/11c07808 level 2
   ffe0fc00/11c07c00 level 2
   ffe0fc00/11c08000 level 2
   fff0fc00/11c08400 level 2
   ffe0fc00/11c09000 level 2
   fff0fc00/11c09400 level 2
   f7e0fc08/11c09800 level 2
   f7e0fc08/11c09808 level 2
   f7e0fc08/11c09c00 level 2
   f7e0fc08/11c09c08 level 2
   ffe0fc00/11c0a000 level 2
   fff0fc00/11c0a400 level 2
   ffe0fc00/11c0b000 level 2
   fff0fc00/11c0b400 level 2
   f7e0fc08/11c0b800 level 2
   f7e0fc08/11c0b808 level 2
   f7e0fc08/11c0bc00 level 2
   f7e0fc08/11c0bc08 level 2
   ffe0fc00/11c0c000 level 2
   ffe0fc00/11c0d000 level 2
   f7e0fc08/11c0d400 level 2
   f7e0fc08/11c0d408 level 2
   f7e0fc08/11c0d800 level 2
   f7e0fc08/11c0d808 level 2
   f7e0fc08/11c0dc00 level 2
   f7e0fc08/11c0dc08 level 2
   ffe0fc00/11c0e000 level 2
   ffe0fc00/11c0f000 level 2
   f7e0fc08/11c0f400 level 2
   f7e0fc08/11c0f408 level 2
   f7e0fc08/11c0f800 level 2
   f7e0fc08/11c0f808 level 2
   ffe0fc00/11c0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc00_11c00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c00000))
        return iemDecodeA64_SMAX_32_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c40000))
        return iemDecodeA64_UMAX_32U_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c80000))
        return iemDecodeA64_SMIN_32_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11cc0000))
        return iemDecodeA64_UMIN_32U_minmax_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc00/91c00400 level 2
   ffe0fc00/91c01000 level 2
   f7e0fc08/91c01800 level 2
   f7e0fc08/91c01808 level 2
   f7e0fc08/91c01c00 level 2
   f7e0fc08/91c01c08 level 2
   ffe0fc00/91c02000 level 2
   fff0fc00/91c02400 level 2
   ffe0fc00/91c03000 level 2
   f7e0fc08/91c03800 level 2
   f7e0fc08/91c03808 level 2
   f7e0fc08/91c03c00 level 2
   f7e0fc08/91c03c08 level 2
   ffe0fc00/91c04000 level 2
   fff0fc00/91c04400 level 2
   ffe0fc00/91c05000 level 2
   f7e0fc08/91c05800 level 2
   f7e0fc08/91c05808 level 2
   f7e0fc08/91c05c00 level 2
   f7e0fc08/91c05c08 level 2
   ffe0fc00/91c06000 level 2
   fff0fc00/91c06400 level 2
   ffe0fc00/91c07000 level 2
   f7e0fc08/91c07800 level 2
   f7e0fc08/91c07808 level 2
   ffe0fc00/91c07c00 level 2
   ffe0fc00/91c08000 level 2
   fff0fc00/91c08400 level 2
   ffe0fc00/91c09000 level 2
   fff0fc00/91c09400 level 2
   f7e0fc08/91c09800 level 2
   f7e0fc08/91c09808 level 2
   f7e0fc08/91c09c00 level 2
   f7e0fc08/91c09c08 level 2
   ffe0fc00/91c0a000 level 2
   fff0fc00/91c0a400 level 2
   ffe0fc00/91c0b000 level 2
   fff0fc00/91c0b400 level 2
   f7e0fc08/91c0b800 level 2
   f7e0fc08/91c0b808 level 2
   f7e0fc08/91c0bc00 level 2
   f7e0fc08/91c0bc08 level 2
   ffe0fc00/91c0c000 level 2
   ffe0fc00/91c0d000 level 2
   f7e0fc08/91c0d400 level 2
   f7e0fc08/91c0d408 level 2
   f7e0fc08/91c0d800 level 2
   f7e0fc08/91c0d808 level 2
   f7e0fc08/91c0dc00 level 2
   f7e0fc08/91c0dc08 level 2
   ffe0fc00/91c0e000 level 2
   ffe0fc00/91c0f000 level 2
   f7e0fc08/91c0f400 level 2
   f7e0fc08/91c0f408 level 2
   f7e0fc08/91c0f800 level 2
   f7e0fc08/91c0f808 level 2
   ffe0fc00/91c0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc00_91c00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c00000))
        return iemDecodeA64_SMAX_64_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c40000))
        return iemDecodeA64_UMAX_64U_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c80000))
        return iemDecodeA64_SMIN_64_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91cc0000))
        return iemDecodeA64_UMIN_64U_minmax_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc00/a1c00400 level 2
   fff0fc00/a1d00400 level 2
   7ff8fc00/21c00c00 level 2
   7ff8fc00/21c80c00 level 2
   7ff8fc00/21d00c00 level 2
   7ff8fc00/21d80c00 level 2
   ffe0fc00/a1c01000 level 2
   ffe4fc00/a1c01400 level 2
   ffe4fc00/a1c41400 level 2
   ffe0fc00/a1c02000 level 2
   fff0fc00/a1c02400 level 2
   fff0fc00/a1d02400 level 2
   7ff8fc00/21c02800 level 2
   7ff8fc00/21c82800 level 2
   7ff8fc00/21d02800 level 2
   7ff8fc00/21d82800 level 2
   7ff8fc00/21c02c00 level 2
   7ff8fc00/21c82c00 level 2
   7ff8fc00/21d02c00 level 2
   7ff8fc00/21d82c00 level 2
   ffe0fc00/a1c03000 level 2
   ffe4fc00/a1c03400 level 2
   ffe4fc00/a1c43400 level 2
   ffe0fc00/a1c04000 level 2
   fff0fc00/a1c04400 level 2
   fff0fc00/a1d04400 level 2
   7ff8fc00/21c04800 level 2
   7ff8fc00/21c84800 level 2
   7ff8fc00/21d04800 level 2
   7ff8fc00/21d84800 level 2
   7ff8fc00/21c04c00 level 2
   7ff8fc00/21c84c00 level 2
   7ff8fc00/21d04c00 level 2
   7ff8fc00/21d84c00 level 2
   ffe0fc00/a1c05000 level 2
   ffe4fc00/a1c05400 level 2
   ffe4fc00/a1c45400 level 2
   ffe0fc00/a1c06000 level 2
   fff0fc00/a1c06400 level 2
   fff0fc00/a1d06400 level 2
   7ff8fc00/21c06800 level 2
   7ff8fc00/21c86800 level 2
   7ff8fc00/21d06800 level 2
   7ff8fc00/21d86800 level 2
   7ff8fc00/21c06c00 level 2
   7ff8fc00/21c86c00 level 2
   7ff8fc00/21d06c00 level 2
   7ff8fc00/21d86c00 level 2
   ffe0fc00/a1c07000 level 2
   ffe4fc00/a1c07400 level 2
   ffe4fc00/a1c47400 level 2
   ffe0fc00/a1c07c00 level 2
   ffe0fc00/a1c08000 level 2
   fff0fc00/a1c08400 level 2
   fff0fc00/a1d08400 level 2
   ffe0fc00/a1c09000 level 2
   fff0fc00/a1c09400 level 2
   fff0fc00/a1d09400 level 2
   ffe0fc00/a1c0a000 level 2
   fff0fc00/a1c0a400 level 2
   fff0fc00/a1d0a400 level 2
   ffe0fc00/a1c0b000 level 2
   fff0fc00/a1c0b400 level 2
   fff0fc00/a1d0b400 level 2
   ffe0fc00/a1c0c000 level 2
   7ff8fc00/21c0c400 level 2
   7ff8fc00/21c8c400 level 2
   7ff8fc00/21d0c400 level 2
   7ff8fc00/21d8c400 level 2
   ffe0fc00/a1c0d000 level 2
   ffe0fc00/a1c0e000 level 2
   7ff8fc00/21c0e400 level 2
   7ff8fc00/21c8e400 level 2
   7ff8fc00/21d0e400 level 2
   7ff8fc00/21d8e400 level 2
   ffe0fc00/a1c0f000 level 2
   ffe0fc00/a1c0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc00_a1c00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1c00000))
        return iemDecodeA64_usmopa_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1c00010))
        return iemDecodeA64_usmops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc00/c1d00400 level 2
   fff0fc00/c1d02400 level 2
   fff0fc00/c1d04400 level 2
   fff0fc00/c1d06400 level 2
   mask=0x38 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc00_c1d00400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmla_za_zzi_d2xi,
        iemDecodeA64_sdot_za_zzi_d2xi,
        iemDecodeA64_fmls_za_zzi_d2xi,
        iemDecodeA64_udot_za_zzi_d2xi,
        iemDecodeA64_fdot_za_z8z8i_2xi,
        iemDecodeA64_fdot_za_z8z8i_2xi,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00000038 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c00400/0xf8100000
   mask=0xf8100000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%36 (0x17) multi-if=%6 (0x4) reuse=%2 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SETP_SET_memcms,
        iemDecodeA64_SETP_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETP_SET_memcms,
        iemDecodeA64_SETP_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_SETP_SET_memcms,
        iemDecodeA64_SETP_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fff0fc00_c1d00400_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETP_SET_memcms,
        iemDecodeA64_SETP_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8100000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc10/41c00800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc10_41c00800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff01010)) == UINT32_C(0xc1c00000))
        return iemDecodeA64_fmlal_za_z8z8i_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09030)) == UINT32_C(0xc1d00020))
        return iemDecodeA64_fdot_za_z8z8i_2xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09830)) == UINT32_C(0xc1d00800))
        return iemDecodeA64_fvdotb_za32_z8z8i_2xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c00800/0x78000010
   mask=0x78000010 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%38 (0xc) multi-if=%16 (0x5) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_11c00000_2,
        iemDecodeA64_7fe0fc00_11c00000_2,
        iemDecodeA64_LDAPR_32L_ldapstl_writeback,
        iemDecodeA64_LDAPR_32L_ldapstl_writeback,
        iemDecodeA64_usmopa_za_pp_zz_64,
        iemDecodeA64_usmops_za_pp_zz_64,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc10_41c00800_2,
        iemDecodeA64_fvdott_za32_z8z8i_2xi,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_LDAPR_64L_ldapstl_writeback,
        iemDecodeA64_LDAPR_64L_ldapstl_writeback,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7ff8fc00/11c00c00 level 2
   7ff8fc00/11c02800 level 2
   7ff8fc00/11c02c00 level 2
   7ff8fc00/11c04800 level 2
   7ff8fc00/11c04c00 level 2
   7ff8fc00/11c06800 level 2
   7ff8fc00/11c06c00 level 2
   7ff8fc00/11c0c400 level 2
   7ff8fc00/11c0e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7ff8fc00_11c00c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c00000))
        return iemDecodeA64_SMAX_32_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c40000))
        return iemDecodeA64_UMAX_32U_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c00000))
        return iemDecodeA64_SMAX_64_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c40000))
        return iemDecodeA64_UMAX_64U_minmax_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7ff8fc00/11c80c00 level 2
   7ff8fc00/11c82800 level 2
   7ff8fc00/11c82c00 level 2
   7ff8fc00/11c84800 level 2
   7ff8fc00/11c84c00 level 2
   7ff8fc00/11c86800 level 2
   7ff8fc00/11c86c00 level 2
   7ff8fc00/11c8c400 level 2
   7ff8fc00/11c8e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7ff8fc00_11c80c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c80000))
        return iemDecodeA64_SMIN_32_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11cc0000))
        return iemDecodeA64_UMIN_32U_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c80000))
        return iemDecodeA64_SMIN_64_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91cc0000))
        return iemDecodeA64_UMIN_64U_minmax_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7ff8fc00/41d00c00 level 2
   7ff8fc00/41d80c00 level 2
   7ff8fc00/41d02800 level 2
   7ff8fc00/41d82800 level 2
   7ff8fc00/41d02c00 level 2
   7ff8fc00/41d82c00 level 2
   7ff8fc00/41d04800 level 2
   7ff8fc00/41d84800 level 2
   7ff8fc00/41d04c00 level 2
   7ff8fc00/41d84c00 level 2
   7ff8fc00/41d06800 level 2
   7ff8fc00/41d86800 level 2
   7ff8fc00/41d06c00 level 2
   7ff8fc00/41d86c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7ff8fc00_41d00c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09030)) == UINT32_C(0xc1d00020))
        return iemDecodeA64_fdot_za_z8z8i_2xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09830)) == UINT32_C(0xc1d00800))
        return iemDecodeA64_fvdotb_za32_z8z8i_2xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09830)) == UINT32_C(0xc1d00810))
        return iemDecodeA64_fvdott_za32_z8z8i_2xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c00c00/0x78180000
   --decoder-hint1 0x7e0fc00/0x1c02800/0x78180000
   --decoder-hint1 0x7e0fc00/0x1c02c00/0x78180000
   --decoder-hint1 0x7e0fc00/0x1c04800/0x78180000
   --decoder-hint1 0x7e0fc00/0x1c04c00/0x78180000
   --decoder-hint1 0x7e0fc00/0x1c06800/0x78180000
   --decoder-hint1 0x7e0fc00/0x1c06c00/0x78180000
   mask=0x78180000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%22 (0xe) multi-if=%25 (0x10) reuse=%20 (0xd) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7ff8fc00_11c00c00_2,
        iemDecodeA64_7ff8fc00_11c80c00_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_7ff8fc00_41d00c00_2,
        iemDecodeA64_7ff8fc00_41d00c00_2,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78180000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 19) & UINT32_C(0x00000003)) /* bit 19 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1c01000 level 2
   ffe4fc00/c1c01400 level 2
   ffe4fc00/c1c41400 level 2
   ffe0fc00/c1c03000 level 2
   ffe4fc00/c1c03400 level 2
   ffe4fc00/c1c43400 level 2
   ffe0fc00/c1c05000 level 2
   ffe4fc00/c1c05400 level 2
   ffe4fc00/c1c45400 level 2
   ffe0fc00/c1c07000 level 2
   ffe4fc00/c1c07400 level 2
   ffe4fc00/c1c47400 level 2
   ffe0fc00/c1c07c00 level 2
   mask=0x100038 entries=0x10 children=0xe valid=%88 (0xe) leaf=%88 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1c01000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlal_za_zzi_1,
        iemDecodeA64_smlsl_za_zzi_1,
        iemDecodeA64_umlal_za_zzi_1,
        iemDecodeA64_umlsl_za_zzi_1,
        iemDecodeA64_smlal_za_zzi_1,
        iemDecodeA64_smlsl_za_zzi_1,
        iemDecodeA64_umlal_za_zzi_1,
        iemDecodeA64_umlsl_za_zzi_1,
        iemDecodeA64_smlal_za_zzi_2xi,
        iemDecodeA64_smlsl_za_zzi_2xi,
        iemDecodeA64_umlal_za_zzi_2xi,
        iemDecodeA64_umlsl_za_zzi_2xi,
        iemDecodeA64_fvdot_za_z8z8i_2xi,
        iemDecodeA64_fvdot_za_z8z8i_2xi,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100038 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c01000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c03000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c05000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c07000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%28 (0x9) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_LDAPURSB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe4fc00/11c01400 level 2
   ffe4fc00/11c03400 level 2
   ffe4fc00/11c05400 level 2
   ffe4fc00/11c07400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_11c01400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c00000))
        return iemDecodeA64_SMAX_32_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c80000))
        return iemDecodeA64_SMIN_32_minmax_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe4fc00/11c41400 level 2
   ffe4fc00/11c43400 level 2
   ffe4fc00/11c45400 level 2
   ffe4fc00/11c47400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_11c41400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11c40000))
        return iemDecodeA64_UMAX_32U_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x11cc0000))
        return iemDecodeA64_UMIN_32U_minmax_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe4fc00/91c01400 level 2
   ffe4fc00/91c03400 level 2
   ffe4fc00/91c05400 level 2
   ffe4fc00/91c07400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_91c01400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c00000))
        return iemDecodeA64_SMAX_64_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c80000))
        return iemDecodeA64_SMIN_64_minmax_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe4fc00/91c41400 level 2
   ffe4fc00/91c43400 level 2
   ffe4fc00/91c45400 level 2
   ffe4fc00/91c47400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_91c41400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91c40000))
        return iemDecodeA64_UMAX_64U_minmax_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x91cc0000))
        return iemDecodeA64_UMIN_64U_minmax_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c01400/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%34 (0x16) multi-if=%9 (0x6) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe4fc00_11c01400_2,
        iemDecodeA64_ffe4fc00_11c41400_2,
        iemDecodeA64_SETPT_SET_memcms,
        iemDecodeA64_SETPT_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETPT_SET_memcms,
        iemDecodeA64_SETPT_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_ffe4fc00_91c01400_2,
        iemDecodeA64_ffe4fc00_91c41400_2,
        iemDecodeA64_SETPT_SET_memcms,
        iemDecodeA64_SETPT_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETPT_SET_memcms,
        iemDecodeA64_SETPT_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc08/a1c01800 level 2
   f7e0fc08/a1c01c00 level 2
   f7e0fc08/a1c03800 level 2
   f7e0fc08/a1c03c00 level 2
   f7e0fc08/a1c05800 level 2
   f7e0fc08/a1c05c00 level 2
   f7e0fc08/a1c07800 level 2
   f7e0fc08/a1c09800 level 2
   f7e0fc08/a1c09c00 level 2
   f7e0fc08/a1c0b800 level 2
   f7e0fc08/a1c0bc00 level 2
   f7e0fc08/a1c0d400 level 2
   f7e0fc08/a1c0d800 level 2
   f7e0fc08/a1c0dc00 level 2
   f7e0fc08/a1c0f400 level 2
   f7e0fc08/a1c0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc08_a1c01800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9c00000))
        return iemDecodeA64_LDP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1c00000))
        return iemDecodeA64_usmopa_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1c00010))
        return iemDecodeA64_usmops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc08/c1c01800 level 2
   f7e0fc08/c1c01c00 level 2
   f7e0fc08/c1c03800 level 2
   f7e0fc08/c1c03c00 level 2
   f7e0fc08/c1c05800 level 2
   f7e0fc08/c1c05c00 level 2
   f7e0fc08/c1c07800 level 2
   mask=0x8100030 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%44 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc08_c1c01800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlal_za_zzi_1,
        iemDecodeA64_umlal_za_zzi_1,
        iemDecodeA64_smlal_za_zzi_1,
        iemDecodeA64_umlal_za_zzi_1,
        iemDecodeA64_smlal_za_zzi_2xi,
        iemDecodeA64_umlal_za_zzi_2xi,
        iemDecodeA64_fvdot_za_z8z8i_2xi,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x08100030 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000003)) /* bit  4 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc08/c1c01808 level 2
   f7e0fc08/c1c01c08 level 2
   f7e0fc08/c1c03808 level 2
   f7e0fc08/c1c03c08 level 2
   f7e0fc08/c1c05808 level 2
   f7e0fc08/c1c05c08 level 2
   f7e0fc08/c1c07808 level 2
   mask=0x8100030 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%44 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc08_c1c01808_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlsl_za_zzi_1,
        iemDecodeA64_umlsl_za_zzi_1,
        iemDecodeA64_smlsl_za_zzi_1,
        iemDecodeA64_umlsl_za_zzi_1,
        iemDecodeA64_smlsl_za_zzi_2xi,
        iemDecodeA64_umlsl_za_zzi_2xi,
        iemDecodeA64_fvdot_za_z8z8i_2xi,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x08100030 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000003)) /* bit  4 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc08/e1c01800 level 2
   f7e0fc08/e1c01808 level 2
   f7e0fc08/e1c01c00 level 2
   f7e0fc08/e1c01c08 level 2
   f7e0fc08/e1c03800 level 2
   f7e0fc08/e1c03808 level 2
   f7e0fc08/e1c03c00 level 2
   f7e0fc08/e1c03c08 level 2
   f7e0fc08/e1c05800 level 2
   f7e0fc08/e1c05808 level 2
   f7e0fc08/e1c05c00 level 2
   f7e0fc08/e1c05c08 level 2
   f7e0fc08/e1c07800 level 2
   f7e0fc08/e1c07808 level 2
   f7e0fc08/e1c09800 level 2
   f7e0fc08/e1c09808 level 2
   f7e0fc08/e1c09c00 level 2
   f7e0fc08/e1c09c08 level 2
   f7e0fc08/e1c0b800 level 2
   f7e0fc08/e1c0b808 level 2
   f7e0fc08/e1c0bc00 level 2
   f7e0fc08/e1c0bc08 level 2
   f7e0fc08/e1c0d400 level 2
   f7e0fc08/e1c0d408 level 2
   f7e0fc08/e1c0d800 level 2
   f7e0fc08/e1c0d808 level 2
   f7e0fc08/e1c0dc00 level 2
   f7e0fc08/e1c0dc08 level 2
   f7e0fc08/e1c0f400 level 2
   f7e0fc08/e1c0f408 level 2
   f7e0fc08/e1c0f800 level 2
   f7e0fc08/e1c0f808 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc08_e1c01800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1c00000))
        return iemDecodeA64_ld1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c01800/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c01c00/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c03800/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c03c00/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c05800/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c05c00/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c07800/0xf0000008
   mask=0xf0000008 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%28 (0x9) multi-if=%22 (0x7) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_f7e0fc08_a1c01800_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_f7e0fc08_c1c01800_2,
        iemDecodeA64_f7e0fc08_c1c01808_2,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc08_e1c01800_2,
        iemDecodeA64_f7e0fc08_e1c01800_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000008 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000001)) /* bit  3 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c02000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c04000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c06000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%28 (0x9) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_LDAPURSB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_7fe0fc00_41c00000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c02400/0xf8100000
   mask=0xf8100000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%36 (0x17) multi-if=%6 (0x4) reuse=%8 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SETPN_SET_memcms,
        iemDecodeA64_SETPN_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETPN_SET_memcms,
        iemDecodeA64_SETPN_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_SETPN_SET_memcms,
        iemDecodeA64_SETPN_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fff0fc00_c1d00400_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETPN_SET_memcms,
        iemDecodeA64_SETPN_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8100000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c03400/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%34 (0x16) multi-if=%9 (0x6) reuse=%12 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe4fc00_11c01400_2,
        iemDecodeA64_ffe4fc00_11c41400_2,
        iemDecodeA64_SETPTN_SET_memcms,
        iemDecodeA64_SETPTN_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETPTN_SET_memcms,
        iemDecodeA64_SETPTN_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_ffe4fc00_91c01400_2,
        iemDecodeA64_ffe4fc00_91c41400_2,
        iemDecodeA64_SETPTN_SET_memcms,
        iemDecodeA64_SETPTN_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETPTN_SET_memcms,
        iemDecodeA64_SETPTN_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c04400/0xf8100000
   mask=0xf8100000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%36 (0x17) multi-if=%6 (0x4) reuse=%8 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SETM_SET_memcms,
        iemDecodeA64_SETM_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETM_SET_memcms,
        iemDecodeA64_SETM_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_SETM_SET_memcms,
        iemDecodeA64_SETM_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fff0fc00_c1d00400_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETM_SET_memcms,
        iemDecodeA64_SETM_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8100000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c05400/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%34 (0x16) multi-if=%9 (0x6) reuse=%12 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe4fc00_11c01400_2,
        iemDecodeA64_ffe4fc00_11c41400_2,
        iemDecodeA64_SETMT_SET_memcms,
        iemDecodeA64_SETMT_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETMT_SET_memcms,
        iemDecodeA64_SETMT_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_ffe4fc00_91c01400_2,
        iemDecodeA64_ffe4fc00_91c41400_2,
        iemDecodeA64_SETMT_SET_memcms,
        iemDecodeA64_SETMT_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETMT_SET_memcms,
        iemDecodeA64_SETMT_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c06400/0xf8100000
   mask=0xf8100000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%36 (0x17) multi-if=%6 (0x4) reuse=%8 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SETMN_SET_memcms,
        iemDecodeA64_SETMN_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETMN_SET_memcms,
        iemDecodeA64_SETMN_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_SETMN_SET_memcms,
        iemDecodeA64_SETMN_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fff0fc00_c1d00400_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETMN_SET_memcms,
        iemDecodeA64_SETMN_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8100000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c07400/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%34 (0x16) multi-if=%9 (0x6) reuse=%12 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe4fc00_11c01400_2,
        iemDecodeA64_ffe4fc00_11c41400_2,
        iemDecodeA64_SETMTN_SET_memcms,
        iemDecodeA64_SETMTN_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETMTN_SET_memcms,
        iemDecodeA64_SETMTN_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_ffe4fc00_91c01400_2,
        iemDecodeA64_ffe4fc00_91c41400_2,
        iemDecodeA64_SETMTN_SET_memcms,
        iemDecodeA64_SETMTN_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETMTN_SET_memcms,
        iemDecodeA64_SETMTN_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c07c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%28 (0x9) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_CASPAT_CP64_comswappr_unpriv,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c1c01000_2,
        iemDecodeA64_CASAT_C64_comswap_unpriv,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fc70/c1d08000 level 3
   fff0fc70/c1d0a000 level 3
   fff0fc70/c1d0c000 level 3
   fff0fc70/c1d0e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc70_c1d08000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08000))
        return iemDecodeA64_fmla_za_zzi_d4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08008))
        return iemDecodeA64_sdot_za_zzi_d4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc70/c1d08010 level 3
   fff0fc70/c1d0a010 level 3
   fff0fc70/c1d0c010 level 3
   fff0fc70/c1d0e010 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc70_c1d08010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08010))
        return iemDecodeA64_fmls_za_zzi_d4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08018))
        return iemDecodeA64_udot_za_zzi_d4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/c1c08000 level 2
   ffe0fc00/c1c0a000 level 2
   ffe0fc00/c1c0c000 level 2
   ffe0fc00/c1c0e000 level 2
   mask=0x100070 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%25 (0x4) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1c08000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fff0fc70_c1d08000_3,
        iemDecodeA64_fff0fc70_c1d08010_3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00100070 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000007)) /* bit  4 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c08000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c0a000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c0c000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c0e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%28 (0x9) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_LDAPURSB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c1c08000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fc00/c1d08400 level 2
   fff0fc00/c1d0a400 level 2
   7ff8fc00/41d0c400 level 2
   7ff8fc00/41d8c400 level 2
   7ff8fc00/41d0e400 level 2
   7ff8fc00/41d8e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc00_c1d08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08000))
        return iemDecodeA64_fmla_za_zzi_d4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08008))
        return iemDecodeA64_sdot_za_zzi_d4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08010))
        return iemDecodeA64_fmls_za_zzi_d4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08018))
        return iemDecodeA64_udot_za_zzi_d4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c08400/0xf8100000
   mask=0xf8100000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%36 (0x17) multi-if=%8 (0x5) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SETE_SET_memcms,
        iemDecodeA64_SETE_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETE_SET_memcms,
        iemDecodeA64_SETE_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_SETE_SET_memcms,
        iemDecodeA64_SETE_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fff0fc00_c1d08400_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETE_SET_memcms,
        iemDecodeA64_SETE_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8100000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe0fc10/41c08800 level 2
   5fe0fc10/41c08c00 level 2
   5fe0fc10/41c0a800 level 2
   5fe0fc10/41c0ac00 level 2
   5fe0fc10/41c0c800 level 2
   5fe0fc10/41c0cc00 level 2
   5fe0fc10/41c0e800 level 2
   5fe0fc10/41c0ec00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc10_41c08800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1c00000))
        return iemDecodeA64_ld1q_za_p_rrr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff01010)) == UINT32_C(0xc1c00000))
        return iemDecodeA64_fmlal_za_z8z8i_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09878)) == UINT32_C(0xc1d08808))
        return iemDecodeA64_svdot_za_zzi_d4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c08800/0x58000010
   --decoder-hint1 0x7e0fc00/0x1c08c00/0x58000010
   --decoder-hint1 0x7e0fc00/0x1c0a800/0x58000010
   --decoder-hint1 0x7e0fc00/0x1c0ac00/0x58000010
   --decoder-hint1 0x7e0fc00/0x1c0c800/0x58000010
   --decoder-hint1 0x7e0fc00/0x1c0cc00/0x58000010
   --decoder-hint1 0x7e0fc00/0x1c0e800/0x58000010
   --decoder-hint1 0x7e0fc00/0x1c0ec00/0x58000010
   mask=0x58000010 entries=0x10 children=0xe valid=%88 (0xe) leaf=%44 (0x7) multi-if=%31 (0x5) reuse=%38 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_usmopa_za_pp_zz_64,
        iemDecodeA64_usmops_za_pp_zz_64,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_11c00000_2,
        iemDecodeA64_7fe0fc00_11c00000_2,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_5fe0fc10_41c08800_2,
        iemDecodeA64_uvdot_za_zzi_d4xi,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x58000010 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/c1c09000 level 2
   ffe0fc00/c1c0b000 level 2
   ffe0fc00/c1c0d000 level 2
   ffe0fc00/c1c0f000 level 2
   ffe0fc00/c1c0fc00 level 2
   mask=0x100018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_c1c09000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlal_za_zzi_1,
        iemDecodeA64_smlsl_za_zzi_1,
        iemDecodeA64_umlal_za_zzi_1,
        iemDecodeA64_umlsl_za_zzi_1,
        iemDecodeA64_smlal_za_zzi_4xi,
        iemDecodeA64_smlsl_za_zzi_4xi,
        iemDecodeA64_umlal_za_zzi_4xi,
        iemDecodeA64_umlsl_za_zzi_4xi,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c09000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c0b000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c0d000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x1c0f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%28 (0x9) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_LDAPURSB_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPURSH_32_ldapstl_unscaled,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c1c09000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fc00/c1c09400 level 2
   fff0fc00/c1c0b400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc00_c1c09400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff01018)) == UINT32_C(0xc1c01000))
        return iemDecodeA64_smlal_za_zzi_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff01018)) == UINT32_C(0xc1c01008))
        return iemDecodeA64_smlsl_za_zzi_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff01018)) == UINT32_C(0xc1c01010))
        return iemDecodeA64_umlal_za_zzi_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff01018)) == UINT32_C(0xc1c01018))
        return iemDecodeA64_umlsl_za_zzi_1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fc00/c1d09400 level 2
   fff0fc00/c1d0b400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fc00_c1d09400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09000))
        return iemDecodeA64_smlal_za_zzi_4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09008))
        return iemDecodeA64_smlsl_za_zzi_4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09010))
        return iemDecodeA64_umlal_za_zzi_4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09018))
        return iemDecodeA64_umlsl_za_zzi_4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c09400/0xf8100000
   mask=0xf8100000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%34 (0x16) multi-if=%9 (0x6) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SETET_SET_memcms,
        iemDecodeA64_SETET_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETET_SET_memcms,
        iemDecodeA64_SETET_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_SETET_SET_memcms,
        iemDecodeA64_SETET_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fff0fc00_c1c09400_2,
        iemDecodeA64_fff0fc00_c1d09400_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETET_SET_memcms,
        iemDecodeA64_SETET_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8100000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc08/c1c09800 level 2
   f7e0fc08/c1c09c00 level 2
   f7e0fc08/c1c0b800 level 2
   f7e0fc08/c1c0bc00 level 2
   f7e0fc08/c1c0d400 level 2
   f7e0fc08/c1c0d800 level 2
   f7e0fc08/c1c0dc00 level 2
   f7e0fc08/c1c0f400 level 2
   f7e0fc08/c1c0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc08_c1c09800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff01018)) == UINT32_C(0xc1c01000))
        return iemDecodeA64_smlal_za_zzi_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff01018)) == UINT32_C(0xc1c01010))
        return iemDecodeA64_umlal_za_zzi_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09000))
        return iemDecodeA64_smlal_za_zzi_4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09010))
        return iemDecodeA64_umlal_za_zzi_4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc08/c1c09808 level 2
   f7e0fc08/c1c09c08 level 2
   f7e0fc08/c1c0b808 level 2
   f7e0fc08/c1c0bc08 level 2
   f7e0fc08/c1c0d408 level 2
   f7e0fc08/c1c0d808 level 2
   f7e0fc08/c1c0dc08 level 2
   f7e0fc08/c1c0f408 level 2
   f7e0fc08/c1c0f808 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc08_c1c09808_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff01018)) == UINT32_C(0xc1c01008))
        return iemDecodeA64_smlsl_za_zzi_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff01018)) == UINT32_C(0xc1c01018))
        return iemDecodeA64_umlsl_za_zzi_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09008))
        return iemDecodeA64_smlsl_za_zzi_4xi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff09078)) == UINT32_C(0xc1d09018))
        return iemDecodeA64_umlsl_za_zzi_4xi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c09800/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c09c00/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c0b800/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c0bc00/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c0d400/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c0d800/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c0dc00/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c0f400/0xf0000008
   --decoder-hint1 0x7e0fc00/0x1c0f800/0xf0000008
   mask=0xf0000008 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%28 (0x9) multi-if=%28 (0x9) reuse=%22 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c09800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_f7e0fc08_a1c01800_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_f7e0fc08_c1c09800_2,
        iemDecodeA64_f7e0fc08_c1c09808_2,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc08_e1c01800_2,
        iemDecodeA64_f7e0fc08_e1c01800_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000008 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000001)) /* bit  3 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c0a400/0xf8100000
   mask=0xf8100000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%36 (0x17) multi-if=%8 (0x5) reuse=%8 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SETEN_SET_memcms,
        iemDecodeA64_SETEN_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETEN_SET_memcms,
        iemDecodeA64_SETEN_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_SETEN_SET_memcms,
        iemDecodeA64_SETEN_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fff0fc00_c1d08400_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETEN_SET_memcms,
        iemDecodeA64_SETEN_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8100000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c0b400/0xf8100000
   mask=0xf8100000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%34 (0x16) multi-if=%9 (0x6) reuse=%9 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SETETN_SET_memcms,
        iemDecodeA64_SETETN_SET_memcms,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_SETETN_SET_memcms,
        iemDecodeA64_SETETN_SET_memcms,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_SETETN_SET_memcms,
        iemDecodeA64_SETETN_SET_memcms,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fff0fc00_c1c09400_2,
        iemDecodeA64_fff0fc00_c1d09400_2,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_SETETN_SET_memcms,
        iemDecodeA64_SETETN_SET_memcms,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8100000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c0c400/0x78180000
   --decoder-hint1 0x7e0fc00/0x1c0e400/0x78180000
   mask=0x78180000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%22 (0xe) multi-if=%25 (0x10) reuse=%25 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7ff8fc00_11c00c00_2,
        iemDecodeA64_7ff8fc00_11c80c00_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fmlal_za_z8z8i_1,
        iemDecodeA64_fff0fc00_c1d08400_2,
        iemDecodeA64_fff0fc00_c1d08400_2,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78180000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 19) & UINT32_C(0x00000003)) /* bit 19 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1c0fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%28 (0x9) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01c0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_fff0fc00_11c00400_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_CASPALT_CP64_comswappr_unpriv,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_fff0fc00_91c00400_2,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_fff0fc00_a1c00400_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c1c09000_2,
        iemDecodeA64_CASALT_C64_comswap_unpriv,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ld1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc18/21e00008 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc18_21e00008_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1e00008))
        return iemDecodeA64_umop4a_za_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1e00208))
        return iemDecodeA64_umop4a_za_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1f00008))
        return iemDecodeA64_umop4a_za_zz_h1x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1f00208))
        return iemDecodeA64_umop4a_za_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc18/21e00018 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc18_21e00018_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1e00018))
        return iemDecodeA64_umop4s_za_zz_h1x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1e00218))
        return iemDecodeA64_umop4s_za_zz_h2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1f00018))
        return iemDecodeA64_umop4s_za_zz_h1x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff1fe38)) == UINT32_C(0xa1f00218))
        return iemDecodeA64_umop4s_za_zz_h2x2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc18/41e00000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc18_41e00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c3e)) == UINT32_C(0xc1a00000))
        return iemDecodeA64_smlall_za_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa39c7e)) == UINT32_C(0xc1a10000))
        return iemDecodeA64_smlall_za_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc18/41e00008 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc18_41e00008_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c3e)) == UINT32_C(0xc1a00008))
        return iemDecodeA64_smlsll_za_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa39c7e)) == UINT32_C(0xc1a10008))
        return iemDecodeA64_smlsll_za_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc18/41e00010 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc18_41e00010_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c3e)) == UINT32_C(0xc1a00010))
        return iemDecodeA64_umlall_za_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa39c7e)) == UINT32_C(0xc1a10010))
        return iemDecodeA64_umlall_za_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc18/41e00018 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc18_41e00018_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa19c3e)) == UINT32_C(0xc1a00018))
        return iemDecodeA64_umlsll_za_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa39c7e)) == UINT32_C(0xc1a10018))
        return iemDecodeA64_umlsll_za_zzw_4x4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e00000/0x78000018
   mask=0x78000018 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%25 (0x10) multi-if=%22 (0xe) reuse=%12 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_umopa_za_pp_zz_64,
        iemDecodeA64_7fe0fc18_21e00008_2,
        iemDecodeA64_umops_za_pp_zz_64,
        iemDecodeA64_7fe0fc18_21e00018_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc18_41e00000_2,
        iemDecodeA64_7fe0fc18_41e00008_2,
        iemDecodeA64_7fe0fc18_41e00010_2,
        iemDecodeA64_7fe0fc18_41e00018_2,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_LDGM_64bulk_ldsttags,
        iemDecodeA64_LDGM_64bulk_ldsttags,
        iemDecodeA64_LDGM_64bulk_ldsttags,
        iemDecodeA64_LDGM_64bulk_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78000018 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/a1e00400 level 2
   f7e0fc00/a1e00800 level 2
   f7e0fc00/a1e00c00 level 2
   f7e0fc00/a1e01400 level 2
   f7e0fc00/a1e03400 level 2
   d7e0fc00/81e08800 level 2
   d7e0fc00/81e08c00 level 2
   d7e0fc00/81e09400 level 2
   d7e0fc00/81e09800 level 2
   d7e0fc00/81e09c00 level 2
   d7e0fc00/81e0c400 level 2
   d7e0fc00/81e0cc00 level 2
   d7e0fc00/81e0e400 level 2
   d7e0fc00/81e0e800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_a1e00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9c00000))
        return iemDecodeA64_LDP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1e00000))
        return iemDecodeA64_umopa_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1e00010))
        return iemDecodeA64_umops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/e1e00400 level 2
   f7e0fc00/e1e00800 level 2
   f7e0fc00/e1e00c00 level 2
   f7e0fc00/e1e01400 level 2
   f7e0fc00/e1e03400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_e1e00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e00400 level 1
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDTADDAL_32_memop_unpriv,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDTADDAL_64_memop_unpriv,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_f7e0fc00_e1e00400_2,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/c1e00800 level 2
   7fe0fc00/41e02800 level 2
   7fe0fc00/41e04800 level 2
   7fe0fc00/41e06800 level 2
   mask=0x10018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_c1e00800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlal_za_zzw_2x2,
        iemDecodeA64_smlsl_za_zzw_2x2,
        iemDecodeA64_umlal_za_zzw_2x2,
        iemDecodeA64_umlsl_za_zzw_2x2,
        iemDecodeA64_smlal_za_zzw_4x4,
        iemDecodeA64_smlsl_za_zzw_4x4,
        iemDecodeA64_umlal_za_zzw_4x4,
        iemDecodeA64_umlsl_za_zzw_4x4,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00010018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 14) & UINT32_C(0x00000004)) /* bit 16 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e00800/0xf0000000
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_RCWCASAL_C64_rcwcomswap,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_RCWSCASAL_C64_rcwcomswap,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_f7e0fc00_c1e00800_2,
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_f7e0fc00_e1e00400_2,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e00c00 level 1
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_RCWCASPAL_C64_rcwcomswappr,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_RCWSCASPAL_C64_rcwcomswappr,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STZ2G_64Spre_ldsttags,
        iemDecodeA64_f7e0fc00_e1e00400_2,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/21e01000 level 2
   7fe0fc00/21e01800 level 2
   7fe0fc00/21e01c00 level 2
   7fe0fc00/21e02000 level 2
   ffe0fc00/a1e02400 level 2
   7fe0fc00/21e02800 level 2
   ffe0fc00/a1e02c00 level 2
   7fe0fc00/21e03000 level 2
   7fe0fc00/21e03800 level 2
   7fe0fc00/21e03c00 level 2
   7fe0fc00/21e04000 level 2
   ffe0fc00/a1e04400 level 2
   7fe0fc00/21e04800 level 2
   ffe0fc00/a1e04c00 level 2
   7fe0fc00/21e05000 level 2
   7fe0fc00/21e05400 level 2
   7fe0fc00/21e05800 level 2
   7fe0fc00/21e05c00 level 2
   7fe0fc00/21e06000 level 2
   ffe0fc00/a1e06400 level 2
   7fe0fc00/21e06800 level 2
   ffe0fc00/a1e06c00 level 2
   7fe0fc00/21e07000 level 2
   7fe0fc00/21e07400 level 2
   7fe0fc00/21e07800 level 2
   7fe0fc00/21e07c00 level 2
   dfe0fc00/81e08000 level 2
   ffe0fc00/a1e08400 level 2
   ffe0fc00/a1e09000 level 2
   ffe0fc00/a1e0a400 level 2
   ffe0fc00/a1e0ac00 level 2
   ffe0fc00/a1e0b400 level 2
   7fe0fc03/21e0b800 level 2
   7fe0fc03/21e0b801 level 2
   7fe0fc03/21e0b802 level 2
   7fe0fc03/21e0b803 level 2
   ffe0fc00/a1e0bc00 level 2
   ffe0fc00/a1e0c000 level 2
   ffe0fc00/a1e0c800 level 2
   dfe0fc00/81e0d000 level 2
   7fe0fc00/21e0d400 level 2
   7fe0fc00/21e0d800 level 2
   7fe0fc00/21e0dc00 level 2
   7fe0fc00/21e0e000 level 2
   ffe0fc00/a1e0ec00 level 2
   dfe0fc00/81e0f000 level 2
   ffe0fc00/a1e0f400 level 2
   ffe0fc00/a1e0f800 level 2
   ffe0fc00/a1e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_21e01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1e00000))
        return iemDecodeA64_umopa_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1e00010))
        return iemDecodeA64_umops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc00/41e01000 level 2
   7fe0fc00/41e03000 level 2
   7fe0fc00/41e05000 level 2
   7fe0fc00/41e07000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_41e01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe19c38)) == UINT32_C(0xc1e01008))
        return iemDecodeA64_bfmla_za_zzw_2x2_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe19c38)) == UINT32_C(0xc1e01018))
        return iemDecodeA64_bfmls_za_zzw_2x2_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1e11008))
        return iemDecodeA64_bfmla_za_zzw_4x4_16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe39c78)) == UINT32_C(0xc1e11018))
        return iemDecodeA64_bfmls_za_zzw_4x4_16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e01000 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDCLRPAL_128_memop_128,
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc00_41e01000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/c1e01400 level 2
   f7e0fc00/c1e03400 level 2
   7fe0fc00/41e05400 level 2
   7fe0fc00/41e07400 level 2
   mask=0x10018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_c1e01400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sdot_za_zzw_2x2,
        iemDecodeA64_sdot_za32_zzw_2x2,
        iemDecodeA64_udot_za_zzw_2x2,
        iemDecodeA64_udot_za32_zzw_2x2,
        iemDecodeA64_sdot_za_zzw_4x4,
        iemDecodeA64_sdot_za32_zzw_4x4,
        iemDecodeA64_udot_za_zzw_4x4,
        iemDecodeA64_udot_za32_zzw_4x4,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00010018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 14) & UINT32_C(0x00000004)) /* bit 16 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e01400/0xf0000000
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDTCLRAL_32_memop_unpriv,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDTCLRAL_64_memop_unpriv,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_f7e0fc00_c1e01400_2,
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_f7e0fc00_e1e00400_2,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e01800 level 1
   07e0fc00/01e03800 level 1
   07e0fc00/01e05800 level 1
   07e0fc00/01e07800 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%19 (0x3) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_dfe0fc00_c1a01800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/41e01c00 level 2
   7fe0fc00/41e03c00 level 2
   7fe0fc00/41e05c00 level 2
   7fe0fc00/41e07c00 level 2
   mask=0x50018 entries=0x10 children=0xc valid=%75 (0xc) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_41e01c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_za_zw_2x2,
        iemDecodeA64_fsub_za_zw_2x2,
        iemDecodeA64_add_za_zw_2x2,
        iemDecodeA64_sub_za_zw_2x2,
        iemDecodeA64_fadd_za_zw_4x4,
        iemDecodeA64_fsub_za_zw_4x4,
        iemDecodeA64_add_za_zw_4x4,
        iemDecodeA64_sub_za_zw_4x4,
        iemDecodeA64_bfadd_za_zw_2x2_16,
        iemDecodeA64_bfsub_za_zw_2x2_16,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_bfadd_za_zw_4x4_16,
        iemDecodeA64_bfsub_za_zw_4x4_16,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00050018 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 14) & UINT32_C(0x00000004)) /* bit 16 L 1 -> 2 */
                        | ((uOpcode >> 15) & UINT32_C(0x00000008)) /* bit 18 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e01c00/0x78000000
   --decoder-hint1 0x7e0fc00/0x1e03c00/0x78000000
   --decoder-hint1 0x7e0fc00/0x1e05c00/0x78000000
   --decoder-hint1 0x7e0fc00/0x1e07c00/0x78000000
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc00_41e01c00_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_STZ2G_64Spre_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/41e02000 level 2
   7fe0fc00/41e04000 level 2
   7fe0fc00/41e06000 level 2
   mask=0x10018 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_41e02000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smlall_za_zzw_2x2,
        iemDecodeA64_smlsll_za_zzw_2x2,
        iemDecodeA64_umlall_za_zzw_2x2,
        iemDecodeA64_umlsll_za_zzw_2x2,
        iemDecodeA64_smlall_za_zzw_4x4,
        iemDecodeA64_smlsll_za_zzw_4x4,
        iemDecodeA64_umlall_za_zzw_4x4,
        iemDecodeA64_umlsll_za_zzw_4x4,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00010018 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 14) & UINT32_C(0x00000004)) /* bit 16 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e02000 level 1
   07e0fc00/01e04000 level 1
   07e0fc00/01e06000 level 1
   mask=0x78000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%19 (0x3) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc00_41e02000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e02400 level 1
   07e0fc00/01e04400 level 1
   07e0fc00/01e06400 level 1
   07e0fc00/01e0f400 level 1
   mask=0xf8000000 entries=0x20 children=0x9 valid=%28 (0x9) leaf=%25 (0x8) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e02800 level 1
   07e0fc00/01e04800 level 1
   07e0fc00/01e06800 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%19 (0x3) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_f7e0fc00_c1e00800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e02c00 level 1
   07e0fc00/01e04c00 level 1
   07e0fc00/01e06c00 level 1
   07e0fc00/01e0ec00 level 1
   07e0fc00/01e0fc00 level 1
   mask=0xf8000000 entries=0x20 children=0x9 valid=%28 (0x9) leaf=%25 (0x8) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Spre_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e03000 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDSETPAL_128_memop_128,
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc00_41e01000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e03400/0xf0000000
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDTSETAL_32_memop_unpriv,
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDTSETAL_64_memop_unpriv,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_f7e0fc00_c1e01400_2,
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_f7e0fc00_e1e00400_2,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e05000 level 1
   07e0fc00/01e07000 level 1
   mask=0x78000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%19 (0x3) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc00_41e01000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e05400 level 1
   07e0fc00/01e07400 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%19 (0x3) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_f7e0fc00_c1e01400_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/19e08000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_19e08000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x39c00000))
        return iemDecodeA64_LDRSB_32_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e08000))
        return iemDecodeA64_SWPPAL_128_memop_128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc00/c1e08000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c1e08000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21e021)) == UINT32_C(0xc1208000))
        return iemDecodeA64_sel_mz_p_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23e063)) == UINT32_C(0xc1218000))
        return iemDecodeA64_sel_mz_p_zz_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e08000 level 1
   mask=0xd8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%31 (0x5) multi-if=%19 (0x3) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_dfe0fc00_19e08000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_dfe0fc00_c1e08000_2,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e08400 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%31 (0xa) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_SWPTAL_32_memop_unpriv,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SWPTAL_64_memop_unpriv,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* d7e0fc00/c1e08800 level 2
   d7e0fc00/c1e08c00 level 2
   d7e0fc00/c1e09400 level 2
   d7e0fc00/c1e09800 level 2
   d7e0fc00/c1e09c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_d7e0fc00_c1e08800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21e021)) == UINT32_C(0xc1208000))
        return iemDecodeA64_sel_mz_p_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23e063)) == UINT32_C(0xc1218000))
        return iemDecodeA64_sel_mz_p_zz_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e08800 level 1
   07e0fc00/01e09800 level 1
   mask=0xd0000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_d7e0fc00_c1e08800_2,
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xd0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000001)) /* bit 28 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e08c00 level 1
   07e0fc00/01e09c00 level 1
   mask=0xd0000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_d7e0fc00_c1e08800_2,
        iemDecodeA64_STZ2G_64Spre_ldsttags,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xd0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000001)) /* bit 28 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e09000 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%28 (0x9) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_RCWCLRPAL_128_memop_128,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_RCWSCLRPAL_128_memop_128,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe0fc00_c1208000_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e09400 level 1
   mask=0xd0000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_d7e0fc00_c1e08800_2,
        iemDecodeA64_STZ2G_64Spost_ldsttags,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xd0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000001)) /* bit 28 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 2fe0fc18/09e0a000 level 2
   2fe0fc18/09e0a008 level 2
   2fe0fc18/09e0a010 level 2
   2fe0fc18/09e0a018 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_2fe0fc18_09e0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x19e0a000))
        return iemDecodeA64_RCWSWPPAL_128_memop_128(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x59e0a000))
        return iemDecodeA64_RCWSSWPPAL_128_memop_128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 2fe0fc18/21e0a000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_2fe0fc18_21e0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1e00000))
        return iemDecodeA64_umopa_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 2fe0fc18/29e0a000 level 2
   2fe0fc18/29e0a008 level 2
   2fe0fc18/29e0a010 level 2
   2fe0fc18/29e0a018 level 2
   mask=0xd0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_2fe0fc18_29e0a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xd0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000001)) /* bit 28 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e0a000/0x28000018
   mask=0x28000018 entries=0x10 children=0xf valid=%94 (0xf) leaf=%12 (0x2) multi-if=%31 (0x5) reuse=%62 (0xa) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_c160a000_2,
        iemDecodeA64_ffe0fc00_c160a000_2,
        iemDecodeA64_ffe0fc00_c160a000_2,
        iemDecodeA64_ffe0fc00_c160a000_2,
        iemDecodeA64_2fe0fc18_09e0a000_2,
        iemDecodeA64_2fe0fc18_09e0a000_2,
        iemDecodeA64_2fe0fc18_09e0a000_2,
        iemDecodeA64_2fe0fc18_09e0a000_2,
        iemDecodeA64_2fe0fc18_21e0a000_2,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_umops_za_pp_zz_64,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_2fe0fc18_29e0a000_2,
        iemDecodeA64_2fe0fc18_29e0a000_2,
        iemDecodeA64_2fe0fc18_29e0a000_2,
        iemDecodeA64_2fe0fc18_29e0a000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x28000018 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000003)) /* bit  3 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000004)) /* bit 27 L 1 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000008)) /* bit 29 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0a400 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%28 (0x9) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_sqdmulh_mz_zzv_2x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0ff90/c1e0a800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0ff90_c1e0a800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a800))
        return iemDecodeA64_smax_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a801))
        return iemDecodeA64_umax_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a820))
        return iemDecodeA64_smin_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a821))
        return iemDecodeA64_umin_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0ff90/c1e0a900 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0ff90_c1e0a900_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a900))
        return iemDecodeA64_fmax_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a901))
        return iemDecodeA64_fmin_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a920))
        return iemDecodeA64_fmaxnm_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120a921))
        return iemDecodeA64_fminnm_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0ff90/c1e0aa00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0ff90_c1e0aa00_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120aa20))
        return iemDecodeA64_srshl_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30ffe3)) == UINT32_C(0xc120aa21))
        return iemDecodeA64_urshl_mz_zzv_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe0fc10/41e0a800 level 2
   mask=0xa0000380 entries=0x20 children=0xd valid=%41 (0xd) leaf=%31 (0xa) multi-if=%9 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc10_41e0a800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0ff90_c1e0a800_3,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ffe0ff90_c1e0a900_3,
        iemDecodeA64_fscale_mz_zzv_4x1,
        iemDecodeA64_ffe0ff90_c1e0aa00_3,
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_add_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xa0000380 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  7) & UINT32_C(0x00000007)) /* bit  7 L 3 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000008)) /* bit 29 L 1 -> 3 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe0fc10/59e0a800 level 2
   5fe0fc10/59e0a810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe0fc10_59e0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x79c00000))
        return iemDecodeA64_LDRSH_32_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xd9e00800))
        return iemDecodeA64_STZ2G_64Soffset_ldsttags(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e0a800/0x58000010
   mask=0x58000010 entries=0x10 children=0xc valid=%75 (0xc) leaf=%25 (0x4) multi-if=%38 (0x6) reuse=%38 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_umopa_za_pp_zz_64,
        iemDecodeA64_umops_za_pp_zz_64,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_5fe0fc10_41e0a800_2,
        iemDecodeA64_ffe0fc00_c160a800_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_5fe0fc10_59e0a800_2,
        iemDecodeA64_5fe0fc10_59e0a800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x58000010 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0ac00 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%28 (0x9) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_sqdmulh_mz_zzv_4x1,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Spre_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc08/21e0b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc08_21e0b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x29c00000))
        return iemDecodeA64_LDP_32_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xa9c00000))
        return iemDecodeA64_LDP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1e00000))
        return iemDecodeA64_umopa_za_pp_zz_64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00018)) == UINT32_C(0xa1e00010))
        return iemDecodeA64_umops_za_pp_zz_64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e0fc08/61e0b000 level 2
   77e0fc08/61e0b008 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc08_61e0b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x69c00000))
        return iemDecodeA64_LDPSW_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e0b000/0x70000008
   mask=0x70000008 entries=0x10 children=0xe valid=%88 (0xe) leaf=%50 (0x8) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_RCWSETPAL_128_memop_128,
        iemDecodeA64_RCWSETPAL_128_memop_128,
        iemDecodeA64_77e0fc08_21e0b000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c160b000_2,
        iemDecodeA64_ffe0fc00_c160b000_2,
        iemDecodeA64_RCWSSETPAL_128_memop_128,
        iemDecodeA64_RCWSSETPAL_128_memop_128,
        iemDecodeA64_77e0fc08_61e0b000_2,
        iemDecodeA64_77e0fc08_61e0b000_2,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x70000008 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000001)) /* bit  3 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000000e)) /* bit 28 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0b400 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%28 (0x9) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_sqdmulh_mz_zzw_2x2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x1e0b800/0x78000003
   mask=0x78000003 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%25 (0x10) multi-if=%19 (0xc) reuse=%22 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc03_41a0b800_2,
        iemDecodeA64_7fe0fc03_41a0b801_2,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78000003 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000003)) /* bit  0 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0bc00 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%28 (0x9) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_sqdmulh_mz_zzw_4x4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Spre_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0c000 level 1
   mask=0xf8000000 entries=0x20 children=0x9 valid=%28 (0x9) leaf=%25 (0x8) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fclamp_mz_zz_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* d7e0fc00/c1e0c400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_d7e0fc00_c1e0c400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120c400))
        return iemDecodeA64_sclamp_mz_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120c401))
        return iemDecodeA64_uclamp_mz_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e0c400 level 1
   mask=0xd0000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_d7e0fc00_c1e0c400_2,
        iemDecodeA64_STZ2G_64Spost_ldsttags,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xd0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000001)) /* bit 28 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0c800 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%28 (0x9) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fclamp_mz_zz_4,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* d7e0fc00/c1e0cc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_d7e0fc00_c1e0cc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc03)) == UINT32_C(0xc120cc00))
        return iemDecodeA64_sclamp_mz_zz_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc03)) == UINT32_C(0xc120cc01))
        return iemDecodeA64_uclamp_mz_zz_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e0cc00 level 1
   mask=0xd0000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_d7e0fc00_c1e0cc00_2,
        iemDecodeA64_STZ2G_64Spre_ldsttags,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xd0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000001)) /* bit 28 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc00/c1e0d000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc00_c1e0d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120d000))
        return iemDecodeA64_zip_mz_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc01)) == UINT32_C(0xc120d001))
        return iemDecodeA64_uzp_mz_zz_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e0d000 level 1
   mask=0xd8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%38 (0x6) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_dfe0fc00_c1e0d000_2,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/41e0d400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_41e0d400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc20)) == UINT32_C(0xc1e0d400))
        return iemDecodeA64_sqrshr_z_mz2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc20)) == UINT32_C(0xc1e0d420))
        return iemDecodeA64_uqrshr_z_mz2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc20)) == UINT32_C(0xc1f0d400))
        return iemDecodeA64_sqrshru_z_mz2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e0d400 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%25 (0x4) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc00_41e0d400_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_STZ2G_64Spost_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0d800 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0dc00 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%25 (0x4) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_ffe0fc00_c120dc00_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_STZ2G_64Spre_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/41e0e000 level 2
   mask=0x130001 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%38 (0x6) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_41e0e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_sunpk_mz_z_2,
        iemDecodeA64_uunpk_mz_z_2,
        iemDecodeA64_bf2cvt_mz2_z8,
        iemDecodeA64_bf2cvtl_mz2_z8,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_sunpk_mz_z_4,
        iemDecodeA64_uunpk_mz_z_4,
        iemDecodeA64_fff7fc21_c136e000_3,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_fff7fc01_c173e000_3,
        iemDecodeA64_fff7fc01_c173e000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00130001 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x00000006)) /* bit 16 L 2 -> 1 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0e000 level 1
   mask=0x78000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%19 (0x3) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_7fe0fc00_29c00000_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_7fe0fc00_41e0e000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_7fe0fc00_69c00000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* d7e0fc00/c1e0e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_d7e0fc00_c1e0e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21fc21)) == UINT32_C(0xc120e400))
        return iemDecodeA64_fmul_mz_zzw_2x2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff23fc63)) == UINT32_C(0xc121e400))
        return iemDecodeA64_fmul_mz_zzw_4x4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e0e400 level 1
   mask=0xd0000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_d7e0fc00_c1e0e400_2,
        iemDecodeA64_STZ2G_64Spost_ldsttags,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xd0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000001)) /* bit 28 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* d7e0fc00/c1e0e800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_d7e0fc00_c1e0e800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff21fc21)) == UINT32_C(0xc120e800))
        return iemDecodeA64_fmul_mz_zzv_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff21fc63)) == UINT32_C(0xc121e800))
        return iemDecodeA64_fmul_mz_zzv_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xe9c00000))
        return iemDecodeA64_LDTP_64_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00010)) == UINT32_C(0xe1e00000))
        return iemDecodeA64_st1q_za_p_rrr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/01e0e800 level 1
   mask=0xd0000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_f7e0fc00_a1e00400_2,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_d7e0fc00_c1e0e800_2,
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xd0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000001)) /* bit 28 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0f000 level 1
   mask=0xd8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xd8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000003)) /* bit 27 L 2 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000c)) /* bit 30 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/01e0f800 level 1
   mask=0xf8000000 entries=0x20 children=0x9 valid=%28 (0x9) leaf=%25 (0x8) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_01e0f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_32_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDRSB_32_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDPSW_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDRSH_32_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_7fe0fc00_21e01000_2,
        iemDecodeA64_LDP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_STZ2G_64Soffset_ldsttags,
        iemDecodeA64_st1q_za_p_rrr,
        iemDecodeA64_LDTP_64_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x2000000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02000000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_AND_32_log_imm,
        iemDecodeA64_ADC_32_addsub_carry,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_ORR_32_log_imm,
        iemDecodeA64_ADCS_32_addsub_carry,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_EOR_32_log_imm,
        iemDecodeA64_SBC_32_addsub_carry,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_ANDS_32S_log_imm,
        iemDecodeA64_SBCS_32_addsub_carry,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_ADC_64_addsub_carry,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_ORR_64_log_imm,
        iemDecodeA64_ADCS_64_addsub_carry,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_SBC_64_addsub_carry,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
        iemDecodeA64_SBCS_64_addsub_carry,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/b2000400 level 2
   f7e0fc00/b2008400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_b2000400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xb2000000))
        return iemDecodeA64_ORR_64_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe07c10)) == UINT32_C(0xba000400))
        return iemDecodeA64_RMIF_only_rmif(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02000400 level 1
   07e0fc00/02008400 level 1
   mask=0xf0000000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%94 (0xf) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02000400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_AND_32_log_imm,
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_ORR_32_log_imm,
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_EOR_32_log_imm,
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_ANDS_32S_log_imm,
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_f7e0fc00_b2000400_2,
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/32000800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_32000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x32000000))
        return iemDecodeA64_ORR_32_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0x3a00080d))
        return iemDecodeA64_SETF8_only_setf(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02000800 level 1
   mask=0xf0000000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%94 (0xf) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02000800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_AND_32_log_imm,
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_f7e0fc00_32000800_2,
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_EOR_32_log_imm,
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_ANDS_32S_log_imm,
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_ORR_64_log_imm,
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02000c00 level 1
   07e0fc00/02001000 level 1
   07e0fc00/02001400 level 1
   07e0fc00/02001800 level 1
   07e0fc00/02001c00 level 1
   07e0fc00/02004000 level 1
   07e0fc00/02004400 level 1
   07e0fc00/02004c00 level 1
   07e0fc00/02005000 level 1
   07e0fc00/02005400 level 1
   07e0fc00/02005800 level 1
   07e0fc00/02005c00 level 1
   07e0fc00/02006000 level 1
   07e0fc00/02006400 level 1
   07e0fc00/02006800 level 1
   07e0fc00/02006c00 level 1
   07e0fc00/02007000 level 1
   07e0fc00/02007400 level 1
   07e0fc00/02007800 level 1
   07e0fc00/02007c00 level 1
   07e0fc00/02008000 level 1
   07e0fc00/02008800 level 1
   07e0fc00/02008c00 level 1
   07e0fc00/02009000 level 1
   07e0fc00/02009400 level 1
   07e0fc00/02009800 level 1
   07e0fc00/02009c00 level 1
   07e0fc00/0200a000 level 1
   07e0fc00/0200a400 level 1
   07e0fc00/0200a800 level 1
   07e0fc00/0200ac00 level 1
   07e0fc00/0200b000 level 1
   07e0fc00/0200b400 level 1
   07e0fc00/0200b800 level 1
   07e0fc00/0200bc00 level 1
   07e0fc00/0200c000 level 1
   07e0fc00/0200c400 level 1
   07e0fc00/0200c800 level 1
   07e0fc00/0200cc00 level 1
   07e0fc00/0200d000 level 1
   07e0fc00/0200d400 level 1
   07e0fc00/0200d800 level 1
   07e0fc00/0200dc00 level 1
   07e0fc00/0200e000 level 1
   07e0fc00/0200e400 level 1
   07e0fc00/0200e800 level 1
   07e0fc00/0200ec00 level 1
   07e0fc00/0200f000 level 1
   07e0fc00/0200f400 level 1
   07e0fc00/0200f800 level 1
   07e0fc00/0200fc00 level 1
   mask=0xf0000000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%100 (0x10) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02000c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_AND_32_log_imm,
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_ORR_32_log_imm,
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_EOR_32_log_imm,
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_ANDS_32S_log_imm,
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_ORR_64_log_imm,
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/92002000 level 2
   f7e0fc00/92002400 level 2
   f7e0fc00/92002800 level 2
   f7e0fc00/92002c00 level 2
   f7e0fc00/92003000 level 2
   f7e0fc00/92003400 level 2
   f7e0fc00/92003800 level 2
   f7e0fc00/92003c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_92002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0x92000000))
        return iemDecodeA64_AND_64_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0x9a002000))
        return iemDecodeA64_ADDPT_64_addsub_pt(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/d2002000 level 2
   f7e0fc00/d2002400 level 2
   f7e0fc00/d2002800 level 2
   f7e0fc00/d2002c00 level 2
   f7e0fc00/d2003000 level 2
   f7e0fc00/d2003400 level 2
   f7e0fc00/d2003800 level 2
   f7e0fc00/d2003c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_d2002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xd2000000))
        return iemDecodeA64_EOR_64_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xda002000))
        return iemDecodeA64_SUBPT_64_addsub_pt(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02002000 level 1
   07e0fc00/02002400 level 1
   07e0fc00/02002800 level 1
   07e0fc00/02002c00 level 1
   07e0fc00/02003000 level 1
   07e0fc00/02003400 level 1
   07e0fc00/02003800 level 1
   07e0fc00/02003c00 level 1
   mask=0xf0000000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%88 (0xe) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02002000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_AND_32_log_imm,
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_ORR_32_log_imm,
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_EOR_32_log_imm,
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_ANDS_32S_log_imm,
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_f7e0fc00_92002000_2,
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_ORR_64_log_imm,
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_f7e0fc00_d2002000_2,
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/32004800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_32004800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x32000000))
        return iemDecodeA64_ORR_32_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0x3a00480d))
        return iemDecodeA64_SETF16_only_setf(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02004800 level 1
   mask=0xf0000000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%94 (0xf) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02004800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_AND_32_log_imm,
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_f7e0fc00_32004800_2,
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_EOR_32_log_imm,
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_ANDS_32S_log_imm,
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_ORR_64_log_imm,
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02200000 level 1
   07e0fc00/02200400 level 1
   07e0fc00/02200800 level 1
   07e0fc00/02200c00 level 1
   07e0fc00/02201000 level 1
   07e0fc00/02201400 level 1
   07e0fc00/02201800 level 1
   07e0fc00/02201c00 level 1
   07e0fc00/02202000 level 1
   07e0fc00/02202400 level 1
   07e0fc00/02202800 level 1
   07e0fc00/02202c00 level 1
   07e0fc00/02203000 level 1
   07e0fc00/02203400 level 1
   07e0fc00/02203800 level 1
   07e0fc00/02203c00 level 1
   07e0fc00/02204000 level 1
   07e0fc00/02204400 level 1
   07e0fc00/02204800 level 1
   07e0fc00/02204c00 level 1
   07e0fc00/02205000 level 1
   07e0fc00/02205400 level 1
   07e0fc00/02205800 level 1
   07e0fc00/02205c00 level 1
   07e0fc00/02206000 level 1
   07e0fc00/02206400 level 1
   07e0fc00/02206800 level 1
   07e0fc00/02206c00 level 1
   07e0fc00/02207000 level 1
   07e0fc00/02207400 level 1
   07e0fc00/02207800 level 1
   07e0fc00/02207c00 level 1
   07e0fc00/02208000 level 1
   07e0fc00/02208400 level 1
   07e0fc00/02208800 level 1
   07e0fc00/02208c00 level 1
   07e0fc00/02209000 level 1
   07e0fc00/02209400 level 1
   07e0fc00/02209800 level 1
   07e0fc00/02209c00 level 1
   07e0fc00/0220a000 level 1
   07e0fc00/0220a400 level 1
   07e0fc00/0220a800 level 1
   07e0fc00/0220ac00 level 1
   07e0fc00/0220b000 level 1
   07e0fc00/0220b400 level 1
   07e0fc00/0220b800 level 1
   07e0fc00/0220bc00 level 1
   07e0fc00/0220c000 level 1
   07e0fc00/0220c400 level 1
   07e0fc00/0220c800 level 1
   07e0fc00/0220cc00 level 1
   07e0fc00/0220d000 level 1
   07e0fc00/0220d400 level 1
   07e0fc00/0220d800 level 1
   07e0fc00/0220dc00 level 1
   07e0fc00/0220e000 level 1
   07e0fc00/0220e400 level 1
   07e0fc00/0220e800 level 1
   07e0fc00/0220ec00 level 1
   07e0fc00/0220f000 level 1
   07e0fc00/0220f400 level 1
   07e0fc00/0220f800 level 1
   07e0fc00/0220fc00 level 1
   mask=0xf0000000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%100 (0x10) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02200000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_BIC_32_log_shift,
        iemDecodeA64_AND_32_log_imm,
        iemDecodeA64_ORN_32_log_shift,
        iemDecodeA64_ORR_32_log_imm,
        iemDecodeA64_EON_32_log_shift,
        iemDecodeA64_EOR_32_log_imm,
        iemDecodeA64_BICS_32_log_shift,
        iemDecodeA64_ANDS_32S_log_imm,
        iemDecodeA64_BIC_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_ORN_64_log_shift,
        iemDecodeA64_ORR_64_log_imm,
        iemDecodeA64_EON_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_BICS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/b2400000 level 2
   f7e0fc00/b2401000 level 2
   f7e0fc00/b2402000 level 2
   f7e0fc00/b2403000 level 2
   f7e0fc00/b2404000 level 2
   f7e0fc00/b2405000 level 2
   f7e0fc00/b2406000 level 2
   f7e0fc00/b2407000 level 2
   f7e0fc00/b2408000 level 2
   f7e0fc00/b2409000 level 2
   f7e0fc00/b240a000 level 2
   f7e0fc00/b240b000 level 2
   f7e0fc00/b240c000 level 2
   f7e0fc00/b240d000 level 2
   f7e0fc00/b240e000 level 2
   f7e0fc00/b240f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_b2400000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xb2000000))
        return iemDecodeA64_ORR_64_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0xba400000))
        return iemDecodeA64_CCMN_64_condcmp_reg(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/f2400000 level 2
   f7e0fc00/f2401000 level 2
   f7e0fc00/f2402000 level 2
   f7e0fc00/f2403000 level 2
   f7e0fc00/f2404000 level 2
   f7e0fc00/f2405000 level 2
   f7e0fc00/f2406000 level 2
   f7e0fc00/f2407000 level 2
   f7e0fc00/f2408000 level 2
   f7e0fc00/f2409000 level 2
   f7e0fc00/f240a000 level 2
   f7e0fc00/f240b000 level 2
   f7e0fc00/f240c000 level 2
   f7e0fc00/f240d000 level 2
   f7e0fc00/f240e000 level 2
   f7e0fc00/f240f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_f2400000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xf2000000))
        return iemDecodeA64_ANDS_64S_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0xfa400000))
        return iemDecodeA64_CCMP_64_condcmp_reg(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02400000 level 1
   07e0fc00/02401000 level 1
   07e0fc00/02402000 level 1
   07e0fc00/02403000 level 1
   07e0fc00/02404000 level 1
   07e0fc00/02405000 level 1
   07e0fc00/02406000 level 1
   07e0fc00/02407000 level 1
   07e0fc00/02408000 level 1
   07e0fc00/02409000 level 1
   07e0fc00/0240a000 level 1
   07e0fc00/0240b000 level 1
   07e0fc00/0240c000 level 1
   07e0fc00/0240d000 level 1
   07e0fc00/0240e000 level 1
   07e0fc00/0240f000 level 1
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02400000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_CCMN_32_condcmp_reg,
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_CCMP_32_condcmp_reg,
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_f7e0fc00_b2400000_2,
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_f7e0fc00_f2400000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02400400 level 1
   07e0fc00/02400c00 level 1
   07e0fc00/02401400 level 1
   07e0fc00/02401c00 level 1
   07e0fc00/02402400 level 1
   07e0fc00/02402c00 level 1
   07e0fc00/02403400 level 1
   07e0fc00/02403c00 level 1
   07e0fc00/02404400 level 1
   07e0fc00/02404c00 level 1
   07e0fc00/02405400 level 1
   07e0fc00/02405c00 level 1
   07e0fc00/02406400 level 1
   07e0fc00/02406c00 level 1
   07e0fc00/02407400 level 1
   07e0fc00/02407c00 level 1
   07e0fc00/02408400 level 1
   07e0fc00/02408c00 level 1
   07e0fc00/02409400 level 1
   07e0fc00/02409c00 level 1
   07e0fc00/0240a400 level 1
   07e0fc00/0240ac00 level 1
   07e0fc00/0240b400 level 1
   07e0fc00/0240bc00 level 1
   07e0fc00/0240c400 level 1
   07e0fc00/0240cc00 level 1
   07e0fc00/0240d400 level 1
   07e0fc00/0240dc00 level 1
   07e0fc00/0240e400 level 1
   07e0fc00/0240ec00 level 1
   07e0fc00/0240f400 level 1
   07e0fc00/0240fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02400400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_ORR_64_log_imm,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/b2400800 level 2
   f7e0fc00/b2401800 level 2
   f7e0fc00/b2402800 level 2
   f7e0fc00/b2403800 level 2
   f7e0fc00/b2404800 level 2
   f7e0fc00/b2405800 level 2
   f7e0fc00/b2406800 level 2
   f7e0fc00/b2407800 level 2
   f7e0fc00/b2408800 level 2
   f7e0fc00/b2409800 level 2
   f7e0fc00/b240a800 level 2
   f7e0fc00/b240b800 level 2
   f7e0fc00/b240c800 level 2
   f7e0fc00/b240d800 level 2
   f7e0fc00/b240e800 level 2
   f7e0fc00/b240f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_b2400800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xb2000000))
        return iemDecodeA64_ORR_64_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0xba400800))
        return iemDecodeA64_CCMN_64_condcmp_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/f2400800 level 2
   f7e0fc00/f2401800 level 2
   f7e0fc00/f2402800 level 2
   f7e0fc00/f2403800 level 2
   f7e0fc00/f2404800 level 2
   f7e0fc00/f2405800 level 2
   f7e0fc00/f2406800 level 2
   f7e0fc00/f2407800 level 2
   f7e0fc00/f2408800 level 2
   f7e0fc00/f2409800 level 2
   f7e0fc00/f240a800 level 2
   f7e0fc00/f240b800 level 2
   f7e0fc00/f240c800 level 2
   f7e0fc00/f240d800 level 2
   f7e0fc00/f240e800 level 2
   f7e0fc00/f240f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_f2400800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff800000)) == UINT32_C(0xf2000000))
        return iemDecodeA64_ANDS_64S_log_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0xfa400800))
        return iemDecodeA64_CCMP_64_condcmp_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02400800 level 1
   07e0fc00/02401800 level 1
   07e0fc00/02402800 level 1
   07e0fc00/02403800 level 1
   07e0fc00/02404800 level 1
   07e0fc00/02405800 level 1
   07e0fc00/02406800 level 1
   07e0fc00/02407800 level 1
   07e0fc00/02408800 level 1
   07e0fc00/02409800 level 1
   07e0fc00/0240a800 level 1
   07e0fc00/0240b800 level 1
   07e0fc00/0240c800 level 1
   07e0fc00/0240d800 level 1
   07e0fc00/0240e800 level 1
   07e0fc00/0240f800 level 1
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02400800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_CCMN_32_condcmp_imm,
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_CCMP_32_condcmp_imm,
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_f7e0fc00_b2400800_2,
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_f7e0fc00_f2400800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02600000 level 1
   07e0fc00/02600400 level 1
   07e0fc00/02600800 level 1
   07e0fc00/02600c00 level 1
   07e0fc00/02601000 level 1
   07e0fc00/02601400 level 1
   07e0fc00/02601800 level 1
   07e0fc00/02601c00 level 1
   07e0fc00/02602000 level 1
   07e0fc00/02602400 level 1
   07e0fc00/02602800 level 1
   07e0fc00/02602c00 level 1
   07e0fc00/02603000 level 1
   07e0fc00/02603400 level 1
   07e0fc00/02603800 level 1
   07e0fc00/02603c00 level 1
   07e0fc00/02604000 level 1
   07e0fc00/02604400 level 1
   07e0fc00/02604800 level 1
   07e0fc00/02604c00 level 1
   07e0fc00/02605000 level 1
   07e0fc00/02605400 level 1
   07e0fc00/02605800 level 1
   07e0fc00/02605c00 level 1
   07e0fc00/02606000 level 1
   07e0fc00/02606400 level 1
   07e0fc00/02606800 level 1
   07e0fc00/02606c00 level 1
   07e0fc00/02607000 level 1
   07e0fc00/02607400 level 1
   07e0fc00/02607800 level 1
   07e0fc00/02607c00 level 1
   07e0fc00/02608000 level 1
   07e0fc00/02608400 level 1
   07e0fc00/02608800 level 1
   07e0fc00/02608c00 level 1
   07e0fc00/02609000 level 1
   07e0fc00/02609400 level 1
   07e0fc00/02609800 level 1
   07e0fc00/02609c00 level 1
   07e0fc00/0260a000 level 1
   07e0fc00/0260a400 level 1
   07e0fc00/0260a800 level 1
   07e0fc00/0260ac00 level 1
   07e0fc00/0260b000 level 1
   07e0fc00/0260b400 level 1
   07e0fc00/0260b800 level 1
   07e0fc00/0260bc00 level 1
   07e0fc00/0260c000 level 1
   07e0fc00/0260c400 level 1
   07e0fc00/0260c800 level 1
   07e0fc00/0260cc00 level 1
   07e0fc00/0260d000 level 1
   07e0fc00/0260d400 level 1
   07e0fc00/0260d800 level 1
   07e0fc00/0260dc00 level 1
   07e0fc00/0260e000 level 1
   07e0fc00/0260e400 level 1
   07e0fc00/0260e800 level 1
   07e0fc00/0260ec00 level 1
   07e0fc00/0260f000 level 1
   07e0fc00/0260f400 level 1
   07e0fc00/0260f800 level 1
   07e0fc00/0260fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02600000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_BIC_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORN_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EON_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_BICS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_BIC_64_log_shift,
        iemDecodeA64_AND_64_log_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORN_64_log_shift,
        iemDecodeA64_ORR_64_log_imm,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EON_64_log_shift,
        iemDecodeA64_EOR_64_log_imm,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_BICS_64_log_shift,
        iemDecodeA64_ANDS_64S_log_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02800000 level 1
   07e0fc00/02801000 level 1
   07e0fc00/02802000 level 1
   07e0fc00/02803000 level 1
   07e0fc00/02804000 level 1
   07e0fc00/02805000 level 1
   07e0fc00/02806000 level 1
   07e0fc00/02807000 level 1
   07e0fc00/02808000 level 1
   07e0fc00/02809000 level 1
   07e0fc00/0280a000 level 1
   07e0fc00/0280b000 level 1
   07e0fc00/0280c000 level 1
   07e0fc00/0280d000 level 1
   07e0fc00/0280e000 level 1
   07e0fc00/0280f000 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02800000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_MOVN_32_movewide,
        iemDecodeA64_CSEL_32_condsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_MOVZ_32_movewide,
        iemDecodeA64_CSINV_32_condsel,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_MOVK_32_movewide,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_CSEL_64_condsel,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_CSINV_64_condsel,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02800400 level 1
   07e0fc00/02801400 level 1
   07e0fc00/02802400 level 1
   07e0fc00/02803400 level 1
   07e0fc00/02804400 level 1
   07e0fc00/02805400 level 1
   07e0fc00/02806400 level 1
   07e0fc00/02807400 level 1
   07e0fc00/02808400 level 1
   07e0fc00/02809400 level 1
   07e0fc00/0280a400 level 1
   07e0fc00/0280b400 level 1
   07e0fc00/0280c400 level 1
   07e0fc00/0280d400 level 1
   07e0fc00/0280e400 level 1
   07e0fc00/0280f400 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02800400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_MOVN_32_movewide,
        iemDecodeA64_CSINC_32_condsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_MOVZ_32_movewide,
        iemDecodeA64_CSNEG_32_condsel,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_MOVK_32_movewide,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_CSINC_64_condsel,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_CSNEG_64_condsel,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02800800 level 1
   07e0fc00/02800c00 level 1
   07e0fc00/02801800 level 1
   07e0fc00/02801c00 level 1
   07e0fc00/02802800 level 1
   07e0fc00/02802c00 level 1
   07e0fc00/02803800 level 1
   07e0fc00/02803c00 level 1
   07e0fc00/02804800 level 1
   07e0fc00/02804c00 level 1
   07e0fc00/02805800 level 1
   07e0fc00/02805c00 level 1
   07e0fc00/02806800 level 1
   07e0fc00/02806c00 level 1
   07e0fc00/02807800 level 1
   07e0fc00/02807c00 level 1
   07e0fc00/02808800 level 1
   07e0fc00/02808c00 level 1
   07e0fc00/02809800 level 1
   07e0fc00/02809c00 level 1
   07e0fc00/0280a800 level 1
   07e0fc00/0280ac00 level 1
   07e0fc00/0280b800 level 1
   07e0fc00/0280bc00 level 1
   07e0fc00/0280c800 level 1
   07e0fc00/0280cc00 level 1
   07e0fc00/0280d800 level 1
   07e0fc00/0280dc00 level 1
   07e0fc00/0280e800 level 1
   07e0fc00/0280ec00 level 1
   07e0fc00/0280f800 level 1
   07e0fc00/0280fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02800800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_MOVN_32_movewide,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_MOVZ_32_movewide,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_MOVK_32_movewide,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02a00000 level 1
   07e0fc00/02a00400 level 1
   07e0fc00/02a00800 level 1
   07e0fc00/02a00c00 level 1
   07e0fc00/02a01000 level 1
   07e0fc00/02a01400 level 1
   07e0fc00/02a01800 level 1
   07e0fc00/02a01c00 level 1
   07e0fc00/02a02000 level 1
   07e0fc00/02a02400 level 1
   07e0fc00/02a02800 level 1
   07e0fc00/02a02c00 level 1
   07e0fc00/02a03000 level 1
   07e0fc00/02a03400 level 1
   07e0fc00/02a03800 level 1
   07e0fc00/02a03c00 level 1
   07e0fc00/02a04000 level 1
   07e0fc00/02a04400 level 1
   07e0fc00/02a04800 level 1
   07e0fc00/02a04c00 level 1
   07e0fc00/02a05000 level 1
   07e0fc00/02a05400 level 1
   07e0fc00/02a05800 level 1
   07e0fc00/02a05c00 level 1
   07e0fc00/02a06000 level 1
   07e0fc00/02a06400 level 1
   07e0fc00/02a06800 level 1
   07e0fc00/02a06c00 level 1
   07e0fc00/02a07000 level 1
   07e0fc00/02a07400 level 1
   07e0fc00/02a07800 level 1
   07e0fc00/02a07c00 level 1
   07e0fc00/02a08000 level 1
   07e0fc00/02a08400 level 1
   07e0fc00/02a08800 level 1
   07e0fc00/02a08c00 level 1
   07e0fc00/02a09000 level 1
   07e0fc00/02a09400 level 1
   07e0fc00/02a09800 level 1
   07e0fc00/02a09c00 level 1
   07e0fc00/02a0a000 level 1
   07e0fc00/02a0a400 level 1
   07e0fc00/02a0a800 level 1
   07e0fc00/02a0ac00 level 1
   07e0fc00/02a0b000 level 1
   07e0fc00/02a0b400 level 1
   07e0fc00/02a0b800 level 1
   07e0fc00/02a0bc00 level 1
   07e0fc00/02a0c000 level 1
   07e0fc00/02a0c400 level 1
   07e0fc00/02a0c800 level 1
   07e0fc00/02a0cc00 level 1
   07e0fc00/02a0d000 level 1
   07e0fc00/02a0d400 level 1
   07e0fc00/02a0d800 level 1
   07e0fc00/02a0dc00 level 1
   07e0fc00/02a0e000 level 1
   07e0fc00/02a0e400 level 1
   07e0fc00/02a0e800 level 1
   07e0fc00/02a0ec00 level 1
   07e0fc00/02a0f000 level 1
   07e0fc00/02a0f400 level 1
   07e0fc00/02a0f800 level 1
   07e0fc00/02a0fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02a00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_BIC_32_log_shift,
        iemDecodeA64_MOVN_32_movewide,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORN_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EON_32_log_shift,
        iemDecodeA64_MOVZ_32_movewide,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_BICS_32_log_shift,
        iemDecodeA64_MOVK_32_movewide,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_BIC_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORN_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EON_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_BICS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac00000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac00000))
        return iemDecodeA64_RBIT_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac10000))
        return iemDecodeA64_PACIA_64P_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c00000 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%44 (0xe) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_RBIT_32_dp_1src,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_SUBP_64S_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_SUBPS_64S_dp_2src,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac00000_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac00400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac00400))
        return iemDecodeA64_REV16_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac10400))
        return iemDecodeA64_PACIB_64P_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c00400 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%38 (0xc) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_REV16_32_dp_1src,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac00400_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac00800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac00800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac00800))
        return iemDecodeA64_REV32_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac10800))
        return iemDecodeA64_PACDA_64P_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c00800 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%44 (0xe) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_UDIV_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_REV_32_dp_1src,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_UDIV_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac00800_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac00c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac00c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac00c00))
        return iemDecodeA64_REV_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac10c00))
        return iemDecodeA64_PACDB_64P_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c00c00 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%41 (0xd) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_SDIV_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_SDIV_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac00c00_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac01000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac01000))
        return iemDecodeA64_CLZ_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac11000))
        return iemDecodeA64_AUTIA_64P_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c01000 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%41 (0xd) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CLZ_32_dp_1src,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_IRG_64I_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac01000_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac01400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac01400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac01400))
        return iemDecodeA64_CLS_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac11400))
        return iemDecodeA64_AUTIB_64P_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c01400 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%41 (0xd) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CLS_32_dp_1src,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_GMI_64G_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac01400_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac01800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac01800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac01800))
        return iemDecodeA64_CTZ_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac11800))
        return iemDecodeA64_AUTDA_64P_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c01800 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%38 (0xc) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CTZ_32_dp_1src,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac01800_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac01c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac01c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac01c00))
        return iemDecodeA64_CNT_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac11c00))
        return iemDecodeA64_AUTDB_64P_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c01c00 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%38 (0xc) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CNT_32_dp_1src,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac01c00_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/dac02000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_dac02000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0xdac02000))
        return iemDecodeA64_ABS_64_dp_1src(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xdac123e0))
        return iemDecodeA64_PACIZA_64Z_dp_1src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/02c02000 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%44 (0xe) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LSLV_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_ABS_32_dp_1src,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_LSLV_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_ffe0fc00_dac02000_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c02400 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_LSRV_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_LSRV_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACIZB_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c02800 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_ASRV_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_ASRV_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACDZA_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c02c00 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_RORV_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_RORV_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACDZB_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c03000 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_PACGA_64P_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_AUTIZA_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c03400 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_AUTIZB_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c03800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_AUTDZA_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c03c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c03c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_AUTDZB_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c04000 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CRC32B_32C_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_XPACI_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c04400 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CRC32H_32C_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_XPACD_64Z_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c04800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CRC32W_32C_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c04c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_CRC32X_64C_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c05000 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CRC32CB_32C_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c05400 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CRC32CH_32C_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c05800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CRC32CW_32C_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c05c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_CRC32CX_64C_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c06000 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_SMAX_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_SMAX_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c06400 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_UMAX_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_UMAX_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c06800 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_SMIN_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_SMIN_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c06c00 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_UMIN_32_dp_2src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_UMIN_64_dp_2src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c07000 level 1
   07e0fc00/02c07400 level 1
   07e0fc00/02c07800 level 1
   07e0fc00/02c07c00 level 1
   07e0fc00/02c09800 level 1
   07e0fc00/02c09c00 level 1
   07e0fc00/02c0a800 level 1
   07e0fc00/02c0ac00 level 1
   07e0fc00/02c0b000 level 1
   07e0fc00/02c0b400 level 1
   07e0fc00/02c0c000 level 1
   07e0fc00/02c0c400 level 1
   07e0fc00/02c0c800 level 1
   07e0fc00/02c0cc00 level 1
   07e0fc00/02c0d000 level 1
   07e0fc00/02c0d400 level 1
   07e0fc00/02c0d800 level 1
   07e0fc00/02c0dc00 level 1
   07e0fc00/02c0e000 level 1
   07e0fc00/02c0e400 level 1
   07e0fc00/02c0e800 level 1
   07e0fc00/02c0ec00 level 1
   07e0fc00/02c0f000 level 1
   07e0fc00/02c0f400 level 1
   07e0fc00/02c0f800 level 1
   07e0fc00/02c0fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%34 (0xb) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c08000 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACNBIASPPC_64LR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c08400 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACNBIBSPPC_64LR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c08800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACIA171615_64LR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c08c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACIB171615_64LR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c09000 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_AUTIASPPCR_64LRR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c09400 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_AUTIBSPPCR_64LRR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c0a000 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACIASPPC_64LR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c0a400 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_PACIBSPPC_64LR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c0b800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_AUTIA171615_64LR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02c0bc00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02c0bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_AND_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORR_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EOR_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ANDS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_AND_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORR_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EOR_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_AUTIB171615_64LR_dp_1src,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ANDS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/02e00000 level 1
   07e0fc00/02e00400 level 1
   07e0fc00/02e00800 level 1
   07e0fc00/02e00c00 level 1
   07e0fc00/02e01000 level 1
   07e0fc00/02e01400 level 1
   07e0fc00/02e01800 level 1
   07e0fc00/02e01c00 level 1
   07e0fc00/02e02000 level 1
   07e0fc00/02e02400 level 1
   07e0fc00/02e02800 level 1
   07e0fc00/02e02c00 level 1
   07e0fc00/02e03000 level 1
   07e0fc00/02e03400 level 1
   07e0fc00/02e03800 level 1
   07e0fc00/02e03c00 level 1
   07e0fc00/02e04000 level 1
   07e0fc00/02e04400 level 1
   07e0fc00/02e04800 level 1
   07e0fc00/02e04c00 level 1
   07e0fc00/02e05000 level 1
   07e0fc00/02e05400 level 1
   07e0fc00/02e05800 level 1
   07e0fc00/02e05c00 level 1
   07e0fc00/02e06000 level 1
   07e0fc00/02e06400 level 1
   07e0fc00/02e06800 level 1
   07e0fc00/02e06c00 level 1
   07e0fc00/02e07000 level 1
   07e0fc00/02e07400 level 1
   07e0fc00/02e07800 level 1
   07e0fc00/02e07c00 level 1
   07e0fc00/02e08000 level 1
   07e0fc00/02e08400 level 1
   07e0fc00/02e08800 level 1
   07e0fc00/02e08c00 level 1
   07e0fc00/02e09000 level 1
   07e0fc00/02e09400 level 1
   07e0fc00/02e09800 level 1
   07e0fc00/02e09c00 level 1
   07e0fc00/02e0a000 level 1
   07e0fc00/02e0a400 level 1
   07e0fc00/02e0a800 level 1
   07e0fc00/02e0ac00 level 1
   07e0fc00/02e0b000 level 1
   07e0fc00/02e0b400 level 1
   07e0fc00/02e0b800 level 1
   07e0fc00/02e0bc00 level 1
   07e0fc00/02e0c000 level 1
   07e0fc00/02e0c400 level 1
   07e0fc00/02e0c800 level 1
   07e0fc00/02e0cc00 level 1
   07e0fc00/02e0d000 level 1
   07e0fc00/02e0d400 level 1
   07e0fc00/02e0d800 level 1
   07e0fc00/02e0dc00 level 1
   07e0fc00/02e0e000 level 1
   07e0fc00/02e0e400 level 1
   07e0fc00/02e0e800 level 1
   07e0fc00/02e0ec00 level 1
   07e0fc00/02e0f000 level 1
   07e0fc00/02e0f400 level 1
   07e0fc00/02e0f800 level 1
   07e0fc00/02e0fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%34 (0xb) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_02e00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_BIC_32_log_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ORN_32_log_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_EON_32_log_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_BICS_32_log_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_BIC_64_log_shift,
        iemDecodeA64_MOVN_64_movewide,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ORN_64_log_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_EON_64_log_shift,
        iemDecodeA64_MOVZ_64_movewide,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_BICS_64_log_shift,
        iemDecodeA64_MOVK_64_movewide,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03000000 level 1
   07e0fc00/03000400 level 1
   07e0fc00/03000800 level 1
   07e0fc00/03000c00 level 1
   07e0fc00/03001000 level 1
   07e0fc00/03001400 level 1
   07e0fc00/03001800 level 1
   07e0fc00/03001c00 level 1
   07e0fc00/03002000 level 1
   07e0fc00/03002400 level 1
   07e0fc00/03002800 level 1
   07e0fc00/03002c00 level 1
   07e0fc00/03003000 level 1
   07e0fc00/03003400 level 1
   07e0fc00/03003800 level 1
   07e0fc00/03003c00 level 1
   07e0fc00/03004000 level 1
   07e0fc00/03004400 level 1
   07e0fc00/03004800 level 1
   07e0fc00/03004c00 level 1
   07e0fc00/03005000 level 1
   07e0fc00/03005400 level 1
   07e0fc00/03005800 level 1
   07e0fc00/03005c00 level 1
   07e0fc00/03006000 level 1
   07e0fc00/03006400 level 1
   07e0fc00/03006800 level 1
   07e0fc00/03006c00 level 1
   07e0fc00/03007000 level 1
   07e0fc00/03007400 level 1
   07e0fc00/03007800 level 1
   07e0fc00/03007c00 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03000000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_shift,
        iemDecodeA64_SBFM_32M_bitfield,
        iemDecodeA64_MADD_32A_dp_3src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ADDS_32_addsub_shift,
        iemDecodeA64_BFM_32M_bitfield,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SUB_32_addsub_shift,
        iemDecodeA64_UBFM_32M_bitfield,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUBS_32_addsub_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_ADD_64_addsub_shift,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_MADD_64A_dp_3src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ADDS_64_addsub_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_SUB_64_addsub_shift,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_SUBS_64_addsub_shift,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03008000 level 1
   07e0fc00/03008400 level 1
   07e0fc00/03008800 level 1
   07e0fc00/03008c00 level 1
   07e0fc00/03009000 level 1
   07e0fc00/03009400 level 1
   07e0fc00/03009800 level 1
   07e0fc00/03009c00 level 1
   07e0fc00/0300a000 level 1
   07e0fc00/0300a400 level 1
   07e0fc00/0300a800 level 1
   07e0fc00/0300ac00 level 1
   07e0fc00/0300b000 level 1
   07e0fc00/0300b400 level 1
   07e0fc00/0300b800 level 1
   07e0fc00/0300bc00 level 1
   07e0fc00/0300c000 level 1
   07e0fc00/0300c400 level 1
   07e0fc00/0300c800 level 1
   07e0fc00/0300cc00 level 1
   07e0fc00/0300d000 level 1
   07e0fc00/0300d400 level 1
   07e0fc00/0300d800 level 1
   07e0fc00/0300dc00 level 1
   07e0fc00/0300e000 level 1
   07e0fc00/0300e400 level 1
   07e0fc00/0300e800 level 1
   07e0fc00/0300ec00 level 1
   07e0fc00/0300f000 level 1
   07e0fc00/0300f400 level 1
   07e0fc00/0300f800 level 1
   07e0fc00/0300fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03008000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_shift,
        iemDecodeA64_SBFM_32M_bitfield,
        iemDecodeA64_MSUB_32A_dp_3src,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ADDS_32_addsub_shift,
        iemDecodeA64_BFM_32M_bitfield,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SUB_32_addsub_shift,
        iemDecodeA64_UBFM_32M_bitfield,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUBS_32_addsub_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_ADD_64_addsub_shift,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_MSUB_64A_dp_3src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ADDS_64_addsub_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_SUB_64_addsub_shift,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_SUBS_64_addsub_shift,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03200000 level 1
   07e0fc00/03200400 level 1
   07e0fc00/03200800 level 1
   07e0fc00/03200c00 level 1
   07e0fc00/03201000 level 1
   07e0fc00/03201400 level 1
   07e0fc00/03201800 level 1
   07e0fc00/03201c00 level 1
   07e0fc00/03202000 level 1
   07e0fc00/03202400 level 1
   07e0fc00/03202800 level 1
   07e0fc00/03202c00 level 1
   07e0fc00/03203000 level 1
   07e0fc00/03203400 level 1
   07e0fc00/03203800 level 1
   07e0fc00/03203c00 level 1
   07e0fc00/03204000 level 1
   07e0fc00/03204400 level 1
   07e0fc00/03204800 level 1
   07e0fc00/03204c00 level 1
   07e0fc00/03205000 level 1
   07e0fc00/03205400 level 1
   07e0fc00/03205800 level 1
   07e0fc00/03205c00 level 1
   07e0fc00/03206000 level 1
   07e0fc00/03206400 level 1
   07e0fc00/03206800 level 1
   07e0fc00/03206c00 level 1
   07e0fc00/03207000 level 1
   07e0fc00/03207400 level 1
   07e0fc00/03207800 level 1
   07e0fc00/03207c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03200000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_ext,
        iemDecodeA64_SBFM_32M_bitfield,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ADDS_32S_addsub_ext,
        iemDecodeA64_BFM_32M_bitfield,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SUB_32_addsub_ext,
        iemDecodeA64_UBFM_32M_bitfield,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUBS_32S_addsub_ext,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_ADD_64_addsub_ext,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_SMADDL_64WA_dp_3src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ADDS_64S_addsub_ext,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_SUB_64_addsub_ext,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_SUBS_64S_addsub_ext,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03208000 level 1
   07e0fc00/03208400 level 1
   07e0fc00/03208800 level 1
   07e0fc00/03208c00 level 1
   07e0fc00/03209000 level 1
   07e0fc00/03209400 level 1
   07e0fc00/03209800 level 1
   07e0fc00/03209c00 level 1
   07e0fc00/0320a000 level 1
   07e0fc00/0320a400 level 1
   07e0fc00/0320a800 level 1
   07e0fc00/0320ac00 level 1
   07e0fc00/0320b000 level 1
   07e0fc00/0320b400 level 1
   07e0fc00/0320b800 level 1
   07e0fc00/0320bc00 level 1
   07e0fc00/0320c000 level 1
   07e0fc00/0320c400 level 1
   07e0fc00/0320c800 level 1
   07e0fc00/0320cc00 level 1
   07e0fc00/0320d000 level 1
   07e0fc00/0320d400 level 1
   07e0fc00/0320d800 level 1
   07e0fc00/0320dc00 level 1
   07e0fc00/0320e000 level 1
   07e0fc00/0320e400 level 1
   07e0fc00/0320e800 level 1
   07e0fc00/0320ec00 level 1
   07e0fc00/0320f000 level 1
   07e0fc00/0320f400 level 1
   07e0fc00/0320f800 level 1
   07e0fc00/0320fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03208000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_ext,
        iemDecodeA64_SBFM_32M_bitfield,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ADDS_32S_addsub_ext,
        iemDecodeA64_BFM_32M_bitfield,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SUB_32_addsub_ext,
        iemDecodeA64_UBFM_32M_bitfield,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUBS_32S_addsub_ext,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_ADD_64_addsub_ext,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_SMSUBL_64WA_dp_3src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ADDS_64S_addsub_ext,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_SUB_64_addsub_ext,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_SUBS_64S_addsub_ext,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03400000 level 1
   07e0fc00/03400400 level 1
   07e0fc00/03400800 level 1
   07e0fc00/03400c00 level 1
   07e0fc00/03401000 level 1
   07e0fc00/03401400 level 1
   07e0fc00/03401800 level 1
   07e0fc00/03401c00 level 1
   07e0fc00/03402000 level 1
   07e0fc00/03402400 level 1
   07e0fc00/03402800 level 1
   07e0fc00/03402c00 level 1
   07e0fc00/03403000 level 1
   07e0fc00/03403400 level 1
   07e0fc00/03403800 level 1
   07e0fc00/03403c00 level 1
   07e0fc00/03404000 level 1
   07e0fc00/03404400 level 1
   07e0fc00/03404800 level 1
   07e0fc00/03404c00 level 1
   07e0fc00/03405000 level 1
   07e0fc00/03405400 level 1
   07e0fc00/03405800 level 1
   07e0fc00/03405c00 level 1
   07e0fc00/03406000 level 1
   07e0fc00/03406400 level 1
   07e0fc00/03406800 level 1
   07e0fc00/03406c00 level 1
   07e0fc00/03407000 level 1
   07e0fc00/03407400 level 1
   07e0fc00/03407800 level 1
   07e0fc00/03408000 level 1
   07e0fc00/03408400 level 1
   07e0fc00/03408800 level 1
   07e0fc00/03408c00 level 1
   07e0fc00/03409000 level 1
   07e0fc00/03409400 level 1
   07e0fc00/03409800 level 1
   07e0fc00/03409c00 level 1
   07e0fc00/0340a000 level 1
   07e0fc00/0340a400 level 1
   07e0fc00/0340a800 level 1
   07e0fc00/0340ac00 level 1
   07e0fc00/0340b000 level 1
   07e0fc00/0340b400 level 1
   07e0fc00/0340b800 level 1
   07e0fc00/0340bc00 level 1
   07e0fc00/0340c000 level 1
   07e0fc00/0340c400 level 1
   07e0fc00/0340c800 level 1
   07e0fc00/0340cc00 level 1
   07e0fc00/0340d000 level 1
   07e0fc00/0340d400 level 1
   07e0fc00/0340d800 level 1
   07e0fc00/0340dc00 level 1
   07e0fc00/0340e000 level 1
   07e0fc00/0340e400 level 1
   07e0fc00/0340e800 level 1
   07e0fc00/0340ec00 level 1
   07e0fc00/0340f000 level 1
   07e0fc00/0340f400 level 1
   07e0fc00/0340f800 level 1
   07e0fc00/0340fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%34 (0xb) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03400000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ADDS_32_addsub_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SUB_32_addsub_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUBS_32_addsub_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_ADD_64_addsub_shift,
        iemDecodeA64_SBFM_64M_bitfield,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ADDS_64_addsub_shift,
        iemDecodeA64_BFM_64M_bitfield,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_SUB_64_addsub_shift,
        iemDecodeA64_UBFM_64M_bitfield,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_SUBS_64_addsub_shift,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03407c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03407c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ADDS_32_addsub_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SUB_32_addsub_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUBS_32_addsub_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_ADD_64_addsub_shift,
        iemDecodeA64_SBFM_64M_bitfield,
        iemDecodeA64_SMULH_64_dp_3src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ADDS_64_addsub_shift,
        iemDecodeA64_BFM_64M_bitfield,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_SUB_64_addsub_shift,
        iemDecodeA64_UBFM_64M_bitfield,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_SUBS_64_addsub_shift,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03600000 level 1
   07e0fc00/03600400 level 1
   07e0fc00/03600800 level 1
   07e0fc00/03600c00 level 1
   07e0fc00/03601000 level 1
   07e0fc00/03601400 level 1
   07e0fc00/03601800 level 1
   07e0fc00/03601c00 level 1
   07e0fc00/03602000 level 1
   07e0fc00/03602400 level 1
   07e0fc00/03602800 level 1
   07e0fc00/03602c00 level 1
   07e0fc00/03603000 level 1
   07e0fc00/03603400 level 1
   07e0fc00/03603800 level 1
   07e0fc00/03603c00 level 1
   07e0fc00/03604000 level 1
   07e0fc00/03604400 level 1
   07e0fc00/03604800 level 1
   07e0fc00/03604c00 level 1
   07e0fc00/03605000 level 1
   07e0fc00/03605400 level 1
   07e0fc00/03605800 level 1
   07e0fc00/03605c00 level 1
   07e0fc00/03606000 level 1
   07e0fc00/03606400 level 1
   07e0fc00/03606800 level 1
   07e0fc00/03606c00 level 1
   07e0fc00/03607000 level 1
   07e0fc00/03607400 level 1
   07e0fc00/03607800 level 1
   07e0fc00/03607c00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03600000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x93400000))
        return iemDecodeA64_SBFM_64M_bitfield(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xb3400000))
        return iemDecodeA64_BFM_64M_bitfield(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xd3400000))
        return iemDecodeA64_UBFM_64M_bitfield(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x9b600000))
        return iemDecodeA64_MADDPT_64A_dp_3src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/03608000 level 1
   07e0fc00/03608400 level 1
   07e0fc00/03608800 level 1
   07e0fc00/03608c00 level 1
   07e0fc00/03609000 level 1
   07e0fc00/03609400 level 1
   07e0fc00/03609800 level 1
   07e0fc00/03609c00 level 1
   07e0fc00/0360a000 level 1
   07e0fc00/0360a400 level 1
   07e0fc00/0360a800 level 1
   07e0fc00/0360ac00 level 1
   07e0fc00/0360b000 level 1
   07e0fc00/0360b400 level 1
   07e0fc00/0360b800 level 1
   07e0fc00/0360bc00 level 1
   07e0fc00/0360c000 level 1
   07e0fc00/0360c400 level 1
   07e0fc00/0360c800 level 1
   07e0fc00/0360cc00 level 1
   07e0fc00/0360d000 level 1
   07e0fc00/0360d400 level 1
   07e0fc00/0360d800 level 1
   07e0fc00/0360dc00 level 1
   07e0fc00/0360e000 level 1
   07e0fc00/0360e400 level 1
   07e0fc00/0360e800 level 1
   07e0fc00/0360ec00 level 1
   07e0fc00/0360f000 level 1
   07e0fc00/0360f400 level 1
   07e0fc00/0360f800 level 1
   07e0fc00/0360fc00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03608000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x93400000))
        return iemDecodeA64_SBFM_64M_bitfield(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xb3400000))
        return iemDecodeA64_BFM_64M_bitfield(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xd3400000))
        return iemDecodeA64_UBFM_64M_bitfield(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x9b608000))
        return iemDecodeA64_MSUBPT_64A_dp_3src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/03800000 level 1
   07e0fc00/03800400 level 1
   07e0fc00/03800800 level 1
   07e0fc00/03800c00 level 1
   07e0fc00/03801000 level 1
   07e0fc00/03801400 level 1
   07e0fc00/03801800 level 1
   07e0fc00/03801c00 level 1
   07e0fc00/03802000 level 1
   07e0fc00/03802400 level 1
   07e0fc00/03802800 level 1
   07e0fc00/03802c00 level 1
   07e0fc00/03803000 level 1
   07e0fc00/03803400 level 1
   07e0fc00/03803800 level 1
   07e0fc00/03803c00 level 1
   07e0fc00/03804000 level 1
   07e0fc00/03804400 level 1
   07e0fc00/03804800 level 1
   07e0fc00/03804c00 level 1
   07e0fc00/03805000 level 1
   07e0fc00/03805400 level 1
   07e0fc00/03805800 level 1
   07e0fc00/03805c00 level 1
   07e0fc00/03806000 level 1
   07e0fc00/03806400 level 1
   07e0fc00/03806800 level 1
   07e0fc00/03806c00 level 1
   07e0fc00/03807000 level 1
   07e0fc00/03807400 level 1
   07e0fc00/03807800 level 1
   07e0fc00/03807c00 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03800000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_shift,
        iemDecodeA64_EXTR_32_extract,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ADDS_32_addsub_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SUB_32_addsub_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUBS_32_addsub_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_ADD_64_addsub_shift,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ADDS_64_addsub_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_SUB_64_addsub_shift,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_SUBS_64_addsub_shift,
        iemDecodeA64_AUTIASPPC_only_dp_1src_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03808000 level 1
   07e0fc00/03808400 level 1
   07e0fc00/03808800 level 1
   07e0fc00/03808c00 level 1
   07e0fc00/03809000 level 1
   07e0fc00/03809400 level 1
   07e0fc00/03809800 level 1
   07e0fc00/03809c00 level 1
   07e0fc00/0380a000 level 1
   07e0fc00/0380a400 level 1
   07e0fc00/0380a800 level 1
   07e0fc00/0380ac00 level 1
   07e0fc00/0380b000 level 1
   07e0fc00/0380b400 level 1
   07e0fc00/0380b800 level 1
   07e0fc00/0380bc00 level 1
   07e0fc00/0380c000 level 1
   07e0fc00/0380c400 level 1
   07e0fc00/0380c800 level 1
   07e0fc00/0380cc00 level 1
   07e0fc00/0380d000 level 1
   07e0fc00/0380d400 level 1
   07e0fc00/0380d800 level 1
   07e0fc00/0380dc00 level 1
   07e0fc00/0380e000 level 1
   07e0fc00/0380e400 level 1
   07e0fc00/0380e800 level 1
   07e0fc00/0380ec00 level 1
   07e0fc00/0380f000 level 1
   07e0fc00/0380f400 level 1
   07e0fc00/0380f800 level 1
   07e0fc00/0380fc00 level 1
   mask=0xe8000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%56 (0x9) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03808000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_ADDS_32_addsub_shift,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SUB_32_addsub_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_SUBS_32_addsub_shift,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ADD_64_addsub_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_ADDS_64_addsub_shift,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUB_64_addsub_shift,
        iemDecodeA64_AUTIASPPC_only_dp_1src_imm,
        iemDecodeA64_SUBS_64_addsub_shift,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xe8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000e)) /* bit 29 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03a00000 level 1
   07e0fc00/03a00400 level 1
   07e0fc00/03a00800 level 1
   07e0fc00/03a00c00 level 1
   07e0fc00/03a01000 level 1
   07e0fc00/03a01400 level 1
   07e0fc00/03a01800 level 1
   07e0fc00/03a01c00 level 1
   07e0fc00/03a02000 level 1
   07e0fc00/03a02400 level 1
   07e0fc00/03a02800 level 1
   07e0fc00/03a02c00 level 1
   07e0fc00/03a03000 level 1
   07e0fc00/03a03400 level 1
   07e0fc00/03a03800 level 1
   07e0fc00/03a03c00 level 1
   07e0fc00/03a04000 level 1
   07e0fc00/03a04400 level 1
   07e0fc00/03a04800 level 1
   07e0fc00/03a04c00 level 1
   07e0fc00/03a05000 level 1
   07e0fc00/03a05400 level 1
   07e0fc00/03a05800 level 1
   07e0fc00/03a05c00 level 1
   07e0fc00/03a06000 level 1
   07e0fc00/03a06400 level 1
   07e0fc00/03a06800 level 1
   07e0fc00/03a06c00 level 1
   07e0fc00/03a07000 level 1
   07e0fc00/03a07400 level 1
   07e0fc00/03a07800 level 1
   07e0fc00/03a07c00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03a00000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xf3a0001f))
        return iemDecodeA64_AUTIBSPPC_only_dp_1src_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x9ba00000))
        return iemDecodeA64_UMADDL_64WA_dp_3src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/03a08000 level 1
   07e0fc00/03a08400 level 1
   07e0fc00/03a08800 level 1
   07e0fc00/03a08c00 level 1
   07e0fc00/03a09000 level 1
   07e0fc00/03a09400 level 1
   07e0fc00/03a09800 level 1
   07e0fc00/03a09c00 level 1
   07e0fc00/03a0a000 level 1
   07e0fc00/03a0a400 level 1
   07e0fc00/03a0a800 level 1
   07e0fc00/03a0ac00 level 1
   07e0fc00/03a0b000 level 1
   07e0fc00/03a0b400 level 1
   07e0fc00/03a0b800 level 1
   07e0fc00/03a0bc00 level 1
   07e0fc00/03a0c000 level 1
   07e0fc00/03a0c400 level 1
   07e0fc00/03a0c800 level 1
   07e0fc00/03a0cc00 level 1
   07e0fc00/03a0d000 level 1
   07e0fc00/03a0d400 level 1
   07e0fc00/03a0d800 level 1
   07e0fc00/03a0dc00 level 1
   07e0fc00/03a0e000 level 1
   07e0fc00/03a0e400 level 1
   07e0fc00/03a0e800 level 1
   07e0fc00/03a0ec00 level 1
   07e0fc00/03a0f000 level 1
   07e0fc00/03a0f400 level 1
   07e0fc00/03a0f800 level 1
   07e0fc00/03a0fc00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03a08000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xf3a0001f))
        return iemDecodeA64_AUTIBSPPC_only_dp_1src_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x9ba08000))
        return iemDecodeA64_UMSUBL_64WA_dp_3src(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/03c00000 level 1
   07e0fc00/03c00400 level 1
   07e0fc00/03c00800 level 1
   07e0fc00/03c00c00 level 1
   07e0fc00/03c01000 level 1
   07e0fc00/03c01400 level 1
   07e0fc00/03c01800 level 1
   07e0fc00/03c01c00 level 1
   07e0fc00/03c02000 level 1
   07e0fc00/03c02400 level 1
   07e0fc00/03c02800 level 1
   07e0fc00/03c02c00 level 1
   07e0fc00/03c03000 level 1
   07e0fc00/03c03400 level 1
   07e0fc00/03c03800 level 1
   07e0fc00/03c03c00 level 1
   07e0fc00/03c04000 level 1
   07e0fc00/03c04400 level 1
   07e0fc00/03c04800 level 1
   07e0fc00/03c04c00 level 1
   07e0fc00/03c05000 level 1
   07e0fc00/03c05400 level 1
   07e0fc00/03c05800 level 1
   07e0fc00/03c05c00 level 1
   07e0fc00/03c06000 level 1
   07e0fc00/03c06400 level 1
   07e0fc00/03c06800 level 1
   07e0fc00/03c06c00 level 1
   07e0fc00/03c07000 level 1
   07e0fc00/03c07400 level 1
   07e0fc00/03c07800 level 1
   07e0fc00/03c08000 level 1
   07e0fc00/03c08400 level 1
   07e0fc00/03c08800 level 1
   07e0fc00/03c08c00 level 1
   07e0fc00/03c09000 level 1
   07e0fc00/03c09400 level 1
   07e0fc00/03c09800 level 1
   07e0fc00/03c09c00 level 1
   07e0fc00/03c0a000 level 1
   07e0fc00/03c0a400 level 1
   07e0fc00/03c0a800 level 1
   07e0fc00/03c0ac00 level 1
   07e0fc00/03c0b000 level 1
   07e0fc00/03c0b400 level 1
   07e0fc00/03c0b800 level 1
   07e0fc00/03c0bc00 level 1
   07e0fc00/03c0c000 level 1
   07e0fc00/03c0c400 level 1
   07e0fc00/03c0c800 level 1
   07e0fc00/03c0cc00 level 1
   07e0fc00/03c0d000 level 1
   07e0fc00/03c0d400 level 1
   07e0fc00/03c0d800 level 1
   07e0fc00/03c0dc00 level 1
   07e0fc00/03c0e000 level 1
   07e0fc00/03c0e400 level 1
   07e0fc00/03c0e800 level 1
   07e0fc00/03c0ec00 level 1
   07e0fc00/03c0f000 level 1
   07e0fc00/03c0f400 level 1
   07e0fc00/03c0f800 level 1
   07e0fc00/03c0fc00 level 1
   mask=0xe8000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%56 (0x9) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03c00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_ADDS_32_addsub_shift,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SUB_32_addsub_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_SUBS_32_addsub_shift,
        iemDecodeA64_EXTR_64_extract,
        iemDecodeA64_ADD_64_addsub_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_ADDS_64_addsub_shift,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUB_64_addsub_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SUBS_64_addsub_shift,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xe8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000e)) /* bit 29 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/03c07c00 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_03c07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_32_addsub_shift,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ADDS_32_addsub_shift,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SUB_32_addsub_shift,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUBS_32_addsub_shift,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_ADD_64_addsub_shift,
        iemDecodeA64_EXTR_64_extract,
        iemDecodeA64_UMULH_64_dp_3src,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_ADDS_64_addsub_shift,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_SUB_64_addsub_shift,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_SUBS_64_addsub_shift,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04000000 level 2
   ffe0fc00/04000400 level 2
   ffe0fc00/04000c00 level 2
   ffe0fc00/04001000 level 2
   ffe0fc00/04001400 level 2
   f7e0fc10/04001800 level 2
   f7e0fc10/04001810 level 2
   ffe0fc00/04001c00 level 2
   ffe0fc00/04400000 level 2
   ffe0fc00/04400400 level 2
   ffe0fc00/04400c00 level 2
   ffe0fc00/04401000 level 2
   ffe0fc00/04401400 level 2
   f7e0fc10/04401800 level 2
   f7e0fc10/04401810 level 2
   ffe0fc00/04401c00 level 2
   f7e0fc10/04801000 level 2
   f7e0fc10/04801010 level 2
   f7e0fc10/04801400 level 2
   f7e0fc10/04801410 level 2
   f7e0fc10/04801c00 level 2
   f7e0fc10/04801c10 level 2
   mask=0x1f0000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04000000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_add_z_p_zz,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_subr_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smax_z_p_zz,
        iemDecodeA64_umax_z_p_zz,
        iemDecodeA64_smin_z_p_zz,
        iemDecodeA64_umin_z_p_zz,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_mul_z_p_zz,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_umulh_z_p_zz,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_orr_z_p_zz,
        iemDecodeA64_eor_z_p_zz,
        iemDecodeA64_and_z_p_zz,
        iemDecodeA64_bic_z_p_zz,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/24000000 level 2
   ffe0fc00/24000400 level 2
   ffe0fc00/24000c00 level 2
   ffe0fc00/24001000 level 2
   ffe0fc00/24001400 level 2
   ffe0fc00/24001c00 level 2
   ffe0fc00/24400000 level 2
   ffe0fc00/24400400 level 2
   ffe0fc00/24400c00 level 2
   ffe0fc00/24401000 level 2
   ffe0fc00/24401400 level 2
   ffe0fc00/24401c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_24000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000000))
        return iemDecodeA64_cmphs_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000010))
        return iemDecodeA64_cmphi_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/54000000 level 2
   ffe0fc00/54000400 level 2
   ffe0fc00/54000c00 level 2
   ffe0fc00/54001000 level 2
   ffe0fc00/54001400 level 2
   ffe0fc00/54001c00 level 2
   ffe0fc00/54002000 level 2
   ffe0fc00/54002400 level 2
   ffe0fc00/54002800 level 2
   ffe0fc00/54002c00 level 2
   ffe0fc00/54003000 level 2
   ffe0fc00/54003400 level 2
   ffe0fc00/54003800 level 2
   ffe0fc00/54003c00 level 2
   ffe0fc00/54004000 level 2
   ffe0fc00/54004400 level 2
   ffe0fc00/54004800 level 2
   ffe0fc00/54004c00 level 2
   ffe0fc00/54005000 level 2
   ffe0fc00/54005400 level 2
   ffe0fc00/54005800 level 2
   ffe0fc00/54005c00 level 2
   ffe0fc00/54006000 level 2
   ffe0fc00/54006400 level 2
   ffe0fc00/54006800 level 2
   ffe0fc00/54006c00 level 2
   ffe0fc00/54007000 level 2
   ffe0fc00/54007400 level 2
   ffe0fc00/54007800 level 2
   ffe0fc00/54007c00 level 2
   ffe0fc00/5400c000 level 2
   ffe0fc00/5400c400 level 2
   ffe0fc00/5400c800 level 2
   ffe0fc00/5400cc00 level 2
   ffe0fc00/5400d000 level 2
   ffe0fc00/5400d400 level 2
   ffe0fc00/5400d800 level 2
   ffe0fc00/5400dc00 level 2
   ffe0fc00/5400e000 level 2
   ffe0fc00/5400e400 level 2
   ffe0fc00/5400e800 level 2
   ffe0fc00/5400ec00 level 2
   ffe0fc00/5400f000 level 2
   ffe0fc00/5400f400 level 2
   ffe0fc00/5400f800 level 2
   ffe0fc00/5400fc00 level 2
   ffe0fc00/54200000 level 2
   ffe0fc00/54200400 level 2
   ffe0fc00/54200800 level 2
   ffe0fc00/54200c00 level 2
   ffe0fc00/54201000 level 2
   ffe0fc00/54201400 level 2
   ffe0fc00/54201800 level 2
   ffe0fc00/54201c00 level 2
   ffe0fc00/54202000 level 2
   ffe0fc00/54202400 level 2
   ffe0fc00/54202800 level 2
   ffe0fc00/54202c00 level 2
   ffe0fc00/54203000 level 2
   ffe0fc00/54203400 level 2
   ffe0fc00/54203800 level 2
   ffe0fc00/54203c00 level 2
   ffe0fc00/54204000 level 2
   ffe0fc00/54204400 level 2
   ffe0fc00/54204800 level 2
   ffe0fc00/54204c00 level 2
   ffe0fc00/54205000 level 2
   ffe0fc00/54205400 level 2
   ffe0fc00/54205800 level 2
   ffe0fc00/54205c00 level 2
   ffe0fc00/54206000 level 2
   ffe0fc00/54206400 level 2
   ffe0fc00/54206800 level 2
   ffe0fc00/54206c00 level 2
   ffe0fc00/54207000 level 2
   ffe0fc00/54207400 level 2
   ffe0fc00/54207800 level 2
   ffe0fc00/54207c00 level 2
   ffe0fc00/54208000 level 2
   ffe0fc00/54208400 level 2
   ffe0fc00/54208800 level 2
   ffe0fc00/54208c00 level 2
   ffe0fc00/54209000 level 2
   ffe0fc00/54209400 level 2
   ffe0fc00/54209800 level 2
   ffe0fc00/54209c00 level 2
   ffe0fc00/5420a000 level 2
   ffe0fc00/5420a400 level 2
   ffe0fc00/5420a800 level 2
   ffe0fc00/5420ac00 level 2
   ffe0fc00/5420b000 level 2
   ffe0fc00/5420b400 level 2
   ffe0fc00/5420b800 level 2
   ffe0fc00/5420bc00 level 2
   ffe0fc00/5420c000 level 2
   ffe0fc00/5420c400 level 2
   ffe0fc00/5420c800 level 2
   ffe0fc00/5420cc00 level 2
   ffe0fc00/5420d000 level 2
   ffe0fc00/5420d400 level 2
   ffe0fc00/5420d800 level 2
   ffe0fc00/5420dc00 level 2
   ffe0fc00/5420e000 level 2
   ffe0fc00/5420e400 level 2
   ffe0fc00/5420e800 level 2
   ffe0fc00/5420ec00 level 2
   ffe0fc00/5420f000 level 2
   ffe0fc00/5420f400 level 2
   ffe0fc00/5420f800 level 2
   ffe0fc00/5420fc00 level 2
   ffe0fc00/54400000 level 2
   ffe0fc00/54400400 level 2
   ffe0fc00/54400c00 level 2
   ffe0fc00/54401000 level 2
   ffe0fc00/54401400 level 2
   ffe0fc00/54401c00 level 2
   ffe0fc00/54402000 level 2
   ffe0fc00/54402400 level 2
   ffe0fc00/54402800 level 2
   ffe0fc00/54402c00 level 2
   ffe0fc00/54403000 level 2
   ffe0fc00/54403400 level 2
   ffe0fc00/54403800 level 2
   ffe0fc00/54403c00 level 2
   ffe0fc00/54404000 level 2
   ffe0fc00/54404400 level 2
   ffe0fc00/54404800 level 2
   ffe0fc00/54404c00 level 2
   ffe0fc00/54405000 level 2
   ffe0fc00/54405400 level 2
   ffe0fc00/54405800 level 2
   ffe0fc00/54405c00 level 2
   ffe0fc00/54406000 level 2
   ffe0fc00/54406400 level 2
   ffe0fc00/54406800 level 2
   ffe0fc00/54406c00 level 2
   ffe0fc00/54407000 level 2
   ffe0fc00/54407400 level 2
   ffe0fc00/54407800 level 2
   ffe0fc00/54407c00 level 2
   ffe0fc00/5440c000 level 2
   ffe0fc00/5440c400 level 2
   ffe0fc00/5440c800 level 2
   ffe0fc00/5440cc00 level 2
   ffe0fc00/5440d000 level 2
   ffe0fc00/5440d400 level 2
   ffe0fc00/5440d800 level 2
   ffe0fc00/5440dc00 level 2
   ffe0fc00/5440e000 level 2
   ffe0fc00/5440e400 level 2
   ffe0fc00/5440e800 level 2
   ffe0fc00/5440ec00 level 2
   ffe0fc00/5440f000 level 2
   ffe0fc00/5440f400 level 2
   ffe0fc00/5440f800 level 2
   ffe0fc00/5440fc00 level 2
   ffe0fc00/54600000 level 2
   ffe0fc00/54600400 level 2
   ffe0fc00/54600800 level 2
   ffe0fc00/54600c00 level 2
   ffe0fc00/54601000 level 2
   ffe0fc00/54601400 level 2
   ffe0fc00/54601800 level 2
   ffe0fc00/54601c00 level 2
   ffe0fc00/54602000 level 2
   ffe0fc00/54602400 level 2
   ffe0fc00/54602800 level 2
   ffe0fc00/54602c00 level 2
   ffe0fc00/54603000 level 2
   ffe0fc00/54603400 level 2
   ffe0fc00/54603800 level 2
   ffe0fc00/54603c00 level 2
   ffe0fc00/54604000 level 2
   ffe0fc00/54604400 level 2
   ffe0fc00/54604800 level 2
   ffe0fc00/54604c00 level 2
   ffe0fc00/54605000 level 2
   ffe0fc00/54605400 level 2
   ffe0fc00/54605800 level 2
   ffe0fc00/54605c00 level 2
   ffe0fc00/54606000 level 2
   ffe0fc00/54606400 level 2
   ffe0fc00/54606800 level 2
   ffe0fc00/54606c00 level 2
   ffe0fc00/54607000 level 2
   ffe0fc00/54607400 level 2
   ffe0fc00/54607800 level 2
   ffe0fc00/54607c00 level 2
   ffe0fc00/54608000 level 2
   ffe0fc00/54608400 level 2
   ffe0fc00/54608800 level 2
   ffe0fc00/54608c00 level 2
   ffe0fc00/54609000 level 2
   ffe0fc00/54609400 level 2
   ffe0fc00/54609800 level 2
   ffe0fc00/54609c00 level 2
   ffe0fc00/5460a000 level 2
   ffe0fc00/5460a400 level 2
   ffe0fc00/5460a800 level 2
   ffe0fc00/5460ac00 level 2
   ffe0fc00/5460b000 level 2
   ffe0fc00/5460b400 level 2
   ffe0fc00/5460b800 level 2
   ffe0fc00/5460bc00 level 2
   ffe0fc00/5460c000 level 2
   ffe0fc00/5460c400 level 2
   ffe0fc00/5460c800 level 2
   ffe0fc00/5460cc00 level 2
   ffe0fc00/5460d000 level 2
   ffe0fc00/5460d400 level 2
   ffe0fc00/5460d800 level 2
   ffe0fc00/5460dc00 level 2
   ffe0fc00/5460e000 level 2
   ffe0fc00/5460e400 level 2
   ffe0fc00/5460e800 level 2
   ffe0fc00/5460ec00 level 2
   ffe0fc00/5460f000 level 2
   ffe0fc00/5460f400 level 2
   ffe0fc00/5460f800 level 2
   ffe0fc00/5460fc00 level 2
   ffe0fc00/54802000 level 2
   ffe0fc00/54802400 level 2
   ffe0fc00/54802c00 level 2
   ffe0fc00/54803000 level 2
   ffe0fc00/54803400 level 2
   ffe0fc00/54803c00 level 2
   ffe0fc00/54804000 level 2
   ffe0fc00/54804400 level 2
   ffe0fc00/54804800 level 2
   ffe0fc00/54804c00 level 2
   ffe0fc00/54805000 level 2
   ffe0fc00/54805400 level 2
   ffe0fc00/54805800 level 2
   ffe0fc00/54805c00 level 2
   ffe0fc00/54806000 level 2
   ffe0fc00/54806400 level 2
   ffe0fc00/54806800 level 2
   ffe0fc00/54806c00 level 2
   ffe0fc00/54807000 level 2
   ffe0fc00/54807400 level 2
   ffe0fc00/54807800 level 2
   ffe0fc00/54807c00 level 2
   ffe0fc00/5480c000 level 2
   ffe0fc00/5480c400 level 2
   ffe0fc00/5480c800 level 2
   ffe0fc00/5480cc00 level 2
   ffe0fc00/5480d000 level 2
   ffe0fc00/5480d400 level 2
   ffe0fc00/5480d800 level 2
   ffe0fc00/5480dc00 level 2
   ffe0fc00/5480e000 level 2
   ffe0fc00/5480e400 level 2
   ffe0fc00/5480e800 level 2
   ffe0fc00/5480ec00 level 2
   ffe0fc00/5480f000 level 2
   ffe0fc00/5480f400 level 2
   ffe0fc00/5480f800 level 2
   ffe0fc00/5480fc00 level 2
   ffe0fc00/54a00000 level 2
   ffe0fc00/54a00400 level 2
   ffe0fc00/54a00800 level 2
   ffe0fc00/54a00c00 level 2
   ffe0fc00/54a01000 level 2
   ffe0fc00/54a01400 level 2
   ffe0fc00/54a01800 level 2
   ffe0fc00/54a01c00 level 2
   ffe0fc00/54a02000 level 2
   ffe0fc00/54a02400 level 2
   ffe0fc00/54a02800 level 2
   ffe0fc00/54a02c00 level 2
   ffe0fc00/54a03000 level 2
   ffe0fc00/54a03400 level 2
   ffe0fc00/54a03800 level 2
   ffe0fc00/54a03c00 level 2
   ffe0fc00/54a04000 level 2
   ffe0fc00/54a04400 level 2
   ffe0fc00/54a04800 level 2
   ffe0fc00/54a04c00 level 2
   ffe0fc00/54a05000 level 2
   ffe0fc00/54a05400 level 2
   ffe0fc00/54a05800 level 2
   ffe0fc00/54a05c00 level 2
   ffe0fc00/54a06000 level 2
   ffe0fc00/54a06400 level 2
   ffe0fc00/54a06800 level 2
   ffe0fc00/54a06c00 level 2
   ffe0fc00/54a07000 level 2
   ffe0fc00/54a07400 level 2
   ffe0fc00/54a07800 level 2
   ffe0fc00/54a07c00 level 2
   ffe0fc00/54a08000 level 2
   ffe0fc00/54a08400 level 2
   ffe0fc00/54a08800 level 2
   ffe0fc00/54a08c00 level 2
   ffe0fc00/54a09000 level 2
   ffe0fc00/54a09400 level 2
   ffe0fc00/54a09800 level 2
   ffe0fc00/54a09c00 level 2
   ffe0fc00/54a0a000 level 2
   ffe0fc00/54a0a400 level 2
   ffe0fc00/54a0a800 level 2
   ffe0fc00/54a0ac00 level 2
   ffe0fc00/54a0b000 level 2
   ffe0fc00/54a0b400 level 2
   ffe0fc00/54a0b800 level 2
   ffe0fc00/54a0bc00 level 2
   ffe0fc00/54a0c000 level 2
   ffe0fc00/54a0c400 level 2
   ffe0fc00/54a0c800 level 2
   ffe0fc00/54a0cc00 level 2
   ffe0fc00/54a0d000 level 2
   ffe0fc00/54a0d400 level 2
   ffe0fc00/54a0d800 level 2
   ffe0fc00/54a0dc00 level 2
   ffe0fc00/54a0e000 level 2
   ffe0fc00/54a0e400 level 2
   ffe0fc00/54a0e800 level 2
   ffe0fc00/54a0ec00 level 2
   ffe0fc00/54a0f000 level 2
   ffe0fc00/54a0f400 level 2
   ffe0fc00/54a0f800 level 2
   ffe0fc00/54a0fc00 level 2
   ffe0fc00/54c02000 level 2
   ffe0fc00/54c02400 level 2
   ffe0fc00/54c02800 level 2
   ffe0fc00/54c02c00 level 2
   ffe0fc00/54c03000 level 2
   ffe0fc00/54c03400 level 2
   ffe0fc00/54c03800 level 2
   ffe0fc00/54c03c00 level 2
   ffe0fc00/54c04000 level 2
   ffe0fc00/54c04400 level 2
   ffe0fc00/54c04800 level 2
   ffe0fc00/54c04c00 level 2
   ffe0fc00/54c05000 level 2
   ffe0fc00/54c05400 level 2
   ffe0fc00/54c05800 level 2
   ffe0fc00/54c05c00 level 2
   ffe0fc00/54c06000 level 2
   ffe0fc00/54c06400 level 2
   ffe0fc00/54c06800 level 2
   ffe0fc00/54c06c00 level 2
   ffe0fc00/54c07000 level 2
   ffe0fc00/54c07400 level 2
   ffe0fc00/54c07800 level 2
   ffe0fc00/54c07c00 level 2
   ffe0fc00/54c0c000 level 2
   ffe0fc00/54c0c400 level 2
   ffe0fc00/54c0c800 level 2
   ffe0fc00/54c0cc00 level 2
   ffe0fc00/54c0d000 level 2
   ffe0fc00/54c0d400 level 2
   ffe0fc00/54c0d800 level 2
   ffe0fc00/54c0dc00 level 2
   ffe0fc00/54c0e000 level 2
   ffe0fc00/54c0e400 level 2
   ffe0fc00/54c0e800 level 2
   ffe0fc00/54c0ec00 level 2
   ffe0fc00/54c0f000 level 2
   ffe0fc00/54c0f400 level 2
   ffe0fc00/54c0f800 level 2
   ffe0fc00/54c0fc00 level 2
   ffe0fc00/54e00000 level 2
   ffe0fc00/54e00400 level 2
   ffe0fc00/54e00800 level 2
   ffe0fc00/54e00c00 level 2
   ffe0fc00/54e01000 level 2
   ffe0fc00/54e01400 level 2
   ffe0fc00/54e01800 level 2
   ffe0fc00/54e01c00 level 2
   ffe0fc00/54e02000 level 2
   ffe0fc00/54e02400 level 2
   ffe0fc00/54e02800 level 2
   ffe0fc00/54e02c00 level 2
   ffe0fc00/54e03000 level 2
   ffe0fc00/54e03400 level 2
   ffe0fc00/54e03800 level 2
   ffe0fc00/54e03c00 level 2
   ffe0fc00/54e04000 level 2
   ffe0fc00/54e04400 level 2
   ffe0fc00/54e04800 level 2
   ffe0fc00/54e04c00 level 2
   ffe0fc00/54e05000 level 2
   ffe0fc00/54e05400 level 2
   ffe0fc00/54e05800 level 2
   ffe0fc00/54e05c00 level 2
   ffe0fc00/54e06000 level 2
   ffe0fc00/54e06400 level 2
   ffe0fc00/54e06800 level 2
   ffe0fc00/54e06c00 level 2
   ffe0fc00/54e07000 level 2
   ffe0fc00/54e07400 level 2
   ffe0fc00/54e07800 level 2
   ffe0fc00/54e07c00 level 2
   ffe0fc00/54e08000 level 2
   ffe0fc00/54e08400 level 2
   ffe0fc00/54e08800 level 2
   ffe0fc00/54e08c00 level 2
   ffe0fc00/54e09000 level 2
   ffe0fc00/54e09400 level 2
   ffe0fc00/54e09800 level 2
   ffe0fc00/54e09c00 level 2
   ffe0fc00/54e0a000 level 2
   ffe0fc00/54e0a400 level 2
   ffe0fc00/54e0a800 level 2
   ffe0fc00/54e0ac00 level 2
   ffe0fc00/54e0b000 level 2
   ffe0fc00/54e0b400 level 2
   ffe0fc00/54e0b800 level 2
   ffe0fc00/54e0bc00 level 2
   ffe0fc00/54e0c000 level 2
   ffe0fc00/54e0c400 level 2
   ffe0fc00/54e0c800 level 2
   ffe0fc00/54e0cc00 level 2
   ffe0fc00/54e0d000 level 2
   ffe0fc00/54e0d400 level 2
   ffe0fc00/54e0d800 level 2
   ffe0fc00/54e0dc00 level 2
   ffe0fc00/54e0e000 level 2
   ffe0fc00/54e0e400 level 2
   ffe0fc00/54e0e800 level 2
   ffe0fc00/54e0ec00 level 2
   ffe0fc00/54e0f000 level 2
   ffe0fc00/54e0f400 level 2
   ffe0fc00/54e0f800 level 2
   ffe0fc00/54e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_54000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/d4000000 level 2
   ffe0fc00/d4000400 level 2
   f7e0fc10/d4000800 level 2
   ffe0fc00/d4000c00 level 2
   ffe0fc00/d4001000 level 2
   ffe0fc00/d4001400 level 2
   f7e0fc10/d4001800 level 2
   ffe0fc00/d4001c00 level 2
   ffe0fc00/d4002000 level 2
   ffe0fc00/d4002400 level 2
   ffe0fc00/d4002800 level 2
   ffe0fc00/d4002c00 level 2
   ffe0fc00/d4003000 level 2
   ffe0fc00/d4003400 level 2
   ffe0fc00/d4003800 level 2
   ffe0fc00/d4003c00 level 2
   ffe0fc00/d4004000 level 2
   ffe0fc00/d4004400 level 2
   ffe0fc00/d4004800 level 2
   ffe0fc00/d4004c00 level 2
   ffe0fc00/d4005000 level 2
   ffe0fc00/d4005400 level 2
   ffe0fc00/d4005800 level 2
   ffe0fc00/d4005c00 level 2
   ffe0fc00/d4006000 level 2
   ffe0fc00/d4006400 level 2
   ffe0fc00/d4006800 level 2
   ffe0fc00/d4006c00 level 2
   ffe0fc00/d4007000 level 2
   ffe0fc00/d4007400 level 2
   ffe0fc00/d4007800 level 2
   ffe0fc00/d4007c00 level 2
   dfe0fc10/d4009800 level 2
   f7e0fc10/d400b800 level 2
   ffe0fc00/d400c000 level 2
   ffe0fc00/d400c400 level 2
   ffe0fc00/d400c800 level 2
   ffe0fc00/d400cc00 level 2
   ffe0fc00/d400d000 level 2
   ffe0fc00/d400d400 level 2
   ffe0fc00/d400d800 level 2
   ffe0fc00/d400dc00 level 2
   ffe0fc00/d400e000 level 2
   ffe0fc00/d400e400 level 2
   ffe0fc00/d400e800 level 2
   ffe0fc00/d400ec00 level 2
   ffe0fc00/d400f000 level 2
   ffe0fc00/d400f400 level 2
   ffe0fc00/d400f800 level 2
   ffe0fc00/d400fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d4000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4000001))
        return iemDecodeA64_SVC_EX_exception(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4000002))
        return iemDecodeA64_HVC_EX_exception(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4000003))
        return iemDecodeA64_SMC_EX_exception(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4000000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04000000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_ST4_asisdlse_R4,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST4_asisdlse_R4,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4000400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04000400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_ST4_asisdlse_R4,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST4_asisdlse_R4,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7fffc10/04000800 level 3
   f7fffc10/04000810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_f7fffc10_04000800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c000000))
        return iemDecodeA64_ST4_asisdlse_R4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04000000))
        return iemDecodeA64_add_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/04000800 level 2
   f7e0fc10/04000810 level 2
   mask=0x1f0000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_04000800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7fffc10_04000800_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_subr_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smax_z_p_zz,
        iemDecodeA64_umax_z_p_zz,
        iemDecodeA64_smin_z_p_zz,
        iemDecodeA64_umin_z_p_zz,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_mul_z_p_zz,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_umulh_z_p_zz,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_orr_z_p_zz,
        iemDecodeA64_eor_z_p_zz,
        iemDecodeA64_and_z_p_zz,
        iemDecodeA64_bic_z_p_zz,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/14000800 level 2
   f7e0fc10/14000810 level 2
   f7e0fc10/14001800 level 2
   f7e0fc10/14001810 level 2
   f7e0fc10/1400b800 level 2
   f7e0fc10/1400b810 level 2
   f7e0fc10/14400800 level 2
   f7e0fc10/14400810 level 2
   f7e0fc10/14401800 level 2
   f7e0fc10/14401810 level 2
   f7e0fc10/14801000 level 2
   f7e0fc10/14801010 level 2
   f7e0fc10/14801400 level 2
   f7e0fc10/14801410 level 2
   f7e0fc10/14801c00 level 2
   f7e0fc10/14801c10 level 2
   f7e0fc10/14c01000 level 2
   f7e0fc10/14c01010 level 2
   f7e0fc10/14c01400 level 2
   f7e0fc10/14c01410 level 2
   f7e0fc10/14c01800 level 2
   f7e0fc10/14c01810 level 2
   f7e0fc10/14c01c00 level 2
   f7e0fc10/14c01c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_14000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x1c000000))
        return iemDecodeA64_LDR_S_loadlit(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/24000800 level 2
   f7e0fc10/24001800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_24000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000000))
        return iemDecodeA64_cmphs_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c000000))
        return iemDecodeA64_STNP_S_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/24000810 level 2
   f7e0fc10/24001810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_24000810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000010))
        return iemDecodeA64_cmphi_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c000000))
        return iemDecodeA64_STNP_S_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/44000800 level 2
   f7e0fc10/44000810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_44000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c000000))
        return iemDecodeA64_ST4_asisdlse_R4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x44000800))
        return iemDecodeA64_sqdmlalbt_z_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/54000800 level 2
   f7e0fc10/54001800 level 2
   f7e0fc10/5400b800 level 2
   f7e0fc10/54400800 level 2
   f7e0fc10/54401800 level 2
   f7e0fc10/54801000 level 2
   f7e0fc10/54801400 level 2
   f7e0fc10/54801c00 level 2
   f7e0fc10/54c01000 level 2
   f7e0fc10/54c01400 level 2
   f7e0fc10/54c01800 level 2
   f7e0fc10/54c01c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_54000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x5c000000))
        return iemDecodeA64_LDR_D_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/54000810 level 2
   f7e0fc10/54001810 level 2
   f7e0fc10/5400b810 level 2
   f7e0fc10/54400810 level 2
   f7e0fc10/54401810 level 2
   f7e0fc10/54801010 level 2
   f7e0fc10/54801410 level 2
   f7e0fc10/54801c10 level 2
   f7e0fc10/54c01010 level 2
   f7e0fc10/54c01410 level 2
   f7e0fc10/54c01810 level 2
   f7e0fc10/54c01c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_54000810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x5c000000))
        return iemDecodeA64_LDR_D_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/64000800 level 2
   f7e0fc10/64000810 level 2
   f7e0fc10/64001800 level 2
   f7e0fc10/64001810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_64000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6c000000))
        return iemDecodeA64_STNP_D_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/94000800 level 2
   f7e0fc10/94000810 level 2
   f7e0fc10/94001800 level 2
   f7e0fc10/94001810 level 2
   f7e0fc10/9400b800 level 2
   f7e0fc10/9400b810 level 2
   f7e0fc10/94400800 level 2
   f7e0fc10/94400810 level 2
   f7e0fc10/94401800 level 2
   f7e0fc10/94401810 level 2
   f7e0fc10/94801000 level 2
   f7e0fc10/94801010 level 2
   f7e0fc10/94801400 level 2
   f7e0fc10/94801410 level 2
   f7e0fc10/94801c00 level 2
   f7e0fc10/94801c10 level 2
   f7e0fc10/94c01000 level 2
   f7e0fc10/94c01010 level 2
   f7e0fc10/94c01400 level 2
   f7e0fc10/94c01410 level 2
   f7e0fc10/94c01800 level 2
   f7e0fc10/94c01810 level 2
   f7e0fc10/94c01c00 level 2
   f7e0fc10/94c01c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_94000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x9c000000))
        return iemDecodeA64_LDR_Q_loadlit(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/a4000800 level 2
   f7e0fc10/a4000810 level 2
   f7e0fc10/a4001800 level 2
   f7e0fc10/a4001810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_a4000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xac000000))
        return iemDecodeA64_STNP_Q_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa4000000))
        return iemDecodeA64_ld1rqb_z_p_br_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4000800/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1f valid=%97 (0x1f) leaf=%44 (0xe) multi-if=%47 (0xf) reuse=%22 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04000800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc10_04000800_2,
        iemDecodeA64_f7e0fc10_04000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24000800_2,
        iemDecodeA64_f7e0fc10_24000810_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_f7e0fc10_44000800_2,
        iemDecodeA64_f7e0fc10_44000800_2,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64000800_2,
        iemDecodeA64_f7e0fc10_64000800_2,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_a4000800_2,
        iemDecodeA64_f7e0fc10_a4000800_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_CBGT_64_regs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4000c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04000c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_ST4_asisdlse_R4,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_ST4_asisdlse_R4,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4001000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04001000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4001400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04001400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4001800/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1f valid=%97 (0x1f) leaf=%50 (0x10) multi-if=%41 (0xd) reuse=%47 (0xf) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04001800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24000800_2,
        iemDecodeA64_f7e0fc10_24000810_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64000800_2,
        iemDecodeA64_f7e0fc10_64000800_2,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_a4000800_2,
        iemDecodeA64_f7e0fc10_a4000800_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_CBGT_64_regs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4001c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04001c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04002000 level 2
   ffe0fc00/04002400 level 2
   ffe0fc00/04002800 level 2
   ffe0fc00/04002c00 level 2
   ffe0fc00/04003000 level 2
   ffe0fc00/04003400 level 2
   ffe0fc00/04003800 level 2
   ffe0fc00/04003c00 level 2
   ffe0fc00/04402000 level 2
   ffe0fc00/04402400 level 2
   ffe0fc00/04402800 level 2
   ffe0fc00/04402c00 level 2
   ffe0fc00/04403000 level 2
   ffe0fc00/04403400 level 2
   ffe0fc00/04403800 level 2
   ffe0fc00/04403c00 level 2
   ffe0fc00/04802000 level 2
   ffe0fc00/04802400 level 2
   ffe0fc00/04802c00 level 2
   ffe0fc00/04803000 level 2
   ffe0fc00/04803400 level 2
   ffe0fc00/04803c00 level 2
   ffe0fc00/04c02000 level 2
   ffe0fc00/04c02400 level 2
   ffe0fc00/04c02800 level 2
   ffe0fc00/04c02c00 level 2
   ffe0fc00/04c03000 level 2
   ffe0fc00/04c03400 level 2
   ffe0fc00/04c03800 level 2
   ffe0fc00/04c03c00 level 2
   mask=0x1f0000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04002000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_saddv_r_p_z,
        iemDecodeA64_uaddv_r_p_z,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_addqv_z_p_z,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smaxv_r_p_z,
        iemDecodeA64_umaxv_r_p_z,
        iemDecodeA64_sminv_r_p_z,
        iemDecodeA64_uminv_r_p_z,
        iemDecodeA64_smaxqv_z_p_z,
        iemDecodeA64_umaxqv_z_p_z,
        iemDecodeA64_sminqv_z_p_z,
        iemDecodeA64_uminqv_z_p_z,
        iemDecodeA64_movprfx_z_p_z,
        iemDecodeA64_movprfx_z_p_z,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_orv_r_p_z,
        iemDecodeA64_eorv_r_p_z,
        iemDecodeA64_andv_r_p_z,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_orqv_z_p_z,
        iemDecodeA64_eorqv_z_p_z,
        iemDecodeA64_andqv_z_p_z,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/24002000 level 2
   ffe0fc00/24002400 level 2
   ffe0fc00/24002800 level 2
   ffe0fc00/24002c00 level 2
   ffe0fc00/24003000 level 2
   ffe0fc00/24003400 level 2
   ffe0fc00/24003800 level 2
   ffe0fc00/24003c00 level 2
   ffe0fc00/24402000 level 2
   ffe0fc00/24402400 level 2
   ffe0fc00/24402800 level 2
   ffe0fc00/24402c00 level 2
   ffe0fc00/24403000 level 2
   ffe0fc00/24403400 level 2
   ffe0fc00/24403800 level 2
   ffe0fc00/24403c00 level 2
   ffe0fc00/24802000 level 2
   ffe0fc00/24802400 level 2
   ffe0fc00/24802c00 level 2
   ffe0fc00/24803000 level 2
   ffe0fc00/24803400 level 2
   ffe0fc00/24803c00 level 2
   ffe0fc00/24c02000 level 2
   ffe0fc00/24c02400 level 2
   ffe0fc00/24c02800 level 2
   ffe0fc00/24c02c00 level 2
   ffe0fc00/24c03000 level 2
   ffe0fc00/24c03400 level 2
   ffe0fc00/24c03800 level 2
   ffe0fc00/24c03c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_24002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24002000))
        return iemDecodeA64_cmpeq_p_p_zw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24002010))
        return iemDecodeA64_cmpne_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4002000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1d valid=%91 (0x1d) leaf=%78 (0x19) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04002000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ST1_asisdlse_R4_4v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ST1_asisdlse_R4_4v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4002400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1d valid=%91 (0x1d) leaf=%78 (0x19) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04002400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ST1_asisdlse_R4_4v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ST1_asisdlse_R4_4v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4002800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04002800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ST1_asisdlse_R4_4v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ST1_asisdlse_R4_4v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4002c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1d valid=%91 (0x1d) leaf=%78 (0x19) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04002c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ST1_asisdlse_R4_4v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ST1_asisdlse_R4_4v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4003000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04003000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4003400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04003400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4003800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04003800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4003c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04003c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGT_32_regs,
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqb_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGT_64_regs,
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/24004000 level 2
   ffe0fc00/24004400 level 2
   ffe0fc00/24004800 level 2
   ffe0fc00/24004c00 level 2
   ffe0fc00/24005000 level 2
   ffe0fc00/24005400 level 2
   ffe0fc00/24005800 level 2
   ffe0fc00/24005c00 level 2
   ffe0fc00/24404000 level 2
   ffe0fc00/24404400 level 2
   ffe0fc00/24404800 level 2
   ffe0fc00/24404c00 level 2
   ffe0fc00/24405000 level 2
   ffe0fc00/24405400 level 2
   ffe0fc00/24405800 level 2
   ffe0fc00/24405c00 level 2
   ffe0fc00/24804000 level 2
   ffe0fc00/24804400 level 2
   ffe0fc00/24804800 level 2
   ffe0fc00/24804c00 level 2
   ffe0fc00/24805000 level 2
   ffe0fc00/24805400 level 2
   ffe0fc00/24805800 level 2
   ffe0fc00/24805c00 level 2
   ffe0fc00/24c04000 level 2
   ffe0fc00/24c04400 level 2
   ffe0fc00/24c04800 level 2
   ffe0fc00/24c04c00 level 2
   ffe0fc00/24c05000 level 2
   ffe0fc00/24c05400 level 2
   ffe0fc00/24c05800 level 2
   ffe0fc00/24c05c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_24004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24004000))
        return iemDecodeA64_cmpge_p_p_zw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24004010))
        return iemDecodeA64_cmpgt_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4004000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04004000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ST3_asisdlse_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_smlalb_z_zzz,
        iemDecodeA64_ST3_asisdlse_R3,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4004400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04004400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ST3_asisdlse_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_smlalt_z_zzz,
        iemDecodeA64_ST3_asisdlse_R3,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4004800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04004800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ST3_asisdlse_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalb_z_zzz,
        iemDecodeA64_ST3_asisdlse_R3,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4004c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04004c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ST3_asisdlse_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_umlalt_z_zzz,
        iemDecodeA64_ST3_asisdlse_R3,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4005000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04005000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_smlslb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4005400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04005400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_smlslt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4005800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04005800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlslb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4005c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04005c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_umlslt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/24006000 level 2
   ffe0fc00/24006400 level 2
   ffe0fc00/24006800 level 2
   ffe0fc00/24006c00 level 2
   ffe0fc00/24007000 level 2
   ffe0fc00/24007400 level 2
   ffe0fc00/24007800 level 2
   ffe0fc00/24007c00 level 2
   ffe0fc00/24406000 level 2
   ffe0fc00/24406400 level 2
   ffe0fc00/24406800 level 2
   ffe0fc00/24406c00 level 2
   ffe0fc00/24407000 level 2
   ffe0fc00/24407400 level 2
   ffe0fc00/24407800 level 2
   ffe0fc00/24407c00 level 2
   ffe0fc00/24806000 level 2
   ffe0fc00/24806400 level 2
   ffe0fc00/24806800 level 2
   ffe0fc00/24806c00 level 2
   ffe0fc00/24807000 level 2
   ffe0fc00/24807400 level 2
   ffe0fc00/24807800 level 2
   ffe0fc00/24807c00 level 2
   ffe0fc00/24c06000 level 2
   ffe0fc00/24c06400 level 2
   ffe0fc00/24c06800 level 2
   ffe0fc00/24c06c00 level 2
   ffe0fc00/24c07000 level 2
   ffe0fc00/24c07400 level 2
   ffe0fc00/24c07800 level 2
   ffe0fc00/24c07c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_24006000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24006000))
        return iemDecodeA64_cmplt_p_p_zw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24006010))
        return iemDecodeA64_cmple_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4006000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04006000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ST1_asisdlse_R3_3v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_sqdmlalb_z_zzz,
        iemDecodeA64_ST1_asisdlse_R3_3v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4006400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04006400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ST1_asisdlse_R3_3v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_sqdmlalt_z_zzz,
        iemDecodeA64_ST1_asisdlse_R3_3v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4006800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04006800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ST1_asisdlse_R3_3v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslb_z_zzz,
        iemDecodeA64_ST1_asisdlse_R3_3v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4006c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04006c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ST1_asisdlse_R3_3v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_sqdmlslt_z_zzz,
        iemDecodeA64_ST1_asisdlse_R3_3v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4007000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04007000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ST1_asisdlse_R1_1v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_sqrdmlah_z_zzz,
        iemDecodeA64_ST1_asisdlse_R1_1v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4007400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04007400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ST1_asisdlse_R1_1v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_sqrdmlsh_z_zzz,
        iemDecodeA64_ST1_asisdlse_R1_1v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4007800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04007800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ST1_asisdlse_R1_1v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST1_asisdlse_R1_1v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4007c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04007c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ST1_asisdlse_R1_1v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST1_asisdlse_R1_1v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/04008000 level 2
   bfe0fc10/04008010 level 2
   bfe0fc10/04008400 level 2
   bfe0fc10/04008410 level 2
   bfe0fc10/04008800 level 2
   bfe0fc10/04008810 level 2
   bfe0fc10/04008c00 level 2
   bfe0fc10/04008c10 level 2
   bfe0fc10/04009000 level 2
   bfe0fc10/04009010 level 2
   bfe0fc10/04009400 level 2
   bfe0fc10/04009410 level 2
   bfe0fc10/04009c00 level 2
   bfe0fc10/04009c10 level 2
   bfe0fc10/04408000 level 2
   bfe0fc10/04408010 level 2
   bfe0fc10/04408400 level 2
   bfe0fc10/04408410 level 2
   bfe0fc10/04408800 level 2
   bfe0fc10/04408810 level 2
   bfe0fc10/04408c00 level 2
   bfe0fc10/04408c10 level 2
   bfe0fc10/04409000 level 2
   bfe0fc10/04409010 level 2
   bfe0fc10/04409400 level 2
   bfe0fc10/04409410 level 2
   bfe0fc10/04409c00 level 2
   bfe0fc10/04409c10 level 2
   bfe0fc10/04808000 level 2
   bfe0fc10/04808010 level 2
   bfe0fc10/04808400 level 2
   bfe0fc10/04808410 level 2
   bfe0fc10/04808800 level 2
   bfe0fc10/04808810 level 2
   bfe0fc10/04808c00 level 2
   bfe0fc10/04808c10 level 2
   bfe0fc10/04c08000 level 2
   bfe0fc10/04c08010 level 2
   bfe0fc10/04c08400 level 2
   bfe0fc10/04c08410 level 2
   bfe0fc10/04c08800 level 2
   bfe0fc10/04c08810 level 2
   bfe0fc10/04c08c00 level 2
   bfe0fc10/04c08c10 level 2
   bfe0fc10/04c09000 level 2
   bfe0fc10/04c09010 level 2
   bfe0fc10/04c09400 level 2
   bfe0fc10/04c09410 level 2
   bfe0fc10/04c09c00 level 2
   bfe0fc10/04c09c10 level 2
   mask=0x401f0000 entries=0x40 children=0x2e valid=%72 (0x2e) leaf=%72 (0x2e) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04008000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_p_zi,
        iemDecodeA64_lsr_z_p_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_lsl_z_p_zi,
        iemDecodeA64_asrd_z_p_zi,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_sqshl_z_p_zi,
        iemDecodeA64_uqshl_z_p_zi,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_srshr_z_p_zi,
        iemDecodeA64_urshr_z_p_zi,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_sqshlu_z_p_zi,
        iemDecodeA64_asr_z_p_zz,
        iemDecodeA64_lsr_z_p_zz,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_lsl_z_p_zz,
        iemDecodeA64_asrr_z_p_zz,
        iemDecodeA64_lsrr_z_p_zz,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_lslr_z_p_zz,
        iemDecodeA64_asr_z_p_zw,
        iemDecodeA64_lsr_z_p_zw,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_lsl_z_p_zw,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_srshl_z_p_zz,
        iemDecodeA64_urshl_z_p_zz,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_srshlr_z_p_zz,
        iemDecodeA64_urshlr_z_p_zz,
        iemDecodeA64_sqshl_z_p_zz,
        iemDecodeA64_uqshl_z_p_zz,
        iemDecodeA64_sqrshl_z_p_zz,
        iemDecodeA64_uqrshl_z_p_zz,
        iemDecodeA64_sqshlr_z_p_zz,
        iemDecodeA64_uqshlr_z_p_zz,
        iemDecodeA64_sqrshlr_z_p_zz,
        iemDecodeA64_uqrshlr_z_p_zz,
        iemDecodeA64_shadd_z_p_zz,
        iemDecodeA64_uhadd_z_p_zz,
        iemDecodeA64_shsub_z_p_zz,
        iemDecodeA64_uhsub_z_p_zz,
        iemDecodeA64_srhadd_z_p_zz,
        iemDecodeA64_urhadd_z_p_zz,
        iemDecodeA64_shsubr_z_p_zz,
        iemDecodeA64_uhsubr_z_p_zz,
        iemDecodeA64_sqadd_z_p_zz,
        iemDecodeA64_uqadd_z_p_zz,
        iemDecodeA64_sqsub_z_p_zz,
        iemDecodeA64_uqsub_z_p_zz,
        iemDecodeA64_suqadd_z_p_zz,
        iemDecodeA64_usqadd_z_p_zz,
        iemDecodeA64_sqsubr_z_p_zz,
        iemDecodeA64_uqsubr_z_p_zz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x401f0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000020)) /* bit 30 L 1 -> 5 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/14008000 level 2
   bfe0fc10/14008400 level 2
   bfe0fc10/14008800 level 2
   bfe0fc10/14008c00 level 2
   bfe0fc10/14009000 level 2
   bfe0fc10/14009400 level 2
   bfe0fc10/14009c00 level 2
   bfe0fc10/1400a000 level 2
   bfe0fc10/1400a400 level 2
   bfe0fc10/1400a800 level 2
   bfe0fc10/1400ac00 level 2
   bfe0fc10/1400b000 level 2
   bfe0fc10/1400b400 level 2
   bfe0fc10/1400bc00 level 2
   bfe0fc10/14408000 level 2
   bfe0fc10/14408400 level 2
   bfe0fc10/14408800 level 2
   bfe0fc10/14408c00 level 2
   bfe0fc10/14409000 level 2
   bfe0fc10/14409400 level 2
   bfe0fc10/14409c00 level 2
   bfe0fc10/1440a000 level 2
   bfe0fc10/1440a400 level 2
   bfe0fc10/1440a800 level 2
   bfe0fc10/1440ac00 level 2
   bfe0fc10/1440b000 level 2
   bfe0fc10/1440b400 level 2
   bfe0fc10/1440b800 level 2
   bfe0fc10/1440bc00 level 2
   bfe0fc10/14800000 level 2
   bfe0fc10/14800400 level 2
   bfe0fc10/14800800 level 2
   bfe0fc10/14800c00 level 2
   bfe0fc10/14802800 level 2
   bfe0fc10/14808000 level 2
   bfe0fc10/14808400 level 2
   bfe0fc10/14808800 level 2
   bfe0fc10/14808c00 level 2
   bfe0fc10/1480a000 level 2
   bfe0fc10/1480a400 level 2
   bfe0fc10/1480a800 level 2
   bfe0fc10/1480ac00 level 2
   bfe0fc10/1480b000 level 2
   bfe0fc10/1480b400 level 2
   bfe0fc10/1480b800 level 2
   bfe0fc10/1480bc00 level 2
   bfe0fc10/14c00000 level 2
   bfe0fc10/14c00400 level 2
   bfe0fc10/14c00c00 level 2
   bfe0fc10/14c08000 level 2
   bfe0fc10/14c08400 level 2
   bfe0fc10/14c08800 level 2
   bfe0fc10/14c08c00 level 2
   bfe0fc10/14c09000 level 2
   bfe0fc10/14c09400 level 2
   bfe0fc10/14c09c00 level 2
   bfe0fc10/14c0a000 level 2
   bfe0fc10/14c0a400 level 2
   bfe0fc10/14c0a800 level 2
   bfe0fc10/14c0ac00 level 2
   bfe0fc10/14c0b000 level 2
   bfe0fc10/14c0b400 level 2
   bfe0fc10/14c0b800 level 2
   bfe0fc10/14c0bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_14008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/14008010 level 2
   bfe0fc10/14008410 level 2
   bfe0fc10/14008810 level 2
   bfe0fc10/14008c10 level 2
   bfe0fc10/14009010 level 2
   bfe0fc10/14009410 level 2
   bfe0fc10/14009c10 level 2
   bfe0fc10/1400a010 level 2
   bfe0fc10/1400a410 level 2
   bfe0fc10/1400a810 level 2
   bfe0fc10/1400ac10 level 2
   bfe0fc10/1400b010 level 2
   bfe0fc10/1400b410 level 2
   bfe0fc10/1400bc10 level 2
   bfe0fc10/14408010 level 2
   bfe0fc10/14408410 level 2
   bfe0fc10/14408810 level 2
   bfe0fc10/14408c10 level 2
   bfe0fc10/14409010 level 2
   bfe0fc10/14409410 level 2
   bfe0fc10/14409c10 level 2
   bfe0fc10/1440a010 level 2
   bfe0fc10/1440a410 level 2
   bfe0fc10/1440a810 level 2
   bfe0fc10/1440ac10 level 2
   bfe0fc10/1440b010 level 2
   bfe0fc10/1440b410 level 2
   bfe0fc10/1440b810 level 2
   bfe0fc10/1440bc10 level 2
   bfe0fc10/14800010 level 2
   bfe0fc10/14800410 level 2
   bfe0fc10/14800810 level 2
   bfe0fc10/14800c10 level 2
   bfe0fc10/14802810 level 2
   bfe0fc10/14808010 level 2
   bfe0fc10/14808410 level 2
   bfe0fc10/14808810 level 2
   bfe0fc10/14808c10 level 2
   bfe0fc10/1480a010 level 2
   bfe0fc10/1480a410 level 2
   bfe0fc10/1480a810 level 2
   bfe0fc10/1480ac10 level 2
   bfe0fc10/1480b010 level 2
   bfe0fc10/1480b410 level 2
   bfe0fc10/1480b810 level 2
   bfe0fc10/1480bc10 level 2
   bfe0fc10/14c00010 level 2
   bfe0fc10/14c00410 level 2
   bfe0fc10/14c00c10 level 2
   bfe0fc10/14c08010 level 2
   bfe0fc10/14c08410 level 2
   bfe0fc10/14c08810 level 2
   bfe0fc10/14c08c10 level 2
   bfe0fc10/14c09010 level 2
   bfe0fc10/14c09410 level 2
   bfe0fc10/14c09c10 level 2
   bfe0fc10/14c0a010 level 2
   bfe0fc10/14c0a410 level 2
   bfe0fc10/14c0a810 level 2
   bfe0fc10/14c0ac10 level 2
   bfe0fc10/14c0b010 level 2
   bfe0fc10/14c0b410 level 2
   bfe0fc10/14c0b810 level 2
   bfe0fc10/14c0bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_14008010_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/1c008000 level 2
   bfe0fc10/1c008010 level 2
   bfe0fc10/1c008400 level 2
   bfe0fc10/1c008410 level 2
   bfe0fc10/1c008800 level 2
   bfe0fc10/1c008810 level 2
   bfe0fc10/1c008c00 level 2
   bfe0fc10/1c008c10 level 2
   bfe0fc10/1c009000 level 2
   bfe0fc10/1c009010 level 2
   bfe0fc10/1c009400 level 2
   bfe0fc10/1c009410 level 2
   bfe0fc10/1c009c00 level 2
   bfe0fc10/1c009c10 level 2
   bfe0fc10/1c00a000 level 2
   bfe0fc10/1c00a010 level 2
   bfe0fc10/1c00a400 level 2
   bfe0fc10/1c00a410 level 2
   bfe0fc10/1c00a800 level 2
   bfe0fc10/1c00a810 level 2
   bfe0fc10/1c00ac00 level 2
   bfe0fc10/1c00ac10 level 2
   bfe0fc10/1c00b000 level 2
   bfe0fc10/1c00b010 level 2
   bfe0fc10/1c00b400 level 2
   bfe0fc10/1c00b410 level 2
   bfe0fc10/1c00bc00 level 2
   bfe0fc10/1c00bc10 level 2
   bfe0fc10/1c408000 level 2
   bfe0fc10/1c408010 level 2
   bfe0fc10/1c408400 level 2
   bfe0fc10/1c408410 level 2
   bfe0fc10/1c408800 level 2
   bfe0fc10/1c408810 level 2
   bfe0fc10/1c408c00 level 2
   bfe0fc10/1c408c10 level 2
   bfe0fc10/1c409000 level 2
   bfe0fc10/1c409010 level 2
   bfe0fc10/1c409400 level 2
   bfe0fc10/1c409410 level 2
   bfe0fc10/1c409c00 level 2
   bfe0fc10/1c409c10 level 2
   bfe0fc10/1c40a000 level 2
   bfe0fc10/1c40a010 level 2
   bfe0fc10/1c40a400 level 2
   bfe0fc10/1c40a410 level 2
   bfe0fc10/1c40a800 level 2
   bfe0fc10/1c40a810 level 2
   bfe0fc10/1c40ac00 level 2
   bfe0fc10/1c40ac10 level 2
   bfe0fc10/1c40b000 level 2
   bfe0fc10/1c40b010 level 2
   bfe0fc10/1c40b400 level 2
   bfe0fc10/1c40b410 level 2
   bfe0fc10/1c40b800 level 2
   bfe0fc10/1c40b810 level 2
   bfe0fc10/1c40bc00 level 2
   bfe0fc10/1c40bc10 level 2
   bfe0fc10/1c800000 level 2
   bfe0fc10/1c800010 level 2
   bfe0fc10/1c800400 level 2
   bfe0fc10/1c800410 level 2
   bfe0fc10/1c800800 level 2
   bfe0fc10/1c800810 level 2
   bfe0fc10/1c800c00 level 2
   bfe0fc10/1c800c10 level 2
   bfe0fc10/1c802800 level 2
   bfe0fc10/1c802810 level 2
   bfe0fc10/1c808000 level 2
   bfe0fc10/1c808010 level 2
   bfe0fc10/1c808400 level 2
   bfe0fc10/1c808410 level 2
   bfe0fc10/1c808800 level 2
   bfe0fc10/1c808810 level 2
   bfe0fc10/1c808c00 level 2
   bfe0fc10/1c808c10 level 2
   bfe0fc10/1c80a000 level 2
   bfe0fc10/1c80a010 level 2
   bfe0fc10/1c80a400 level 2
   bfe0fc10/1c80a410 level 2
   bfe0fc10/1c80a800 level 2
   bfe0fc10/1c80a810 level 2
   bfe0fc10/1c80ac00 level 2
   bfe0fc10/1c80ac10 level 2
   bfe0fc10/1c80b000 level 2
   bfe0fc10/1c80b010 level 2
   bfe0fc10/1c80b400 level 2
   bfe0fc10/1c80b410 level 2
   bfe0fc10/1c80b800 level 2
   bfe0fc10/1c80b810 level 2
   bfe0fc10/1c80bc00 level 2
   bfe0fc10/1c80bc10 level 2
   bfe0fc10/1cc00000 level 2
   bfe0fc10/1cc00010 level 2
   bfe0fc10/1cc00400 level 2
   bfe0fc10/1cc00410 level 2
   bfe0fc10/1cc00c00 level 2
   bfe0fc10/1cc00c10 level 2
   bfe0fc10/1cc08000 level 2
   bfe0fc10/1cc08010 level 2
   bfe0fc10/1cc08400 level 2
   bfe0fc10/1cc08410 level 2
   bfe0fc10/1cc08800 level 2
   bfe0fc10/1cc08810 level 2
   bfe0fc10/1cc08c00 level 2
   bfe0fc10/1cc08c10 level 2
   bfe0fc10/1cc09000 level 2
   bfe0fc10/1cc09010 level 2
   bfe0fc10/1cc09400 level 2
   bfe0fc10/1cc09410 level 2
   bfe0fc10/1cc09c00 level 2
   bfe0fc10/1cc09c10 level 2
   bfe0fc10/1cc0a000 level 2
   bfe0fc10/1cc0a010 level 2
   bfe0fc10/1cc0a400 level 2
   bfe0fc10/1cc0a410 level 2
   bfe0fc10/1cc0a800 level 2
   bfe0fc10/1cc0a810 level 2
   bfe0fc10/1cc0ac00 level 2
   bfe0fc10/1cc0ac10 level 2
   bfe0fc10/1cc0b000 level 2
   bfe0fc10/1cc0b010 level 2
   bfe0fc10/1cc0b400 level 2
   bfe0fc10/1cc0b410 level 2
   bfe0fc10/1cc0b800 level 2
   bfe0fc10/1cc0b810 level 2
   bfe0fc10/1cc0bc00 level 2
   bfe0fc10/1cc0bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_1c008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x1c000000))
        return iemDecodeA64_LDR_S_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x5c000000))
        return iemDecodeA64_LDR_D_loadlit(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64008000 level 3
   ffebfc10/64008010 level 3
   ffebfc10/64008400 level 3
   ffebfc10/64008410 level 3
   ffebfc10/64008800 level 3
   ffebfc10/64008810 level 3
   ffebfc10/64008c00 level 3
   ffebfc10/64008c10 level 3
   ffebfc10/64009000 level 3
   ffebfc10/64009010 level 3
   ffebfc10/64009400 level 3
   ffebfc10/64009410 level 3
   ffebfc10/64009c00 level 3
   ffebfc10/64009c10 level 3
   ffebfc10/64408000 level 3
   ffebfc10/64408010 level 3
   ffebfc10/64408400 level 3
   ffebfc10/64408410 level 3
   ffebfc10/64408800 level 3
   ffebfc10/64408810 level 3
   ffebfc10/64408c00 level 3
   ffebfc10/64408c10 level 3
   ffebfc10/64409000 level 3
   ffebfc10/64409010 level 3
   ffebfc10/64409400 level 3
   ffebfc10/64409410 level 3
   ffebfc10/64409c00 level 3
   ffebfc10/64409c10 level 3
   ffebfc10/64808000 level 3
   ffebfc10/64808010 level 3
   ffebfc10/64808400 level 3
   ffebfc10/64808410 level 3
   ffebfc10/64808800 level 3
   ffebfc10/64808810 level 3
   ffebfc10/64808c00 level 3
   ffebfc10/64808c10 level 3
   ffebfc10/64c08000 level 3
   ffebfc10/64c08010 level 3
   ffebfc10/64c08400 level 3
   ffebfc10/64c08410 level 3
   ffebfc10/64c08800 level 3
   ffebfc10/64c08810 level 3
   ffebfc10/64c08c00 level 3
   ffebfc10/64c08c10 level 3
   ffebfc10/64c09000 level 3
   ffebfc10/64c09010 level 3
   ffebfc10/64c09400 level 3
   ffebfc10/64c09410 level 3
   ffebfc10/64c09c00 level 3
   ffebfc10/64c09c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64008000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ee000)) == UINT32_C(0x64008000))
        return iemDecodeA64_fcadd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64108000))
        return iemDecodeA64_faddp_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64148000))
        return iemDecodeA64_fmaxnmp_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64018000 level 3
   ffebfc10/64018010 level 3
   ffebfc10/64018400 level 3
   ffebfc10/64018410 level 3
   ffebfc10/64018800 level 3
   ffebfc10/64018810 level 3
   ffebfc10/64018c00 level 3
   ffebfc10/64018c10 level 3
   ffebfc10/64019000 level 3
   ffebfc10/64019010 level 3
   ffebfc10/64019400 level 3
   ffebfc10/64019410 level 3
   ffebfc10/64019c00 level 3
   ffebfc10/64019c10 level 3
   ffebfc10/64418000 level 3
   ffebfc10/64418010 level 3
   ffebfc10/64418400 level 3
   ffebfc10/64418410 level 3
   ffebfc10/64418800 level 3
   ffebfc10/64418810 level 3
   ffebfc10/64418c00 level 3
   ffebfc10/64418c10 level 3
   ffebfc10/64419000 level 3
   ffebfc10/64419010 level 3
   ffebfc10/64419400 level 3
   ffebfc10/64419410 level 3
   ffebfc10/64419c00 level 3
   ffebfc10/64419c10 level 3
   ffebfc10/64818000 level 3
   ffebfc10/64818010 level 3
   ffebfc10/64818400 level 3
   ffebfc10/64818410 level 3
   ffebfc10/64818800 level 3
   ffebfc10/64818810 level 3
   ffebfc10/64818c00 level 3
   ffebfc10/64818c10 level 3
   ffebfc10/64c18000 level 3
   ffebfc10/64c18010 level 3
   ffebfc10/64c18400 level 3
   ffebfc10/64c18410 level 3
   ffebfc10/64c18800 level 3
   ffebfc10/64c18810 level 3
   ffebfc10/64c18c00 level 3
   ffebfc10/64c18c10 level 3
   ffebfc10/64c19000 level 3
   ffebfc10/64c19010 level 3
   ffebfc10/64c19400 level 3
   ffebfc10/64c19410 level 3
   ffebfc10/64c19c00 level 3
   ffebfc10/64c19c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64018000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ee000)) == UINT32_C(0x64008000))
        return iemDecodeA64_fcadd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64158000))
        return iemDecodeA64_fminnmp_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64088000 level 3
   ffebfc10/64088010 level 3
   ffebfc10/64088400 level 3
   ffebfc10/64088410 level 3
   ffebfc10/64088800 level 3
   ffebfc10/64088810 level 3
   ffebfc10/64088c00 level 3
   ffebfc10/64088c10 level 3
   ffebfc10/64089000 level 3
   ffebfc10/64089010 level 3
   ffebfc10/64089400 level 3
   ffebfc10/64089410 level 3
   ffebfc10/64089c00 level 3
   ffebfc10/64089c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64088000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64188000))
        return iemDecodeA64_frintn_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffa000)) == UINT32_C(0x641c8000))
        return iemDecodeA64_frint32z_z_p_z_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64098000 level 3
   ffebfc10/64098010 level 3
   ffebfc10/64098400 level 3
   ffebfc10/64098410 level 3
   ffebfc10/64098800 level 3
   ffebfc10/64098810 level 3
   ffebfc10/64098c00 level 3
   ffebfc10/64098c10 level 3
   ffebfc10/64099000 level 3
   ffebfc10/64099010 level 3
   ffebfc10/64099400 level 3
   ffebfc10/64099410 level 3
   ffebfc10/64099c00 level 3
   ffebfc10/64099c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64098000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64198000))
        return iemDecodeA64_frinta_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffa000)) == UINT32_C(0x641d8000))
        return iemDecodeA64_frint64z_z_p_z_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/24008000 level 2
   bfe0fc10/24008400 level 2
   bfe0fc10/24008800 level 2
   bfe0fc10/24008c00 level 2
   bfe0fc10/24009000 level 2
   bfe0fc10/24009400 level 2
   bfe0fc10/24009c00 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%75 (0xc) multi-if=%25 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24008000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_ffebfc10_64008000_3,
        iemDecodeA64_ffebfc10_64018000_3,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_ffebfc10_64088000_3,
        iemDecodeA64_ffebfc10_64098000_3,
        iemDecodeA64_flogb_z_p_z_z,
        iemDecodeA64_frecpx_z_p_z_z,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/24008010 level 2
   bfe0fc10/24008410 level 2
   bfe0fc10/24008810 level 2
   bfe0fc10/24008c10 level 2
   bfe0fc10/24009010 level 2
   bfe0fc10/24009410 level 2
   bfe0fc10/24009c10 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%75 (0xc) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24008010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_ffebfc10_64008000_3,
        iemDecodeA64_ffebfc10_64018000_3,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_ffebfc10_64088000_3,
        iemDecodeA64_ffebfc10_64098000_3,
        iemDecodeA64_flogb_z_p_z_z,
        iemDecodeA64_frecpx_z_p_z_z,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/2c008000 level 2
   bfe0fc10/2c008010 level 2
   bfe0fc10/2c008400 level 2
   bfe0fc10/2c008410 level 2
   bfe0fc10/2c008800 level 2
   bfe0fc10/2c008810 level 2
   bfe0fc10/2c008c00 level 2
   bfe0fc10/2c008c10 level 2
   bfe0fc10/2c009000 level 2
   bfe0fc10/2c009010 level 2
   bfe0fc10/2c009400 level 2
   bfe0fc10/2c009410 level 2
   bfe0fc10/2c009c00 level 2
   bfe0fc10/2c009c10 level 2
   bfe0fc10/2c00a000 level 2
   bfe0fc10/2c00a010 level 2
   bfe0fc10/2c00a400 level 2
   bfe0fc10/2c00a410 level 2
   bfe0fc10/2c00a800 level 2
   bfe0fc10/2c00a810 level 2
   bfe0fc10/2c00ac00 level 2
   bfe0fc10/2c00ac10 level 2
   bfe0fc10/2c00b000 level 2
   bfe0fc10/2c00b010 level 2
   bfe0fc10/2c00b400 level 2
   bfe0fc10/2c00b410 level 2
   bfe0fc10/2c00bc00 level 2
   bfe0fc10/2c00bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2c008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c000000))
        return iemDecodeA64_STNP_S_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6c000000))
        return iemDecodeA64_STNP_D_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/34008000 level 2
   bfe0fc10/34008010 level 2
   bfe0fc10/34008400 level 2
   bfe0fc10/34008410 level 2
   bfe0fc10/34008800 level 2
   bfe0fc10/34008810 level 2
   bfe0fc10/34008c00 level 2
   bfe0fc10/34008c10 level 2
   bfe0fc10/34009000 level 2
   bfe0fc10/34009010 level 2
   bfe0fc10/34009400 level 2
   bfe0fc10/34009410 level 2
   bfe0fc10/34009c00 level 2
   bfe0fc10/34009c10 level 2
   bfe0fc10/3400a000 level 2
   bfe0fc10/3400a010 level 2
   bfe0fc10/3400a400 level 2
   bfe0fc10/3400a410 level 2
   bfe0fc10/3400a800 level 2
   bfe0fc10/3400a810 level 2
   bfe0fc10/3400ac00 level 2
   bfe0fc10/3400ac10 level 2
   bfe0fc10/3400b000 level 2
   bfe0fc10/3400b010 level 2
   bfe0fc10/3400b400 level 2
   bfe0fc10/3400b410 level 2
   bfe0fc10/3400bc00 level 2
   bfe0fc10/3400bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_34008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74008000))
        return iemDecodeA64_CBBGT_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/3c008000 level 2
   bfe0fc10/3c008010 level 2
   bfe0fc10/3c009000 level 2
   bfe0fc10/3c009010 level 2
   bfe0fc10/3c00a000 level 2
   bfe0fc10/3c00a010 level 2
   bfe0fc10/3c00b000 level 2
   bfe0fc10/3c00b010 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_3c008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c000000))
        return iemDecodeA64_STUR_B_ldst_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x7c000000))
        return iemDecodeA64_STUR_H_ldst_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/84008000 level 2
   bfe0fc10/84008010 level 2
   bfe0fc10/84008400 level 2
   bfe0fc10/84008410 level 2
   bfe0fc10/84008800 level 2
   bfe0fc10/84008810 level 2
   bfe0fc10/84008c00 level 2
   bfe0fc10/84008c10 level 2
   bfe0fc10/84009000 level 2
   bfe0fc10/84009010 level 2
   bfe0fc10/84009400 level 2
   bfe0fc10/84009410 level 2
   bfe0fc10/84009c00 level 2
   bfe0fc10/84009c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_84008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0x84008000))
        return iemDecodeA64_ldnt1sb_z_p_ar_s_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4008000))
        return iemDecodeA64_ldnt1sb_z_p_ar_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/94008000 level 2
   bfe0fc10/94008400 level 2
   bfe0fc10/94008800 level 2
   bfe0fc10/94008c00 level 2
   bfe0fc10/94009000 level 2
   bfe0fc10/94009400 level 2
   bfe0fc10/94009c00 level 2
   bfe0fc10/9400a000 level 2
   bfe0fc10/9400a400 level 2
   bfe0fc10/9400a800 level 2
   bfe0fc10/9400ac00 level 2
   bfe0fc10/9400b000 level 2
   bfe0fc10/9400b400 level 2
   bfe0fc10/9400bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_94008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4000001))
        return iemDecodeA64_SVC_EX_exception(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4000002))
        return iemDecodeA64_HVC_EX_exception(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4000003))
        return iemDecodeA64_SMC_EX_exception(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/ac008000 level 2
   bfe0fc10/ac008010 level 2
   bfe0fc10/ac008400 level 2
   bfe0fc10/ac008410 level 2
   bfe0fc10/ac008800 level 2
   bfe0fc10/ac008810 level 2
   bfe0fc10/ac008c00 level 2
   bfe0fc10/ac008c10 level 2
   bfe0fc10/ac009000 level 2
   bfe0fc10/ac009010 level 2
   bfe0fc10/ac009400 level 2
   bfe0fc10/ac009410 level 2
   bfe0fc10/ac009c00 level 2
   bfe0fc10/ac009c10 level 2
   bfe0fc10/ac00a000 level 2
   bfe0fc10/ac00a010 level 2
   bfe0fc10/ac00a400 level 2
   bfe0fc10/ac00a410 level 2
   bfe0fc10/ac00a800 level 2
   bfe0fc10/ac00a810 level 2
   bfe0fc10/ac00ac00 level 2
   bfe0fc10/ac00ac10 level 2
   bfe0fc10/ac00b000 level 2
   bfe0fc10/ac00b010 level 2
   bfe0fc10/ac00b400 level 2
   bfe0fc10/ac00b410 level 2
   bfe0fc10/ac00bc00 level 2
   bfe0fc10/ac00bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_ac008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xac000000))
        return iemDecodeA64_STNP_Q_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xec000000))
        return iemDecodeA64_STTNP_Q_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/bc008000 level 2
   bfe0fc10/bc008010 level 2
   bfe0fc10/bc009000 level 2
   bfe0fc10/bc009010 level 2
   bfe0fc10/bc00a000 level 2
   bfe0fc10/bc00a010 level 2
   bfe0fc10/bc00b000 level 2
   bfe0fc10/bc00b010 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_bc008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xbc000000))
        return iemDecodeA64_STUR_S_ldst_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xfc000000))
        return iemDecodeA64_STUR_D_ldst_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4008000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%28 (0x9) multi-if=%53 (0x11) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04008000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_ST2_asisdlse_R2,
        iemDecodeA64_ST2_asisdlse_R2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24008000_2,
        iemDecodeA64_bfe0fc10_24008010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008000_2,
        iemDecodeA64_bfe0fc10_3c008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008000_2,
        iemDecodeA64_bfe0fc10_bc008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/3c008400 level 2
   bfe0fc10/3c008410 level 2
   bfe0fc10/3c009400 level 2
   bfe0fc10/3c009410 level 2
   bfe0fc10/3c00a400 level 2
   bfe0fc10/3c00a410 level 2
   bfe0fc10/3c00b400 level 2
   bfe0fc10/3c00b410 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_3c008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c000400))
        return iemDecodeA64_STR_B_ldst_immpost(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x7c000400))
        return iemDecodeA64_STR_H_ldst_immpost(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/bc008400 level 2
   bfe0fc10/bc008410 level 2
   bfe0fc10/bc009400 level 2
   bfe0fc10/bc009410 level 2
   bfe0fc10/bc00a400 level 2
   bfe0fc10/bc00a410 level 2
   bfe0fc10/bc00b400 level 2
   bfe0fc10/bc00b410 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_bc008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xbc000400))
        return iemDecodeA64_STR_S_ldst_immpost(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xfc000400))
        return iemDecodeA64_STR_D_ldst_immpost(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4008400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%28 (0x9) multi-if=%53 (0x11) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04008400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_ST2_asisdlse_R2,
        iemDecodeA64_ST2_asisdlse_R2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24008000_2,
        iemDecodeA64_bfe0fc10_24008010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008400_2,
        iemDecodeA64_bfe0fc10_3c008400_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008400_2,
        iemDecodeA64_bfe0fc10_bc008400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4008800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%28 (0x9) multi-if=%41 (0xd) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04008800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_ST2_asisdlse_R2,
        iemDecodeA64_ST2_asisdlse_R2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24008000_2,
        iemDecodeA64_bfe0fc10_24008010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/3c008c00 level 2
   bfe0fc10/3c008c10 level 2
   bfe0fc10/3c009c00 level 2
   bfe0fc10/3c009c10 level 2
   bfe0fc10/3c00ac00 level 2
   bfe0fc10/3c00ac10 level 2
   bfe0fc10/3c00bc00 level 2
   bfe0fc10/3c00bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_3c008c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c000c00))
        return iemDecodeA64_STR_B_ldst_immpre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x7c000c00))
        return iemDecodeA64_STR_H_ldst_immpre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/bc008c00 level 2
   bfe0fc10/bc008c10 level 2
   bfe0fc10/bc009c00 level 2
   bfe0fc10/bc009c10 level 2
   bfe0fc10/bc00ac00 level 2
   bfe0fc10/bc00ac10 level 2
   bfe0fc10/bc00bc00 level 2
   bfe0fc10/bc00bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_bc008c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xbc000c00))
        return iemDecodeA64_STR_S_ldst_immpre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xfc000c00))
        return iemDecodeA64_STR_D_ldst_immpre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4008c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%28 (0x9) multi-if=%53 (0x11) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04008c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_ST2_asisdlse_R2,
        iemDecodeA64_ST2_asisdlse_R2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24008000_2,
        iemDecodeA64_bfe0fc10_24008010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008c00_2,
        iemDecodeA64_bfe0fc10_3c008c00_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008c00_2,
        iemDecodeA64_bfe0fc10_bc008c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4009000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%22 (0x7) multi-if=%53 (0x11) reuse=%66 (0x15) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04009000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24008000_2,
        iemDecodeA64_bfe0fc10_24008010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008000_2,
        iemDecodeA64_bfe0fc10_3c008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008000_2,
        iemDecodeA64_bfe0fc10_bc008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4009400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%22 (0x7) multi-if=%53 (0x11) reuse=%66 (0x15) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04009400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24008000_2,
        iemDecodeA64_bfe0fc10_24008010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008400_2,
        iemDecodeA64_bfe0fc10_3c008400_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008400_2,
        iemDecodeA64_bfe0fc10_bc008400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffedfc10/04009800 level 3
   ffedfc10/04009810 level 3
   ffedfc10/04409800 level 3
   ffedfc10/04409810 level 3
   ffedfc10/04809000 level 3
   ffedfc10/04809010 level 3
   ffedfc10/04809400 level 3
   ffedfc10/04809410 level 3
   ffedfc10/04809800 level 3
   ffedfc10/04809810 level 3
   ffedfc10/04809c00 level 3
   ffedfc10/04809c10 level 3
   ffedfc10/04c09800 level 3
   ffedfc10/04c09810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc10_04009800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04008000))
        return iemDecodeA64_asr_z_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04108000))
        return iemDecodeA64_asr_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffedfc10/04019800 level 3
   ffedfc10/04019810 level 3
   ffedfc10/04419800 level 3
   ffedfc10/04419810 level 3
   ffedfc10/04819000 level 3
   ffedfc10/04819010 level 3
   ffedfc10/04819400 level 3
   ffedfc10/04819410 level 3
   ffedfc10/04819800 level 3
   ffedfc10/04819810 level 3
   ffedfc10/04819c00 level 3
   ffedfc10/04819c10 level 3
   ffedfc10/04c19800 level 3
   ffedfc10/04c19810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc10_04019800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04018000))
        return iemDecodeA64_lsr_z_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04038000))
        return iemDecodeA64_lsl_z_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04118000))
        return iemDecodeA64_lsr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04138000))
        return iemDecodeA64_lsl_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffedfc10/04049800 level 3
   ffedfc10/04049810 level 3
   ffedfc10/04449800 level 3
   ffedfc10/04449810 level 3
   ffedfc10/04849000 level 3
   ffedfc10/04849010 level 3
   ffedfc10/04849400 level 3
   ffedfc10/04849410 level 3
   ffedfc10/04849800 level 3
   ffedfc10/04849810 level 3
   ffedfc10/04849c00 level 3
   ffedfc10/04849c10 level 3
   ffedfc10/04c49800 level 3
   ffedfc10/04c49810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc10_04049800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04048000))
        return iemDecodeA64_asrd_z_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04068000))
        return iemDecodeA64_sqshl_z_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04148000))
        return iemDecodeA64_asrr_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffedfc10/04059800 level 3
   ffedfc10/04059810 level 3
   ffedfc10/04459800 level 3
   ffedfc10/04459810 level 3
   ffedfc10/04859000 level 3
   ffedfc10/04859010 level 3
   ffedfc10/04859400 level 3
   ffedfc10/04859410 level 3
   ffedfc10/04859800 level 3
   ffedfc10/04859810 level 3
   ffedfc10/04859c00 level 3
   ffedfc10/04859c10 level 3
   ffedfc10/04c59800 level 3
   ffedfc10/04c59810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc10_04059800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04078000))
        return iemDecodeA64_uqshl_z_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04158000))
        return iemDecodeA64_lsrr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04178000))
        return iemDecodeA64_lslr_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffedfc10/04099800 level 3
   ffedfc10/04099810 level 3
   ffedfc10/04499800 level 3
   ffedfc10/04499810 level 3
   ffedfc10/04899000 level 3
   ffedfc10/04899010 level 3
   ffedfc10/04899400 level 3
   ffedfc10/04899410 level 3
   ffedfc10/04899800 level 3
   ffedfc10/04899810 level 3
   ffedfc10/04899c00 level 3
   ffedfc10/04899c10 level 3
   ffedfc10/04c99800 level 3
   ffedfc10/04c99810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc10_04099800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04198000))
        return iemDecodeA64_lsr_z_p_zw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x041b8000))
        return iemDecodeA64_lsl_z_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffedfc10/040d9800 level 3
   ffedfc10/040d9810 level 3
   ffedfc10/044d9800 level 3
   ffedfc10/044d9810 level 3
   ffedfc10/048d9000 level 3
   ffedfc10/048d9010 level 3
   ffedfc10/048d9400 level 3
   ffedfc10/048d9410 level 3
   ffedfc10/048d9800 level 3
   ffedfc10/048d9810 level 3
   ffedfc10/048d9c00 level 3
   ffedfc10/048d9c10 level 3
   ffedfc10/04cd9800 level 3
   ffedfc10/04cd9810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffedfc10_040d9800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040d8000))
        return iemDecodeA64_urshr_z_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040f8000))
        return iemDecodeA64_sqshlu_z_p_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/04009800 level 2
   dfe0fc10/04409800 level 2
   dfe0fc10/04809000 level 2
   dfe0fc10/04809400 level 2
   dfe0fc10/04809800 level 2
   dfe0fc10/04809c00 level 2
   dfe0fc10/04c09800 level 2
   mask=0x200d0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_04009800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffedfc10_04009800_3,
        iemDecodeA64_ffedfc10_04019800_3,
        iemDecodeA64_ffedfc10_04049800_3,
        iemDecodeA64_ffedfc10_04059800_3,
        iemDecodeA64_asr_z_p_zw,
        iemDecodeA64_ffedfc10_04099800_3,
        iemDecodeA64_srshr_z_p_zi,
        iemDecodeA64_ffedfc10_040d9800_3,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x200d0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000008)) /* bit 29 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/04009810 level 2
   dfe0fc10/04409810 level 2
   dfe0fc10/04809010 level 2
   dfe0fc10/04809410 level 2
   dfe0fc10/04809810 level 2
   dfe0fc10/04809c10 level 2
   dfe0fc10/04c09810 level 2
   mask=0x200d0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%38 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_04009810_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffedfc10_04009800_3,
        iemDecodeA64_ffedfc10_04019800_3,
        iemDecodeA64_ffedfc10_04049800_3,
        iemDecodeA64_ffedfc10_04059800_3,
        iemDecodeA64_asr_z_p_zw,
        iemDecodeA64_ffedfc10_04099800_3,
        iemDecodeA64_srshr_z_p_zi,
        iemDecodeA64_ffedfc10_040d9800_3,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x200d0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000006)) /* bit 18 L 2 -> 1 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000008)) /* bit 29 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/14009800 level 2
   dfe0fc10/14009810 level 2
   dfe0fc10/14409800 level 2
   dfe0fc10/14409810 level 2
   dfe0fc10/14809000 level 2
   dfe0fc10/14809010 level 2
   dfe0fc10/14809400 level 2
   dfe0fc10/14809410 level 2
   dfe0fc10/14809800 level 2
   dfe0fc10/14809810 level 2
   dfe0fc10/14809c00 level 2
   dfe0fc10/14809c10 level 2
   dfe0fc10/14c00800 level 2
   dfe0fc10/14c00810 level 2
   dfe0fc10/14c09800 level 2
   dfe0fc10/14c09810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_14009800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/44009800 level 2
   dfe0fc10/44009810 level 2
   mask=0x201f0000 entries=0x40 children=0x29 valid=%64 (0x29) leaf=%64 (0x29) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_44009800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_srshl_z_p_zz,
        iemDecodeA64_urshl_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_srshlr_z_p_zz,
        iemDecodeA64_urshlr_z_p_zz,
        iemDecodeA64_sqshl_z_p_zz,
        iemDecodeA64_uqshl_z_p_zz,
        iemDecodeA64_sqrshl_z_p_zz,
        iemDecodeA64_uqrshl_z_p_zz,
        iemDecodeA64_sqshlr_z_p_zz,
        iemDecodeA64_uqshlr_z_p_zz,
        iemDecodeA64_sqrshlr_z_p_zz,
        iemDecodeA64_uqrshlr_z_p_zz,
        iemDecodeA64_shadd_z_p_zz,
        iemDecodeA64_uhadd_z_p_zz,
        iemDecodeA64_shsub_z_p_zz,
        iemDecodeA64_uhsub_z_p_zz,
        iemDecodeA64_srhadd_z_p_zz,
        iemDecodeA64_urhadd_z_p_zz,
        iemDecodeA64_shsubr_z_p_zz,
        iemDecodeA64_uhsubr_z_p_zz,
        iemDecodeA64_sqadd_z_p_zz,
        iemDecodeA64_uqadd_z_p_zz,
        iemDecodeA64_sqsub_z_p_zz,
        iemDecodeA64_uqsub_z_p_zz,
        iemDecodeA64_suqadd_z_p_zz,
        iemDecodeA64_usqadd_z_p_zz,
        iemDecodeA64_sqsubr_z_p_zz,
        iemDecodeA64_uqsubr_z_p_zz,
        iemDecodeA64_fcadd_z_p_zz,
        iemDecodeA64_fcadd_z_p_zz,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_faddp_z_p_zz,
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_fmaxnmp_z_p_zz,
        iemDecodeA64_fminnmp_z_p_zz,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_frintn_z_p_z_z,
        iemDecodeA64_frinta_z_p_z_z,
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_frecpx_z_p_z_z,
        iemDecodeA64_frint32z_z_p_z_z,
        iemDecodeA64_frint64z_z_p_z_z,
        iemDecodeA64_flogb_z_p_z_z,
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x201f0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000020)) /* bit 29 L 1 -> 5 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/54009800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_54009800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74008000))
        return iemDecodeA64_CBBGT_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/54009810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_54009810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74008000))
        return iemDecodeA64_CBBGT_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/94009800 level 2
   dfe0fc10/94009810 level 2
   dfe0fc10/94409800 level 2
   dfe0fc10/94409810 level 2
   dfe0fc10/94809000 level 2
   dfe0fc10/94809010 level 2
   dfe0fc10/94809400 level 2
   dfe0fc10/94809410 level 2
   dfe0fc10/94809800 level 2
   dfe0fc10/94809810 level 2
   dfe0fc10/94809c00 level 2
   dfe0fc10/94809c10 level 2
   dfe0fc10/94c00800 level 2
   dfe0fc10/94c00810 level 2
   dfe0fc10/94c09800 level 2
   dfe0fc10/94c09810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_94009800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb4000000))
        return iemDecodeA64_CBZ_64_compbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/c4009800 level 2
   dfe0fc10/c4009810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_c4009800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe4008000))
        return iemDecodeA64_st1b_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4008000))
        return iemDecodeA64_ldnt1sb_z_p_ar_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4009800/0xd8000010
   mask=0xd8000010 entries=0x20 children=0x1d valid=%91 (0x1d) leaf=%50 (0x10) multi-if=%28 (0x9) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04009800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dfe0fc10_04009800_2,
        iemDecodeA64_dfe0fc10_04009810_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_dfe0fc10_44009800_2,
        iemDecodeA64_dfe0fc10_44009800_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_dfe0fc10_54009800_2,
        iemDecodeA64_dfe0fc10_54009810_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ldnt1sb_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1sb_z_p_ar_s_x32_unscaled,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_dfe0fc10_c4009800_2,
        iemDecodeA64_dfe0fc10_c4009800_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4009c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%22 (0x7) multi-if=%53 (0x11) reuse=%66 (0x15) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04009c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24008000_2,
        iemDecodeA64_bfe0fc10_24008010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008c00_2,
        iemDecodeA64_bfe0fc10_3c008c00_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_bfe0fc10_84008000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008c00_2,
        iemDecodeA64_bfe0fc10_bc008c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/0400a000 level 2
   bfe0fc10/0400a010 level 2
   bfe0fc10/0400a400 level 2
   bfe0fc10/0400a410 level 2
   bfe0fc10/0400a800 level 2
   bfe0fc10/0400a810 level 2
   bfe0fc10/0400ac00 level 2
   bfe0fc10/0400ac10 level 2
   bfe0fc10/0400b000 level 2
   bfe0fc10/0400b010 level 2
   bfe0fc10/0400b400 level 2
   bfe0fc10/0400b410 level 2
   bfe0fc10/0400bc00 level 2
   bfe0fc10/0400bc10 level 2
   bfe0fc10/0440a000 level 2
   bfe0fc10/0440a010 level 2
   bfe0fc10/0440a400 level 2
   bfe0fc10/0440a410 level 2
   bfe0fc10/0440a800 level 2
   bfe0fc10/0440a810 level 2
   bfe0fc10/0440ac00 level 2
   bfe0fc10/0440ac10 level 2
   bfe0fc10/0440b000 level 2
   bfe0fc10/0440b010 level 2
   bfe0fc10/0440b400 level 2
   bfe0fc10/0440b410 level 2
   bfe0fc10/0440b800 level 2
   bfe0fc10/0440b810 level 2
   bfe0fc10/0440bc00 level 2
   bfe0fc10/0440bc10 level 2
   bfe0fc10/0480a000 level 2
   bfe0fc10/0480a010 level 2
   bfe0fc10/0480a400 level 2
   bfe0fc10/0480a410 level 2
   bfe0fc10/0480a800 level 2
   bfe0fc10/0480a810 level 2
   bfe0fc10/0480ac00 level 2
   bfe0fc10/0480ac10 level 2
   bfe0fc10/0480b000 level 2
   bfe0fc10/0480b010 level 2
   bfe0fc10/0480b400 level 2
   bfe0fc10/0480b410 level 2
   bfe0fc10/0480b800 level 2
   bfe0fc10/0480b810 level 2
   bfe0fc10/0480bc00 level 2
   bfe0fc10/0480bc10 level 2
   bfe0fc10/04c0a000 level 2
   bfe0fc10/04c0a010 level 2
   bfe0fc10/04c0a400 level 2
   bfe0fc10/04c0a410 level 2
   bfe0fc10/04c0a800 level 2
   bfe0fc10/04c0a810 level 2
   bfe0fc10/04c0ac00 level 2
   bfe0fc10/04c0ac10 level 2
   bfe0fc10/04c0b000 level 2
   bfe0fc10/04c0b010 level 2
   bfe0fc10/04c0b400 level 2
   bfe0fc10/04c0b410 level 2
   bfe0fc10/04c0b800 level 2
   bfe0fc10/04c0b810 level 2
   bfe0fc10/04c0bc00 level 2
   bfe0fc10/04c0bc10 level 2
   mask=0x401f0000 entries=0x40 children=0x2d valid=%70 (0x2d) leaf=%70 (0x2d) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_0400a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sxtb_z_p_z_z,
        iemDecodeA64_uxtb_z_p_z_z,
        iemDecodeA64_sxth_z_p_z_z,
        iemDecodeA64_uxth_z_p_z_z,
        iemDecodeA64_sxtw_z_p_z_z,
        iemDecodeA64_uxtw_z_p_z_z,
        iemDecodeA64_abs_z_p_z_z,
        iemDecodeA64_neg_z_p_z_z,
        iemDecodeA64_cls_z_p_z_z,
        iemDecodeA64_clz_z_p_z_z,
        iemDecodeA64_cnt_z_p_z_z,
        iemDecodeA64_cnot_z_p_z_z,
        iemDecodeA64_fabs_z_p_z_z,
        iemDecodeA64_fneg_z_p_z_z,
        iemDecodeA64_not_z_p_z_z,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_sxtb_z_p_z_m,
        iemDecodeA64_uxtb_z_p_z_m,
        iemDecodeA64_sxth_z_p_z_m,
        iemDecodeA64_uxth_z_p_z_m,
        iemDecodeA64_sxtw_z_p_z_m,
        iemDecodeA64_uxtw_z_p_z_m,
        iemDecodeA64_abs_z_p_z_m,
        iemDecodeA64_neg_z_p_z_m,
        iemDecodeA64_cls_z_p_z_m,
        iemDecodeA64_clz_z_p_z_m,
        iemDecodeA64_cnt_z_p_z_m,
        iemDecodeA64_cnot_z_p_z_m,
        iemDecodeA64_fabs_z_p_z_m,
        iemDecodeA64_fneg_z_p_z_m,
        iemDecodeA64_not_z_p_z_m,
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_urecpe_z_p_z_m,
        iemDecodeA64_ursqrte_z_p_z_m,
        iemDecodeA64_urecpe_z_p_z_z,
        iemDecodeA64_ursqrte_z_p_z_z,
        iemDecodeA64_sadalp_z_p_z,
        iemDecodeA64_uadalp_z_p_z,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_sqabs_z_p_z_m,
        iemDecodeA64_sqneg_z_p_z_m,
        iemDecodeA64_sqabs_z_p_z_z,
        iemDecodeA64_sqneg_z_p_z_z,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_addp_z_p_zz,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_smaxp_z_p_zz,
        iemDecodeA64_umaxp_z_p_zz,
        iemDecodeA64_sminp_z_p_zz,
        iemDecodeA64_uminp_z_p_zz,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x401f0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000020)) /* bit 30 L 1 -> 5 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffebfc10/6400a000 level 3
   ffebfc10/6400a010 level 3
   ffebfc10/6400a400 level 3
   ffebfc10/6400a410 level 3
   ffebfc10/6400a800 level 3
   ffebfc10/6400a810 level 3
   ffebfc10/6400ac00 level 3
   ffebfc10/6400ac10 level 3
   ffebfc10/6400b000 level 3
   ffebfc10/6400b010 level 3
   ffebfc10/6400b400 level 3
   ffebfc10/6400b410 level 3
   ffebfc10/6400b800 level 3
   ffebfc10/6400b810 level 3
   ffebfc10/6400bc00 level 3
   ffebfc10/6400bc10 level 3
   ffebfc10/6440a000 level 3
   ffebfc10/6440a010 level 3
   ffebfc10/6440a400 level 3
   ffebfc10/6440a410 level 3
   ffebfc10/6440a800 level 3
   ffebfc10/6440a810 level 3
   ffebfc10/6440ac00 level 3
   ffebfc10/6440ac10 level 3
   ffebfc10/6440b000 level 3
   ffebfc10/6440b010 level 3
   ffebfc10/6440b400 level 3
   ffebfc10/6440b410 level 3
   ffebfc10/6440b800 level 3
   ffebfc10/6440b810 level 3
   ffebfc10/6440bc00 level 3
   ffebfc10/6440bc10 level 3
   ffebfc10/64c0a000 level 3
   ffebfc10/64c0a010 level 3
   ffebfc10/64c0a400 level 3
   ffebfc10/64c0a410 level 3
   ffebfc10/64c0a800 level 3
   ffebfc10/64c0a810 level 3
   ffebfc10/64c0ac00 level 3
   ffebfc10/64c0ac10 level 3
   ffebfc10/64c0b000 level 3
   ffebfc10/64c0b010 level 3
   ffebfc10/64c0b400 level 3
   ffebfc10/64c0b410 level 3
   ffebfc10/64c0b800 level 3
   ffebfc10/64c0b810 level 3
   ffebfc10/64c0bc00 level 3
   ffebfc10/64c0bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_6400a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6410a000))
        return iemDecodeA64_faddqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6414a000))
        return iemDecodeA64_fmaxnmqv_z_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/6402a000 level 3
   ffebfc10/6402a010 level 3
   ffebfc10/6402a400 level 3
   ffebfc10/6402a410 level 3
   ffebfc10/6402a800 level 3
   ffebfc10/6402a810 level 3
   ffebfc10/6402ac00 level 3
   ffebfc10/6402ac10 level 3
   ffebfc10/6402b000 level 3
   ffebfc10/6402b010 level 3
   ffebfc10/6402b400 level 3
   ffebfc10/6402b410 level 3
   ffebfc10/6402b800 level 3
   ffebfc10/6402b810 level 3
   ffebfc10/6402bc00 level 3
   ffebfc10/6402bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_6402a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6416a000))
        return iemDecodeA64_fmaxqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6402a000))
        return iemDecodeA64_fcvtxnt_z_p_z_d2sz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/6408a000 level 3
   ffebfc10/6408a010 level 3
   ffebfc10/6408a400 level 3
   ffebfc10/6408a410 level 3
   ffebfc10/6408a800 level 3
   ffebfc10/6408a810 level 3
   ffebfc10/6408ac00 level 3
   ffebfc10/6408ac10 level 3
   ffebfc10/6408b000 level 3
   ffebfc10/6408b010 level 3
   ffebfc10/6408b400 level 3
   ffebfc10/6408b410 level 3
   ffebfc10/6408b800 level 3
   ffebfc10/6408b810 level 3
   ffebfc10/6408bc00 level 3
   ffebfc10/6408bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_6408a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6418a000))
        return iemDecodeA64_frintp_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffa000)) == UINT32_C(0x641ca000))
        return iemDecodeA64_frint32x_z_p_z_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/640aa000 level 3
   ffebfc10/640aa010 level 3
   ffebfc10/640aa400 level 3
   ffebfc10/640aa410 level 3
   ffebfc10/640aa800 level 3
   ffebfc10/640aa810 level 3
   ffebfc10/640aac00 level 3
   ffebfc10/640aac10 level 3
   ffebfc10/640ab000 level 3
   ffebfc10/640ab010 level 3
   ffebfc10/640ab400 level 3
   ffebfc10/640ab410 level 3
   ffebfc10/640ab800 level 3
   ffebfc10/640ab810 level 3
   ffebfc10/640abc00 level 3
   ffebfc10/640abc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_640aa000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff8000)) == UINT32_C(0x641e8000))
        return iemDecodeA64_flogb_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x640aa000))
        return iemDecodeA64_fcvtxnt_z_p_z_d2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/2400a000 level 2
   bfe0fc10/2400a400 level 2
   bfe0fc10/2400a800 level 2
   bfe0fc10/2400ac00 level 2
   bfe0fc10/2400b000 level 2
   bfe0fc10/2400b400 level 2
   bfe0fc10/2400bc00 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%75 (0xc) multi-if=%25 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2400a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_ffebfc10_6400a000_3,
        iemDecodeA64_fminnmqv_z_p_z,
        iemDecodeA64_ffebfc10_6402a000_3,
        iemDecodeA64_fminqv_z_p_z,
        iemDecodeA64_ffebfc10_6408a000_3,
        iemDecodeA64_frint64x_z_p_z_z,
        iemDecodeA64_ffebfc10_640aa000_3,
        iemDecodeA64_fsqrt_z_p_z_z,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/2400a010 level 2
   bfe0fc10/2400a410 level 2
   bfe0fc10/2400a810 level 2
   bfe0fc10/2400ac10 level 2
   bfe0fc10/2400b010 level 2
   bfe0fc10/2400b410 level 2
   bfe0fc10/2400bc10 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%75 (0xc) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2400a010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_ffebfc10_6400a000_3,
        iemDecodeA64_fminnmqv_z_p_z,
        iemDecodeA64_ffebfc10_6402a000_3,
        iemDecodeA64_fminqv_z_p_z,
        iemDecodeA64_ffebfc10_6408a000_3,
        iemDecodeA64_frint64x_z_p_z_z,
        iemDecodeA64_ffebfc10_640aa000_3,
        iemDecodeA64_fsqrt_z_p_z_z,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/8400a000 level 2
   bfe0fc10/8400a010 level 2
   bfe0fc10/8400a400 level 2
   bfe0fc10/8400a410 level 2
   bfe0fc10/8400a800 level 2
   bfe0fc10/8400a810 level 2
   bfe0fc10/8400ac00 level 2
   bfe0fc10/8400ac10 level 2
   bfe0fc10/8400b000 level 2
   bfe0fc10/8400b010 level 2
   bfe0fc10/8400b400 level 2
   bfe0fc10/8400b410 level 2
   bfe0fc10/8400bc00 level 2
   bfe0fc10/8400bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_8400a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0x8400a000))
        return iemDecodeA64_ldnt1b_z_p_ar_s_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc400a000))
        return iemDecodeA64_ld1q_z_p_ar_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/a400a000 level 2
   bfe0fc10/a400a010 level 2
   bfe0fc10/a400a400 level 2
   bfe0fc10/a400a410 level 2
   bfe0fc10/a400a800 level 2
   bfe0fc10/a400a810 level 2
   bfe0fc10/a400ac00 level 2
   bfe0fc10/a400ac10 level 2
   bfe0fc10/a400b000 level 2
   bfe0fc10/a400b010 level 2
   bfe0fc10/a400b400 level 2
   bfe0fc10/a400b410 level 2
   bfe0fc10/a400bc00 level 2
   bfe0fc10/a400bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_a400a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe400a000))
        return iemDecodeA64_st1b_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa400a000))
        return iemDecodeA64_ld1b_z_p_bi_u8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa410a000))
        return iemDecodeA64_ldnf1b_z_p_bi_u8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400a000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%22 (0x7) multi-if=%59 (0x13) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_ST1_asisdlse_R2_2v,
        iemDecodeA64_ST1_asisdlse_R2_2v,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2400a000_2,
        iemDecodeA64_bfe0fc10_2400a010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008000_2,
        iemDecodeA64_bfe0fc10_3c008000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008000_2,
        iemDecodeA64_bfe0fc10_bc008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400a400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%22 (0x7) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_ST1_asisdlse_R2_2v,
        iemDecodeA64_ST1_asisdlse_R2_2v,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2400a000_2,
        iemDecodeA64_bfe0fc10_2400a010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008400_2,
        iemDecodeA64_bfe0fc10_3c008400_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008400_2,
        iemDecodeA64_bfe0fc10_bc008400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400a800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%22 (0x7) multi-if=%47 (0xf) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_ST1_asisdlse_R2_2v,
        iemDecodeA64_ST1_asisdlse_R2_2v,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2400a000_2,
        iemDecodeA64_bfe0fc10_2400a010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400ac00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%22 (0x7) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_ST1_asisdlse_R2_2v,
        iemDecodeA64_ST1_asisdlse_R2_2v,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2400a000_2,
        iemDecodeA64_bfe0fc10_2400a010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008c00_2,
        iemDecodeA64_bfe0fc10_3c008c00_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008c00_2,
        iemDecodeA64_bfe0fc10_bc008c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400b000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%16 (0x5) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2400a000_2,
        iemDecodeA64_bfe0fc10_2400a010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008000_2,
        iemDecodeA64_bfe0fc10_3c008000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008000_2,
        iemDecodeA64_bfe0fc10_bc008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400b400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%16 (0x5) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2400a000_2,
        iemDecodeA64_bfe0fc10_2400a010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008400_2,
        iemDecodeA64_bfe0fc10_3c008400_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008400_2,
        iemDecodeA64_bfe0fc10_bc008400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/0400b800 level 2
   f7e0fc10/0400b810 level 2
   mask=0x81f0000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%47 (0x1e) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_0400b800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sxtb_z_p_z_z,
        iemDecodeA64_uxtb_z_p_z_z,
        iemDecodeA64_sxth_z_p_z_z,
        iemDecodeA64_uxth_z_p_z_z,
        iemDecodeA64_sxtw_z_p_z_z,
        iemDecodeA64_uxtw_z_p_z_z,
        iemDecodeA64_abs_z_p_z_z,
        iemDecodeA64_neg_z_p_z_z,
        iemDecodeA64_cls_z_p_z_z,
        iemDecodeA64_clz_z_p_z_z,
        iemDecodeA64_cnt_z_p_z_z,
        iemDecodeA64_cnot_z_p_z_z,
        iemDecodeA64_fabs_z_p_z_z,
        iemDecodeA64_fneg_z_p_z_z,
        iemDecodeA64_not_z_p_z_z,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_sxtb_z_p_z_m,
        iemDecodeA64_uxtb_z_p_z_m,
        iemDecodeA64_sxth_z_p_z_m,
        iemDecodeA64_uxth_z_p_z_m,
        iemDecodeA64_sxtw_z_p_z_m,
        iemDecodeA64_uxtw_z_p_z_m,
        iemDecodeA64_abs_z_p_z_m,
        iemDecodeA64_neg_z_p_z_m,
        iemDecodeA64_cls_z_p_z_m,
        iemDecodeA64_clz_z_p_z_m,
        iemDecodeA64_cnt_z_p_z_m,
        iemDecodeA64_cnot_z_p_z_m,
        iemDecodeA64_fabs_z_p_z_m,
        iemDecodeA64_fneg_z_p_z_m,
        iemDecodeA64_not_z_p_z_m,
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x081f0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */
                        | ((uOpcode >> 22) & UINT32_C(0x00000020)) /* bit 27 L 1 -> 5 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/2400b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_2400b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x2400a000))
        return iemDecodeA64_cmpeq_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c000000))
        return iemDecodeA64_STNP_S_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/2400b810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_2400b810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x2400a010))
        return iemDecodeA64_cmpne_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c000000))
        return iemDecodeA64_STNP_S_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/4400b800 level 2
   f7e0fc10/4400b810 level 2
   mask=0x1f0000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%47 (0xf) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_4400b800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_urecpe_z_p_z_m,
        iemDecodeA64_ursqrte_z_p_z_m,
        iemDecodeA64_urecpe_z_p_z_z,
        iemDecodeA64_ursqrte_z_p_z_z,
        iemDecodeA64_sadalp_z_p_z,
        iemDecodeA64_uadalp_z_p_z,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqabs_z_p_z_m,
        iemDecodeA64_sqneg_z_p_z_m,
        iemDecodeA64_sqabs_z_p_z_z,
        iemDecodeA64_sqneg_z_p_z_z,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_addp_z_p_zz,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_smaxp_z_p_zz,
        iemDecodeA64_umaxp_z_p_zz,
        iemDecodeA64_sminp_z_p_zz,
        iemDecodeA64_uminp_z_p_zz,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/6400b800 level 2
   f7e0fc10/6400b810 level 2
   mask=0x80b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%75 (0xc) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_6400b800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffebfc10_6400a000_3,
        iemDecodeA64_fminnmqv_z_p_z,
        iemDecodeA64_ffebfc10_6402a000_3,
        iemDecodeA64_fminqv_z_p_z,
        iemDecodeA64_ffebfc10_6408a000_3,
        iemDecodeA64_frint64x_z_p_z_z,
        iemDecodeA64_ffebfc10_640aa000_3,
        iemDecodeA64_fsqrt_z_p_z_z,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_STNP_D_ldstnapair_offs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/a400b800 level 2
   f7e0fc10/a400b810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_a400b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xac000000))
        return iemDecodeA64_STNP_Q_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa400a000))
        return iemDecodeA64_ld1b_z_p_bi_u8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa410a000))
        return iemDecodeA64_ldnf1b_z_p_bi_u8(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/e400b800 level 2
   f7e0fc10/e400b810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_e400b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xec000000))
        return iemDecodeA64_STTNP_Q_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe400a000))
        return iemDecodeA64_st1b_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400b800/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1d valid=%91 (0x1d) leaf=%31 (0xa) multi-if=%41 (0xd) reuse=%38 (0xc) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc10_0400b800_2,
        iemDecodeA64_f7e0fc10_0400b800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_2400b800_2,
        iemDecodeA64_f7e0fc10_2400b810_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_f7e0fc10_4400b800_2,
        iemDecodeA64_f7e0fc10_4400b800_2,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_6400b800_2,
        iemDecodeA64_f7e0fc10_6400b800_2,
        iemDecodeA64_CBBGT_8_regs,
        iemDecodeA64_CBBGT_8_regs,
        iemDecodeA64_ldnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_a400b800_2,
        iemDecodeA64_f7e0fc10_a400b800_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_ld1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e400b800_2,
        iemDecodeA64_f7e0fc10_e400b800_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400bc00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%16 (0x5) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2400a000_2,
        iemDecodeA64_bfe0fc10_2400a010_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_2c008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_34008000_2,
        iemDecodeA64_bfe0fc10_3c008c00_2,
        iemDecodeA64_bfe0fc10_3c008c00_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_bfe0fc10_8400a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94008000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_a400a000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_bfe0fc10_ac008000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc008c00_2,
        iemDecodeA64_bfe0fc10_bc008c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2400c000 level 2
   ffe0fc00/2400c400 level 2
   ffe0fc00/2400c800 level 2
   ffe0fc00/2400cc00 level 2
   ffe0fc00/2400d000 level 2
   ffe0fc00/2400d400 level 2
   ffe0fc00/2400d800 level 2
   ffe0fc00/2400dc00 level 2
   ffe0fc00/2440c000 level 2
   ffe0fc00/2440c400 level 2
   ffe0fc00/2440c800 level 2
   ffe0fc00/2440cc00 level 2
   ffe0fc00/2440d000 level 2
   ffe0fc00/2440d400 level 2
   ffe0fc00/2440d800 level 2
   ffe0fc00/2440dc00 level 2
   ffe0fc00/2480c000 level 2
   ffe0fc00/2480c400 level 2
   ffe0fc00/2480c800 level 2
   ffe0fc00/2480cc00 level 2
   ffe0fc00/2480d000 level 2
   ffe0fc00/2480d400 level 2
   ffe0fc00/2480d800 level 2
   ffe0fc00/2480dc00 level 2
   ffe0fc00/24c0c000 level 2
   ffe0fc00/24c0c400 level 2
   ffe0fc00/24c0c800 level 2
   ffe0fc00/24c0cc00 level 2
   ffe0fc00/24c0d000 level 2
   ffe0fc00/24c0d400 level 2
   ffe0fc00/24c0d800 level 2
   ffe0fc00/24c0dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2400c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x2400c000))
        return iemDecodeA64_cmphs_p_p_zw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x2400c010))
        return iemDecodeA64_cmphi_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/6400c000 level 2
   ffe0fc00/6400c400 level 2
   ffe0fc00/6400c800 level 2
   ffe0fc00/6400cc00 level 2
   ffe0fc00/6400d000 level 2
   ffe0fc00/6400d400 level 2
   ffe0fc00/6400d800 level 2
   ffe0fc00/6400dc00 level 2
   mask=0x70000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6400c000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintm_z_p_z_z,
        iemDecodeA64_frintx_z_p_z_z,
        iemDecodeA64_fcvtx_z_p_z_d2sz,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_frint32z_z_p_z_z,
        iemDecodeA64_frint64z_z_p_z_z,
        iemDecodeA64_flogb_z_p_z_z,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_sclamp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400c000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_prfb_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_uclamp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400c000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_prfb_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sdot_z32_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400c000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_udot_z32_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400c000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_prfb_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400c000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_prfb_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400c000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_prfb_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400c000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400c000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_prfb_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_ldnt1b_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2400e000 level 2
   ffe0fc00/2400e400 level 2
   ffe0fc00/2400e800 level 2
   ffe0fc00/2400ec00 level 2
   ffe0fc00/2400f000 level 2
   ffe0fc00/2400f400 level 2
   ffe0fc00/2400f800 level 2
   ffe0fc00/2400fc00 level 2
   ffe0fc00/2440e000 level 2
   ffe0fc00/2440e400 level 2
   ffe0fc00/2440e800 level 2
   ffe0fc00/2440ec00 level 2
   ffe0fc00/2440f000 level 2
   ffe0fc00/2440f400 level 2
   ffe0fc00/2440f800 level 2
   ffe0fc00/2440fc00 level 2
   ffe0fc00/2480e000 level 2
   ffe0fc00/2480e400 level 2
   ffe0fc00/2480e800 level 2
   ffe0fc00/2480ec00 level 2
   ffe0fc00/2480f000 level 2
   ffe0fc00/2480f400 level 2
   ffe0fc00/2480f800 level 2
   ffe0fc00/2480fc00 level 2
   ffe0fc00/24c0e000 level 2
   ffe0fc00/24c0e400 level 2
   ffe0fc00/24c0e800 level 2
   ffe0fc00/24c0ec00 level 2
   ffe0fc00/24c0f000 level 2
   ffe0fc00/24c0f400 level 2
   ffe0fc00/24c0f800 level 2
   ffe0fc00/24c0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2400e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x2400e000))
        return iemDecodeA64_cmplo_p_p_zw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x2400e010))
        return iemDecodeA64_cmpls_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/6400e000 level 2
   ffe0fc00/6400e400 level 2
   ffe0fc00/6400e800 level 2
   ffe0fc00/6400ec00 level 2
   ffe0fc00/6400f000 level 2
   ffe0fc00/6400f400 level 2
   ffe0fc00/6400f800 level 2
   ffe0fc00/6400fc00 level 2
   mask=0x70000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6400e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintz_z_p_z_z,
        iemDecodeA64_frinti_z_p_z_z,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_frint32x_z_p_z_z,
        iemDecodeA64_frint64x_z_p_z_z,
        iemDecodeA64_flogb_z_p_z_z,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/e400e000 level 2
   ffe0fc00/e400e400 level 2
   ffe0fc00/e400e800 level 2
   ffe0fc00/e400ec00 level 2
   ffe0fc00/e400f000 level 2
   ffe0fc00/e400f400 level 2
   ffe0fc00/e400f800 level 2
   ffe0fc00/e400fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e400e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff90e000)) == UINT32_C(0xe400e000))
        return iemDecodeA64_st1b_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe410e000))
        return iemDecodeA64_stnt1b_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_zipq1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400e000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_prfb_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_prfb_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e400e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_zipq2_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400e000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_prfb_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_prfb_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e400e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_uzpq1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400e000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e400e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_uzpq2_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400e000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_prfb_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_prfb_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e400e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%62 (0x14) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_B_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400e000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STUR_H_ldst_unscaled,
        iemDecodeA64_prfb_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STUR_S_ldst_unscaled,
        iemDecodeA64_prfb_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e400e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%62 (0x14) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400e000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STR_H_ldst_immpost,
        iemDecodeA64_prfb_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpost,
        iemDecodeA64_prfb_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e400e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_tblq_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400e000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e400e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x400fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%62 (0x14) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0400fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6400e000_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGT_16_regs,
        iemDecodeA64_STR_H_ldst_immpre,
        iemDecodeA64_prfb_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_immpre,
        iemDecodeA64_prfb_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e400e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/24200000 level 2
   ffe0fc00/24200400 level 2
   ffe0fc00/24200800 level 2
   ffe0fc00/24200c00 level 2
   ffe0fc00/24201000 level 2
   ffe0fc00/24201400 level 2
   ffe0fc00/24201800 level 2
   ffe0fc00/24201c00 level 2
   ffe0fc00/24204000 level 2
   ffe0fc00/24204400 level 2
   ffe0fc00/24204800 level 2
   ffe0fc00/24204c00 level 2
   ffe0fc00/24205000 level 2
   ffe0fc00/24205400 level 2
   ffe0fc00/24205800 level 2
   ffe0fc00/24205c00 level 2
   ffe0fc00/24208000 level 2
   ffe0fc00/24208400 level 2
   ffe0fc00/24208800 level 2
   ffe0fc00/24208c00 level 2
   ffe0fc00/24209000 level 2
   ffe0fc00/24209400 level 2
   ffe0fc00/24209800 level 2
   ffe0fc00/24209c00 level 2
   ffe0fc00/2420c000 level 2
   ffe0fc00/2420c400 level 2
   ffe0fc00/2420c800 level 2
   ffe0fc00/2420cc00 level 2
   ffe0fc00/2420d000 level 2
   ffe0fc00/2420d400 level 2
   ffe0fc00/2420d800 level 2
   ffe0fc00/2420dc00 level 2
   ffe0fc00/24600000 level 2
   ffe0fc00/24600400 level 2
   ffe0fc00/24600800 level 2
   ffe0fc00/24600c00 level 2
   ffe0fc00/24601000 level 2
   ffe0fc00/24601400 level 2
   ffe0fc00/24601800 level 2
   ffe0fc00/24601c00 level 2
   ffe0fc00/24604000 level 2
   ffe0fc00/24604400 level 2
   ffe0fc00/24604800 level 2
   ffe0fc00/24604c00 level 2
   ffe0fc00/24605000 level 2
   ffe0fc00/24605400 level 2
   ffe0fc00/24605800 level 2
   ffe0fc00/24605c00 level 2
   ffe0fc00/24608000 level 2
   ffe0fc00/24608400 level 2
   ffe0fc00/24608800 level 2
   ffe0fc00/24608c00 level 2
   ffe0fc00/24609000 level 2
   ffe0fc00/24609400 level 2
   ffe0fc00/24609800 level 2
   ffe0fc00/24609c00 level 2
   ffe0fc00/2460c000 level 2
   ffe0fc00/2460c400 level 2
   ffe0fc00/2460c800 level 2
   ffe0fc00/2460cc00 level 2
   ffe0fc00/2460d000 level 2
   ffe0fc00/2460d400 level 2
   ffe0fc00/2460d800 level 2
   ffe0fc00/2460dc00 level 2
   ffe0fc00/24a00000 level 2
   ffe0fc00/24a00400 level 2
   ffe0fc00/24a00800 level 2
   ffe0fc00/24a00c00 level 2
   ffe0fc00/24a01000 level 2
   ffe0fc00/24a01400 level 2
   ffe0fc00/24a01800 level 2
   ffe0fc00/24a01c00 level 2
   ffe0fc00/24a04000 level 2
   ffe0fc00/24a04400 level 2
   ffe0fc00/24a04800 level 2
   ffe0fc00/24a04c00 level 2
   ffe0fc00/24a05000 level 2
   ffe0fc00/24a05400 level 2
   ffe0fc00/24a05800 level 2
   ffe0fc00/24a05c00 level 2
   ffe0fc00/24a08000 level 2
   ffe0fc00/24a08400 level 2
   ffe0fc00/24a08800 level 2
   ffe0fc00/24a08c00 level 2
   ffe0fc00/24a09000 level 2
   ffe0fc00/24a09400 level 2
   ffe0fc00/24a09800 level 2
   ffe0fc00/24a09c00 level 2
   ffe0fc00/24a0c000 level 2
   ffe0fc00/24a0c400 level 2
   ffe0fc00/24a0c800 level 2
   ffe0fc00/24a0cc00 level 2
   ffe0fc00/24a0d000 level 2
   ffe0fc00/24a0d400 level 2
   ffe0fc00/24a0d800 level 2
   ffe0fc00/24a0dc00 level 2
   ffe0fc00/24e00000 level 2
   ffe0fc00/24e00400 level 2
   ffe0fc00/24e00800 level 2
   ffe0fc00/24e00c00 level 2
   ffe0fc00/24e01000 level 2
   ffe0fc00/24e01400 level 2
   ffe0fc00/24e01800 level 2
   ffe0fc00/24e01c00 level 2
   ffe0fc00/24e04000 level 2
   ffe0fc00/24e04400 level 2
   ffe0fc00/24e04800 level 2
   ffe0fc00/24e04c00 level 2
   ffe0fc00/24e05000 level 2
   ffe0fc00/24e05400 level 2
   ffe0fc00/24e05800 level 2
   ffe0fc00/24e05c00 level 2
   ffe0fc00/24e08000 level 2
   ffe0fc00/24e08400 level 2
   ffe0fc00/24e08800 level 2
   ffe0fc00/24e08c00 level 2
   ffe0fc00/24e09000 level 2
   ffe0fc00/24e09400 level 2
   ffe0fc00/24e09800 level 2
   ffe0fc00/24e09c00 level 2
   ffe0fc00/24e0c000 level 2
   ffe0fc00/24e0c400 level 2
   ffe0fc00/24e0c800 level 2
   ffe0fc00/24e0cc00 level 2
   ffe0fc00/24e0d000 level 2
   ffe0fc00/24e0d400 level 2
   ffe0fc00/24e0d800 level 2
   ffe0fc00/24e0dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_24200000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff202010)) == UINT32_C(0x24200000))
        return iemDecodeA64_cmphs_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff202010)) == UINT32_C(0x24200010))
        return iemDecodeA64_cmphi_p_p_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4200000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04200000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_add_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFADD_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmla_z_zzzi_h,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_LDFADD_16,
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFADD_32,
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_LDFADD_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4200400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04200400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmls_z_zzzi_h,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4200800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04200800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_mla_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmla_z_zzzi_h,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4200c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04200c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_mls_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmls_z_zzzi_h,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4201000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04201000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqadd_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmlah_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4201400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04201400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqadd_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmlsh_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4201800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04201800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqsub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4201c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04201c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqsub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/24202000 level 2
   ffe0fc00/24202400 level 2
   ffe0fc00/24202800 level 2
   ffe0fc00/24202c00 level 2
   ffe0fc00/24203000 level 2
   ffe0fc00/24203400 level 2
   ffe0fc00/24203800 level 2
   ffe0fc00/24203c00 level 2
   ffe0fc00/24206000 level 2
   ffe0fc00/24206400 level 2
   ffe0fc00/24206800 level 2
   ffe0fc00/24206c00 level 2
   ffe0fc00/24207000 level 2
   ffe0fc00/24207400 level 2
   ffe0fc00/24207800 level 2
   ffe0fc00/24207c00 level 2
   ffe0fc00/2420a000 level 2
   ffe0fc00/2420a400 level 2
   ffe0fc00/2420a800 level 2
   ffe0fc00/2420ac00 level 2
   ffe0fc00/2420b000 level 2
   ffe0fc00/2420b400 level 2
   ffe0fc00/2420b800 level 2
   ffe0fc00/2420bc00 level 2
   ffe0fc00/2420e000 level 2
   ffe0fc00/2420e400 level 2
   ffe0fc00/2420e800 level 2
   ffe0fc00/2420ec00 level 2
   ffe0fc00/2420f000 level 2
   ffe0fc00/2420f400 level 2
   ffe0fc00/2420f800 level 2
   ffe0fc00/2420fc00 level 2
   ffe0fc00/24602000 level 2
   ffe0fc00/24602400 level 2
   ffe0fc00/24602800 level 2
   ffe0fc00/24602c00 level 2
   ffe0fc00/24603000 level 2
   ffe0fc00/24603400 level 2
   ffe0fc00/24603800 level 2
   ffe0fc00/24603c00 level 2
   ffe0fc00/24606000 level 2
   ffe0fc00/24606400 level 2
   ffe0fc00/24606800 level 2
   ffe0fc00/24606c00 level 2
   ffe0fc00/24607000 level 2
   ffe0fc00/24607400 level 2
   ffe0fc00/24607800 level 2
   ffe0fc00/24607c00 level 2
   ffe0fc00/2460a000 level 2
   ffe0fc00/2460a400 level 2
   ffe0fc00/2460a800 level 2
   ffe0fc00/2460ac00 level 2
   ffe0fc00/2460b000 level 2
   ffe0fc00/2460b400 level 2
   ffe0fc00/2460b800 level 2
   ffe0fc00/2460bc00 level 2
   ffe0fc00/2460e000 level 2
   ffe0fc00/2460e400 level 2
   ffe0fc00/2460e800 level 2
   ffe0fc00/2460ec00 level 2
   ffe0fc00/2460f000 level 2
   ffe0fc00/2460f400 level 2
   ffe0fc00/2460f800 level 2
   ffe0fc00/2460fc00 level 2
   ffe0fc00/24a02000 level 2
   ffe0fc00/24a02400 level 2
   ffe0fc00/24a02800 level 2
   ffe0fc00/24a02c00 level 2
   ffe0fc00/24a03000 level 2
   ffe0fc00/24a03400 level 2
   ffe0fc00/24a03800 level 2
   ffe0fc00/24a03c00 level 2
   ffe0fc00/24a06000 level 2
   ffe0fc00/24a06400 level 2
   ffe0fc00/24a06800 level 2
   ffe0fc00/24a06c00 level 2
   ffe0fc00/24a07000 level 2
   ffe0fc00/24a07400 level 2
   ffe0fc00/24a07800 level 2
   ffe0fc00/24a07c00 level 2
   ffe0fc00/24a0a000 level 2
   ffe0fc00/24a0a400 level 2
   ffe0fc00/24a0a800 level 2
   ffe0fc00/24a0ac00 level 2
   ffe0fc00/24a0b000 level 2
   ffe0fc00/24a0b400 level 2
   ffe0fc00/24a0b800 level 2
   ffe0fc00/24a0bc00 level 2
   ffe0fc00/24a0e000 level 2
   ffe0fc00/24a0e400 level 2
   ffe0fc00/24a0e800 level 2
   ffe0fc00/24a0ec00 level 2
   ffe0fc00/24a0f000 level 2
   ffe0fc00/24a0f400 level 2
   ffe0fc00/24a0f800 level 2
   ffe0fc00/24a0fc00 level 2
   ffe0fc00/24e02000 level 2
   ffe0fc00/24e02400 level 2
   ffe0fc00/24e02800 level 2
   ffe0fc00/24e02c00 level 2
   ffe0fc00/24e03000 level 2
   ffe0fc00/24e03400 level 2
   ffe0fc00/24e03800 level 2
   ffe0fc00/24e03c00 level 2
   ffe0fc00/24e06000 level 2
   ffe0fc00/24e06400 level 2
   ffe0fc00/24e06800 level 2
   ffe0fc00/24e06c00 level 2
   ffe0fc00/24e07000 level 2
   ffe0fc00/24e07400 level 2
   ffe0fc00/24e07800 level 2
   ffe0fc00/24e07c00 level 2
   ffe0fc00/24e0a000 level 2
   ffe0fc00/24e0a400 level 2
   ffe0fc00/24e0a800 level 2
   ffe0fc00/24e0ac00 level 2
   ffe0fc00/24e0b000 level 2
   ffe0fc00/24e0b400 level 2
   ffe0fc00/24e0b800 level 2
   ffe0fc00/24e0bc00 level 2
   ffe0fc00/24e0e000 level 2
   ffe0fc00/24e0e400 level 2
   ffe0fc00/24e0e800 level 2
   ffe0fc00/24e0ec00 level 2
   ffe0fc00/24e0f000 level 2
   ffe0fc00/24e0f400 level 2
   ffe0fc00/24e0f800 level 2
   ffe0fc00/24e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_24202000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff202010)) == UINT32_C(0x24202000))
        return iemDecodeA64_cmplo_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff202010)) == UINT32_C(0x24202010))
        return iemDecodeA64_cmpls_p_p_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4202000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04202000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmul_z_zzi_h,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/64202400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_64202400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x64202400))
        return iemDecodeA64_fclamp_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x64202400))
        return iemDecodeA64_bfclamp_z_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4202400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04202400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64202400_2,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4202800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04202800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmul_z_zzi_h,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4202c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04202c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4203000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04203000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4203400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04203400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_xar_z_zzi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4203800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04203800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor3_z_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4203c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04203c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bsl_z_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBGE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rob_z_p_bi_u8,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1q_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBGE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4204000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04204000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ii,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMAX_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fdot_z_zzzi,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMAX_16,
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMAX_32,
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMAX_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4204400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04204400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fdot_z_zz8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4204800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04204800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ir,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4204c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04204c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_rr,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fdot_z_zz8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4205000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04205000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addvl_r_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMIN_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalb_z_z8z8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMIN_16,
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMIN_32,
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMIN_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4205400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04205400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addvl_r_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalb_z_z8z8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4205800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04205800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addsvl_r_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalb_z_z8z8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4205c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04205c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addsvl_r_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalb_z_z8z8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4206000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04206000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mul_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMAXNM_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMAXNM_16,
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMAXNM_32,
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMAXNM_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4206400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04206400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_pmul_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/3c206800 level 2
   ffe0fc00/3c207800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_3c206800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c200800))
        return iemDecodeA64_STR_B_ldst_regoff(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0ec00)) == UINT32_C(0x3c206800))
        return iemDecodeA64_STR_BL_ldst_regoff(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4206800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04206800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_ffe0fc00_3c206800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4206c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04206c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_umulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4207000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04207000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqdmulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMINNM_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMINNM_16,
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMINNM_32,
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMINNM_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4207400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04207400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqrdmulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4207800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04207800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_ffe0fc00_3c206800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4207c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04207c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u16,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2b_z_p_br_contiguous,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4208000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04208000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFADD_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fdot_z_zzz,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_STFADD_16,
        iemDecodeA64_ld1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFADD_32,
        iemDecodeA64_ld1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFADD_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4208400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04208400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsr_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fdot_z_zz8z8,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4208800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04208800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbb_z32_z8z8z8,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_ld1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_ld1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4208c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04208c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsl_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4209000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04209000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4209400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04209400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4209800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04209800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbt_z32_z8z8z8,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_ld1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_ld1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4209c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04209c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsl_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a420a000 level 2
   ffe0fc00/a420a400 level 2
   ffe0fc00/a420a800 level 2
   ffe0fc00/a420ac00 level 2
   ffe0fc00/a420b000 level 2
   ffe0fc00/a420b400 level 2
   ffe0fc00/a420b800 level 2
   ffe0fc00/a420bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a420a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa420a000))
        return iemDecodeA64_ld1b_z_p_bi_u16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa430a000))
        return iemDecodeA64_ldnf1b_z_p_bi_u16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420a000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x420a400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x420ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_d_s32_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a420a000_2,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420a800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_d_s32_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltb_z32_z8z8z8,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_ldff1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a420a000_2,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_ldff1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ftssel_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a420a000_2,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a420a000_2,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fexpa_z_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltt_z32_z8z8z8,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_ldff1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a420a000_2,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_ldff1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_movprfx_z_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBBGE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sb_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a420a000_2,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sb_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFMAX_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbb_z32_z8z8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_STFMAX_16,
        iemDecodeA64_ld1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFMAX_32,
        iemDecodeA64_ld1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFMAX_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420c400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x420cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbb_z32_z8z8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbb_z32_z8z8z8i,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_ld1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_ld1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFMIN_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_STFMIN_16,
        iemDecodeA64_ld1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFMIN_32,
        iemDecodeA64_ld1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFMIN_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x420dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_ld1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_br_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_ld1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0420e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0420e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0420e000))
        return iemDecodeA64_cntb_r_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0430e000))
        return iemDecodeA64_incb_r_rs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/e420e000 level 2
   ffe0fc00/e420e400 level 2
   ffe0fc00/e420e800 level 2
   ffe0fc00/e420ec00 level 2
   ffe0fc00/e420f000 level 2
   ffe0fc00/e420f400 level 2
   ffe0fc00/e420f800 level 2
   ffe0fc00/e420fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e420e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff90e000)) == UINT32_C(0xe400e000))
        return iemDecodeA64_st1b_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe430e000))
        return iemDecodeA64_st2b_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0420e000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFMAXNM_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmmla_z32_zz8z8,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_STFMAXNM_16,
        iemDecodeA64_ldff1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFMAXNM_32,
        iemDecodeA64_ldff1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e420e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFMAXNM_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_decb_r_rs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmmla_z32_zzz_h,
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e420e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_ldff1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_ldff1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e420e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e420e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0420f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0420f000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0420f000))
        return iemDecodeA64_sqincb_r_rs_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0430f000))
        return iemDecodeA64_sqincb_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0420f000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFMINNM_16,
        iemDecodeA64_sqdmulh_z_zzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_STFMINNM_16,
        iemDecodeA64_ldff1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFMINNM_32,
        iemDecodeA64_ldff1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e420e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFMINNM_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0420f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0420f400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0420f400))
        return iemDecodeA64_uqincb_r_rs_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0430f400))
        return iemDecodeA64_uqincb_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0420f400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmulh_z_zzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e420e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0420f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0420f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0420f800))
        return iemDecodeA64_sqdecb_r_rs_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0430f800))
        return iemDecodeA64_sqdecb_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0420f800_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_regoff,
        iemDecodeA64_mul_z_zzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_STR_H_ldst_regoff,
        iemDecodeA64_ldff1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_regoff,
        iemDecodeA64_ldff1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e420e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0420fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0420fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0420fc00))
        return iemDecodeA64_uqdecb_r_rs_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0430fc00))
        return iemDecodeA64_uqdecb_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x420fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0420fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0420fc00_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STNP_D_ldstnapair_offs,
        iemDecodeA64_CBHGE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1b_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2b_z_p_bi_contiguous,
        iemDecodeA64_STNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BRK_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e420e000_2,
        iemDecodeA64_STTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4400000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04400000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_LD4_asisdlse_R4,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD4_asisdlse_R4,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_bi_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4400400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04400400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_LD4_asisdlse_R4,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD4_asisdlse_R4,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_bi_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7fffc10/04400800 level 3
   f7fffc10/04400810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_f7fffc10_04400800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c400000))
        return iemDecodeA64_LD4_asisdlse_R4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04000000))
        return iemDecodeA64_add_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/04400800 level 2
   f7e0fc10/04400810 level 2
   mask=0x1f0000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_04400800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7fffc10_04400800_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_subr_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smax_z_p_zz,
        iemDecodeA64_umax_z_p_zz,
        iemDecodeA64_smin_z_p_zz,
        iemDecodeA64_umin_z_p_zz,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_mul_z_p_zz,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_umulh_z_p_zz,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_orr_z_p_zz,
        iemDecodeA64_eor_z_p_zz,
        iemDecodeA64_and_z_p_zz,
        iemDecodeA64_bic_z_p_zz,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/24400800 level 2
   f7e0fc10/24401800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_24400800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000000))
        return iemDecodeA64_cmphs_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c400000))
        return iemDecodeA64_LDNP_S_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/24400810 level 2
   f7e0fc10/24401810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_24400810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000010))
        return iemDecodeA64_cmphi_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c400000))
        return iemDecodeA64_LDNP_S_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/44400800 level 2
   f7e0fc10/44400810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_44400800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c400000))
        return iemDecodeA64_LD4_asisdlse_R4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x44000800))
        return iemDecodeA64_sqdmlalbt_z_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/64400800 level 2
   f7e0fc10/64400810 level 2
   f7e0fc10/64401800 level 2
   f7e0fc10/64401810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_64400800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6c400000))
        return iemDecodeA64_LDNP_D_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/e4400800 level 2
   f7e0fc10/e4400810 level 2
   f7e0fc10/e4401800 level 2
   f7e0fc10/e4401810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_e4400800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xec400000))
        return iemDecodeA64_LDTNP_Q_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4400000))
        return iemDecodeA64_st2q_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4400800/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1f valid=%97 (0x1f) leaf=%47 (0xf) multi-if=%44 (0xe) reuse=%31 (0xa) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04400800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc10_04400800_2,
        iemDecodeA64_f7e0fc10_04400800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24400800_2,
        iemDecodeA64_f7e0fc10_24400810_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_f7e0fc10_44400800_2,
        iemDecodeA64_f7e0fc10_44400800_2,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64400800_2,
        iemDecodeA64_f7e0fc10_64400800_2,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4400800_2,
        iemDecodeA64_f7e0fc10_e4400800_2,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_CBHI_64_regs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4400c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04400c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_LD4_asisdlse_R4,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_LD4_asisdlse_R4,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_bi_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4401000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04401000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_bi_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4401400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04401400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_bi_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4401800/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1f valid=%97 (0x1f) leaf=%53 (0x11) multi-if=%38 (0xc) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04401800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24400800_2,
        iemDecodeA64_f7e0fc10_24400810_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64400800_2,
        iemDecodeA64_f7e0fc10_64400800_2,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4400800_2,
        iemDecodeA64_f7e0fc10_e4400800_2,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_CBHI_64_regs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4401c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04401c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24000000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ld1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ld1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_bi_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4402000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04402000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_LD1_asisdlse_R4_4v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_LD1_asisdlse_R4_4v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4402400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04402400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_LD1_asisdlse_R4_4v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_LD1_asisdlse_R4_4v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4402800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04402800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_LD1_asisdlse_R4_4v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_LD1_asisdlse_R4_4v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4402c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04402c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_LD1_asisdlse_R4_4v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_LD1_asisdlse_R4_4v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4403000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04403000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4403400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04403400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4403800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04403800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4403c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04403c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHI_32_regs,
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ldff1sb_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ldff1sb_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1b_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHI_64_regs,
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4404000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04404000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_LD3_asisdlse_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_smlalb_z_zzz,
        iemDecodeA64_LD3_asisdlse_R3,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4404400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04404400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_LD3_asisdlse_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_smlalt_z_zzz,
        iemDecodeA64_LD3_asisdlse_R3,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4404800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04404800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_LD3_asisdlse_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalb_z_zzz,
        iemDecodeA64_LD3_asisdlse_R3,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4404c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04404c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_LD3_asisdlse_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_umlalt_z_zzz,
        iemDecodeA64_LD3_asisdlse_R3,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4405000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04405000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_smlslb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4405400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04405400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_smlslt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4405800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04405800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlslb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4405c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04405c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_umlslt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4406000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04406000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_LD1_asisdlse_R3_3v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_sqdmlalb_z_zzz,
        iemDecodeA64_LD1_asisdlse_R3_3v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4406400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04406400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_LD1_asisdlse_R3_3v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_sqdmlalt_z_zzz,
        iemDecodeA64_LD1_asisdlse_R3_3v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4406800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04406800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_LD1_asisdlse_R3_3v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslb_z_zzz,
        iemDecodeA64_LD1_asisdlse_R3_3v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4406c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04406c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_LD1_asisdlse_R3_3v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_sqdmlslt_z_zzz,
        iemDecodeA64_LD1_asisdlse_R3_3v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4407000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04407000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_LD1_asisdlse_R1_1v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_sqrdmlah_z_zzz,
        iemDecodeA64_LD1_asisdlse_R1_1v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4407400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04407400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_LD1_asisdlse_R1_1v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_sqrdmlsh_z_zzz,
        iemDecodeA64_LD1_asisdlse_R1_1v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4407800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04407800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_LD1_asisdlse_R1_1v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD1_asisdlse_R1_1v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4407c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04407c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_LD1_asisdlse_R1_1v,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD1_asisdlse_R1_1v,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u32,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffebfc10/64498000 level 3
   ffebfc10/64498010 level 3
   ffebfc10/64498400 level 3
   ffebfc10/64498410 level 3
   ffebfc10/64498800 level 3
   ffebfc10/64498810 level 3
   ffebfc10/64498c00 level 3
   ffebfc10/64498c10 level 3
   ffebfc10/64499000 level 3
   ffebfc10/64499010 level 3
   ffebfc10/64499400 level 3
   ffebfc10/64499410 level 3
   ffebfc10/64499c00 level 3
   ffebfc10/64499c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64498000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64198000))
        return iemDecodeA64_frinta_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645d8000))
        return iemDecodeA64_scvtf_z_p_z_w2fp16z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/644b8000 level 3
   ffebfc10/644b8010 level 3
   ffebfc10/644b8400 level 3
   ffebfc10/644b8410 level 3
   ffebfc10/644b8800 level 3
   ffebfc10/644b8810 level 3
   ffebfc10/644b8c00 level 3
   ffebfc10/644b8c10 level 3
   ffebfc10/644b9000 level 3
   ffebfc10/644b9010 level 3
   ffebfc10/644b9400 level 3
   ffebfc10/644b9410 level 3
   ffebfc10/644b9c00 level 3
   ffebfc10/644b9c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_644b8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x641b8000))
        return iemDecodeA64_frecpx_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645f8000))
        return iemDecodeA64_fcvtzs_z_p_z_fp162wz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/24408000 level 2
   bfe0fc10/24408400 level 2
   bfe0fc10/24408800 level 2
   bfe0fc10/24408c00 level 2
   bfe0fc10/24409000 level 2
   bfe0fc10/24409400 level 2
   bfe0fc10/24409c00 level 2
   mask=0x400b0000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%69 (0xb) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24408000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_ffebfc10_64008000_3,
        iemDecodeA64_ffebfc10_64018000_3,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_frintn_z_p_z_z,
        iemDecodeA64_ffebfc10_64498000_3,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_ffebfc10_644b8000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/24408010 level 2
   bfe0fc10/24408410 level 2
   bfe0fc10/24408810 level 2
   bfe0fc10/24408c10 level 2
   bfe0fc10/24409010 level 2
   bfe0fc10/24409410 level 2
   bfe0fc10/24409c10 level 2
   mask=0x400b0000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%69 (0xb) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24408010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_ffebfc10_64008000_3,
        iemDecodeA64_ffebfc10_64018000_3,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_frintn_z_p_z_z,
        iemDecodeA64_ffebfc10_64498000_3,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_ffebfc10_644b8000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/2c408000 level 2
   bfe0fc10/2c408010 level 2
   bfe0fc10/2c408400 level 2
   bfe0fc10/2c408410 level 2
   bfe0fc10/2c408800 level 2
   bfe0fc10/2c408810 level 2
   bfe0fc10/2c408c00 level 2
   bfe0fc10/2c408c10 level 2
   bfe0fc10/2c409000 level 2
   bfe0fc10/2c409010 level 2
   bfe0fc10/2c409400 level 2
   bfe0fc10/2c409410 level 2
   bfe0fc10/2c409c00 level 2
   bfe0fc10/2c409c10 level 2
   bfe0fc10/2c40a000 level 2
   bfe0fc10/2c40a010 level 2
   bfe0fc10/2c40a400 level 2
   bfe0fc10/2c40a410 level 2
   bfe0fc10/2c40a800 level 2
   bfe0fc10/2c40a810 level 2
   bfe0fc10/2c40ac00 level 2
   bfe0fc10/2c40ac10 level 2
   bfe0fc10/2c40b000 level 2
   bfe0fc10/2c40b010 level 2
   bfe0fc10/2c40b400 level 2
   bfe0fc10/2c40b410 level 2
   bfe0fc10/2c40b800 level 2
   bfe0fc10/2c40b810 level 2
   bfe0fc10/2c40bc00 level 2
   bfe0fc10/2c40bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2c408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c400000))
        return iemDecodeA64_LDNP_S_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6c400000))
        return iemDecodeA64_LDNP_D_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/34408000 level 2
   bfe0fc10/34408010 level 2
   bfe0fc10/34408400 level 2
   bfe0fc10/34408410 level 2
   bfe0fc10/34408800 level 2
   bfe0fc10/34408810 level 2
   bfe0fc10/34408c00 level 2
   bfe0fc10/34408c10 level 2
   bfe0fc10/34409000 level 2
   bfe0fc10/34409010 level 2
   bfe0fc10/34409400 level 2
   bfe0fc10/34409410 level 2
   bfe0fc10/34409c00 level 2
   bfe0fc10/34409c10 level 2
   bfe0fc10/3440a000 level 2
   bfe0fc10/3440a010 level 2
   bfe0fc10/3440a400 level 2
   bfe0fc10/3440a410 level 2
   bfe0fc10/3440a800 level 2
   bfe0fc10/3440a810 level 2
   bfe0fc10/3440ac00 level 2
   bfe0fc10/3440ac10 level 2
   bfe0fc10/3440b000 level 2
   bfe0fc10/3440b010 level 2
   bfe0fc10/3440b400 level 2
   bfe0fc10/3440b410 level 2
   bfe0fc10/3440b800 level 2
   bfe0fc10/3440b810 level 2
   bfe0fc10/3440bc00 level 2
   bfe0fc10/3440bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_34408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74408000))
        return iemDecodeA64_CBBHI_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/3c408000 level 2
   bfe0fc10/3c408010 level 2
   bfe0fc10/3c409000 level 2
   bfe0fc10/3c409010 level 2
   bfe0fc10/3c40a000 level 2
   bfe0fc10/3c40a010 level 2
   bfe0fc10/3c40b000 level 2
   bfe0fc10/3c40b010 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_3c408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c400000))
        return iemDecodeA64_LDUR_B_ldst_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x7c400000))
        return iemDecodeA64_LDUR_H_ldst_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/84408000 level 2
   bfe0fc10/84408010 level 2
   bfe0fc10/84408400 level 2
   bfe0fc10/84408410 level 2
   bfe0fc10/84408800 level 2
   bfe0fc10/84408810 level 2
   bfe0fc10/84408c00 level 2
   bfe0fc10/84408c10 level 2
   bfe0fc10/84409000 level 2
   bfe0fc10/84409010 level 2
   bfe0fc10/84409400 level 2
   bfe0fc10/84409410 level 2
   bfe0fc10/84409c00 level 2
   bfe0fc10/84409c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_84408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x84408000))
        return iemDecodeA64_ld1rb_z_p_bi_u8(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4408000))
        return iemDecodeA64_ld1sb_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/94408000 level 2
   bfe0fc10/94408400 level 2
   bfe0fc10/94408800 level 2
   bfe0fc10/94408c00 level 2
   bfe0fc10/94409000 level 2
   bfe0fc10/94409400 level 2
   bfe0fc10/94409c00 level 2
   bfe0fc10/9440a000 level 2
   bfe0fc10/9440a400 level 2
   bfe0fc10/9440a800 level 2
   bfe0fc10/9440ac00 level 2
   bfe0fc10/9440b000 level 2
   bfe0fc10/9440b400 level 2
   bfe0fc10/9440b800 level 2
   bfe0fc10/9440bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_94408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4400000))
        return iemDecodeA64_HLT_EX_exception(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/ac408000 level 2
   bfe0fc10/ac408010 level 2
   bfe0fc10/ac408400 level 2
   bfe0fc10/ac408410 level 2
   bfe0fc10/ac408800 level 2
   bfe0fc10/ac408810 level 2
   bfe0fc10/ac408c00 level 2
   bfe0fc10/ac408c10 level 2
   bfe0fc10/ac409000 level 2
   bfe0fc10/ac409010 level 2
   bfe0fc10/ac409400 level 2
   bfe0fc10/ac409410 level 2
   bfe0fc10/ac409c00 level 2
   bfe0fc10/ac409c10 level 2
   bfe0fc10/ac40a000 level 2
   bfe0fc10/ac40a010 level 2
   bfe0fc10/ac40a400 level 2
   bfe0fc10/ac40a410 level 2
   bfe0fc10/ac40a800 level 2
   bfe0fc10/ac40a810 level 2
   bfe0fc10/ac40ac00 level 2
   bfe0fc10/ac40ac10 level 2
   bfe0fc10/ac40b000 level 2
   bfe0fc10/ac40b010 level 2
   bfe0fc10/ac40b400 level 2
   bfe0fc10/ac40b410 level 2
   bfe0fc10/ac40b800 level 2
   bfe0fc10/ac40b810 level 2
   bfe0fc10/ac40bc00 level 2
   bfe0fc10/ac40bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_ac408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xac400000))
        return iemDecodeA64_LDNP_Q_ldstnapair_offs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xec400000))
        return iemDecodeA64_LDTNP_Q_ldstnapair_offs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/bc408000 level 2
   bfe0fc10/bc408010 level 2
   bfe0fc10/bc409000 level 2
   bfe0fc10/bc409010 level 2
   bfe0fc10/bc40a000 level 2
   bfe0fc10/bc40a010 level 2
   bfe0fc10/bc40b000 level 2
   bfe0fc10/bc40b010 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_bc408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xbc400000))
        return iemDecodeA64_LDUR_S_ldst_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xfc400000))
        return iemDecodeA64_LDUR_D_ldst_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4408000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%28 (0x9) multi-if=%53 (0x11) reuse=%38 (0xc) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04408000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_LD2_asisdlse_R2,
        iemDecodeA64_LD2_asisdlse_R2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24408000_2,
        iemDecodeA64_bfe0fc10_24408010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408000_2,
        iemDecodeA64_bfe0fc10_3c408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408000_2,
        iemDecodeA64_bfe0fc10_bc408000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/3c408400 level 2
   bfe0fc10/3c408410 level 2
   bfe0fc10/3c409400 level 2
   bfe0fc10/3c409410 level 2
   bfe0fc10/3c40a400 level 2
   bfe0fc10/3c40a410 level 2
   bfe0fc10/3c40b400 level 2
   bfe0fc10/3c40b410 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_3c408400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c400400))
        return iemDecodeA64_LDR_B_ldst_immpost(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x7c400400))
        return iemDecodeA64_LDR_H_ldst_immpost(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/bc408400 level 2
   bfe0fc10/bc408410 level 2
   bfe0fc10/bc409400 level 2
   bfe0fc10/bc409410 level 2
   bfe0fc10/bc40a400 level 2
   bfe0fc10/bc40a410 level 2
   bfe0fc10/bc40b400 level 2
   bfe0fc10/bc40b410 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_bc408400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xbc400400))
        return iemDecodeA64_LDR_S_ldst_immpost(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xfc400400))
        return iemDecodeA64_LDR_D_ldst_immpost(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4408400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%28 (0x9) multi-if=%53 (0x11) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04408400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_LD2_asisdlse_R2,
        iemDecodeA64_LD2_asisdlse_R2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24408000_2,
        iemDecodeA64_bfe0fc10_24408010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408400_2,
        iemDecodeA64_bfe0fc10_3c408400_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408400_2,
        iemDecodeA64_bfe0fc10_bc408400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4408800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%28 (0x9) multi-if=%41 (0xd) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04408800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_LD2_asisdlse_R2,
        iemDecodeA64_LD2_asisdlse_R2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24408000_2,
        iemDecodeA64_bfe0fc10_24408010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/3c408c00 level 2
   bfe0fc10/3c408c10 level 2
   bfe0fc10/3c409c00 level 2
   bfe0fc10/3c409c10 level 2
   bfe0fc10/3c40ac00 level 2
   bfe0fc10/3c40ac10 level 2
   bfe0fc10/3c40bc00 level 2
   bfe0fc10/3c40bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_3c408c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c400c00))
        return iemDecodeA64_LDR_B_ldst_immpre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x7c400c00))
        return iemDecodeA64_LDR_H_ldst_immpre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/bc408c00 level 2
   bfe0fc10/bc408c10 level 2
   bfe0fc10/bc409c00 level 2
   bfe0fc10/bc409c10 level 2
   bfe0fc10/bc40ac00 level 2
   bfe0fc10/bc40ac10 level 2
   bfe0fc10/bc40bc00 level 2
   bfe0fc10/bc40bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_bc408c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xbc400c00))
        return iemDecodeA64_LDR_S_ldst_immpre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xfc400c00))
        return iemDecodeA64_LDR_D_ldst_immpre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4408c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%28 (0x9) multi-if=%53 (0x11) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04408c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_LD2_asisdlse_R2,
        iemDecodeA64_LD2_asisdlse_R2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24408000_2,
        iemDecodeA64_bfe0fc10_24408010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408c00_2,
        iemDecodeA64_bfe0fc10_3c408c00_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408c00_2,
        iemDecodeA64_bfe0fc10_bc408c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4409000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%22 (0x7) multi-if=%53 (0x11) reuse=%66 (0x15) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04409000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24408000_2,
        iemDecodeA64_bfe0fc10_24408010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408000_2,
        iemDecodeA64_bfe0fc10_3c408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408000_2,
        iemDecodeA64_bfe0fc10_bc408000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4409400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%22 (0x7) multi-if=%53 (0x11) reuse=%66 (0x15) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04409400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24408000_2,
        iemDecodeA64_bfe0fc10_24408010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408400_2,
        iemDecodeA64_bfe0fc10_3c408400_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408400_2,
        iemDecodeA64_bfe0fc10_bc408400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/44409800 level 2
   dfe0fc10/44409810 level 2
   mask=0x201f0000 entries=0x40 children=0x28 valid=%62 (0x28) leaf=%62 (0x28) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_44409800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_srshl_z_p_zz,
        iemDecodeA64_urshl_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_srshlr_z_p_zz,
        iemDecodeA64_urshlr_z_p_zz,
        iemDecodeA64_sqshl_z_p_zz,
        iemDecodeA64_uqshl_z_p_zz,
        iemDecodeA64_sqrshl_z_p_zz,
        iemDecodeA64_uqrshl_z_p_zz,
        iemDecodeA64_sqshlr_z_p_zz,
        iemDecodeA64_uqshlr_z_p_zz,
        iemDecodeA64_sqrshlr_z_p_zz,
        iemDecodeA64_uqrshlr_z_p_zz,
        iemDecodeA64_shadd_z_p_zz,
        iemDecodeA64_uhadd_z_p_zz,
        iemDecodeA64_shsub_z_p_zz,
        iemDecodeA64_uhsub_z_p_zz,
        iemDecodeA64_srhadd_z_p_zz,
        iemDecodeA64_urhadd_z_p_zz,
        iemDecodeA64_shsubr_z_p_zz,
        iemDecodeA64_uhsubr_z_p_zz,
        iemDecodeA64_sqadd_z_p_zz,
        iemDecodeA64_uqadd_z_p_zz,
        iemDecodeA64_sqsub_z_p_zz,
        iemDecodeA64_uqsub_z_p_zz,
        iemDecodeA64_suqadd_z_p_zz,
        iemDecodeA64_usqadd_z_p_zz,
        iemDecodeA64_sqsubr_z_p_zz,
        iemDecodeA64_uqsubr_z_p_zz,
        iemDecodeA64_fcadd_z_p_zz,
        iemDecodeA64_fcadd_z_p_zz,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_faddp_z_p_zz,
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_fmaxnmp_z_p_zz,
        iemDecodeA64_fminnmp_z_p_zz,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_frintn_z_p_z_z,
        iemDecodeA64_frinta_z_p_z_z,
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_frecpx_z_p_z_z,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_scvtf_z_p_z_w2fp16z,
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_fcvtzs_z_p_z_fp162wz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x201f0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000020)) /* bit 29 L 1 -> 5 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/54409800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_54409800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74408000))
        return iemDecodeA64_CBBHI_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/54409810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_54409810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74408000))
        return iemDecodeA64_CBBHI_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/c4409800 level 2
   dfe0fc10/c4409810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_c4409800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe4408000))
        return iemDecodeA64_st1b_z_p_bz_s_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4408000))
        return iemDecodeA64_ld1sb_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4409800/0xd8000010
   mask=0xd8000010 entries=0x20 children=0x1d valid=%91 (0x1d) leaf=%53 (0x11) multi-if=%25 (0x8) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04409800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dfe0fc10_04009800_2,
        iemDecodeA64_dfe0fc10_04009810_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_dfe0fc10_44409800_2,
        iemDecodeA64_dfe0fc10_44409800_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_dfe0fc10_54409800_2,
        iemDecodeA64_dfe0fc10_54409810_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_dfe0fc10_c4409800_2,
        iemDecodeA64_dfe0fc10_c4409800_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4409c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%22 (0x7) multi-if=%53 (0x11) reuse=%66 (0x15) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04409c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24408000_2,
        iemDecodeA64_bfe0fc10_24408010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408c00_2,
        iemDecodeA64_bfe0fc10_3c408c00_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_bfe0fc10_84408000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408c00_2,
        iemDecodeA64_bfe0fc10_bc408c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffebfc10/644ba000 level 3
   ffebfc10/644ba010 level 3
   ffebfc10/644ba400 level 3
   ffebfc10/644ba410 level 3
   ffebfc10/644ba800 level 3
   ffebfc10/644ba810 level 3
   ffebfc10/644bac00 level 3
   ffebfc10/644bac10 level 3
   ffebfc10/644bb000 level 3
   ffebfc10/644bb010 level 3
   ffebfc10/644bb400 level 3
   ffebfc10/644bb410 level 3
   ffebfc10/644bb800 level 3
   ffebfc10/644bb810 level 3
   ffebfc10/644bbc00 level 3
   ffebfc10/644bbc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_644ba000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x641ba000))
        return iemDecodeA64_fsqrt_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x645fa000))
        return iemDecodeA64_fcvtzu_z_p_z_fp162wz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/2440a000 level 2
   bfe0fc10/2440a400 level 2
   bfe0fc10/2440a800 level 2
   bfe0fc10/2440ac00 level 2
   bfe0fc10/2440b000 level 2
   bfe0fc10/2440b400 level 2
   bfe0fc10/2440b800 level 2
   bfe0fc10/2440bc00 level 2
   mask=0x400b0000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%81 (0xd) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2440a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_ffebfc10_6400a000_3,
        iemDecodeA64_fminnmqv_z_p_z,
        iemDecodeA64_fmaxqv_z_p_z,
        iemDecodeA64_fminqv_z_p_z,
        iemDecodeA64_frintp_z_p_z_z,
        iemDecodeA64_ucvtf_z_p_z_w2fp16z,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_ffebfc10_644ba000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/2440a010 level 2
   bfe0fc10/2440a410 level 2
   bfe0fc10/2440a810 level 2
   bfe0fc10/2440ac10 level 2
   bfe0fc10/2440b010 level 2
   bfe0fc10/2440b410 level 2
   bfe0fc10/2440b810 level 2
   bfe0fc10/2440bc10 level 2
   mask=0x400b0000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%81 (0xd) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2440a010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_ffebfc10_6400a000_3,
        iemDecodeA64_fminnmqv_z_p_z,
        iemDecodeA64_fmaxqv_z_p_z,
        iemDecodeA64_fminqv_z_p_z,
        iemDecodeA64_frintp_z_p_z_z,
        iemDecodeA64_ucvtf_z_p_z_w2fp16z,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_ffebfc10_644ba000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/8440a000 level 2
   bfe0fc10/8440a010 level 2
   bfe0fc10/8440a400 level 2
   bfe0fc10/8440a410 level 2
   bfe0fc10/8440a800 level 2
   bfe0fc10/8440a810 level 2
   bfe0fc10/8440ac00 level 2
   bfe0fc10/8440ac10 level 2
   bfe0fc10/8440b000 level 2
   bfe0fc10/8440b010 level 2
   bfe0fc10/8440b400 level 2
   bfe0fc10/8440b410 level 2
   bfe0fc10/8440b800 level 2
   bfe0fc10/8440b810 level 2
   bfe0fc10/8440bc00 level 2
   bfe0fc10/8440bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_8440a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x8440a000))
        return iemDecodeA64_ld1rb_z_p_bi_u16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc440a000))
        return iemDecodeA64_ldff1sb_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/a440a000 level 2
   bfe0fc10/a440a010 level 2
   bfe0fc10/a440a400 level 2
   bfe0fc10/a440a410 level 2
   bfe0fc10/a440a800 level 2
   bfe0fc10/a440a810 level 2
   bfe0fc10/a440ac00 level 2
   bfe0fc10/a440ac10 level 2
   bfe0fc10/a440b000 level 2
   bfe0fc10/a440b010 level 2
   bfe0fc10/a440b400 level 2
   bfe0fc10/a440b410 level 2
   bfe0fc10/a440b800 level 2
   bfe0fc10/a440b810 level 2
   bfe0fc10/a440bc00 level 2
   bfe0fc10/a440bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_a440a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe440a000))
        return iemDecodeA64_st1b_z_p_ai_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa440a000))
        return iemDecodeA64_ld1b_z_p_bi_u32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa450a000))
        return iemDecodeA64_ldnf1b_z_p_bi_u32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440a000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%22 (0x7) multi-if=%59 (0x13) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_LD1_asisdlse_R2_2v,
        iemDecodeA64_LD1_asisdlse_R2_2v,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2440a000_2,
        iemDecodeA64_bfe0fc10_2440a010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408000_2,
        iemDecodeA64_bfe0fc10_3c408000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408000_2,
        iemDecodeA64_bfe0fc10_bc408000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440a400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%22 (0x7) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_LD1_asisdlse_R2_2v,
        iemDecodeA64_LD1_asisdlse_R2_2v,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2440a000_2,
        iemDecodeA64_bfe0fc10_2440a010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408400_2,
        iemDecodeA64_bfe0fc10_3c408400_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408400_2,
        iemDecodeA64_bfe0fc10_bc408400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440a800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%22 (0x7) multi-if=%47 (0xf) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_LD1_asisdlse_R2_2v,
        iemDecodeA64_LD1_asisdlse_R2_2v,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2440a000_2,
        iemDecodeA64_bfe0fc10_2440a010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440ac00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%22 (0x7) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_LD1_asisdlse_R2_2v,
        iemDecodeA64_LD1_asisdlse_R2_2v,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2440a000_2,
        iemDecodeA64_bfe0fc10_2440a010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408c00_2,
        iemDecodeA64_bfe0fc10_3c408c00_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408c00_2,
        iemDecodeA64_bfe0fc10_bc408c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440b000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%16 (0x5) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2440a000_2,
        iemDecodeA64_bfe0fc10_2440a010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408000_2,
        iemDecodeA64_bfe0fc10_3c408000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408000_2,
        iemDecodeA64_bfe0fc10_bc408000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440b400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%16 (0x5) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2440a000_2,
        iemDecodeA64_bfe0fc10_2440a010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408400_2,
        iemDecodeA64_bfe0fc10_3c408400_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408400_2,
        iemDecodeA64_bfe0fc10_bc408400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440b800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%16 (0x5) multi-if=%47 (0xf) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2440a000_2,
        iemDecodeA64_bfe0fc10_2440a010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440bc00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%16 (0x5) multi-if=%59 (0x13) reuse=%72 (0x17) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2440a000_2,
        iemDecodeA64_bfe0fc10_2440a010_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_2c408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_34408000_2,
        iemDecodeA64_bfe0fc10_3c408c00_2,
        iemDecodeA64_bfe0fc10_3c408c00_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_bfe0fc10_8440a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_bfe0fc10_94408000_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_a440a000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_bfe0fc10_ac408000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_bfe0fc10_bc408c00_2,
        iemDecodeA64_bfe0fc10_bc408c00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/6440c000 level 2
   ffe0fc00/6440c400 level 2
   ffe0fc00/6440c800 level 2
   ffe0fc00/6440cc00 level 2
   ffe0fc00/6440d000 level 2
   ffe0fc00/6440d400 level 2
   ffe0fc00/6440d800 level 2
   ffe0fc00/6440dc00 level 2
   mask=0x70000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6440c000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintm_z_p_z_z,
        iemDecodeA64_frintx_z_p_z_z,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_scvtf_z_p_z_h2fp16z,
        iemDecodeA64_scvtf_z_p_z_x2fp16z,
        iemDecodeA64_fcvtzs_z_p_z_fp162hz,
        iemDecodeA64_fcvtzs_z_p_z_fp162xz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_sclamp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440c000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_uclamp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440c000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x440d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440c000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440cc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x440dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440c000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ld1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440c000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ld1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440c000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ld1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/6440e000 level 2
   ffe0fc00/6440e400 level 2
   ffe0fc00/6440e800 level 2
   ffe0fc00/6440ec00 level 2
   ffe0fc00/6440f000 level 2
   ffe0fc00/6440f400 level 2
   ffe0fc00/6440f800 level 2
   ffe0fc00/6440fc00 level 2
   mask=0x70000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6440e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintz_z_p_z_z,
        iemDecodeA64_frinti_z_p_z_z,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ucvtf_z_p_z_h2fp16z,
        iemDecodeA64_ucvtf_z_p_z_x2fp16z,
        iemDecodeA64_fcvtzu_z_p_z_fp162hz,
        iemDecodeA64_fcvtzu_z_p_z_fp162xz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/e440e000 level 2
   ffe0fc00/e440e400 level 2
   ffe0fc00/e440e800 level 2
   ffe0fc00/e440ec00 level 2
   ffe0fc00/e440f000 level 2
   ffe0fc00/e440f400 level 2
   ffe0fc00/e440f800 level 2
   ffe0fc00/e440fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e440e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff90e000)) == UINT32_C(0xe400e000))
        return iemDecodeA64_st1b_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe450e000))
        return iemDecodeA64_st3b_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_zipq1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440e000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e440e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_zipq2_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440e000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e440e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_uzpq1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440e000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e440e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_uzpq2_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440e000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e440e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_B_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440e000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDUR_H_ldst_unscaled,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDUR_S_ldst_unscaled,
        iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e440e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDUR_D_ldst_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440e000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDR_H_ldst_immpost,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpost,
        iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e440e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpost,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_tblq_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440e000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e440e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x440fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0440fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6440e000_2,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHI_16_regs,
        iemDecodeA64_LDR_H_ldst_immpre,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_immpre,
        iemDecodeA64_ldff1b_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_HLT_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e440e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_immpre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4600000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04600000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_add_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFADDL_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmla_z_zzzi_h,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_LDFADDL_16,
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFADDL_32,
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_LDFADDL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4600400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04600400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmls_z_zzzi_h,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4600800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04600800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_mla_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmla_z_zzzi_h,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4600c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04600c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_mls_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmls_z_zzzi_h,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4601000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04601000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqadd_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmlah_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4601400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04601400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqadd_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmlsh_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4601800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04601800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqsub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4601c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04601c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqsub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2q_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4602000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04602000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmul_z_zzi_h,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4602400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04602400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fclamp_z_zz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4602800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04602800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmul_z_zzi_h,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4602c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04602c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4603000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04603000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4603400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04603400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_xar_z_zzi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4603800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04603800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bcax_z_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4603c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04603c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bsl1n_z_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHS_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_CBHS_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4604000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04604000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ii,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMAXL_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfdot_z_zzzi,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMAXL_16,
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMAXL_32,
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMAXL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4604400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04604400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fdot_z32_zz8z8i,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4604800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04604800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ir,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4604c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04604c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_rr,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4605000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04605000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addpl_r_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMINL_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMINL_16,
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMINL_32,
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMINL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4605400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04605400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addpl_r_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4605800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04605800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addspl_r_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4605c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04605c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addspl_r_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_br,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4606000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04606000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mul_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMAXNML_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMAXNML_16,
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMAXNML_32,
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMAXNML_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4606400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x4607c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04606400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/3c606800 level 2
   ffe0fc00/3c607800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_3c606800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c600800))
        return iemDecodeA64_LDR_B_ldst_regoff(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0ec00)) == UINT32_C(0x3c606800))
        return iemDecodeA64_LDR_BL_ldst_regoff(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4606800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04606800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_ffe0fc00_3c606800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4606c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04606c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_umulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4607000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04607000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqdmulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMINNML_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMINNML_16,
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMINNML_32,
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMINNML_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4607400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04607400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqrdmulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4607800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04607800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_ffe0fc00_3c606800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1b_z_p_br_u64,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4b_z_p_br_contiguous,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4608000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04608000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFADDL_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfdot_z_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_STFADDL_16,
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFADDL_32,
        iemDecodeA64_prfb_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFADDL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4608400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04608400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsr_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fdot_z32_zz8z8,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4608800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x4609800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04608800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfb_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4608c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04608c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsl_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4609000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04609000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4609400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04609400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4609c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04609c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsl_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u8,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfb_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a460a000 level 2
   ffe0fc00/a460a400 level 2
   ffe0fc00/a460a800 level 2
   ffe0fc00/a460ac00 level 2
   ffe0fc00/a460b000 level 2
   ffe0fc00/a460b400 level 2
   ffe0fc00/a460b800 level 2
   ffe0fc00/a460bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a460a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa460a000))
        return iemDecodeA64_ld1b_z_p_bi_u64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa470a000))
        return iemDecodeA64_ldnf1b_z_p_bi_u64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460a000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x460a400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x460ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_d_u32_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a460a000_2,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_ai_s,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460a800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_d_u32_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_ld1rb_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a460a000_2,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_ai_s,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ftssel_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a460a000_2,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_ai_s,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460b400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x460bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a460a000_2,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_ai_s,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fexpa_z_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBBHS_8_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_ld1rb_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a460a000_2,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfh_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1b_z_p_ai_s,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0460c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0460c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460c000))
        return iemDecodeA64_sqinch_z_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0470c000))
        return iemDecodeA64_inch_z_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0460c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFMAXL_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbt_z32_z8z8z8i,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_STFMAXL_16,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFMAXL_32,
        iemDecodeA64_prfw_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFMAXL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0460c400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0460c400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460c400))
        return iemDecodeA64_uqinch_z_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0470c400))
        return iemDecodeA64_dech_z_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0460c400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbt_z32_z8z8z8i,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqdech_z_zs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbt_z32_z8z8z8i,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqdech_z_zs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlallbt_z32_z8z8z8i,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFMINL_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_STFMINL_16,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFMINL_32,
        iemDecodeA64_prfw_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFMINL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x460dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfw_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_ld1rb_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_br_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfw_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0460e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0460e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460e000))
        return iemDecodeA64_cnth_r_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0470e000))
        return iemDecodeA64_inch_r_rs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/e460e000 level 2
   ffe0fc00/e460e400 level 2
   ffe0fc00/e460e800 level 2
   ffe0fc00/e460ec00 level 2
   ffe0fc00/e460f000 level 2
   ffe0fc00/e460f400 level 2
   ffe0fc00/e460f800 level 2
   ffe0fc00/e460fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e460e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff90e000)) == UINT32_C(0xe400e000))
        return iemDecodeA64_st1b_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe470e000))
        return iemDecodeA64_st4b_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0460e000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFMAXNML_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmmla_z16_zz8z8,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_STFMAXNML_16,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFMAXNML_32,
        iemDecodeA64_prfd_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e460e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFMAXNML_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dech_r_rs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmmla_z_zzz,
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e460e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e460e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e460e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0460f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0460f000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460f000))
        return iemDecodeA64_sqinch_r_rs_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0470f000))
        return iemDecodeA64_sqinch_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0460f000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STBFMINNML_16,
        iemDecodeA64_sqdmulh_z_zzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_STFMINNML_16,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_STFMINNML_32,
        iemDecodeA64_prfd_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e460e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STFMINNML_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0460f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0460f400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460f400))
        return iemDecodeA64_uqinch_r_rs_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0470f400))
        return iemDecodeA64_uqinch_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0460f400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmulh_z_zzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e460e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0460f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0460f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460f800))
        return iemDecodeA64_sqdech_r_rs_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0470f800))
        return iemDecodeA64_sqdech_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0460f800_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_regoff,
        iemDecodeA64_mul_z_zzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_LDR_H_ldst_regoff,
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_regoff,
        iemDecodeA64_prfd_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e460e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_regoff,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0460fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0460fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0460fc00))
        return iemDecodeA64_uqdech_r_rs_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x0470fc00))
        return iemDecodeA64_uqdech_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x460fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0460fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0460fc00_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDNP_S_ldstnapair_offs,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDNP_D_ldstnapair_offs,
        iemDecodeA64_CBHHS_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rb_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4b_z_p_bi_contiguous,
        iemDecodeA64_LDNP_Q_ldstnapair_offs,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_TCANCEL_EX_exception,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e460e000_2,
        iemDecodeA64_LDTNP_Q_ldstnapair_offs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc10/04800000 level 3
   ffeffc10/04800010 level 3
   ffeffc10/04800400 level 3
   ffeffc10/04800410 level 3
   ffeffc10/04800800 level 3
   ffeffc10/04800810 level 3
   ffeffc10/04800c00 level 3
   ffeffc10/04800c10 level 3
   ffeffc10/04801800 level 3
   ffeffc10/04801810 level 3
   ffeffc10/04c00000 level 3
   ffeffc10/04c00010 level 3
   ffeffc10/04c00400 level 3
   ffeffc10/04c00410 level 3
   ffeffc10/04c00800 level 3
   ffeffc10/04c00810 level 3
   ffeffc10/04c00c00 level 3
   ffeffc10/04c00c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc10_04800000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04000000))
        return iemDecodeA64_add_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04100000))
        return iemDecodeA64_mul_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc10/04830000 level 3
   ffeffc10/04830010 level 3
   ffeffc10/04830400 level 3
   ffeffc10/04830410 level 3
   ffeffc10/04830800 level 3
   ffeffc10/04830810 level 3
   ffeffc10/04830c00 level 3
   ffeffc10/04830c10 level 3
   ffeffc10/04831800 level 3
   ffeffc10/04831810 level 3
   ffeffc10/04c30000 level 3
   ffeffc10/04c30010 level 3
   ffeffc10/04c30400 level 3
   ffeffc10/04c30410 level 3
   ffeffc10/04c30800 level 3
   ffeffc10/04c30810 level 3
   ffeffc10/04c30c00 level 3
   ffeffc10/04c30c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc10_04830000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04030000))
        return iemDecodeA64_subr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04130000))
        return iemDecodeA64_umulh_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc10/04880000 level 3
   ffeffc10/04880010 level 3
   ffeffc10/04880400 level 3
   ffeffc10/04880410 level 3
   ffeffc10/04880800 level 3
   ffeffc10/04880810 level 3
   ffeffc10/04880c00 level 3
   ffeffc10/04880c10 level 3
   ffeffc10/04881800 level 3
   ffeffc10/04881810 level 3
   ffeffc10/04c80000 level 3
   ffeffc10/04c80010 level 3
   ffeffc10/04c80400 level 3
   ffeffc10/04c80410 level 3
   ffeffc10/04c80800 level 3
   ffeffc10/04c80810 level 3
   ffeffc10/04c80c00 level 3
   ffeffc10/04c80c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc10_04880000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04080000))
        return iemDecodeA64_smax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04180000))
        return iemDecodeA64_orr_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc10/04890000 level 3
   ffeffc10/04890010 level 3
   ffeffc10/04890400 level 3
   ffeffc10/04890410 level 3
   ffeffc10/04890800 level 3
   ffeffc10/04890810 level 3
   ffeffc10/04890c00 level 3
   ffeffc10/04890c10 level 3
   ffeffc10/04891800 level 3
   ffeffc10/04891810 level 3
   ffeffc10/04c90000 level 3
   ffeffc10/04c90010 level 3
   ffeffc10/04c90400 level 3
   ffeffc10/04c90410 level 3
   ffeffc10/04c90800 level 3
   ffeffc10/04c90810 level 3
   ffeffc10/04c90c00 level 3
   ffeffc10/04c90c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc10_04890000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04090000))
        return iemDecodeA64_umax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04190000))
        return iemDecodeA64_eor_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc10/048a0000 level 3
   ffeffc10/048a0010 level 3
   ffeffc10/048a0400 level 3
   ffeffc10/048a0410 level 3
   ffeffc10/048a0800 level 3
   ffeffc10/048a0810 level 3
   ffeffc10/048a0c00 level 3
   ffeffc10/048a0c10 level 3
   ffeffc10/048a1800 level 3
   ffeffc10/048a1810 level 3
   ffeffc10/04ca0000 level 3
   ffeffc10/04ca0010 level 3
   ffeffc10/04ca0400 level 3
   ffeffc10/04ca0410 level 3
   ffeffc10/04ca0800 level 3
   ffeffc10/04ca0810 level 3
   ffeffc10/04ca0c00 level 3
   ffeffc10/04ca0c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc10_048a0000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040a0000))
        return iemDecodeA64_smin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x041a0000))
        return iemDecodeA64_and_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc10/048b0000 level 3
   ffeffc10/048b0010 level 3
   ffeffc10/048b0400 level 3
   ffeffc10/048b0410 level 3
   ffeffc10/048b0800 level 3
   ffeffc10/048b0810 level 3
   ffeffc10/048b0c00 level 3
   ffeffc10/048b0c10 level 3
   ffeffc10/048b1800 level 3
   ffeffc10/048b1810 level 3
   ffeffc10/04cb0000 level 3
   ffeffc10/04cb0010 level 3
   ffeffc10/04cb0400 level 3
   ffeffc10/04cb0410 level 3
   ffeffc10/04cb0800 level 3
   ffeffc10/04cb0810 level 3
   ffeffc10/04cb0c00 level 3
   ffeffc10/04cb0c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc10_048b0000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040b0000))
        return iemDecodeA64_umin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x041b0000))
        return iemDecodeA64_bic_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/04800000 level 2
   bfe0fc10/04800010 level 2
   mask=0x400f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%75 (0x18) multi-if=%19 (0x6) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04800000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x400f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/0c800000 level 2
   bfe0fc10/0c800010 level 2
   bfe0fc10/0c800400 level 2
   bfe0fc10/0c800410 level 2
   bfe0fc10/0c800800 level 2
   bfe0fc10/0c800810 level 2
   bfe0fc10/0c800c00 level 2
   bfe0fc10/0c800c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_0c800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0c800000))
        return iemDecodeA64_ST4_asisdlsep_R4_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c9f0000))
        return iemDecodeA64_ST4_asisdlsep_I4_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/24800000 level 2
   bfe0fc10/24800400 level 2
   bfe0fc10/24800800 level 2
   bfe0fc10/24800c00 level 2
   bfe0fc10/24c00000 level 2
   bfe0fc10/24c00400 level 2
   bfe0fc10/24c00c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000000))
        return iemDecodeA64_cmphs_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/24800010 level 2
   bfe0fc10/24800410 level 2
   bfe0fc10/24800810 level 2
   bfe0fc10/24800c10 level 2
   bfe0fc10/24c00010 level 2
   bfe0fc10/24c00410 level 2
   bfe0fc10/24c00c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24800010_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000010))
        return iemDecodeA64_cmphi_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/2c800000 level 2
   bfe0fc10/2c800010 level 2
   bfe0fc10/2c800400 level 2
   bfe0fc10/2c800410 level 2
   bfe0fc10/2c800800 level 2
   bfe0fc10/2c800810 level 2
   bfe0fc10/2c800c00 level 2
   bfe0fc10/2c800c10 level 2
   bfe0fc10/2c802800 level 2
   bfe0fc10/2c802810 level 2
   bfe0fc10/2c808000 level 2
   bfe0fc10/2c808010 level 2
   bfe0fc10/2c808400 level 2
   bfe0fc10/2c808410 level 2
   bfe0fc10/2c808800 level 2
   bfe0fc10/2c808810 level 2
   bfe0fc10/2c808c00 level 2
   bfe0fc10/2c808c10 level 2
   bfe0fc10/2c80a000 level 2
   bfe0fc10/2c80a010 level 2
   bfe0fc10/2c80a400 level 2
   bfe0fc10/2c80a410 level 2
   bfe0fc10/2c80a800 level 2
   bfe0fc10/2c80a810 level 2
   bfe0fc10/2c80ac00 level 2
   bfe0fc10/2c80ac10 level 2
   bfe0fc10/2c80b000 level 2
   bfe0fc10/2c80b010 level 2
   bfe0fc10/2c80b400 level 2
   bfe0fc10/2c80b410 level 2
   bfe0fc10/2c80b800 level 2
   bfe0fc10/2c80b810 level 2
   bfe0fc10/2c80bc00 level 2
   bfe0fc10/2c80bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2c800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c800000))
        return iemDecodeA64_STP_S_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6c800000))
        return iemDecodeA64_STP_D_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/84800000 level 2
   bfe0fc10/84800010 level 2
   bfe0fc10/84800400 level 2
   bfe0fc10/84800410 level 2
   bfe0fc10/84800800 level 2
   bfe0fc10/84800810 level 2
   bfe0fc10/84800c00 level 2
   bfe0fc10/84800c10 level 2
   bfe0fc10/84c00000 level 2
   bfe0fc10/84c00010 level 2
   bfe0fc10/84c00400 level 2
   bfe0fc10/84c00410 level 2
   bfe0fc10/84c00c00 level 2
   bfe0fc10/84c00c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_84800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0x84800000))
        return iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0xc4800000))
        return iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/a4800000 level 2
   bfe0fc10/a4800010 level 2
   bfe0fc10/a4800400 level 2
   bfe0fc10/a4800410 level 2
   bfe0fc10/a4800800 level 2
   bfe0fc10/a4800810 level 2
   bfe0fc10/a4800c00 level 2
   bfe0fc10/a4800c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_a4800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa4800000))
        return iemDecodeA64_ld1rqh_z_p_br_contiguous(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4800000))
        return iemDecodeA64_st3q_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/ac800000 level 2
   bfe0fc10/ac800010 level 2
   bfe0fc10/ac800400 level 2
   bfe0fc10/ac800410 level 2
   bfe0fc10/ac800800 level 2
   bfe0fc10/ac800810 level 2
   bfe0fc10/ac800c00 level 2
   bfe0fc10/ac800c10 level 2
   bfe0fc10/ac802800 level 2
   bfe0fc10/ac802810 level 2
   bfe0fc10/ac808000 level 2
   bfe0fc10/ac808010 level 2
   bfe0fc10/ac808400 level 2
   bfe0fc10/ac808410 level 2
   bfe0fc10/ac808800 level 2
   bfe0fc10/ac808810 level 2
   bfe0fc10/ac808c00 level 2
   bfe0fc10/ac808c10 level 2
   bfe0fc10/ac80a000 level 2
   bfe0fc10/ac80a010 level 2
   bfe0fc10/ac80a400 level 2
   bfe0fc10/ac80a410 level 2
   bfe0fc10/ac80a800 level 2
   bfe0fc10/ac80a810 level 2
   bfe0fc10/ac80ac00 level 2
   bfe0fc10/ac80ac10 level 2
   bfe0fc10/ac80b000 level 2
   bfe0fc10/ac80b010 level 2
   bfe0fc10/ac80b400 level 2
   bfe0fc10/ac80b410 level 2
   bfe0fc10/ac80b800 level 2
   bfe0fc10/ac80b810 level 2
   bfe0fc10/ac80bc00 level 2
   bfe0fc10/ac80bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_ac800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xac800000))
        return iemDecodeA64_STP_Q_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xec800000))
        return iemDecodeA64_STTP_Q_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4800000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%31 (0xa) multi-if=%50 (0x10) reuse=%31 (0xa) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04800000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04800000_2,
        iemDecodeA64_bfe0fc10_04800000_2,
        iemDecodeA64_bfe0fc10_0c800000_2,
        iemDecodeA64_bfe0fc10_0c800000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24800000_2,
        iemDecodeA64_bfe0fc10_24800010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4800000_2,
        iemDecodeA64_bfe0fc10_a4800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/04800400 level 2
   bfe0fc10/04800410 level 2
   mask=0x400f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%75 (0x18) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04800400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x400f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4800400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%31 (0xa) multi-if=%50 (0x10) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04800400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04800400_2,
        iemDecodeA64_bfe0fc10_04800400_2,
        iemDecodeA64_bfe0fc10_0c800000_2,
        iemDecodeA64_bfe0fc10_0c800000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24800000_2,
        iemDecodeA64_bfe0fc10_24800010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4800000_2,
        iemDecodeA64_bfe0fc10_a4800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/04800800 level 2
   bfe0fc10/04800810 level 2
   mask=0x400f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%75 (0x18) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04800800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
        iemDecodeA64_sqdmlalbt_z_zzz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x400f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4800800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04800800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04800800_2,
        iemDecodeA64_bfe0fc10_04800800_2,
        iemDecodeA64_bfe0fc10_0c800000_2,
        iemDecodeA64_bfe0fc10_0c800000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24800000_2,
        iemDecodeA64_bfe0fc10_24800010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4800000_2,
        iemDecodeA64_bfe0fc10_a4800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/04800c00 level 2
   bfe0fc10/04800c10 level 2
   mask=0x400f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%75 (0x18) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04800c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x400f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4800c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%31 (0xa) multi-if=%50 (0x10) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04800c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04800c00_2,
        iemDecodeA64_bfe0fc10_04800c00_2,
        iemDecodeA64_bfe0fc10_0c800000_2,
        iemDecodeA64_bfe0fc10_0c800000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24800000_2,
        iemDecodeA64_bfe0fc10_24800010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4800000_2,
        iemDecodeA64_bfe0fc10_a4800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/24801000 level 2
   f7e0fc10/24801400 level 2
   f7e0fc10/24801c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_24801000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000000))
        return iemDecodeA64_cmphs_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c800000))
        return iemDecodeA64_STP_S_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/24801010 level 2
   f7e0fc10/24801410 level 2
   f7e0fc10/24801c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_24801010_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000010))
        return iemDecodeA64_cmphi_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2c800000))
        return iemDecodeA64_STP_S_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/34801000 level 2
   f7e0fc10/34801010 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_34801000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c800000))
        return iemDecodeA64_STUR_Q_ldst_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/64801000 level 2
   f7e0fc10/64801010 level 2
   f7e0fc10/64801400 level 2
   f7e0fc10/64801410 level 2
   f7e0fc10/64801c00 level 2
   f7e0fc10/64801c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_64801000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6c800000))
        return iemDecodeA64_STP_D_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/a4801000 level 2
   f7e0fc10/a4801010 level 2
   f7e0fc10/a4801400 level 2
   f7e0fc10/a4801410 level 2
   f7e0fc10/a4801c00 level 2
   f7e0fc10/a4801c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_a4801000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xac800000))
        return iemDecodeA64_STP_Q_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa4800000))
        return iemDecodeA64_ld1rqh_z_p_br_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/e4801000 level 2
   f7e0fc10/e4801010 level 2
   f7e0fc10/e4801400 level 2
   f7e0fc10/e4801410 level 2
   f7e0fc10/e4801c00 level 2
   f7e0fc10/e4801c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_e4801000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xec800000))
        return iemDecodeA64_STTP_Q_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4800000))
        return iemDecodeA64_st3q_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4801000/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%38 (0xc) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04801000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24801000_2,
        iemDecodeA64_f7e0fc10_24801010_2,
        iemDecodeA64_f7e0fc10_34801000_2,
        iemDecodeA64_f7e0fc10_34801000_2,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64801000_2,
        iemDecodeA64_f7e0fc10_64801000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_a4801000_2,
        iemDecodeA64_f7e0fc10_a4801000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4801000_2,
        iemDecodeA64_f7e0fc10_e4801000_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/34801400 level 2
   f7e0fc10/34801410 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_34801400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c800400))
        return iemDecodeA64_STR_Q_ldst_immpost(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4801400/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04801400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24801000_2,
        iemDecodeA64_f7e0fc10_24801010_2,
        iemDecodeA64_f7e0fc10_34801400_2,
        iemDecodeA64_f7e0fc10_34801400_2,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64801000_2,
        iemDecodeA64_f7e0fc10_64801000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_a4801000_2,
        iemDecodeA64_f7e0fc10_a4801000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4801000_2,
        iemDecodeA64_f7e0fc10_e4801000_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* efe0fc10/04801800 level 2
   efe0fc10/04801810 level 2
   mask=0x100f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%75 (0x18) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_04801800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x100f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000010)) /* bit 28 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* efe0fc10/24801800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_24801800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000000))
        return iemDecodeA64_cmphs_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/24801810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_24801810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000010))
        return iemDecodeA64_cmphi_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/44801800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_44801800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20f000)) == UINT32_C(0x44001000))
        return iemDecodeA64_cdot_z_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/44801810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_44801810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20f000)) == UINT32_C(0x44001000))
        return iemDecodeA64_cdot_z_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/84801800 level 2
   efe0fc10/84801810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_84801800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0x84800000))
        return iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/a4801800 level 2
   efe0fc10/a4801810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_a4801800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb4000000))
        return iemDecodeA64_CBZ_64_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa4800000))
        return iemDecodeA64_ld1rqh_z_p_br_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4801800/0xe8000010
   mask=0xe8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%62 (0x14) multi-if=%25 (0x8) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04801800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_efe0fc10_04801800_2,
        iemDecodeA64_efe0fc10_04801800_2,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_efe0fc10_24801800_2,
        iemDecodeA64_efe0fc10_24801810_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_efe0fc10_44801800_2,
        iemDecodeA64_efe0fc10_44801810_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_efe0fc10_84801800_2,
        iemDecodeA64_efe0fc10_84801800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_efe0fc10_a4801800_2,
        iemDecodeA64_efe0fc10_a4801800_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_bi_contiguous,
        iemDecodeA64_st3q_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_STTP_Q_ldstpair_post,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xe8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000002)) /* bit 27 L 1 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001c)) /* bit 29 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/34801c00 level 2
   f7e0fc10/34801c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_34801c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c800c00))
        return iemDecodeA64_STR_Q_ldst_immpre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4801c00/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04801c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_ffe0fc00_04000000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24801000_2,
        iemDecodeA64_f7e0fc10_24801010_2,
        iemDecodeA64_f7e0fc10_34801c00_2,
        iemDecodeA64_f7e0fc10_34801c00_2,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64801000_2,
        iemDecodeA64_f7e0fc10_64801000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_a4801000_2,
        iemDecodeA64_f7e0fc10_a4801000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4801000_2,
        iemDecodeA64_f7e0fc10_e4801000_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0c802000 level 2
   ffe0fc00/4c802000 level 2
   ffe0fc00/0c802400 level 2
   ffe0fc00/4c802400 level 2
   bfe0fc10/0c802800 level 2
   bfe0fc10/0c802810 level 2
   ffe0fc00/0c802c00 level 2
   ffe0fc00/4c802c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0c802000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0c802000))
        return iemDecodeA64_ST1_asisdlsep_R4_r4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c9f2000))
        return iemDecodeA64_ST1_asisdlsep_I4_i4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4802000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04802000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ffe0fc00_0c802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ffe0fc00_0c802000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4802400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04802400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ffe0fc00_0c802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ffe0fc00_0c802000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff6fc10/04802800 level 3
   fff6fc10/04802810 level 3
   fff6fc10/04803800 level 3
   fff6fc10/04803810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff6fc10_04802800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04002000))
        return iemDecodeA64_saddv_r_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04012000))
        return iemDecodeA64_uaddv_r_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04082000))
        return iemDecodeA64_smaxv_r_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04092000))
        return iemDecodeA64_umaxv_r_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff6fc10/04822800 level 3
   fff6fc10/04822810 level 3
   fff6fc10/04823800 level 3
   fff6fc10/04823810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff6fc10_04822800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040a2000))
        return iemDecodeA64_sminv_r_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040b2000))
        return iemDecodeA64_uminv_r_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff6fc10/04842800 level 3
   fff6fc10/04842810 level 3
   fff6fc10/04843800 level 3
   fff6fc10/04843810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff6fc10_04842800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04052000))
        return iemDecodeA64_addqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040c2000))
        return iemDecodeA64_smaxqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040d2000))
        return iemDecodeA64_umaxqv_z_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff6fc10/04862800 level 3
   fff6fc10/04862810 level 3
   fff6fc10/04863800 level 3
   fff6fc10/04863810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff6fc10_04862800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040e2000))
        return iemDecodeA64_sminqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x040f2000))
        return iemDecodeA64_uminqv_z_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff6fc10/04902800 level 3
   fff6fc10/04902810 level 3
   fff6fc10/04903800 level 3
   fff6fc10/04903810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff6fc10_04902800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ee000)) == UINT32_C(0x04102000))
        return iemDecodeA64_movprfx_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04182000))
        return iemDecodeA64_orv_r_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04192000))
        return iemDecodeA64_eorv_r_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff6fc10/04942800 level 3
   fff6fc10/04942810 level 3
   fff6fc10/04943800 level 3
   fff6fc10/04943810 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff6fc10_04942800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x041c2000))
        return iemDecodeA64_orqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x041d2000))
        return iemDecodeA64_eorqv_z_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/04802800 level 2
   bfe0fc10/04802810 level 2
   mask=0x40160000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04802800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff6fc10_04802800_3,
        iemDecodeA64_fff6fc10_04822800_3,
        iemDecodeA64_fff6fc10_04842800_3,
        iemDecodeA64_fff6fc10_04862800_3,
        iemDecodeA64_fff6fc10_04902800_3,
        iemDecodeA64_andv_r_p_z,
        iemDecodeA64_fff6fc10_04942800_3,
        iemDecodeA64_andqv_z_p_z,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_cmla_z_zzz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x40160000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/24802800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24802800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24002000))
        return iemDecodeA64_cmpeq_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/24802810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24802810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24002010))
        return iemDecodeA64_cmpne_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/84802800 level 2
   bfe0fc10/84802810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_84802800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0x84802000))
        return iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0xc4802000))
        return iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/a4802800 level 2
   bfe0fc10/a4802810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_a4802800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe4802000))
        return iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4802000))
        return iemDecodeA64_ld1rqh_z_p_bi_u16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4802800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%41 (0xd) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04802800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04802800_2,
        iemDecodeA64_bfe0fc10_04802800_2,
        iemDecodeA64_ffe0fc00_0c802000_2,
        iemDecodeA64_ffe0fc00_0c802000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24802800_2,
        iemDecodeA64_bfe0fc10_24802810_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_84802800_2,
        iemDecodeA64_bfe0fc10_84802800_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4802800_2,
        iemDecodeA64_bfe0fc10_a4802800_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4802c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04802c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ffe0fc00_0c802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ffe0fc00_0c802000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4803000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04803000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4803400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04803400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* efe0fc10/04803800 level 2
   efe0fc10/04803810 level 2
   mask=0x10160000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%38 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_04803800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff6fc10_04802800_3,
        iemDecodeA64_fff6fc10_04822800_3,
        iemDecodeA64_fff6fc10_04842800_3,
        iemDecodeA64_fff6fc10_04862800_3,
        iemDecodeA64_fff6fc10_04902800_3,
        iemDecodeA64_andv_r_p_z,
        iemDecodeA64_fff6fc10_04942800_3,
        iemDecodeA64_andqv_z_p_z,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x10160000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000008)) /* bit 28 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* efe0fc10/24803800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_24803800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24002000))
        return iemDecodeA64_cmpeq_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/24803810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_24803810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24002010))
        return iemDecodeA64_cmpne_p_p_zw(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/44803800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_44803800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20f000)) == UINT32_C(0x44003000))
        return iemDecodeA64_sqrdcmlah_z_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/44803810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_44803810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20f000)) == UINT32_C(0x44003000))
        return iemDecodeA64_sqrdcmlah_z_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/84803800 level 2
   efe0fc10/84803810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_84803800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0x84802000))
        return iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe0fc10/a4803800 level 2
   efe0fc10/a4803810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe0fc10_a4803800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb4000000))
        return iemDecodeA64_CBZ_64_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4802000))
        return iemDecodeA64_ld1rqh_z_p_bi_u16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4803800/0xe8000010
   mask=0xe8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%62 (0x14) multi-if=%25 (0x8) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04803800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_efe0fc10_04803800_2,
        iemDecodeA64_efe0fc10_04803800_2,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_efe0fc10_24803800_2,
        iemDecodeA64_efe0fc10_24803810_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_efe0fc10_44803800_2,
        iemDecodeA64_efe0fc10_44803810_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_efe0fc10_84803800_2,
        iemDecodeA64_efe0fc10_84803800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_efe0fc10_a4803800_2,
        iemDecodeA64_efe0fc10_a4803800_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_STTP_Q_ldstpair_post,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xe8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000002)) /* bit 27 L 1 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001c)) /* bit 29 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4803c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04803c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1rqh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0c804000 level 2
   ffe0fc00/4c804000 level 2
   ffe0fc00/0c804400 level 2
   ffe0fc00/4c804400 level 2
   ffe0fc00/0c804800 level 2
   ffe0fc00/4c804800 level 2
   ffe0fc00/0c804c00 level 2
   ffe0fc00/4c804c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0c804000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0c804000))
        return iemDecodeA64_ST3_asisdlsep_R3_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c9f4000))
        return iemDecodeA64_ST3_asisdlsep_I3_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4804000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04804000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c804000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_smlalb_z_zzz,
        iemDecodeA64_ffe0fc00_0c804000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4804400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04804400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c804000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_smlalt_z_zzz,
        iemDecodeA64_ffe0fc00_0c804000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4804800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04804800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c804000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalb_z_zzz,
        iemDecodeA64_ffe0fc00_0c804000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4804c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04804c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c804000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_umlalt_z_zzz,
        iemDecodeA64_ffe0fc00_0c804000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4805000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04805000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_smlslb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4805400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04805400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_smlslt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4805800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04805800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlslb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4805c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04805c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_umlslt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0c806000 level 2
   ffe0fc00/4c806000 level 2
   ffe0fc00/0c806400 level 2
   ffe0fc00/4c806400 level 2
   ffe0fc00/0c806800 level 2
   ffe0fc00/4c806800 level 2
   ffe0fc00/0c806c00 level 2
   ffe0fc00/4c806c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0c806000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0c806000))
        return iemDecodeA64_ST1_asisdlsep_R3_r3(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c9f6000))
        return iemDecodeA64_ST1_asisdlsep_I3_i3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4806000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04806000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c806000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_sqdmlalb_z_zzz,
        iemDecodeA64_ffe0fc00_0c806000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4806400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04806400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c806000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_sqdmlalt_z_zzz,
        iemDecodeA64_ffe0fc00_0c806000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4806800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04806800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c806000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslb_z_zzz,
        iemDecodeA64_ffe0fc00_0c806000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4806c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04806c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c806000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_sqdmlslt_z_zzz,
        iemDecodeA64_ffe0fc00_0c806000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0c807000 level 2
   ffe0fc00/4c807000 level 2
   ffe0fc00/0c807400 level 2
   ffe0fc00/4c807400 level 2
   ffe0fc00/0c807800 level 2
   ffe0fc00/4c807800 level 2
   ffe0fc00/0c807c00 level 2
   ffe0fc00/4c807c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0c807000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0c807000))
        return iemDecodeA64_ST1_asisdlsep_R1_r1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c9f7000))
        return iemDecodeA64_ST1_asisdlsep_I1_i1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4807000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04807000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c807000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_sqrdmlah_z_zzz,
        iemDecodeA64_ffe0fc00_0c807000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4807400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04807400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c807000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_sqrdmlsh_z_zzz,
        iemDecodeA64_ffe0fc00_0c807000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4807800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04807800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c807000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_usdot_z_zzz_s,
        iemDecodeA64_ffe0fc00_0c807000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4807c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04807c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0c807000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0c807000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1sw_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/0c808000 level 2
   bfe0fc10/0c808010 level 2
   bfe0fc10/0c808400 level 2
   bfe0fc10/0c808410 level 2
   bfe0fc10/0c808800 level 2
   bfe0fc10/0c808810 level 2
   bfe0fc10/0c808c00 level 2
   bfe0fc10/0c808c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_0c808000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0c808000))
        return iemDecodeA64_ST2_asisdlsep_R2_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c9f8000))
        return iemDecodeA64_ST2_asisdlsep_I2_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64898000 level 3
   ffebfc10/64898010 level 3
   ffebfc10/64898400 level 3
   ffebfc10/64898410 level 3
   ffebfc10/64898800 level 3
   ffebfc10/64898810 level 3
   ffebfc10/64898c00 level 3
   ffebfc10/64898c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64898000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64198000))
        return iemDecodeA64_frinta_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x649d8000))
        return iemDecodeA64_scvtf_z_p_z_w2sz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/648b8000 level 3
   ffebfc10/648b8010 level 3
   ffebfc10/648b8400 level 3
   ffebfc10/648b8410 level 3
   ffebfc10/648b8800 level 3
   ffebfc10/648b8810 level 3
   ffebfc10/648b8c00 level 3
   ffebfc10/648b8c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_648b8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x641b8000))
        return iemDecodeA64_frecpx_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x649f8000))
        return iemDecodeA64_fcvtzs_z_p_z_s2wz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/24808000 level 2
   bfe0fc10/24808400 level 2
   bfe0fc10/24808800 level 2
   bfe0fc10/24808c00 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%75 (0xc) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24808000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_ffebfc10_64008000_3,
        iemDecodeA64_ffebfc10_64018000_3,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_frintn_z_p_z_z,
        iemDecodeA64_ffebfc10_64898000_3,
        iemDecodeA64_fcvt_z_p_z_s2hz,
        iemDecodeA64_ffebfc10_648b8000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/24808010 level 2
   bfe0fc10/24808410 level 2
   bfe0fc10/24808810 level 2
   bfe0fc10/24808c10 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%75 (0xc) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24808010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_ffebfc10_64008000_3,
        iemDecodeA64_ffebfc10_64018000_3,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_frintn_z_p_z_z,
        iemDecodeA64_ffebfc10_64898000_3,
        iemDecodeA64_fcvt_z_p_z_s2hz,
        iemDecodeA64_ffebfc10_648b8000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/84808000 level 2
   bfe0fc10/84808010 level 2
   bfe0fc10/84808400 level 2
   bfe0fc10/84808410 level 2
   bfe0fc10/84808800 level 2
   bfe0fc10/84808810 level 2
   bfe0fc10/84808c00 level 2
   bfe0fc10/84808c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_84808000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0x84808000))
        return iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4808000))
        return iemDecodeA64_ldnt1sh_z_p_ar_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4808000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%38 (0xc) multi-if=%38 (0xc) reuse=%38 (0xc) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04808000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_0c808000_2,
        iemDecodeA64_bfe0fc10_0c808000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24808000_2,
        iemDecodeA64_bfe0fc10_24808010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_bfe0fc10_84808000_2,
        iemDecodeA64_bfe0fc10_84808000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4808400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%38 (0xc) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04808400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_0c808000_2,
        iemDecodeA64_bfe0fc10_0c808000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24808000_2,
        iemDecodeA64_bfe0fc10_24808010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_bfe0fc10_84808000_2,
        iemDecodeA64_bfe0fc10_84808000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4808800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%31 (0xa) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04808800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_0c808000_2,
        iemDecodeA64_bfe0fc10_0c808000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24808000_2,
        iemDecodeA64_bfe0fc10_24808010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_84808000_2,
        iemDecodeA64_bfe0fc10_84808000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4808c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%38 (0xc) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04808c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_0c808000_2,
        iemDecodeA64_bfe0fc10_0c808000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24808000_2,
        iemDecodeA64_bfe0fc10_24808010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_bfe0fc10_84808000_2,
        iemDecodeA64_bfe0fc10_84808000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/1c809000 level 2
   dfe0fc10/1c809010 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_1c809000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x1c000000))
        return iemDecodeA64_LDR_S_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c800000))
        return iemDecodeA64_STUR_Q_ldst_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/44809000 level 2
   dfe0fc10/44809010 level 2
   dfe0fc10/44809400 level 2
   dfe0fc10/44809410 level 2
   dfe0fc10/44809800 level 2
   dfe0fc10/44809810 level 2
   dfe0fc10/44809c00 level 2
   dfe0fc10/44809c10 level 2
   mask=0x201f0000 entries=0x40 children=0x29 valid=%64 (0x29) leaf=%64 (0x29) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_44809000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_srshl_z_p_zz,
        iemDecodeA64_urshl_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_srshlr_z_p_zz,
        iemDecodeA64_urshlr_z_p_zz,
        iemDecodeA64_sqshl_z_p_zz,
        iemDecodeA64_uqshl_z_p_zz,
        iemDecodeA64_sqrshl_z_p_zz,
        iemDecodeA64_uqrshl_z_p_zz,
        iemDecodeA64_sqshlr_z_p_zz,
        iemDecodeA64_uqshlr_z_p_zz,
        iemDecodeA64_sqrshlr_z_p_zz,
        iemDecodeA64_uqrshlr_z_p_zz,
        iemDecodeA64_shadd_z_p_zz,
        iemDecodeA64_uhadd_z_p_zz,
        iemDecodeA64_shsub_z_p_zz,
        iemDecodeA64_uhsub_z_p_zz,
        iemDecodeA64_srhadd_z_p_zz,
        iemDecodeA64_urhadd_z_p_zz,
        iemDecodeA64_shsubr_z_p_zz,
        iemDecodeA64_uhsubr_z_p_zz,
        iemDecodeA64_sqadd_z_p_zz,
        iemDecodeA64_uqadd_z_p_zz,
        iemDecodeA64_sqsub_z_p_zz,
        iemDecodeA64_uqsub_z_p_zz,
        iemDecodeA64_suqadd_z_p_zz,
        iemDecodeA64_usqadd_z_p_zz,
        iemDecodeA64_sqsubr_z_p_zz,
        iemDecodeA64_uqsubr_z_p_zz,
        iemDecodeA64_fcadd_z_p_zz,
        iemDecodeA64_fcadd_z_p_zz,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_faddp_z_p_zz,
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_fmaxnmp_z_p_zz,
        iemDecodeA64_fminnmp_z_p_zz,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_frintn_z_p_z_z,
        iemDecodeA64_frinta_z_p_z_z,
        iemDecodeA64_fcvt_z_p_z_s2hz,
        iemDecodeA64_frecpx_z_p_z_z,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_scvtf_z_p_z_w2sz,
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_fcvtzs_z_p_z_s2wz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x201f0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000020)) /* bit 29 L 1 -> 5 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/c4809000 level 2
   dfe0fc10/c4809010 level 2
   dfe0fc10/c4809400 level 2
   dfe0fc10/c4809410 level 2
   dfe0fc10/c4809800 level 2
   dfe0fc10/c4809810 level 2
   dfe0fc10/c4809c00 level 2
   dfe0fc10/c4809c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_c4809000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe4808000))
        return iemDecodeA64_st1h_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4808000))
        return iemDecodeA64_ldnt1sh_z_p_ar_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4809000/0xd8000010
   mask=0xd8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%50 (0x10) multi-if=%25 (0x8) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04809000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dfe0fc10_04009800_2,
        iemDecodeA64_dfe0fc10_04009810_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_1c809000_2,
        iemDecodeA64_dfe0fc10_1c809000_2,
        iemDecodeA64_dfe0fc10_44809000_2,
        iemDecodeA64_dfe0fc10_44809000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_B_only_condbranch,
        iemDecodeA64_BC_only_condbranch,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_dfe0fc10_c4809000_2,
        iemDecodeA64_dfe0fc10_c4809000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/1c809400 level 2
   dfe0fc10/1c809410 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_1c809400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x1c000000))
        return iemDecodeA64_LDR_S_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c800400))
        return iemDecodeA64_STR_Q_ldst_immpost(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4809400/0xd8000010
   mask=0xd8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%50 (0x10) multi-if=%25 (0x8) reuse=%34 (0xb) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04809400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dfe0fc10_04009800_2,
        iemDecodeA64_dfe0fc10_04009810_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_1c809400_2,
        iemDecodeA64_dfe0fc10_1c809400_2,
        iemDecodeA64_dfe0fc10_44809000_2,
        iemDecodeA64_dfe0fc10_44809000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_B_only_condbranch,
        iemDecodeA64_BC_only_condbranch,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_dfe0fc10_c4809000_2,
        iemDecodeA64_dfe0fc10_c4809000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4809800/0xd8000010
   mask=0xd8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%56 (0x12) multi-if=%19 (0x6) reuse=%31 (0xa) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04809800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dfe0fc10_04009800_2,
        iemDecodeA64_dfe0fc10_04009810_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_dfe0fc10_44809000_2,
        iemDecodeA64_dfe0fc10_44809000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_B_only_condbranch,
        iemDecodeA64_BC_only_condbranch,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_dfe0fc10_c4809000_2,
        iemDecodeA64_dfe0fc10_c4809000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/1c809c00 level 2
   dfe0fc10/1c809c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_1c809c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x1c000000))
        return iemDecodeA64_LDR_S_loadlit(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3c800c00))
        return iemDecodeA64_STR_Q_ldst_immpre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4809c00/0xd8000010
   mask=0xd8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%50 (0x10) multi-if=%25 (0x8) reuse=%34 (0xb) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04809c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dfe0fc10_04009800_2,
        iemDecodeA64_dfe0fc10_04009810_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_1c809c00_2,
        iemDecodeA64_dfe0fc10_1c809c00_2,
        iemDecodeA64_dfe0fc10_44809000_2,
        iemDecodeA64_dfe0fc10_44809000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_B_only_condbranch,
        iemDecodeA64_BC_only_condbranch,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1sh_z_p_ar_s_x32_unscaled,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_dfe0fc10_c4809000_2,
        iemDecodeA64_dfe0fc10_c4809000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/0c80a000 level 2
   bfe0fc10/0c80a010 level 2
   bfe0fc10/0c80a400 level 2
   bfe0fc10/0c80a410 level 2
   bfe0fc10/0c80a800 level 2
   bfe0fc10/0c80a810 level 2
   bfe0fc10/0c80ac00 level 2
   bfe0fc10/0c80ac10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_0c80a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0c80a000))
        return iemDecodeA64_ST1_asisdlsep_R2_r2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0c9fa000))
        return iemDecodeA64_ST1_asisdlsep_I2_i2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/6480a000 level 3
   ffebfc10/6480a010 level 3
   ffebfc10/6480a400 level 3
   ffebfc10/6480a410 level 3
   ffebfc10/6480a800 level 3
   ffebfc10/6480a810 level 3
   ffebfc10/6480ac00 level 3
   ffebfc10/6480ac10 level 3
   ffebfc10/6480b000 level 3
   ffebfc10/6480b010 level 3
   ffebfc10/6480b400 level 3
   ffebfc10/6480b410 level 3
   ffebfc10/6480b800 level 3
   ffebfc10/6480b810 level 3
   ffebfc10/6480bc00 level 3
   ffebfc10/6480bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_6480a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6410a000))
        return iemDecodeA64_faddqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6414a000))
        return iemDecodeA64_fmaxnmqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6480a000))
        return iemDecodeA64_fcvtnt_z_p_z_s2hz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/6481a000 level 3
   ffebfc10/6481a010 level 3
   ffebfc10/6481a400 level 3
   ffebfc10/6481a410 level 3
   ffebfc10/6481a800 level 3
   ffebfc10/6481a810 level 3
   ffebfc10/6481ac00 level 3
   ffebfc10/6481ac10 level 3
   ffebfc10/6481b000 level 3
   ffebfc10/6481b010 level 3
   ffebfc10/6481b400 level 3
   ffebfc10/6481b410 level 3
   ffebfc10/6481b800 level 3
   ffebfc10/6481b810 level 3
   ffebfc10/6481bc00 level 3
   ffebfc10/6481bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_6481a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6415a000))
        return iemDecodeA64_fminnmqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6481a000))
        return iemDecodeA64_fcvtlt_z_p_z_h2sz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/6482a000 level 3
   ffebfc10/6482a010 level 3
   ffebfc10/6482a400 level 3
   ffebfc10/6482a410 level 3
   ffebfc10/6482a800 level 3
   ffebfc10/6482a810 level 3
   ffebfc10/6482ac00 level 3
   ffebfc10/6482ac10 level 3
   ffebfc10/6482b000 level 3
   ffebfc10/6482b010 level 3
   ffebfc10/6482b400 level 3
   ffebfc10/6482b410 level 3
   ffebfc10/6482b800 level 3
   ffebfc10/6482b810 level 3
   ffebfc10/6482bc00 level 3
   ffebfc10/6482bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_6482a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6416a000))
        return iemDecodeA64_fmaxqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6482a000))
        return iemDecodeA64_bfcvtnt_z_p_z_s2bfz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/6488a000 level 3
   ffebfc10/6488a010 level 3
   ffebfc10/6488a400 level 3
   ffebfc10/6488a410 level 3
   ffebfc10/6488a800 level 3
   ffebfc10/6488a810 level 3
   ffebfc10/6488ac00 level 3
   ffebfc10/6488ac10 level 3
   ffebfc10/6488b000 level 3
   ffebfc10/6488b010 level 3
   ffebfc10/6488b400 level 3
   ffebfc10/6488b410 level 3
   ffebfc10/6488b800 level 3
   ffebfc10/6488b810 level 3
   ffebfc10/6488bc00 level 3
   ffebfc10/6488bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_6488a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6418a000))
        return iemDecodeA64_frintp_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6488a000))
        return iemDecodeA64_fcvtnt_z_p_z_s2h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/6489a000 level 3
   ffebfc10/6489a010 level 3
   ffebfc10/6489a400 level 3
   ffebfc10/6489a410 level 3
   ffebfc10/6489a800 level 3
   ffebfc10/6489a810 level 3
   ffebfc10/6489ac00 level 3
   ffebfc10/6489ac10 level 3
   ffebfc10/6489b000 level 3
   ffebfc10/6489b010 level 3
   ffebfc10/6489b400 level 3
   ffebfc10/6489b410 level 3
   ffebfc10/6489b800 level 3
   ffebfc10/6489b810 level 3
   ffebfc10/6489bc00 level 3
   ffebfc10/6489bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_6489a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6489a000))
        return iemDecodeA64_fcvtlt_z_p_z_h2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x649da000))
        return iemDecodeA64_ucvtf_z_p_z_w2sz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/648aa000 level 3
   ffebfc10/648aa010 level 3
   ffebfc10/648aa400 level 3
   ffebfc10/648aa410 level 3
   ffebfc10/648aa800 level 3
   ffebfc10/648aa810 level 3
   ffebfc10/648aac00 level 3
   ffebfc10/648aac10 level 3
   ffebfc10/648ab000 level 3
   ffebfc10/648ab010 level 3
   ffebfc10/648ab400 level 3
   ffebfc10/648ab410 level 3
   ffebfc10/648ab800 level 3
   ffebfc10/648ab810 level 3
   ffebfc10/648abc00 level 3
   ffebfc10/648abc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_648aa000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x648aa000))
        return iemDecodeA64_bfcvtnt_z_p_z_s2bf(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x649aa000))
        return iemDecodeA64_fcvt_z_p_z_h2sz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/648ba000 level 3
   ffebfc10/648ba010 level 3
   ffebfc10/648ba400 level 3
   ffebfc10/648ba410 level 3
   ffebfc10/648ba800 level 3
   ffebfc10/648ba810 level 3
   ffebfc10/648bac00 level 3
   ffebfc10/648bac10 level 3
   ffebfc10/648bb000 level 3
   ffebfc10/648bb010 level 3
   ffebfc10/648bb400 level 3
   ffebfc10/648bb410 level 3
   ffebfc10/648bb800 level 3
   ffebfc10/648bb810 level 3
   ffebfc10/648bbc00 level 3
   ffebfc10/648bbc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_648ba000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x641ba000))
        return iemDecodeA64_fsqrt_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x649fa000))
        return iemDecodeA64_fcvtzu_z_p_z_s2wz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/2480a000 level 2
   bfe0fc10/2480a400 level 2
   bfe0fc10/2480a800 level 2
   bfe0fc10/2480ac00 level 2
   bfe0fc10/2480b000 level 2
   bfe0fc10/2480b400 level 2
   bfe0fc10/2480b800 level 2
   bfe0fc10/2480bc00 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%56 (0x9) multi-if=%44 (0x7) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2480a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_ffebfc10_6480a000_3,
        iemDecodeA64_ffebfc10_6481a000_3,
        iemDecodeA64_ffebfc10_6482a000_3,
        iemDecodeA64_fminqv_z_p_z,
        iemDecodeA64_ffebfc10_6488a000_3,
        iemDecodeA64_ffebfc10_6489a000_3,
        iemDecodeA64_ffebfc10_648aa000_3,
        iemDecodeA64_ffebfc10_648ba000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/2480a010 level 2
   bfe0fc10/2480a410 level 2
   bfe0fc10/2480a810 level 2
   bfe0fc10/2480ac10 level 2
   bfe0fc10/2480b010 level 2
   bfe0fc10/2480b410 level 2
   bfe0fc10/2480b810 level 2
   bfe0fc10/2480bc10 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%56 (0x9) multi-if=%44 (0x7) reuse=%44 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2480a010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_ffebfc10_6480a000_3,
        iemDecodeA64_ffebfc10_6481a000_3,
        iemDecodeA64_ffebfc10_6482a000_3,
        iemDecodeA64_fminqv_z_p_z,
        iemDecodeA64_ffebfc10_6488a000_3,
        iemDecodeA64_ffebfc10_6489a000_3,
        iemDecodeA64_ffebfc10_648aa000_3,
        iemDecodeA64_ffebfc10_648ba000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/a480a000 level 2
   bfe0fc10/a480a010 level 2
   bfe0fc10/a480a400 level 2
   bfe0fc10/a480a410 level 2
   bfe0fc10/a480a800 level 2
   bfe0fc10/a480a810 level 2
   bfe0fc10/a480ac00 level 2
   bfe0fc10/a480ac10 level 2
   bfe0fc10/a480b000 level 2
   bfe0fc10/a480b010 level 2
   bfe0fc10/a480b400 level 2
   bfe0fc10/a480b410 level 2
   bfe0fc10/a480b800 level 2
   bfe0fc10/a480b810 level 2
   bfe0fc10/a480bc00 level 2
   bfe0fc10/a480bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_a480a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe480a000))
        return iemDecodeA64_st1h_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa480a000))
        return iemDecodeA64_ld1sw_z_p_bi_s64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa490a000))
        return iemDecodeA64_ldnf1sw_z_p_bi_s64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480a000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%38 (0xc) multi-if=%38 (0xc) reuse=%38 (0xc) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0c80a000_2,
        iemDecodeA64_bfe0fc10_0c80a000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2480a000_2,
        iemDecodeA64_bfe0fc10_2480a010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480a400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%38 (0xc) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0c80a000_2,
        iemDecodeA64_bfe0fc10_0c80a000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2480a000_2,
        iemDecodeA64_bfe0fc10_2480a010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480a800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%31 (0xa) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0c80a000_2,
        iemDecodeA64_bfe0fc10_0c80a000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2480a000_2,
        iemDecodeA64_bfe0fc10_2480a010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480ac00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%38 (0xc) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0c80a000_2,
        iemDecodeA64_bfe0fc10_0c80a000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2480a000_2,
        iemDecodeA64_bfe0fc10_2480a010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480b000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%38 (0xc) multi-if=%31 (0xa) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2480a000_2,
        iemDecodeA64_bfe0fc10_2480a010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480b400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%38 (0xc) multi-if=%31 (0xa) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2480a000_2,
        iemDecodeA64_bfe0fc10_2480a010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480b800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%31 (0xa) multi-if=%31 (0xa) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2480a000_2,
        iemDecodeA64_bfe0fc10_2480a010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480bc00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%38 (0xc) multi-if=%31 (0xa) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_2480a000_2,
        iemDecodeA64_bfe0fc10_2480a010_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_bfe0fc10_2c800000_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_ldnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_a480a000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_bfe0fc10_ac800000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/6480c000 level 2
   ffe0fc00/6480c400 level 2
   ffe0fc00/6480c800 level 2
   ffe0fc00/6480cc00 level 2
   ffe0fc00/6480d000 level 2
   ffe0fc00/6480d400 level 2
   ffe0fc00/6480d800 level 2
   ffe0fc00/6480dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6480c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6418c000))
        return iemDecodeA64_frintm_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6419c000))
        return iemDecodeA64_frintx_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x649ac000))
        return iemDecodeA64_bfcvt_z_p_z_s2bfz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_sclamp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480c000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_uclamp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480c000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sdot_z32_zzzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480c000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_udot_z32_zzzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480c000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480c000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480c000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480c000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480c000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldnt1h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1h_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/6480e000 level 2
   ffe0fc00/6480e400 level 2
   ffe0fc00/6480e800 level 2
   ffe0fc00/6480ec00 level 2
   ffe0fc00/6480f000 level 2
   ffe0fc00/6480f400 level 2
   ffe0fc00/6480f800 level 2
   ffe0fc00/6480fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6480e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6418e000))
        return iemDecodeA64_frintz_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6419e000))
        return iemDecodeA64_frinti_z_p_z_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a480e000 level 2
   ffe0fc00/a480e400 level 2
   ffe0fc00/a480e800 level 2
   ffe0fc00/a480ec00 level 2
   ffe0fc00/a480f000 level 2
   ffe0fc00/a480f400 level 2
   ffe0fc00/a480f800 level 2
   ffe0fc00/a480fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a480e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa480e000))
        return iemDecodeA64_ldnt1h_z_p_bi_contiguous(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa490e000))
        return iemDecodeA64_ld2q_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/e480e000 level 2
   ffe0fc00/e480e400 level 2
   ffe0fc00/e480e800 level 2
   ffe0fc00/e480ec00 level 2
   ffe0fc00/e480f000 level 2
   ffe0fc00/e480f400 level 2
   ffe0fc00/e480f800 level 2
   ffe0fc00/e480fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e480e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff90e000)) == UINT32_C(0xe480e000))
        return iemDecodeA64_st1h_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe490e000))
        return iemDecodeA64_stnt1h_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%50 (0x10) multi-if=%16 (0x5) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_zipq1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480e000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a480e000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e480e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%50 (0x10) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_zipq2_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480e000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a480e000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e480e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_uzpq1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480e000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a480e000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e480e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%50 (0x10) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_uzpq2_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480e000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a480e000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e480e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STUR_Q_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480e000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a480e000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e480e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480e000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a480e000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e480e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_tblq_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480e000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a480e000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e480e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x480fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0480fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_6480e000_2,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a480e000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfh_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e480e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/d4a00000 level 2
   ffe0fc00/d4a00400 level 2
   ffe0fc00/d4a00800 level 2
   ffe0fc00/d4a00c00 level 2
   ffe0fc00/d4a01000 level 2
   ffe0fc00/d4a01400 level 2
   ffe0fc00/d4a01800 level 2
   ffe0fc00/d4a01c00 level 2
   ffe0fc00/d4a02000 level 2
   ffe0fc00/d4a02400 level 2
   ffe0fc00/d4a02800 level 2
   ffe0fc00/d4a02c00 level 2
   ffe0fc00/d4a03000 level 2
   ffe0fc00/d4a03400 level 2
   ffe0fc00/d4a03800 level 2
   ffe0fc00/d4a03c00 level 2
   ffe0fc00/d4a04000 level 2
   ffe0fc00/d4a04400 level 2
   ffe0fc00/d4a04800 level 2
   ffe0fc00/d4a04c00 level 2
   ffe0fc00/d4a05000 level 2
   ffe0fc00/d4a05400 level 2
   ffe0fc00/d4a05800 level 2
   ffe0fc00/d4a05c00 level 2
   ffe0fc00/d4a06000 level 2
   ffe0fc00/d4a06400 level 2
   ffe0fc00/d4a06800 level 2
   ffe0fc00/d4a06c00 level 2
   ffe0fc00/d4a07000 level 2
   ffe0fc00/d4a07400 level 2
   ffe0fc00/d4a07800 level 2
   ffe0fc00/d4a07c00 level 2
   ffe0fc00/d4a08000 level 2
   ffe0fc00/d4a08400 level 2
   ffe0fc00/d4a08800 level 2
   ffe0fc00/d4a08c00 level 2
   ffe0fc00/d4a09000 level 2
   ffe0fc00/d4a09400 level 2
   ffe0fc00/d4a09800 level 2
   ffe0fc00/d4a09c00 level 2
   ffe0fc00/d4a0a000 level 2
   ffe0fc00/d4a0a400 level 2
   ffe0fc00/d4a0a800 level 2
   ffe0fc00/d4a0ac00 level 2
   ffe0fc00/d4a0b000 level 2
   ffe0fc00/d4a0b400 level 2
   ffe0fc00/d4a0b800 level 2
   ffe0fc00/d4a0bc00 level 2
   ffe0fc00/d4a0c000 level 2
   ffe0fc00/d4a0c400 level 2
   ffe0fc00/d4a0c800 level 2
   ffe0fc00/d4a0cc00 level 2
   ffe0fc00/d4a0d000 level 2
   ffe0fc00/d4a0d400 level 2
   ffe0fc00/d4a0d800 level 2
   ffe0fc00/d4a0dc00 level 2
   ffe0fc00/d4a0e000 level 2
   ffe0fc00/d4a0e400 level 2
   ffe0fc00/d4a0e800 level 2
   ffe0fc00/d4a0ec00 level 2
   ffe0fc00/d4a0f000 level 2
   ffe0fc00/d4a0f400 level 2
   ffe0fc00/d4a0f800 level 2
   ffe0fc00/d4a0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d4a00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4a00001))
        return iemDecodeA64_DCPS1_DC_exception(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4a00002))
        return iemDecodeA64_DCPS2_DC_exception(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0xd4a00003))
        return iemDecodeA64_DCPS3_DC_exception(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a00000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_add_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFADDA_16,
        iemDecodeA64_sdot_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmla_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFADDA_16,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFADDA_32,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFADDA_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a00400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_udot_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmls_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a00800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_mla_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a00c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_mls_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a01000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqadd_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmlah_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_zzzi_h,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a01400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqadd_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmlsh_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_zzzi_h,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a01800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqsub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_usdot_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_zzzi_h,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a01c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqsub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sudot_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_zzzi_h,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3q_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a02000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlalb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmul_z_zzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a02400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlalt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fclamp_z_zz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a02800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_sqdmlalb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a02c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlalt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a03000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a03400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_xar_z_zzi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a03800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_sqdmlslb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a03c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a03c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bsl2n_z_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1roh_z_p_bi_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a04000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ii,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMAXA_16,
        iemDecodeA64_cdot_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalb_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMAXA_16,
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMAXA_32,
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMAXA_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a04400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cdot_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalt_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a04800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ir,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_cdot_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalb_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a04c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_rr,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cdot_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalt_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a05000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_rdvl_r_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMINA_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalt_z_z8z8z8i,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMINA_16,
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMINA_32,
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMINA_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a05400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_rdvl_r_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalt_z_z8z8z8i,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a05800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_rdsvl_r_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalt_z_z8z8z8i,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a05c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_rdsvl_r_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalt_z_z8z8z8i,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a06000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mul_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMAXNMA_16,
        iemDecodeA64_cmla_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlslb_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMAXNMA_16,
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMAXNMA_32,
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMAXNMA_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a06400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cmla_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlslt_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a06800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_cmla_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlslb_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a06c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_umulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cmla_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlslt_z_zzzi_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a07000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqdmulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMINNMA_16,
        iemDecodeA64_sqrdcmlah_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMINNMA_16,
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMINNMA_32,
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMINNMA_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a07400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqrdmulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdcmlah_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a07800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_sqrdcmlah_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a07c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdcmlah_z_zzzi_h,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u16,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2h_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a08000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlalb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalb_z_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a08400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsr_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlalt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalt_z_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a08800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_smlalb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalb_z_z8z8z8,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a08c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsl_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlalt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a09000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a09400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a09800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a09800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_umlalb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalt_z_z8z8z8,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a09c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a09c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsl_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a4a0a000 level 2
   ffe0fc00/a4a0a400 level 2
   ffe0fc00/a4a0a800 level 2
   ffe0fc00/a4a0ac00 level 2
   ffe0fc00/a4a0b000 level 2
   ffe0fc00/a4a0b400 level 2
   ffe0fc00/a4a0b800 level 2
   ffe0fc00/a4a0bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a4a0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4a0a000))
        return iemDecodeA64_ld1h_z_p_bi_u16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4b0a000))
        return iemDecodeA64_ldnf1h_z_p_bi_u16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_sd_same_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlslb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlslb_z_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_sd_same_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlslt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlslt_z_zzz,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0a800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_sd_same_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_smlslb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_sd_same_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlslt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ftssel_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlslb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0b400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x4a0bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlslt_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fexpa_z_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_umlslb_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04a0c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04a0c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0c000))
        return iemDecodeA64_sqincw_z_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04b0c000))
        return iemDecodeA64_incw_z_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04a0c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smullb_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltb_z32_z8z8z8i,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04a0c400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04a0c400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0c400))
        return iemDecodeA64_uqincw_z_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04b0c400))
        return iemDecodeA64_decw_z_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04a0c400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smullt_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltb_z32_z8z8z8i,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqdecw_z_zs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_smullb_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltb_z32_z8z8z8i,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqdecw_z_zs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smullt_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltb_z32_z8z8z8i,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umullb_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x4a0dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umullt_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_umullb_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04a0e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04a0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0e000))
        return iemDecodeA64_cntw_r_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04b0e000))
        return iemDecodeA64_incw_r_rs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/e4a0e000 level 2
   ffe0fc00/e4a0e400 level 2
   ffe0fc00/e4a0e800 level 2
   ffe0fc00/e4a0ec00 level 2
   ffe0fc00/e4a0f000 level 2
   ffe0fc00/e4a0f400 level 2
   ffe0fc00/e4a0f800 level 2
   ffe0fc00/e4a0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e4a0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff90e000)) == UINT32_C(0xe480e000))
        return iemDecodeA64_st1h_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4b0e000))
        return iemDecodeA64_st2h_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04a0e000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmullb_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4a0e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_decw_r_rs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmullt_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmmla_z_zzz_s,
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4a0e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_sqdmullb_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4a0e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmullt_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4a0e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04a0f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04a0f000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0f000))
        return iemDecodeA64_sqincw_r_rs_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04b0f000))
        return iemDecodeA64_sqincw_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04a0f000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmulh_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4a0e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04a0f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04a0f400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0f400))
        return iemDecodeA64_uqincw_r_rs_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04b0f400))
        return iemDecodeA64_uqincw_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04a0f400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmulh_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4a0e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04a0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04a0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0f800))
        return iemDecodeA64_sqdecw_r_rs_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04b0f800))
        return iemDecodeA64_sqdecw_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%50 (0x10) multi-if=%16 (0x5) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04a0f800_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_regoff,
        iemDecodeA64_mul_z_zzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4a0e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04a0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04a0fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04a0fc00))
        return iemDecodeA64_uqdecw_r_rs_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04b0fc00))
        return iemDecodeA64_uqdecw_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4a0fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%16 (0x5) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04a0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04a0fc00_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_STP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld2h_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d4a00000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4a0e000_2,
        iemDecodeA64_STTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc10/04c40000 level 3
   ffeffc10/04c40010 level 3
   ffeffc10/04c40400 level 3
   ffeffc10/04c40410 level 3
   ffeffc10/04c40800 level 3
   ffeffc10/04c40810 level 3
   ffeffc10/04c40c00 level 3
   ffeffc10/04c40c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc10_04c40000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04140000))
        return iemDecodeA64_sdiv_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x04c40000))
        return iemDecodeA64_addpt_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc10/04c50000 level 3
   ffeffc10/04c50010 level 3
   ffeffc10/04c50400 level 3
   ffeffc10/04c50410 level 3
   ffeffc10/04c50800 level 3
   ffeffc10/04c50810 level 3
   ffeffc10/04c50c00 level 3
   ffeffc10/04c50c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc10_04c50000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x04150000))
        return iemDecodeA64_udiv_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x04c50000))
        return iemDecodeA64_subpt_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/04c00000 level 2
   bfe0fc10/04c00010 level 2
   mask=0x400f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%69 (0x16) multi-if=%25 (0x8) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04c00000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_ffeffc10_04c40000_3,
        iemDecodeA64_ffeffc10_04c50000_3,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
        iemDecodeA64_sdot_z_zzz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x400f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/0cc00000 level 2
   bfe0fc10/0cc00010 level 2
   bfe0fc10/0cc00400 level 2
   bfe0fc10/0cc00410 level 2
   bfe0fc10/0cc00c00 level 2
   bfe0fc10/0cc00c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_0cc00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc00000))
        return iemDecodeA64_LD4_asisdlsep_R4_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdf0000))
        return iemDecodeA64_LD4_asisdlsep_I4_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/2cc00000 level 2
   bfe0fc10/2cc00010 level 2
   bfe0fc10/2cc00400 level 2
   bfe0fc10/2cc00410 level 2
   bfe0fc10/2cc00c00 level 2
   bfe0fc10/2cc00c10 level 2
   bfe0fc10/2cc08000 level 2
   bfe0fc10/2cc08010 level 2
   bfe0fc10/2cc08400 level 2
   bfe0fc10/2cc08410 level 2
   bfe0fc10/2cc08800 level 2
   bfe0fc10/2cc08810 level 2
   bfe0fc10/2cc08c00 level 2
   bfe0fc10/2cc08c10 level 2
   bfe0fc10/2cc09000 level 2
   bfe0fc10/2cc09010 level 2
   bfe0fc10/2cc09400 level 2
   bfe0fc10/2cc09410 level 2
   bfe0fc10/2cc09c00 level 2
   bfe0fc10/2cc09c10 level 2
   bfe0fc10/2cc0a000 level 2
   bfe0fc10/2cc0a010 level 2
   bfe0fc10/2cc0a400 level 2
   bfe0fc10/2cc0a410 level 2
   bfe0fc10/2cc0a800 level 2
   bfe0fc10/2cc0a810 level 2
   bfe0fc10/2cc0ac00 level 2
   bfe0fc10/2cc0ac10 level 2
   bfe0fc10/2cc0b000 level 2
   bfe0fc10/2cc0b010 level 2
   bfe0fc10/2cc0b400 level 2
   bfe0fc10/2cc0b410 level 2
   bfe0fc10/2cc0b800 level 2
   bfe0fc10/2cc0b810 level 2
   bfe0fc10/2cc0bc00 level 2
   bfe0fc10/2cc0bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_2cc00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2cc00000))
        return iemDecodeA64_LDP_S_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6cc00000))
        return iemDecodeA64_LDP_D_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/34c00000 level 2
   bfe0fc10/34c00010 level 2
   bfe0fc10/34c00400 level 2
   bfe0fc10/34c00410 level 2
   bfe0fc10/34c00c00 level 2
   bfe0fc10/34c00c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_34c00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74c00000))
        return iemDecodeA64_CBEQ_32_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/acc00000 level 2
   bfe0fc10/acc00010 level 2
   bfe0fc10/acc00400 level 2
   bfe0fc10/acc00410 level 2
   bfe0fc10/acc00c00 level 2
   bfe0fc10/acc00c10 level 2
   bfe0fc10/acc08000 level 2
   bfe0fc10/acc08010 level 2
   bfe0fc10/acc08400 level 2
   bfe0fc10/acc08410 level 2
   bfe0fc10/acc08800 level 2
   bfe0fc10/acc08810 level 2
   bfe0fc10/acc08c00 level 2
   bfe0fc10/acc08c10 level 2
   bfe0fc10/acc09000 level 2
   bfe0fc10/acc09010 level 2
   bfe0fc10/acc09400 level 2
   bfe0fc10/acc09410 level 2
   bfe0fc10/acc09c00 level 2
   bfe0fc10/acc09c10 level 2
   bfe0fc10/acc0a000 level 2
   bfe0fc10/acc0a010 level 2
   bfe0fc10/acc0a400 level 2
   bfe0fc10/acc0a410 level 2
   bfe0fc10/acc0a800 level 2
   bfe0fc10/acc0a810 level 2
   bfe0fc10/acc0ac00 level 2
   bfe0fc10/acc0ac10 level 2
   bfe0fc10/acc0b000 level 2
   bfe0fc10/acc0b010 level 2
   bfe0fc10/acc0b400 level 2
   bfe0fc10/acc0b410 level 2
   bfe0fc10/acc0b800 level 2
   bfe0fc10/acc0b810 level 2
   bfe0fc10/acc0bc00 level 2
   bfe0fc10/acc0bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_acc00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xacc00000))
        return iemDecodeA64_LDP_Q_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xecc00000))
        return iemDecodeA64_LDTP_Q_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/b4c00000 level 2
   bfe0fc10/b4c00010 level 2
   bfe0fc10/b4c00400 level 2
   bfe0fc10/b4c00410 level 2
   bfe0fc10/b4c00c00 level 2
   bfe0fc10/b4c00c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_b4c00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb4000000))
        return iemDecodeA64_CBZ_64_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0xf4c00000))
        return iemDecodeA64_CBEQ_64_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c00000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%25 (0x8) multi-if=%56 (0x12) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04c00000_2,
        iemDecodeA64_bfe0fc10_04c00000_2,
        iemDecodeA64_bfe0fc10_0cc00000_2,
        iemDecodeA64_bfe0fc10_0cc00000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24800000_2,
        iemDecodeA64_bfe0fc10_24800010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c00000_2,
        iemDecodeA64_bfe0fc10_34c00000_2,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st4q_z_p_bi_contiguous,
        iemDecodeA64_st4q_z_p_bi_contiguous,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_b4c00000_2,
        iemDecodeA64_bfe0fc10_b4c00000_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/04c00400 level 2
   bfe0fc10/04c00410 level 2
   mask=0x400f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%69 (0x16) multi-if=%25 (0x8) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04c00400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_ffeffc10_04c40000_3,
        iemDecodeA64_ffeffc10_04c50000_3,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
        iemDecodeA64_udot_z_zzz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x400f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c00400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%25 (0x8) multi-if=%56 (0x12) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04c00400_2,
        iemDecodeA64_bfe0fc10_04c00400_2,
        iemDecodeA64_bfe0fc10_0cc00000_2,
        iemDecodeA64_bfe0fc10_0cc00000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24800000_2,
        iemDecodeA64_bfe0fc10_24800010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c00000_2,
        iemDecodeA64_bfe0fc10_34c00000_2,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st4q_z_p_bi_contiguous,
        iemDecodeA64_st4q_z_p_bi_contiguous,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_b4c00000_2,
        iemDecodeA64_bfe0fc10_b4c00000_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/04c00800 level 2
   mask=0x200f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%69 (0x16) multi-if=%25 (0x8) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_04c00800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_ffeffc10_04c40000_3,
        iemDecodeA64_ffeffc10_04c50000_3,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
        iemDecodeA64_cmphs_p_p_zz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x200f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000010)) /* bit 29 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/04c00810 level 2
   mask=0x200f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%69 (0x16) multi-if=%25 (0x8) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_04c00810_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_ffeffc10_04c40000_3,
        iemDecodeA64_ffeffc10_04c50000_3,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
        iemDecodeA64_cmphi_p_p_zz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x200f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000010)) /* bit 29 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/0cc00800 level 2
   dfe0fc10/0cc00810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_0cc00800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc00000))
        return iemDecodeA64_LD4_asisdlsep_R4_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdf0000))
        return iemDecodeA64_LD4_asisdlsep_I4_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2cc00000))
        return iemDecodeA64_LDP_S_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/44c00800 level 2
   dfe0fc10/44c00810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_44c00800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x44000800))
        return iemDecodeA64_sqdmlalbt_z_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/4cc00800 level 2
   dfe0fc10/4cc00810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_4cc00800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc00000))
        return iemDecodeA64_LD4_asisdlsep_R4_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdf0000))
        return iemDecodeA64_LD4_asisdlsep_I4_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6cc00000))
        return iemDecodeA64_LDP_D_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/54c00800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_54c00800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74c00000))
        return iemDecodeA64_CBEQ_32_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/54c00810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_54c00810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74c00000))
        return iemDecodeA64_CBEQ_32_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/c4c00800 level 2
   dfe0fc10/c4c00810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_c4c00800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0xc4800000))
        return iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4c00000))
        return iemDecodeA64_st4q_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c00800/0xd8000010
   mask=0xd8000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%44 (0xe) multi-if=%44 (0xe) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dfe0fc10_04c00800_2,
        iemDecodeA64_dfe0fc10_04c00810_2,
        iemDecodeA64_dfe0fc10_0cc00800_2,
        iemDecodeA64_dfe0fc10_0cc00800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_dfe0fc10_44c00800_2,
        iemDecodeA64_dfe0fc10_44c00800_2,
        iemDecodeA64_dfe0fc10_4cc00800_2,
        iemDecodeA64_dfe0fc10_4cc00800_2,
        iemDecodeA64_dfe0fc10_54c00800_2,
        iemDecodeA64_dfe0fc10_54c00810_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_dfe0fc10_c4c00800_2,
        iemDecodeA64_dfe0fc10_c4c00800_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/04c00c00 level 2
   bfe0fc10/04c00c10 level 2
   mask=0x400f0000 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%69 (0x16) multi-if=%25 (0x8) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_04c00c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc10_04800000_3,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_ffeffc10_04830000_3,
        iemDecodeA64_ffeffc10_04c40000_3,
        iemDecodeA64_ffeffc10_04c50000_3,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_ffeffc10_04880000_3,
        iemDecodeA64_ffeffc10_04890000_3,
        iemDecodeA64_ffeffc10_048a0000_3,
        iemDecodeA64_ffeffc10_048b0000_3,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
        iemDecodeA64_sqdmlslbt_z_zzz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x400f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c00c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%25 (0x8) multi-if=%56 (0x12) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04c00c00_2,
        iemDecodeA64_bfe0fc10_04c00c00_2,
        iemDecodeA64_bfe0fc10_0cc00000_2,
        iemDecodeA64_bfe0fc10_0cc00000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24800000_2,
        iemDecodeA64_bfe0fc10_24800010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c00000_2,
        iemDecodeA64_bfe0fc10_34c00000_2,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_bfe0fc10_84800000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st4q_z_p_bi_contiguous,
        iemDecodeA64_st4q_z_p_bi_contiguous,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_b4c00000_2,
        iemDecodeA64_bfe0fc10_b4c00000_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/04c01000 level 2
   f7e0fc10/04c01010 level 2
   f7e0fc10/04c01400 level 2
   f7e0fc10/04c01410 level 2
   f7e0fc10/04c01800 level 2
   f7e0fc10/04c01810 level 2
   f7e0fc10/04c01c00 level 2
   f7e0fc10/04c01c10 level 2
   mask=0x1f0000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%69 (0x16) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_04c01000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_add_z_p_zz,
        iemDecodeA64_sub_z_p_zz,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_subr_z_p_zz,
        iemDecodeA64_addpt_z_p_zz,
        iemDecodeA64_subpt_z_p_zz,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smax_z_p_zz,
        iemDecodeA64_umax_z_p_zz,
        iemDecodeA64_smin_z_p_zz,
        iemDecodeA64_umin_z_p_zz,
        iemDecodeA64_sabd_z_p_zz,
        iemDecodeA64_uabd_z_p_zz,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_mul_z_p_zz,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_smulh_z_p_zz,
        iemDecodeA64_umulh_z_p_zz,
        iemDecodeA64_sdiv_z_p_zz,
        iemDecodeA64_udiv_z_p_zz,
        iemDecodeA64_sdivr_z_p_zz,
        iemDecodeA64_udivr_z_p_zz,
        iemDecodeA64_orr_z_p_zz,
        iemDecodeA64_eor_z_p_zz,
        iemDecodeA64_and_z_p_zz,
        iemDecodeA64_bic_z_p_zz,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/24c01000 level 2
   f7e0fc10/24c01400 level 2
   f7e0fc10/24c01800 level 2
   f7e0fc10/24c01c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_24c01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000000))
        return iemDecodeA64_cmphs_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2cc00000))
        return iemDecodeA64_LDP_S_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/24c01010 level 2
   f7e0fc10/24c01410 level 2
   f7e0fc10/24c01810 level 2
   f7e0fc10/24c01c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_24c01010_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x24000010))
        return iemDecodeA64_cmphi_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2cc00000))
        return iemDecodeA64_LDP_S_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/34c01000 level 2
   f7e0fc10/34c01010 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_34c01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3cc00000))
        return iemDecodeA64_LDUR_Q_ldst_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/64c01000 level 2
   f7e0fc10/64c01010 level 2
   f7e0fc10/64c01400 level 2
   f7e0fc10/64c01410 level 2
   f7e0fc10/64c01800 level 2
   f7e0fc10/64c01810 level 2
   f7e0fc10/64c01c00 level 2
   f7e0fc10/64c01c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_64c01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff208000)) == UINT32_C(0x64000000))
        return iemDecodeA64_fcmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6cc00000))
        return iemDecodeA64_LDP_D_ldstpair_post(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/e4c01000 level 2
   f7e0fc10/e4c01010 level 2
   f7e0fc10/e4c01400 level 2
   f7e0fc10/e4c01410 level 2
   f7e0fc10/e4c01800 level 2
   f7e0fc10/e4c01810 level 2
   f7e0fc10/e4c01c00 level 2
   f7e0fc10/e4c01c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_e4c01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xecc00000))
        return iemDecodeA64_LDTP_Q_ldstpair_post(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4c00000))
        return iemDecodeA64_st4q_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c01000/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%44 (0xe) multi-if=%44 (0xe) reuse=%31 (0xa) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc10_04c01000_2,
        iemDecodeA64_f7e0fc10_04c01000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24c01000_2,
        iemDecodeA64_f7e0fc10_24c01010_2,
        iemDecodeA64_f7e0fc10_34c01000_2,
        iemDecodeA64_f7e0fc10_34c01000_2,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64c01000_2,
        iemDecodeA64_f7e0fc10_64c01000_2,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4c01000_2,
        iemDecodeA64_f7e0fc10_e4c01000_2,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_CBEQ_64_regs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/34c01400 level 2
   f7e0fc10/34c01410 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_34c01400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3cc00400))
        return iemDecodeA64_LDR_Q_ldst_immpost(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c01400/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%44 (0xe) multi-if=%44 (0xe) reuse=%47 (0xf) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc10_04c01000_2,
        iemDecodeA64_f7e0fc10_04c01000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24c01000_2,
        iemDecodeA64_f7e0fc10_24c01010_2,
        iemDecodeA64_f7e0fc10_34c01400_2,
        iemDecodeA64_f7e0fc10_34c01400_2,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64c01000_2,
        iemDecodeA64_f7e0fc10_64c01000_2,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4c01000_2,
        iemDecodeA64_f7e0fc10_e4c01000_2,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_CBEQ_64_regs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c01800/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%50 (0x10) multi-if=%38 (0xc) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc10_04c01000_2,
        iemDecodeA64_f7e0fc10_04c01000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24c01000_2,
        iemDecodeA64_f7e0fc10_24c01010_2,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64c01000_2,
        iemDecodeA64_f7e0fc10_64c01000_2,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4c01000_2,
        iemDecodeA64_f7e0fc10_e4c01000_2,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_CBEQ_64_regs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/34c01c00 level 2
   f7e0fc10/34c01c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_34c01c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x3cc00c00))
        return iemDecodeA64_LDR_Q_ldst_immpre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c01c00/0xf0000010
   mask=0xf0000010 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%44 (0xe) multi-if=%44 (0xe) reuse=%47 (0xf) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc10_04c01000_2,
        iemDecodeA64_f7e0fc10_04c01000_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_14000800_2,
        iemDecodeA64_f7e0fc10_24c01000_2,
        iemDecodeA64_f7e0fc10_24c01010_2,
        iemDecodeA64_f7e0fc10_34c01c00_2,
        iemDecodeA64_f7e0fc10_34c01c00_2,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_cdot_z_zzz,
        iemDecodeA64_f7e0fc10_54000800_2,
        iemDecodeA64_f7e0fc10_54000810_2,
        iemDecodeA64_f7e0fc10_64c01000_2,
        iemDecodeA64_f7e0fc10_64c01000_2,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_f7e0fc10_94000800_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_f7e0fc10_e4c01000_2,
        iemDecodeA64_f7e0fc10_e4c01000_2,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_CBEQ_64_regs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0cc02000 level 2
   ffe0fc00/4cc02000 level 2
   ffe0fc00/0cc02400 level 2
   ffe0fc00/4cc02400 level 2
   ffe0fc00/0cc02800 level 2
   ffe0fc00/4cc02800 level 2
   ffe0fc00/0cc02c00 level 2
   ffe0fc00/4cc02c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0cc02000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc02000))
        return iemDecodeA64_LD1_asisdlsep_R4_r4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdf2000))
        return iemDecodeA64_LD1_asisdlsep_I4_i4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c02000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ffe0fc00_0cc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ffe0fc00_0cc02000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c02400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ffe0fc00_0cc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ffe0fc00_0cc02000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c02800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ffe0fc00_0cc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ffe0fc00_0cc02000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c02c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_ffe0fc00_0cc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_cmla_z_zzz,
        iemDecodeA64_ffe0fc00_0cc02000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c03000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c03400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c03800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c03c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c03c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04002000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24002000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_sqrdcmlah_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBEQ_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1h_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBEQ_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0cc04000 level 2
   ffe0fc00/4cc04000 level 2
   ffe0fc00/0cc04400 level 2
   ffe0fc00/4cc04400 level 2
   ffe0fc00/0cc04800 level 2
   ffe0fc00/4cc04800 level 2
   ffe0fc00/0cc04c00 level 2
   ffe0fc00/4cc04c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0cc04000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc04000))
        return iemDecodeA64_LD3_asisdlsep_R3_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdf4000))
        return iemDecodeA64_LD3_asisdlsep_I3_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c04000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_smlalb_z_zzz,
        iemDecodeA64_ffe0fc00_0cc04000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c04400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_smlalt_z_zzz,
        iemDecodeA64_ffe0fc00_0cc04000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c04800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalb_z_zzz,
        iemDecodeA64_ffe0fc00_0cc04000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c04c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_umlalt_z_zzz,
        iemDecodeA64_ffe0fc00_0cc04000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c05000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_smlslb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c05400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_smlslt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c05800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlslb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c05c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mla_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24004000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_umlslt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0cc06000 level 2
   ffe0fc00/4cc06000 level 2
   ffe0fc00/0cc06400 level 2
   ffe0fc00/4cc06400 level 2
   ffe0fc00/0cc06800 level 2
   ffe0fc00/4cc06800 level 2
   ffe0fc00/0cc06c00 level 2
   ffe0fc00/4cc06c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0cc06000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc06000))
        return iemDecodeA64_LD1_asisdlsep_R3_r3(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdf6000))
        return iemDecodeA64_LD1_asisdlsep_I3_i3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c06000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_sqdmlalb_z_zzz,
        iemDecodeA64_ffe0fc00_0cc06000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c06400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_sqdmlalt_z_zzz,
        iemDecodeA64_ffe0fc00_0cc06000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c06800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslb_z_zzz,
        iemDecodeA64_ffe0fc00_0cc06000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c06c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_sqdmlslt_z_zzz,
        iemDecodeA64_ffe0fc00_0cc06000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0cc07000 level 2
   ffe0fc00/4cc07000 level 2
   ffe0fc00/0cc07400 level 2
   ffe0fc00/4cc07400 level 2
   ffe0fc00/0cc07800 level 2
   ffe0fc00/4cc07800 level 2
   ffe0fc00/0cc07c00 level 2
   ffe0fc00/4cc07c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0cc07000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc07000))
        return iemDecodeA64_LD1_asisdlsep_R1_r1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdf7000))
        return iemDecodeA64_LD1_asisdlsep_I1_i1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c07000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc07000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_sqrdmlah_z_zzz,
        iemDecodeA64_ffe0fc00_0cc07000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c07400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc07000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_sqrdmlsh_z_zzz,
        iemDecodeA64_ffe0fc00_0cc07000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c07800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc07000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0cc07000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c07c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mls_z_p_zzz,
        iemDecodeA64_ffe0fc00_0cc07000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24006000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0cc07000_2,
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/0cc08000 level 2
   bfe0fc10/0cc08010 level 2
   bfe0fc10/0cc08400 level 2
   bfe0fc10/0cc08410 level 2
   bfe0fc10/0cc08800 level 2
   bfe0fc10/0cc08810 level 2
   bfe0fc10/0cc08c00 level 2
   bfe0fc10/0cc08c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_0cc08000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc08000))
        return iemDecodeA64_LD2_asisdlsep_R2_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdf8000))
        return iemDecodeA64_LD2_asisdlsep_I2_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64c88000 level 3
   ffebfc10/64c88010 level 3
   ffebfc10/64c88400 level 3
   ffebfc10/64c88410 level 3
   ffebfc10/64c88800 level 3
   ffebfc10/64c88810 level 3
   ffebfc10/64c88c00 level 3
   ffebfc10/64c88c10 level 3
   ffebfc10/64c89000 level 3
   ffebfc10/64c89010 level 3
   ffebfc10/64c89400 level 3
   ffebfc10/64c89410 level 3
   ffebfc10/64c89c00 level 3
   ffebfc10/64c89c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64c88000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64188000))
        return iemDecodeA64_frintn_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dc8000))
        return iemDecodeA64_scvtf_z_p_z_w2dz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64c98000 level 3
   ffebfc10/64c98010 level 3
   ffebfc10/64c98400 level 3
   ffebfc10/64c98410 level 3
   ffebfc10/64c98800 level 3
   ffebfc10/64c98810 level 3
   ffebfc10/64c98c00 level 3
   ffebfc10/64c98c10 level 3
   ffebfc10/64c99000 level 3
   ffebfc10/64c99010 level 3
   ffebfc10/64c99400 level 3
   ffebfc10/64c99410 level 3
   ffebfc10/64c99c00 level 3
   ffebfc10/64c99c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64c98000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x64198000))
        return iemDecodeA64_frinta_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dd8000))
        return iemDecodeA64_scvtf_z_p_z_x2sz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64ca8000 level 3
   ffebfc10/64ca8010 level 3
   ffebfc10/64ca8400 level 3
   ffebfc10/64ca8410 level 3
   ffebfc10/64ca8800 level 3
   ffebfc10/64ca8810 level 3
   ffebfc10/64ca8c00 level 3
   ffebfc10/64ca8c10 level 3
   ffebfc10/64ca9000 level 3
   ffebfc10/64ca9010 level 3
   ffebfc10/64ca9400 level 3
   ffebfc10/64ca9410 level 3
   ffebfc10/64ca9c00 level 3
   ffebfc10/64ca9c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64ca8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64da8000))
        return iemDecodeA64_fcvt_z_p_z_d2hz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64de8000))
        return iemDecodeA64_fcvtzs_z_p_z_d2wz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64cb8000 level 3
   ffebfc10/64cb8010 level 3
   ffebfc10/64cb8400 level 3
   ffebfc10/64cb8410 level 3
   ffebfc10/64cb8800 level 3
   ffebfc10/64cb8810 level 3
   ffebfc10/64cb8c00 level 3
   ffebfc10/64cb8c10 level 3
   ffebfc10/64cb9000 level 3
   ffebfc10/64cb9010 level 3
   ffebfc10/64cb9400 level 3
   ffebfc10/64cb9410 level 3
   ffebfc10/64cb9c00 level 3
   ffebfc10/64cb9c10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64cb8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x641b8000))
        return iemDecodeA64_frecpx_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64df8000))
        return iemDecodeA64_fcvtzs_z_p_z_s2xz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/24c08000 level 2
   bfe0fc10/24c08400 level 2
   bfe0fc10/24c08800 level 2
   bfe0fc10/24c08c00 level 2
   bfe0fc10/24c09000 level 2
   bfe0fc10/24c09400 level 2
   bfe0fc10/24c09c00 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24c08000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_cmpge_p_p_zz,
        iemDecodeA64_ffebfc10_64008000_3,
        iemDecodeA64_ffebfc10_64018000_3,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_ffebfc10_64c88000_3,
        iemDecodeA64_ffebfc10_64c98000_3,
        iemDecodeA64_ffebfc10_64ca8000_3,
        iemDecodeA64_ffebfc10_64cb8000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/24c08010 level 2
   bfe0fc10/24c08410 level 2
   bfe0fc10/24c08810 level 2
   bfe0fc10/24c08c10 level 2
   bfe0fc10/24c09010 level 2
   bfe0fc10/24c09410 level 2
   bfe0fc10/24c09c10 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%38 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24c08010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_cmpgt_p_p_zz,
        iemDecodeA64_ffebfc10_64008000_3,
        iemDecodeA64_ffebfc10_64018000_3,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_ffebfc10_64c88000_3,
        iemDecodeA64_ffebfc10_64c98000_3,
        iemDecodeA64_ffebfc10_64ca8000_3,
        iemDecodeA64_ffebfc10_64cb8000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/34c08000 level 2
   bfe0fc10/34c08010 level 2
   bfe0fc10/34c08400 level 2
   bfe0fc10/34c08410 level 2
   bfe0fc10/34c08800 level 2
   bfe0fc10/34c08810 level 2
   bfe0fc10/34c08c00 level 2
   bfe0fc10/34c08c10 level 2
   bfe0fc10/34c09000 level 2
   bfe0fc10/34c09010 level 2
   bfe0fc10/34c09400 level 2
   bfe0fc10/34c09410 level 2
   bfe0fc10/34c09c00 level 2
   bfe0fc10/34c09c10 level 2
   bfe0fc10/34c0a000 level 2
   bfe0fc10/34c0a010 level 2
   bfe0fc10/34c0a400 level 2
   bfe0fc10/34c0a410 level 2
   bfe0fc10/34c0a800 level 2
   bfe0fc10/34c0a810 level 2
   bfe0fc10/34c0ac00 level 2
   bfe0fc10/34c0ac10 level 2
   bfe0fc10/34c0b000 level 2
   bfe0fc10/34c0b010 level 2
   bfe0fc10/34c0b400 level 2
   bfe0fc10/34c0b410 level 2
   bfe0fc10/34c0b800 level 2
   bfe0fc10/34c0b810 level 2
   bfe0fc10/34c0bc00 level 2
   bfe0fc10/34c0bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_34c08000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x34000000))
        return iemDecodeA64_CBZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74c08000))
        return iemDecodeA64_CBBEQ_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/84c08000 level 2
   bfe0fc10/84c08010 level 2
   bfe0fc10/84c08400 level 2
   bfe0fc10/84c08410 level 2
   bfe0fc10/84c08800 level 2
   bfe0fc10/84c08810 level 2
   bfe0fc10/84c08c00 level 2
   bfe0fc10/84c08c10 level 2
   bfe0fc10/84c09000 level 2
   bfe0fc10/84c09010 level 2
   bfe0fc10/84c09400 level 2
   bfe0fc10/84c09410 level 2
   bfe0fc10/84c09c00 level 2
   bfe0fc10/84c09c10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_84c08000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x84c08000))
        return iemDecodeA64_ld1rsw_z_p_bi_s64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4c08000))
        return iemDecodeA64_ld1sh_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c08000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%31 (0xa) multi-if=%44 (0xe) reuse=%41 (0xd) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_0cc08000_2,
        iemDecodeA64_bfe0fc10_0cc08000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c08000_2,
        iemDecodeA64_bfe0fc10_24c08010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c08400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%31 (0xa) multi-if=%44 (0xe) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_0cc08000_2,
        iemDecodeA64_bfe0fc10_0cc08000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c08000_2,
        iemDecodeA64_bfe0fc10_24c08010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c08800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%44 (0xe) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_0cc08000_2,
        iemDecodeA64_bfe0fc10_0cc08000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c08000_2,
        iemDecodeA64_bfe0fc10_24c08010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c08c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%31 (0xa) multi-if=%44 (0xe) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_0cc08000_2,
        iemDecodeA64_bfe0fc10_0cc08000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c08000_2,
        iemDecodeA64_bfe0fc10_24c08010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c09000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%31 (0xa) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c08000_2,
        iemDecodeA64_bfe0fc10_24c08010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c09400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%31 (0xa) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c08000_2,
        iemDecodeA64_bfe0fc10_24c08010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/44c09800 level 2
   dfe0fc10/44c09810 level 2
   mask=0x201f0000 entries=0x40 children=0x2b valid=%67 (0x2b) leaf=%67 (0x2b) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_44c09800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_srshl_z_p_zz,
        iemDecodeA64_urshl_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_srshlr_z_p_zz,
        iemDecodeA64_urshlr_z_p_zz,
        iemDecodeA64_sqshl_z_p_zz,
        iemDecodeA64_uqshl_z_p_zz,
        iemDecodeA64_sqrshl_z_p_zz,
        iemDecodeA64_uqrshl_z_p_zz,
        iemDecodeA64_sqshlr_z_p_zz,
        iemDecodeA64_uqshlr_z_p_zz,
        iemDecodeA64_sqrshlr_z_p_zz,
        iemDecodeA64_uqrshlr_z_p_zz,
        iemDecodeA64_shadd_z_p_zz,
        iemDecodeA64_uhadd_z_p_zz,
        iemDecodeA64_shsub_z_p_zz,
        iemDecodeA64_uhsub_z_p_zz,
        iemDecodeA64_srhadd_z_p_zz,
        iemDecodeA64_urhadd_z_p_zz,
        iemDecodeA64_shsubr_z_p_zz,
        iemDecodeA64_uhsubr_z_p_zz,
        iemDecodeA64_sqadd_z_p_zz,
        iemDecodeA64_uqadd_z_p_zz,
        iemDecodeA64_sqsub_z_p_zz,
        iemDecodeA64_uqsub_z_p_zz,
        iemDecodeA64_suqadd_z_p_zz,
        iemDecodeA64_usqadd_z_p_zz,
        iemDecodeA64_sqsubr_z_p_zz,
        iemDecodeA64_uqsubr_z_p_zz,
        iemDecodeA64_fcadd_z_p_zz,
        iemDecodeA64_fcadd_z_p_zz,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_faddp_z_p_zz,
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_fmaxnmp_z_p_zz,
        iemDecodeA64_fminnmp_z_p_zz,
        iemDecodeA64_fmaxp_z_p_zz,
        iemDecodeA64_fminp_z_p_zz,
        iemDecodeA64_frintn_z_p_z_z,
        iemDecodeA64_frinta_z_p_z_z,
        iemDecodeA64_fcvt_z_p_z_d2hz,
        iemDecodeA64_frecpx_z_p_z_z,
        iemDecodeA64_scvtf_z_p_z_w2dz,
        iemDecodeA64_scvtf_z_p_z_x2sz,
        iemDecodeA64_fcvtzs_z_p_z_d2wz,
        iemDecodeA64_fcvtzs_z_p_z_s2xz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x201f0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000020)) /* bit 29 L 1 -> 5 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe0fc10/54c09800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_54c09800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000000))
        return iemDecodeA64_B_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74c08000))
        return iemDecodeA64_CBBEQ_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/54c09810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_54c09810_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000010)) == UINT32_C(0x54000010))
        return iemDecodeA64_BC_only_condbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0c000)) == UINT32_C(0x74c08000))
        return iemDecodeA64_CBBEQ_8_regs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe0fc10/c4c09800 level 2
   dfe0fc10/c4c09810 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe0fc10_c4c09800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe4c08000))
        return iemDecodeA64_st1h_z_p_bz_s_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4c08000))
        return iemDecodeA64_ld1sh_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c09800/0xd8000010
   mask=0xd8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%50 (0x10) multi-if=%25 (0x8) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c09800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dfe0fc10_04009800_2,
        iemDecodeA64_dfe0fc10_04009810_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_dfe0fc10_14009800_2,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_dfe0fc10_44c09800_2,
        iemDecodeA64_dfe0fc10_44c09800_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_dfe0fc10_54c09800_2,
        iemDecodeA64_dfe0fc10_54c09810_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_dfe0fc10_94009800_2,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_dfe0fc10_c4c09800_2,
        iemDecodeA64_dfe0fc10_c4c09800_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c09c00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%31 (0xa) multi-if=%38 (0xc) reuse=%50 (0x10) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c09c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_bfe0fc10_04008000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c08000_2,
        iemDecodeA64_bfe0fc10_24c08010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_bfe0fc10_84c08000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/0cc0a000 level 2
   bfe0fc10/0cc0a010 level 2
   bfe0fc10/0cc0a400 level 2
   bfe0fc10/0cc0a410 level 2
   bfe0fc10/0cc0a800 level 2
   bfe0fc10/0cc0a810 level 2
   bfe0fc10/0cc0ac00 level 2
   bfe0fc10/0cc0ac10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_0cc0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0cc0a000))
        return iemDecodeA64_LD1_asisdlsep_R2_r2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0cdfa000))
        return iemDecodeA64_LD1_asisdlsep_I2_i2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64c2a000 level 3
   ffebfc10/64c2a010 level 3
   ffebfc10/64c2a400 level 3
   ffebfc10/64c2a410 level 3
   ffebfc10/64c2a800 level 3
   ffebfc10/64c2a810 level 3
   ffebfc10/64c2ac00 level 3
   ffebfc10/64c2ac10 level 3
   ffebfc10/64c2b000 level 3
   ffebfc10/64c2b010 level 3
   ffebfc10/64c2b400 level 3
   ffebfc10/64c2b410 level 3
   ffebfc10/64c2b800 level 3
   ffebfc10/64c2b810 level 3
   ffebfc10/64c2bc00 level 3
   ffebfc10/64c2bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64c2a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6416a000))
        return iemDecodeA64_fmaxqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64c2a000))
        return iemDecodeA64_fcvtnt_z_p_z_d2sz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64c3a000 level 3
   ffebfc10/64c3a010 level 3
   ffebfc10/64c3a400 level 3
   ffebfc10/64c3a410 level 3
   ffebfc10/64c3a800 level 3
   ffebfc10/64c3a810 level 3
   ffebfc10/64c3ac00 level 3
   ffebfc10/64c3ac10 level 3
   ffebfc10/64c3b000 level 3
   ffebfc10/64c3b010 level 3
   ffebfc10/64c3b400 level 3
   ffebfc10/64c3b410 level 3
   ffebfc10/64c3b800 level 3
   ffebfc10/64c3b810 level 3
   ffebfc10/64c3bc00 level 3
   ffebfc10/64c3bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64c3a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6417a000))
        return iemDecodeA64_fminqv_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64c3a000))
        return iemDecodeA64_fcvtlt_z_p_z_s2dz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64c8a000 level 3
   ffebfc10/64c8a010 level 3
   ffebfc10/64c8a400 level 3
   ffebfc10/64c8a410 level 3
   ffebfc10/64c8a800 level 3
   ffebfc10/64c8a810 level 3
   ffebfc10/64c8ac00 level 3
   ffebfc10/64c8ac10 level 3
   ffebfc10/64c8b000 level 3
   ffebfc10/64c8b010 level 3
   ffebfc10/64c8b400 level 3
   ffebfc10/64c8b410 level 3
   ffebfc10/64c8b800 level 3
   ffebfc10/64c8b810 level 3
   ffebfc10/64c8bc00 level 3
   ffebfc10/64c8bc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64c8a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6418a000))
        return iemDecodeA64_frintp_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dca000))
        return iemDecodeA64_ucvtf_z_p_z_w2dz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64caa000 level 3
   ffebfc10/64caa010 level 3
   ffebfc10/64caa400 level 3
   ffebfc10/64caa410 level 3
   ffebfc10/64caa800 level 3
   ffebfc10/64caa810 level 3
   ffebfc10/64caac00 level 3
   ffebfc10/64caac10 level 3
   ffebfc10/64cab000 level 3
   ffebfc10/64cab010 level 3
   ffebfc10/64cab400 level 3
   ffebfc10/64cab410 level 3
   ffebfc10/64cab800 level 3
   ffebfc10/64cab810 level 3
   ffebfc10/64cabc00 level 3
   ffebfc10/64cabc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64caa000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64caa000))
        return iemDecodeA64_fcvtnt_z_p_z_d2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64daa000))
        return iemDecodeA64_fcvt_z_p_z_h2dz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dea000))
        return iemDecodeA64_fcvtzu_z_p_z_d2wz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc10/64cba000 level 3
   ffebfc10/64cba010 level 3
   ffebfc10/64cba400 level 3
   ffebfc10/64cba410 level 3
   ffebfc10/64cba800 level 3
   ffebfc10/64cba810 level 3
   ffebfc10/64cbac00 level 3
   ffebfc10/64cbac10 level 3
   ffebfc10/64cbb000 level 3
   ffebfc10/64cbb010 level 3
   ffebfc10/64cbb400 level 3
   ffebfc10/64cbb410 level 3
   ffebfc10/64cbb800 level 3
   ffebfc10/64cbb810 level 3
   ffebfc10/64cbbc00 level 3
   ffebfc10/64cbbc10 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc10_64cba000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x641ba000))
        return iemDecodeA64_fsqrt_z_p_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64cba000))
        return iemDecodeA64_fcvtlt_z_p_z_s2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x64dfa000))
        return iemDecodeA64_fcvtzu_z_p_z_s2xz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/24c0a000 level 2
   bfe0fc10/24c0a400 level 2
   bfe0fc10/24c0a800 level 2
   bfe0fc10/24c0ac00 level 2
   bfe0fc10/24c0b000 level 2
   bfe0fc10/24c0b400 level 2
   bfe0fc10/24c0b800 level 2
   bfe0fc10/24c0bc00 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24c0a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_cmpeq_p_p_zz,
        iemDecodeA64_ffebfc10_6400a000_3,
        iemDecodeA64_fminnmqv_z_p_z,
        iemDecodeA64_ffebfc10_64c2a000_3,
        iemDecodeA64_ffebfc10_64c3a000_3,
        iemDecodeA64_ffebfc10_64c8a000_3,
        iemDecodeA64_ucvtf_z_p_z_x2sz,
        iemDecodeA64_ffebfc10_64caa000_3,
        iemDecodeA64_ffebfc10_64cba000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/24c0a010 level 2
   bfe0fc10/24c0a410 level 2
   bfe0fc10/24c0a810 level 2
   bfe0fc10/24c0ac10 level 2
   bfe0fc10/24c0b010 level 2
   bfe0fc10/24c0b410 level 2
   bfe0fc10/24c0b810 level 2
   bfe0fc10/24c0bc10 level 2
   mask=0x400b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%38 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_24c0a010_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_cmpne_p_p_zz,
        iemDecodeA64_ffebfc10_6400a000_3,
        iemDecodeA64_fminnmqv_z_p_z,
        iemDecodeA64_ffebfc10_64c2a000_3,
        iemDecodeA64_ffebfc10_64c3a000_3,
        iemDecodeA64_ffebfc10_64c8a000_3,
        iemDecodeA64_ucvtf_z_p_z_x2sz,
        iemDecodeA64_ffebfc10_64caa000_3,
        iemDecodeA64_ffebfc10_64cba000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x400b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000008)) /* bit 30 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc10/84c0a000 level 2
   bfe0fc10/84c0a010 level 2
   bfe0fc10/84c0a400 level 2
   bfe0fc10/84c0a410 level 2
   bfe0fc10/84c0a800 level 2
   bfe0fc10/84c0a810 level 2
   bfe0fc10/84c0ac00 level 2
   bfe0fc10/84c0ac10 level 2
   bfe0fc10/84c0b000 level 2
   bfe0fc10/84c0b010 level 2
   bfe0fc10/84c0b400 level 2
   bfe0fc10/84c0b410 level 2
   bfe0fc10/84c0b800 level 2
   bfe0fc10/84c0b810 level 2
   bfe0fc10/84c0bc00 level 2
   bfe0fc10/84c0bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_84c0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x84c0a000))
        return iemDecodeA64_ld1rh_z_p_bi_u16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xc4c0a000))
        return iemDecodeA64_ldff1sh_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc10/a4c0a000 level 2
   bfe0fc10/a4c0a010 level 2
   bfe0fc10/a4c0a400 level 2
   bfe0fc10/a4c0a410 level 2
   bfe0fc10/a4c0a800 level 2
   bfe0fc10/a4c0a810 level 2
   bfe0fc10/a4c0ac00 level 2
   bfe0fc10/a4c0ac10 level 2
   bfe0fc10/a4c0b000 level 2
   bfe0fc10/a4c0b010 level 2
   bfe0fc10/a4c0b400 level 2
   bfe0fc10/a4c0b410 level 2
   bfe0fc10/a4c0b800 level 2
   bfe0fc10/a4c0b810 level 2
   bfe0fc10/a4c0bc00 level 2
   bfe0fc10/a4c0bc10 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc10_a4c0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe4c0a000))
        return iemDecodeA64_st1h_z_p_ai_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4c0a000))
        return iemDecodeA64_ld1h_z_p_bi_u32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4d0a000))
        return iemDecodeA64_ldnf1h_z_p_bi_u32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0a000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%47 (0xf) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0cc0a000_2,
        iemDecodeA64_bfe0fc10_0cc0a000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c0a000_2,
        iemDecodeA64_bfe0fc10_24c0a010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0a400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%62 (0x14) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0cc0a000_2,
        iemDecodeA64_bfe0fc10_0cc0a000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c0a000_2,
        iemDecodeA64_bfe0fc10_24c0a010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0a800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%19 (0x6) multi-if=%50 (0x10) reuse=%62 (0x14) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0cc0a000_2,
        iemDecodeA64_bfe0fc10_0cc0a000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c0a000_2,
        iemDecodeA64_bfe0fc10_24c0a010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0ac00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%62 (0x14) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0cc0a000_2,
        iemDecodeA64_bfe0fc10_0cc0a000_2,
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c0a000_2,
        iemDecodeA64_bfe0fc10_24c0a010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0b000/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%44 (0xe) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c0a000_2,
        iemDecodeA64_bfe0fc10_24c0a010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0b400/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%44 (0xe) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c0a000_2,
        iemDecodeA64_bfe0fc10_24c0a010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0b800/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%19 (0x6) multi-if=%44 (0xe) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c0a000_2,
        iemDecodeA64_bfe0fc10_24c0a010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0bc00/0xb8000010
   mask=0xb8000010 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%25 (0x8) multi-if=%44 (0xe) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_bfe0fc10_0400a000_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_bfe0fc10_14008000_2,
        iemDecodeA64_bfe0fc10_14008010_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_1c008000_2,
        iemDecodeA64_bfe0fc10_24c0a000_2,
        iemDecodeA64_bfe0fc10_24c0a010_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_2cc00000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_bfe0fc10_34c08000_2,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_bfe0fc10_84c0a000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_a4c0a000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_bfe0fc10_acc00000_2,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8000010 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/64c0c000 level 2
   ffe0fc00/64c0c400 level 2
   ffe0fc00/64c0c800 level 2
   ffe0fc00/64c0cc00 level 2
   ffe0fc00/64c0d000 level 2
   ffe0fc00/64c0d400 level 2
   ffe0fc00/64c0d800 level 2
   ffe0fc00/64c0dc00 level 2
   mask=0x70000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_64c0c000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintm_z_p_z_z,
        iemDecodeA64_frintx_z_p_z_z,
        iemDecodeA64_fcvt_z_p_z_d2sz,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_scvtf_z_p_z_x2dz,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_fcvtzs_z_p_z_d2xz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_sclamp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0c000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_uclamp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0c000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0c000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0cc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x4c0dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0c000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_mlapt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0c000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0c000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mad_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400c000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_madpt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0c000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/64c0e000 level 2
   ffe0fc00/64c0e400 level 2
   ffe0fc00/64c0e800 level 2
   ffe0fc00/64c0ec00 level 2
   ffe0fc00/64c0f000 level 2
   ffe0fc00/64c0f400 level 2
   ffe0fc00/64c0f800 level 2
   ffe0fc00/64c0fc00 level 2
   mask=0x70000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_64c0e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintz_z_p_z_z,
        iemDecodeA64_frinti_z_p_z_z,
        iemDecodeA64_fcvt_z_p_z_s2dz,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ucvtf_z_p_z_x2dz,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_fcvtzu_z_p_z_d2xz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/e4c0e000 level 2
   ffe0fc00/e4c0e400 level 2
   ffe0fc00/e4c0e800 level 2
   ffe0fc00/e4c0ec00 level 2
   ffe0fc00/e4c0f000 level 2
   ffe0fc00/e4c0f400 level 2
   ffe0fc00/e4c0f800 level 2
   ffe0fc00/e4c0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e4c0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff90e000)) == UINT32_C(0xe480e000))
        return iemDecodeA64_st1h_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4d0e000))
        return iemDecodeA64_st3h_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_zipq1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0e000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_zipq2_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0e000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_uzpq1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0e000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_uzpq2_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0e000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDUR_Q_ldst_unscaled,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0e000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpost,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0e000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_tblq_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0e000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4c0fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04c0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_msb_z_p_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_2400e000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_immpre,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_ffe0fc00_64c0e000_2,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHEQ_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld3h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e00000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_add_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFADDAL_16,
        iemDecodeA64_sdot_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmla_z_zzzi_d,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_LDFADDAL_16,
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFADDAL_32,
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4q_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_LDFADDAL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e00400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_udot_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmls_z_zzzi_d,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4q_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e00800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_addpt_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_mla_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4q_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e00c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_subpt_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_mls_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4q_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e01000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqadd_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmlah_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_zzzi_s,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4q_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e01400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqadd_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmlsh_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_zzzi_s,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4q_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e01800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqsub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_zzzi_s,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4q_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e01c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqsub_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fcmla_z_zzzi_s,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4q_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e02000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlalb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmul_z_zzi_d,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e02400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlalt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fclamp_z_zz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e02800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_sqdmlalb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e02c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlalt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e03000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bic_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e03400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_xar_z_zzi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e03800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_sqdmlslb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e03c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e03c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_nbsl_z_zzz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmlslt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBNE_32_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1sh_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_CBNE_64_regs,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e04000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ii,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMAXAL_16,
        iemDecodeA64_cdot_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlalb_z_zzzi,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMAXAL_16,
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMAXAL_32,
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMAXAL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e04400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ri,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cdot_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlalt_z_zzzi,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e04800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_ir,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_cdot_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlalb_z_zzzi,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e04c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_index_z_rr,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cdot_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlalt_z_zzzi,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e05000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMINAL_16,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMINAL_16,
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMINAL_32,
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMINAL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/04e05400 level 1
   07e0fc00/04e05c00 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%47 (0xf) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e05800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e06000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_mul_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMAXNMAL_16,
        iemDecodeA64_cmla_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlslb_z_zzzi,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMAXNMAL_16,
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMAXNMAL_32,
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMAXNMAL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e06400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cmla_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlslt_z_zzzi,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e06800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_smulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_cmla_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlslb_z_zzzi,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e06c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_umulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_cmla_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlslt_z_zzzi,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e07000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqdmulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDBFMINNMAL_16,
        iemDecodeA64_sqrdcmlah_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDFMINNMAL_16,
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_LDFMINNMAL_32,
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDFMINNMAL_64,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e07400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqrdmulh_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdcmlah_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e07800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_sqrdcmlah_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e07c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdcmlah_z_zzzi_s,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldff1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ldff1h_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4h_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e08000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlalb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlalb_z_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e08400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsr_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlalt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlalt_z_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e08800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_smlalb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e08c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsl_z_zw,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlalt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e09000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_asr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e09400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e09800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e09800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_umlalb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e09c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e09c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lsl_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlalt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsw_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a4e0a000 level 2
   ffe0fc00/a4e0a400 level 2
   ffe0fc00/a4e0a800 level 2
   ffe0fc00/a4e0ac00 level 2
   ffe0fc00/a4e0b000 level 2
   ffe0fc00/a4e0b400 level 2
   ffe0fc00/a4e0b800 level 2
   ffe0fc00/a4e0bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a4e0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4e0a000))
        return iemDecodeA64_ld1h_z_p_bi_u64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa4f0a000))
        return iemDecodeA64_ldnf1h_z_p_bi_u64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_sd_same_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlslb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlslb_z_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_sd_same_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlslt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_bfmlslt_z_zzz,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0a800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_sd_same_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_smlslb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_adr_z_az_sd_same_scaled,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smlslt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ftssel_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlslb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0b400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x4e0bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umlslt_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fexpa_z_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_umlslb_z_zzzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBBNE_8_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ffe0fc00_a4e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1sh_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04e0c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04e0c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0c000))
        return iemDecodeA64_sqincd_z_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04f0c000))
        return iemDecodeA64_incd_z_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04e0c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smullb_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltt_z32_z8z8z8i,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04e0c400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04e0c400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0c400))
        return iemDecodeA64_uqincd_z_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04f0c400))
        return iemDecodeA64_decd_z_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04e0c400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smullt_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltt_z32_z8z8z8i,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sqdecd_z_zs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_smullb_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltt_z32_z8z8z8i,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uqdecd_z_zs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_smullt_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmlalltt_z32_z8z8z8i,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umullb_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x4e0dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_umullt_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24200000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_umullb_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1h_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04e0e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04e0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0e000))
        return iemDecodeA64_cntd_r_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04f0e000))
        return iemDecodeA64_incd_r_rs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/e4e0e000 level 2
   ffe0fc00/e4e0e400 level 2
   ffe0fc00/e4e0e800 level 2
   ffe0fc00/e4e0ec00 level 2
   ffe0fc00/e4e0f000 level 2
   ffe0fc00/e4e0f400 level 2
   ffe0fc00/e4e0f800 level 2
   ffe0fc00/e4e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e4e0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff90e000)) == UINT32_C(0xe480e000))
        return iemDecodeA64_st1h_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe4f0e000))
        return iemDecodeA64_st4h_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04e0e000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmullb_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_decd_r_rs,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmullt_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_fmmla_z_zzz_d,
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_sqdmullb_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmullt_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04e0f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04e0f000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0f000))
        return iemDecodeA64_sqincd_r_rs_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04f0f000))
        return iemDecodeA64_sqincd_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04e0f000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqdmulh_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04e0f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04e0f400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0f400))
        return iemDecodeA64_uqincd_r_rs_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04f0f400))
        return iemDecodeA64_uqincd_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04e0f400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqrdmulh_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04e0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04e0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0f800))
        return iemDecodeA64_sqdecd_r_rs_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04f0f800))
        return iemDecodeA64_sqdecd_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04e0f800_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_regoff,
        iemDecodeA64_mul_z_zzi_d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/04e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_04e0fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04e0fc00))
        return iemDecodeA64_uqdecd_r_rs_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0fc00)) == UINT32_C(0x04f0fc00))
        return iemDecodeA64_uqdecd_r_rs_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x4e0fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_04e0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_04e0fc00_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDR_S_loadlit,
        iemDecodeA64_ffe0fc00_24202000_2,
        iemDecodeA64_LDP_S_ldstpair_post,
        iemDecodeA64_CBZ_32_compbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ffe0fc00_54000000_2,
        iemDecodeA64_LDR_D_loadlit,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_post,
        iemDecodeA64_CBHNE_16_regs,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rh_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDR_Q_loadlit,
        iemDecodeA64_ld4h_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_post,
        iemDecodeA64_CBZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1h_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e4e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_post,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05000000 level 2
   ffe0fc00/05000400 level 2
   ffe0fc00/05000800 level 2
   ffe0fc00/05000c00 level 2
   ffe0fc00/05001000 level 2
   ffe0fc00/05001400 level 2
   ffe0fc00/05001800 level 2
   ffe0fc00/05001c00 level 2
   ffe0fc00/05002400 level 2
   ffe0fc00/05002800 level 2
   ffe0fc00/05002c00 level 2
   ffe0fc00/05003000 level 2
   ffe0fc00/05003400 level 2
   ffe0fc00/05003800 level 2
   ffe0fc00/05003c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05100000))
        return iemDecodeA64_cpy_z_o_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05000000))
        return iemDecodeA64_orr_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/25000000 level 2
   ffe0fc00/25000400 level 2
   ffe0fc00/25000800 level 2
   ffe0fc00/25000c00 level 2
   ffe0fc00/25001000 level 2
   ffe0fc00/25001400 level 2
   ffe0fc00/25001800 level 2
   ffe0fc00/25001c00 level 2
   ffe0fc00/25400000 level 2
   ffe0fc00/25400400 level 2
   ffe0fc00/25400800 level 2
   ffe0fc00/25400c00 level 2
   ffe0fc00/25401000 level 2
   ffe0fc00/25401400 level 2
   ffe0fc00/25401800 level 2
   ffe0fc00/25401c00 level 2
   ffe0fc00/25800000 level 2
   ffe0fc00/25800400 level 2
   ffe0fc00/25800800 level 2
   ffe0fc00/25800c00 level 2
   ffe0fc00/25801000 level 2
   ffe0fc00/25801400 level 2
   ffe0fc00/25801800 level 2
   ffe0fc00/25801c00 level 2
   ffe0fc00/25c00000 level 2
   ffe0fc00/25c00400 level 2
   ffe0fc00/25c00800 level 2
   ffe0fc00/25c00c00 level 2
   ffe0fc00/25c01000 level 2
   ffe0fc00/25c01400 level 2
   ffe0fc00/25c01800 level 2
   ffe0fc00/25c01c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25000000))
        return iemDecodeA64_cmpge_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25000010))
        return iemDecodeA64_cmpgt_p_p_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/65000000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x65000000))
        return iemDecodeA64_fadd_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x65000000))
        return iemDecodeA64_bfadd_z_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/d5000000 level 2
   ffe0fc00/d5000400 level 2
   ffe0fc00/d5000800 level 2
   ffe0fc00/d5000c00 level 2
   ffe0fc00/d5001400 level 2
   ffe0fc00/d5001800 level 2
   ffe0fc00/d5001c00 level 2
   ffe7fc00/d5002000 level 3
   ffe7fc00/d5012000 level 3
   ffe7fc00/d5022000 level 3
   ffe7fc38/d5032000 level 3
   ffe7fc38/d5032008 level 3
   ffe7fc38/d5032010 level 3
   ffe7fc38/d5032020 level 3
   ffe7fc38/d5032028 level 3
   ffe7fc38/d5032030 level 3
   ffe7fc3f/d5032038 level 4
   ffe7fc3f/d5032039 level 4
   ffe7fc3f/d503203a level 4
   ffe7fc3f/d503203b level 4
   ffe7fc3f/d503203c level 4
   ffe7fc3f/d503203d level 4
   ffe7fc3f/d503203e level 4
   ffe7fc00/d5042000 level 3
   ffe7fc00/d5052000 level 3
   ffe7fc00/d5062000 level 3
   ffe7fc00/d5072000 level 3
   ffe0fc03/d5002400 level 3
   ffe0fc03/d5002401 level 3
   ffe0fc03/d5002402 level 3
   ffe0fd0f/d5002403 level 4
   ffe0fd0f/d5002407 level 4
   ffe0fd0f/d500240b level 4
   ffe3fd0f/d500240f level 5
   ffe3fd0f/d501240f level 5
   ffe3fd0f/d502240f level 5
   ffe0fd0f/d5002503 level 4
   ffe0fd0f/d5002507 level 4
   ffe0fd0f/d500250b level 4
   ffe0fc15/d5003400 level 3
   ffe0fc15/d5003401 level 3
   ffe0fc15/d5003404 level 3
   ffe0fc15/d5003405 level 3
   ffe0fc15/d5003410 level 3
   ffe0fc15/d5003411 level 3
   ffe0fc15/d5003414 level 3
   ffe0fc75/d5003475 level 4
   ffe0fc15/d5003800 level 3
   ffe0fc15/d5003801 level 3
   ffe0fc15/d5003804 level 3
   ffe0fc15/d5003805 level 3
   ffe0fc15/d5003810 level 3
   ffe0fc15/d5003811 level 3
   ffe0fc15/d5003814 level 3
   ffe0fc75/d5003875 level 4
   ffe0fc15/d5003c00 level 3
   ffe0fc15/d5003c01 level 3
   ffe0fc15/d5003c04 level 3
   ffe0fc15/d5003c05 level 3
   ffe0fc15/d5003c10 level 3
   ffe0fc15/d5003c11 level 3
   ffe0fc15/d5003c14 level 3
   ffe0fc75/d5003c75 level 4
   ffe0fc00/d5005000 level 2
   ffe0fc00/d5005400 level 2
   ffe0fc00/d5005800 level 2
   ffe0fc00/d5005c00 level 2
   ffe0fc00/d5006000 level 2
   ffe0fc00/d5006400 level 2
   ffe0fc00/d5006800 level 2
   ffe0fc00/d5006c00 level 2
   ffe0fc00/d5007000 level 2
   ffe0fc00/d5007400 level 2
   ffe0fc00/d5007800 level 2
   ffe0fc00/d5007c00 level 2
   f7e0fc40/d5008000 level 2
   f7e0fc40/d5008040 level 2
   f7e0fc40/d5008c00 level 2
   f7e0fc40/d5008c40 level 2
   ffeffc00/d5089000 level 3
   ffeffc00/d5099000 level 3
   ffeffc00/d50a9000 level 3
   ffeffc00/d50b9000 level 3
   ffeffc00/d50c9000 level 3
   ffeffc00/d50d9000 level 3
   ffeffc00/d50e9000 level 3
   ffeffc00/d50f9000 level 3
   ffe4fc00/d5009c00 level 2
   ffe4fc00/d5049c00 level 2
   ffe0fc00/d500a000 level 2
   ffe0fc00/d500a400 level 2
   ffe0fc00/d500a800 level 2
   ffe0fc00/d500ac00 level 2
   ffe0fc00/d500b000 level 2
   ffe0fc00/d500b400 level 2
   ffe0fc00/d500b800 level 2
   ffe0fc00/d500bc00 level 2
   ffe0fc00/d500c000 level 2
   ffe0fc00/d500c400 level 2
   ffe0fc00/d500c800 level 2
   ffe0fc00/d500cc00 level 2
   ffe0fc00/d500d000 level 2
   ffe0fc00/d500d400 level 2
   ffe0fc00/d500d800 level 2
   ffe0fc00/d500dc00 level 2
   ffe0fc00/d500e000 level 2
   ffe0fc00/d500e400 level 2
   ffe0fc00/d500e800 level 2
   ffe0fc00/d500ec00 level 2
   ffe0fc00/d500f000 level 2
   ffe0fc00/d500f400 level 2
   ffe0fc00/d500f800 level 2
   ffe0fc00/d500fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5000000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%62 (0x14) multi-if=%12 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05000000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_saddlb_z_zz,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65000000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqw_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65000400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65000400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x65000400))
        return iemDecodeA64_fsub_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x65000400))
        return iemDecodeA64_bfsub_z_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5000400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%75 (0x18) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05000400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYP_CPY_memcms,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_saddlt_z_zz,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYP_CPY_memcms,
        iemDecodeA64_ffe0fc00_65000400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYP_CPY_memcms,
        iemDecodeA64_ld1rqw_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYP_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65000800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x65000800))
        return iemDecodeA64_fmul_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x65000800))
        return iemDecodeA64_bfmul_z_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5000800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%75 (0x18) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05000800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uaddlb_z_zz,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65000800_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ld1rqw_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5000c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05000c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uaddlt_z_zz,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ftsmul_z_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqw_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/d5001000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5001000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xd5031000))
        return iemDecodeA64_WFET_only_systeminstrswithreg(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xd5031020))
        return iemDecodeA64_WFIT_only_systeminstrswithreg(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5001000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05001000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ssublb_z_zz,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqw_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5001000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5001400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05001400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWT_CPY_memcms,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ssublt_z_zz,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWT_CPY_memcms,
        iemDecodeA64_ld1rqw_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPWT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5001800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%78 (0x19) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05001800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_usublb_z_zz,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_frecps_z_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ld1rqw_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5001c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05001c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_usublt_z_zz,
        iemDecodeA64_ST1_asisdlso_B1_1b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frsqrts_z_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqw_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/05002000 level 2
   3fe7fc00/05012000 level 2
   3fe7fc00/05022000 level 2
   3fe7fc00/05032000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_05002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05100000))
        return iemDecodeA64_cpy_z_o_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0xc5002000))
        return iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05000000))
        return iemDecodeA64_orr_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe7fc00/05042000 level 2
   3fe7fc00/05052000 level 2
   3fe7fc00/05062000 level 2
   3fe7fc00/05072000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_05042000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05100000))
        return iemDecodeA64_cpy_z_o_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0e000)) == UINT32_C(0xc5002000))
        return iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe7fc00/15002000 level 2
   3fe7fc00/15012000 level 2
   3fe7fc00/15022000 level 2
   3fe7fc00/15042000 level 2
   3fe7fc00/15052000 level 2
   3fe7fc00/15062000 level 2
   3fe7fc00/15072000 level 2
   mask=0xc0000000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%75 (0x3) multi-if=%25 (0x1) reuse=%25 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_15002000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ffe0fc00_d5000000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0xc0000000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 30) & UINT32_C(0x00000003)) /* bit 30 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffffdfb/d503201b level 5 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdfb_d503201b_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503201f))
        return iemDecodeA64_NOP_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503221f))
        return iemDecodeA64_ESB_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffffdfb/d503205b level 5 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdfb_d503205b_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503205f))
        return iemDecodeA64_WFE_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503225f))
        return iemDecodeA64_TSB_HC_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffffdfb/d503209b level 5 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdfb_d503209b_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503209f))
        return iemDecodeA64_SEV_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503229f))
        return iemDecodeA64_CSDB_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffffdfb/d50320db level 5 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdfb_d50320db_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50320df))
        return iemDecodeA64_DGH_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50322df))
        return iemDecodeA64_CLRBHB_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffffdfb/d503211b level 5 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdfb_d503211b_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503211f))
        return iemDecodeA64_PACIA1716_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503231f))
        return iemDecodeA64_PACIAZ_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffffdfb/d503215b level 5 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdfb_d503215b_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503215f))
        return iemDecodeA64_PACIB1716_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503235f))
        return iemDecodeA64_PACIBZ_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffffdfb/d503219b level 5 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdfb_d503219b_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503219f))
        return iemDecodeA64_AUTIA1716_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503239f))
        return iemDecodeA64_AUTIAZ_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffffdfb/d50321db level 5 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdfb_d50321db_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50321df))
        return iemDecodeA64_AUTIB1716_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50323df))
        return iemDecodeA64_AUTIBZ_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fffffc3b/d503201b level 4
   mask=0x1c0 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%0 (0x0) multi-if=%100 (0x8) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_fffffc3b_d503201b_4, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fffffdfb_d503201b_5,
        iemDecodeA64_fffffdfb_d503205b_5,
        iemDecodeA64_fffffdfb_d503209b_5,
        iemDecodeA64_fffffdfb_d50320db_5,
        iemDecodeA64_fffffdfb_d503211b_5,
        iemDecodeA64_fffffdfb_d503215b_5,
        iemDecodeA64_fffffdfb_d503219b_5,
        iemDecodeA64_fffffdfb_d50321db_5,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x000001c0 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000007)) /* bit  6 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe7fc38/d5032018 level 3
   mask=0x180003 entries=0x10 children=0xd valid=%81 (0xd) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc38_d5032018_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fffffc3b_d503201b_4,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00180003 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000003)) /* bit  0 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000c)) /* bit 19 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffffdff/d503203f level 6 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdff_d503203f_6, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503203f))
        return iemDecodeA64_YIELD_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503223f))
        return iemDecodeA64_PSB_HC_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fdff/d503203f level 5
   mask=0x180000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%75 (0x3) multi-if=%25 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fdff_d503203f_5, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fffffdff_d503203f_6,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x00180000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 19) & UINT32_C(0x00000003)) /* bit 19 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffffdff/d503207f level 6 */
FNIEMOP_DEF_1(iemDecodeA64_fffffdff_d503207f_6, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503207f))
        return iemDecodeA64_WFI_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503227f))
        return iemDecodeA64_GCSB_HD_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fdff/d503207f level 5
   mask=0x180000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%75 (0x3) multi-if=%25 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fdff_d503207f_5, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fffffdff_d503207f_6,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x00180000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 19) & UINT32_C(0x00000003)) /* bit 19 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe7fdff/d50320bf level 5 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fdff_d50320bf_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50320bf))
        return iemDecodeA64_SEVL_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fdff/d50320ff level 5 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fdff_d50320ff_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50320ff))
        return iemDecodeA64_XPACLRI_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fdff/d503213f level 5 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fdff_d503213f_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503233f))
        return iemDecodeA64_PACIASP_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fdff/d503217f level 5 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fdff_d503217f_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503237f))
        return iemDecodeA64_PACIBSP_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fdff/d50321bf level 5 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fdff_d50321bf_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50323bf))
        return iemDecodeA64_AUTIASP_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fdff/d50321ff level 5 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fdff_d50321ff_5, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50323ff))
        return iemDecodeA64_AUTIBSP_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc3f/d503203f level 4
   mask=0x1c0 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%0 (0x0) multi-if=%75 (0x6) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc3f_d503203f_4, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fdff_d503203f_5,
        iemDecodeA64_ffe7fdff_d503207f_5,
        iemDecodeA64_ffe7fdff_d50320bf_5,
        iemDecodeA64_ffe7fdff_d50320ff_5,
        iemDecodeA64_ffe7fdff_d503213f_5,
        iemDecodeA64_ffe7fdff_d503217f_5,
        iemDecodeA64_ffe7fdff_d50321bf_5,
        iemDecodeA64_ffe7fdff_d50321ff_5,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x000001c0 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000007)) /* bit  6 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe7fc38/d5032038 level 3
   mask=0x7 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%0 (0x0) multi-if=%88 (0x7) reuse=%88 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc38_d5032038_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe7fc3f_d503203f_4,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00000007 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000007)) /* bit  0 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/15032000 level 2
   mask=0xc0000038 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%56 (0x12) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_15032000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe7fc38_d5032018_3,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe7fc38_d5032038_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xc0000038 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  3) & UINT32_C(0x00000007)) /* bit  3 L 3 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe7fc00/25002000 level 3
   fff7fc00/25042000 level 3
   fff7fc00/25142000 level 3
   fff7fc00/25052000 level 3
   fff7fc00/25152000 level 3
   fff7fc00/25062000 level 3
   fff7fc00/25162000 level 3
   fff7fc00/25072000 level 3
   fff7fc00/25172000 level 3
   ffe0fc00/25002400 level 2
   ffe0fc00/25002800 level 2
   ffe0fc00/25002c00 level 2
   ffe0fc00/25003000 level 2
   ffe0fc00/25003400 level 2
   ffe0fc00/25003800 level 2
   ffe0fc00/25003c00 level 2
   ffe0fc00/25402000 level 2
   ffe0fc00/25402400 level 2
   ffe0fc00/25402800 level 2
   ffe0fc00/25402c00 level 2
   ffe0fc00/25403000 level 2
   ffe0fc00/25403400 level 2
   ffe0fc00/25403800 level 2
   ffe0fc00/25403c00 level 2
   ffe0fc00/25802000 level 2
   ffe0fc00/25802400 level 2
   ffe0fc00/25802800 level 2
   ffe0fc00/25802c00 level 2
   ffe0fc00/25803000 level 2
   ffe0fc00/25803400 level 2
   ffe0fc00/25803800 level 2
   ffe0fc00/25803c00 level 2
   ffe0fc00/25c02000 level 2
   ffe0fc00/25c02400 level 2
   ffe0fc00/25c02800 level 2
   ffe0fc00/25c02c00 level 2
   ffe0fc00/25c03000 level 2
   ffe0fc00/25c03400 level 2
   ffe0fc00/25c03800 level 2
   ffe0fc00/25c03c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc00_25002000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25002000))
        return iemDecodeA64_cmplt_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25002010))
        return iemDecodeA64_cmple_p_p_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc00/65002000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc00_65002000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65002000))
        return iemDecodeA64_faddv_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65182000))
        return iemDecodeA64_fadda_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65102000))
        return iemDecodeA64_fcmge_p_p_z0(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65102010))
        return iemDecodeA64_fcmgt_p_p_z0(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe7fc00/a5002000 level 3
   ffe7fc10/a5012000 level 3
   ffe7fc10/a5012010 level 3
   ffe7fc10/a5022000 level 3
   ffe7fc10/a5022010 level 3
   ffe7fc10/a5032000 level 3
   ffe7fc10/a5032010 level 3
   ffe0fc00/a5002400 level 2
   ffe0fc00/a5002800 level 2
   ffe0fc00/a5002c00 level 2
   ffe0fc00/a5003000 level 2
   ffe0fc00/a5003400 level 2
   ffe0fc00/a5003800 level 2
   ffe0fc00/a5003c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe7fc00_a5002000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5002000))
        return iemDecodeA64_ld1rqw_z_p_bi_u32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5102000))
        return iemDecodeA64_ld1w_z_p_bi_u128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe7fc00/25002000 level 2
   mask=0xc0000000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%25 (0x1) multi-if=%75 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_25002000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_ffe7fc00_65002000_3,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0xc0000000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 30) & UINT32_C(0x00000003)) /* bit 30 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/25012000 level 2
   mask=0xc0000010 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%75 (0x6) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_25012000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmplt_p_p_zi,
        iemDecodeA64_cmple_p_p_zi,
        iemDecodeA64_fcmlt_p_p_z0,
        iemDecodeA64_fcmle_p_p_z0,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xc0000010 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/25022000 level 2
   mask=0xc0000010 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_25022000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmplt_p_p_zi,
        iemDecodeA64_cmple_p_p_zi,
        iemDecodeA64_fcmeq_p_p_z0,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xc0000010 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/25032000 level 2
   mask=0xc0000010 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_25032000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmplt_p_p_zi,
        iemDecodeA64_cmple_p_p_zi,
        iemDecodeA64_fcmne_p_p_z0,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xc0000010 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/25042000 level 2
   mask=0xc0100000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_25042000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_fmaxnmv_v_p_z,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ld1rqw_z_p_bi_u32,
        iemDecodeA64_ld1w_z_p_bi_u128,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xc0100000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/25052000 level 2
   mask=0xc0100000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_25052000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_fminnmv_v_p_z,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ld1rqw_z_p_bi_u32,
        iemDecodeA64_ld1w_z_p_bi_u128,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xc0100000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/25062000 level 2
   mask=0xc0100000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_25062000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_fmaxv_v_p_z,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ld1rqw_z_p_bi_u32,
        iemDecodeA64_ld1w_z_p_bi_u128,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xc0100000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/25072000 level 2
   mask=0xc0100000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_25072000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_fminv_v_p_z,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ld1rqw_z_p_bi_u32,
        iemDecodeA64_ld1w_z_p_bi_u128,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xc0100000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000006)) /* bit 30 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe7fc00/2d002000 level 2
   3fe7fc00/2d012000 level 2
   3fe7fc00/2d022000 level 2
   3fe7fc00/2d032000 level 2
   3fe7fc00/2d042000 level 2
   3fe7fc00/2d052000 level 2
   3fe7fc00/2d062000 level 2
   3fe7fc00/2d072000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_2d002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2d000000))
        return iemDecodeA64_STP_S_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6d000000))
        return iemDecodeA64_STP_D_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xad000000))
        return iemDecodeA64_STP_Q_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed000000))
        return iemDecodeA64_STTP_Q_ldstpair_off(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe7fc00/35002000 level 2
   3fe7fc00/35012000 level 2
   3fe7fc00/35022000 level 2
   3fe7fc00/35032000 level 2
   3fe7fc00/35042000 level 2
   3fe7fc00/35052000 level 2
   3fe7fc00/35062000 level 2
   3fe7fc00/35072000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_35002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x35000000))
        return iemDecodeA64_CBNZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb5000000))
        return iemDecodeA64_CBNZ_64_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe04000)) == UINT32_C(0x75000000))
        return iemDecodeA64_CBGT_32_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe04000)) == UINT32_C(0xf5000000))
        return iemDecodeA64_CBGT_64_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe7fc00/3d002000 level 2
   3fe7fc00/3d012000 level 2
   3fe7fc00/3d022000 level 2
   3fe7fc00/3d032000 level 2
   3fe7fc00/3d042000 level 2
   3fe7fc00/3d052000 level 2
   3fe7fc00/3d062000 level 2
   3fe7fc00/3d072000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe7fc00_3d002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x3d000000))
        return iemDecodeA64_STR_B_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x7d000000))
        return iemDecodeA64_STR_H_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xbd000000))
        return iemDecodeA64_STR_S_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xfd000000))
        return iemDecodeA64_STR_D_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5002000/0x38070000
   mask=0x38070000 entries=0x40 children=0x31 valid=%77 (0x31) leaf=%2 (0x1) multi-if=%50 (0x20) reuse=%52 (0x21) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05002000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_3fe7fc00_05002000_2,
        iemDecodeA64_3fe7fc00_05002000_2,
        iemDecodeA64_3fe7fc00_05002000_2,
        iemDecodeA64_3fe7fc00_05002000_2,
        iemDecodeA64_3fe7fc00_05042000_2,
        iemDecodeA64_3fe7fc00_05042000_2,
        iemDecodeA64_3fe7fc00_05042000_2,
        iemDecodeA64_3fe7fc00_05042000_2,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_3fe7fc00_15002000_2,
        iemDecodeA64_3fe7fc00_15002000_2,
        iemDecodeA64_3fe7fc00_15002000_2,
        iemDecodeA64_3fe7fc00_15032000_2,
        iemDecodeA64_3fe7fc00_15002000_2,
        iemDecodeA64_3fe7fc00_15002000_2,
        iemDecodeA64_3fe7fc00_15002000_2,
        iemDecodeA64_3fe7fc00_15002000_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_3fe7fc00_25002000_2,
        iemDecodeA64_3fe7fc00_25012000_2,
        iemDecodeA64_3fe7fc00_25022000_2,
        iemDecodeA64_3fe7fc00_25032000_2,
        iemDecodeA64_3fe7fc00_25042000_2,
        iemDecodeA64_3fe7fc00_25052000_2,
        iemDecodeA64_3fe7fc00_25062000_2,
        iemDecodeA64_3fe7fc00_25072000_2,
        iemDecodeA64_3fe7fc00_2d002000_2,
        iemDecodeA64_3fe7fc00_2d002000_2,
        iemDecodeA64_3fe7fc00_2d002000_2,
        iemDecodeA64_3fe7fc00_2d002000_2,
        iemDecodeA64_3fe7fc00_2d002000_2,
        iemDecodeA64_3fe7fc00_2d002000_2,
        iemDecodeA64_3fe7fc00_2d002000_2,
        iemDecodeA64_3fe7fc00_2d002000_2,
        iemDecodeA64_3fe7fc00_35002000_2,
        iemDecodeA64_3fe7fc00_35002000_2,
        iemDecodeA64_3fe7fc00_35002000_2,
        iemDecodeA64_3fe7fc00_35002000_2,
        iemDecodeA64_3fe7fc00_35002000_2,
        iemDecodeA64_3fe7fc00_35002000_2,
        iemDecodeA64_3fe7fc00_35002000_2,
        iemDecodeA64_3fe7fc00_35002000_2,
        iemDecodeA64_3fe7fc00_3d002000_2,
        iemDecodeA64_3fe7fc00_3d002000_2,
        iemDecodeA64_3fe7fc00_3d002000_2,
        iemDecodeA64_3fe7fc00_3d002000_2,
        iemDecodeA64_3fe7fc00_3d002000_2,
        iemDecodeA64_3fe7fc00_3d002000_2,
        iemDecodeA64_3fe7fc00_3d002000_2,
        iemDecodeA64_3fe7fc00_3d002000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x38070000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000038)) /* bit 27 L 3 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/65002400 level 3
   ffeffc00/65002800 level 3
   ffeffc00/65002c00 level 3
   ffeffc00/65402000 level 3
   ffeffc00/65402400 level 3
   ffeffc00/65402800 level 3
   ffeffc00/65402c00 level 3
   ffeffc00/65403400 level 3
   ffeffc00/65403800 level 3
   ffeffc00/65403c00 level 3
   ffeffc00/65802000 level 3
   ffeffc00/65802400 level 3
   ffeffc00/65802800 level 3
   ffeffc00/65802c00 level 3
   ffeffc00/65803400 level 3
   ffeffc00/65803800 level 3
   ffeffc00/65803c00 level 3
   ffeffc00/65c02000 level 3
   ffeffc00/65c02400 level 3
   ffeffc00/65c02800 level 3
   ffeffc00/65c02c00 level 3
   ffeffc00/65c03400 level 3
   ffeffc00/65c03800 level 3
   ffeffc00/65c03c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_65002400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65002000))
        return iemDecodeA64_faddv_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65102000))
        return iemDecodeA64_fcmge_p_p_z0(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65102010))
        return iemDecodeA64_fcmgt_p_p_z0(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/65012400 level 3
   ffeffc00/65012800 level 3
   ffeffc00/65012c00 level 3
   fffffc00/65113400 level 3
   fffffc00/65113800 level 3
   fffffc00/65113c00 level 3
   ffeffc00/65412000 level 3
   ffeffc00/65412400 level 3
   ffeffc00/65412800 level 3
   ffeffc00/65412c00 level 3
   fffffc00/65513000 level 3
   ffeffc00/65413400 level 3
   ffeffc00/65413800 level 3
   ffeffc00/65413c00 level 3
   ffeffc00/65812000 level 3
   ffeffc00/65812400 level 3
   ffeffc00/65812800 level 3
   ffeffc00/65812c00 level 3
   fffffc00/65913000 level 3
   ffeffc00/65813400 level 3
   ffeffc00/65813800 level 3
   ffeffc00/65813c00 level 3
   ffeffc00/65c12000 level 3
   ffeffc00/65c12400 level 3
   ffeffc00/65c12800 level 3
   ffeffc00/65c12c00 level 3
   fffffc00/65d13000 level 3
   ffeffc00/65c13400 level 3
   ffeffc00/65c13800 level 3
   ffeffc00/65c13c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_65012400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65112000))
        return iemDecodeA64_fcmlt_p_p_z0(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65112010))
        return iemDecodeA64_fcmle_p_p_z0(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/65002400 level 2
   ffe0fc00/65002800 level 2
   ffe0fc00/65002c00 level 2
   ffe0fc00/65402000 level 2
   ffe0fc00/65402400 level 2
   ffe0fc00/65402800 level 2
   ffe0fc00/65402c00 level 2
   ffe0fc00/65403400 level 2
   ffe0fc00/65403800 level 2
   ffe0fc00/65403c00 level 2
   ffe0fc00/65802000 level 2
   ffe0fc00/65802400 level 2
   ffe0fc00/65802800 level 2
   ffe0fc00/65802c00 level 2
   ffe0fc00/65803400 level 2
   ffe0fc00/65803800 level 2
   ffe0fc00/65803c00 level 2
   ffe0fc00/65c02000 level 2
   ffe0fc00/65c02400 level 2
   ffe0fc00/65c02800 level 2
   ffe0fc00/65c02c00 level 2
   ffe0fc00/65c03400 level 2
   ffe0fc00/65c03800 level 2
   ffe0fc00/65c03c00 level 2
   mask=0xf0000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65002400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc00_65002400_3,
        iemDecodeA64_ffeffc00_65012400_3,
        iemDecodeA64_fcmeq_p_p_z0,
        iemDecodeA64_fcmne_p_p_z0,
        iemDecodeA64_fmaxnmv_v_p_z,
        iemDecodeA64_fminnmv_v_p_z,
        iemDecodeA64_fmaxv_v_p_z,
        iemDecodeA64_fminv_v_p_z,
        iemDecodeA64_fadda_v_p_z,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffffd0f/d503240f level 6 */
FNIEMOP_DEF_1(iemDecodeA64_fffffd0f_d503240f_6, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffff1f)) == UINT32_C(0xd503241f))
        return iemDecodeA64_BTI_HB_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffff1f)) == UINT32_C(0xd503261f))
        return iemDecodeA64_STSHH_HI_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd50324ff))
        return iemDecodeA64_PACM_HI_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fd0f/d503240f level 5
   mask=0x1c0000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fd0f_d503240f_5, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fffffd0f_d503240f_6,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fd0f/d500240f level 4
   mask=0x30000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%0 (0x0) multi-if=%75 (0x3) reuse=%75 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fd0f_d500240f_4, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe3fd0f_d503240f_5,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x00030000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fd0f/d500250f level 4 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fd0f_d500250f_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd503251f))
        return iemDecodeA64_CHKFEAT_HF_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc03/d5002403 level 3
   mask=0x10c entries=0x8 children=0x8 valid=%100 (0x8) leaf=%0 (0x0) multi-if=%88 (0x7) reuse=%75 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc03_d5002403_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fd0f_d500240f_4,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fd0f_d500250f_4,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x0000010c -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  2) & UINT32_C(0x00000003)) /* bit  2 L 2 -> 0 */
                        | ((uOpcode >>  6) & UINT32_C(0x00000004)) /* bit  8 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/d5002400 level 2
   mask=0x3 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%0 (0x0) multi-if=%75 (0x3) reuse=%75 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5002400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc03_d5002403_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x00000003 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000003)) /* bit  0 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5002400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05002400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPRT_CPY_memcms,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPRT_CPY_memcms,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPRT_CPY_memcms,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5002400_2,
        iemDecodeA64_CPYPRT_CPY_memcms,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/d5002800 level 2
   ffe0fc00/d5002c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5002800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff01f)) == UINT32_C(0xd503201f))
        return iemDecodeA64_HINT_HM_hints(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5002800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%72 (0x17) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05002800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5002800_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5002c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05002c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5002800_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65003000 level 2
   mask=0x1f0010 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%44 (0x1c) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65003000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_faddv_v_p_z,
        iemDecodeA64_faddv_v_p_z,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_fmaxnmv_v_p_z,
        iemDecodeA64_fmaxnmv_v_p_z,
        iemDecodeA64_fminnmv_v_p_z,
        iemDecodeA64_fminnmv_v_p_z,
        iemDecodeA64_fmaxv_v_p_z,
        iemDecodeA64_fmaxv_v_p_z,
        iemDecodeA64_fminv_v_p_z,
        iemDecodeA64_fminv_v_p_z,
        iemDecodeA64_f1cvt_z_z8_b2h,
        iemDecodeA64_f1cvt_z_z8_b2h,
        iemDecodeA64_f1cvtlt_z_z8_b2h,
        iemDecodeA64_f1cvtlt_z_z8_b2h,
        iemDecodeA64_fcvtn_z8_mz2_h2b,
        iemDecodeA64_fcvtn_z8_mz2_h2b,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_frecpe_z_z,
        iemDecodeA64_frecpe_z_z,
        iemDecodeA64_frsqrte_z_z,
        iemDecodeA64_frsqrte_z_z,
        iemDecodeA64_fcmge_p_p_z0,
        iemDecodeA64_fcmgt_p_p_z0,
        iemDecodeA64_fcmlt_p_p_z0,
        iemDecodeA64_fcmle_p_p_z0,
        iemDecodeA64_fcmeq_p_p_z0,
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_fcmne_p_p_z0,
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fadda_v_p_z,
        iemDecodeA64_fadda_v_p_z,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x001f0010 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x0000003e)) /* bit 16 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffcfc00/d5003000 level 3
   mask=0xe0 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%88 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_fffcfc00_d5003000_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_DSB_BOn_barriers,
        iemDecodeA64_CLREX_BN_barriers,
        iemDecodeA64_TCOMMIT_only_barriers,
        iemDecodeA64_DSB_BO_barriers,
        iemDecodeA64_DMB_BO_barriers,
        iemDecodeA64_ISB_BI_barriers,
        iemDecodeA64_SB_only_barriers,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x000000e0 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  5) & UINT32_C(0x00000007)) /* bit  5 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/d5003000 level 2
   mask=0x1c0000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5003000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fffcfc00_d5003000_3,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5003000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05003000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sabdlb_z_zz,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65003000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5003000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffffc00/65103400 level 3
   fffffc00/65103800 level 3
   fffffc00/65103c00 level 3
   fffffc00/65503000 level 3
   fffffc00/65903000 level 3
   fffffc00/65d03000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fffffc00_65103400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65102000))
        return iemDecodeA64_fcmge_p_p_z0(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe010)) == UINT32_C(0x65102010))
        return iemDecodeA64_fcmgt_p_p_z0(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/65003400 level 2
   mask=0x1f0000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65003400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_faddv_v_p_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmaxnmv_v_p_z,
        iemDecodeA64_fminnmv_v_p_z,
        iemDecodeA64_fmaxv_v_p_z,
        iemDecodeA64_fminv_v_p_z,
        iemDecodeA64_f2cvt_z_z8_b2h,
        iemDecodeA64_f2cvtlt_z_z8_b2h,
        iemDecodeA64_fcvtnb_z8_mz2_s2b,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fffffc00_65103400_3,
        iemDecodeA64_ffeffc00_65012400_3,
        iemDecodeA64_fcmeq_p_p_z0,
        iemDecodeA64_fcmne_p_p_z0,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fadda_v_p_z,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc75/d5003415 level 4
   ffe0fc75/d5003815 level 4
   ffe0fc75/d5003c15 level 4 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc75_d5003415_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff0ff)) == UINT32_C(0xd503309f))
        return iemDecodeA64_DSB_BO_barriers(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc75/d5003435 level 4
   ffe0fc75/d5003835 level 4
   ffe0fc75/d5003c35 level 4 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc75_d5003435_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff0ff)) == UINT32_C(0xd50330bf))
        return iemDecodeA64_DMB_BO_barriers(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff3ff)) == UINT32_C(0xd503323f))
        return iemDecodeA64_DSB_BOn_barriers(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc75/d5003455 level 4
   ffe0fc75/d5003855 level 4
   ffe0fc75/d5003c55 level 4 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc75_d5003455_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff0ff)) == UINT32_C(0xd503305f))
        return iemDecodeA64_CLREX_BN_barriers(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffff0ff)) == UINT32_C(0xd50330df))
        return iemDecodeA64_ISB_BI_barriers(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc15/d5003415 level 3
   ffe0fc15/d5003815 level 3
   ffe0fc15/d5003c15 level 3
   mask=0x60 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%0 (0x0) multi-if=%100 (0x4) reuse=%25 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc15_d5003415_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc75_d5003415_4,
        iemDecodeA64_ffe0fc75_d5003435_4,
        iemDecodeA64_ffe0fc75_d5003455_4,
        iemDecodeA64_ffe0fc00_d5000000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x00000060 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >>  5) & UINT32_C(0x00000003)) /* bit  5 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/d5003400 level 2
   ffe0fc00/d5003800 level 2
   ffe0fc00/d5003c00 level 2
   mask=0x15 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%0 (0x0) multi-if=%88 (0x7) reuse=%88 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5003400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc15_d5003415_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00000015 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >>  1) & UINT32_C(0x00000002)) /* bit  2 L 1 -> 1 */
                        | ((uOpcode >>  2) & UINT32_C(0x00000004)) /* bit  4 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5003400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1d valid=%91 (0x1d) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05003400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPT_CPY_memcms,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sabdlt_z_zz,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPT_CPY_memcms,
        iemDecodeA64_ffe0fc00_65003400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPT_CPY_memcms,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5003400_2,
        iemDecodeA64_CPYPT_CPY_memcms,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65003800 level 2
   mask=0x1f0000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65003800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_faddv_v_p_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmaxnmv_v_p_z,
        iemDecodeA64_fminnmv_v_p_z,
        iemDecodeA64_fmaxv_v_p_z,
        iemDecodeA64_fminv_v_p_z,
        iemDecodeA64_bf1cvt_z_z8_b2bf,
        iemDecodeA64_bf1cvtlt_z_z8_b2bf,
        iemDecodeA64_bfcvtn_z8_mz2_bf2b,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fffffc00_65103400_3,
        iemDecodeA64_ffeffc00_65012400_3,
        iemDecodeA64_fcmeq_p_p_z0,
        iemDecodeA64_fcmne_p_p_z0,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fadda_v_p_z,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5003800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1d valid=%91 (0x1d) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05003800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uabdlb_z_zz,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65003800_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5003400_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65003c00 level 2
   mask=0x1f0000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65003c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_faddv_v_p_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmaxnmv_v_p_z,
        iemDecodeA64_fminnmv_v_p_z,
        iemDecodeA64_fmaxv_v_p_z,
        iemDecodeA64_fminv_v_p_z,
        iemDecodeA64_bf2cvt_z_z8_b2bf,
        iemDecodeA64_bf2cvtlt_z_z8_b2bf,
        iemDecodeA64_fcvtnt_z8_mz2_s2b,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_fffffc00_65103400_3,
        iemDecodeA64_ffeffc00_65012400_3,
        iemDecodeA64_fcmeq_p_p_z0,
        iemDecodeA64_fcmne_p_p_z0,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fadda_v_p_z,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5003c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05003c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05000000_2,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uabdlt_z_zz,
        iemDecodeA64_ST3_asisdlso_B3_3b,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65003c00_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe7fc00_a5002000_3,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5003400_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/05004000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_05004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d004000))
        return iemDecodeA64_ST1_asisdlso_H1_1h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05104000))
        return iemDecodeA64_cpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05000000))
        return iemDecodeA64_orr_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fe10/25104000 level 4
   fff0fe10/25104400 level 3
   fff0fe10/25104800 level 3
   fff0fe10/25104c00 level 3
   fff0fe10/25105000 level 3
   fff0fe10/25105400 level 3
   fff0fe10/25105800 level 3
   fff0fe10/25105c00 level 3
   fff0fe10/25106000 level 3
   fff0fe10/25106400 level 3
   fff0fe10/25106800 level 3
   fff0fe10/25106c00 level 3
   fff0fe10/25107000 level 3
   fff0fe10/25107400 level 3
   fff0fe10/25107800 level 3
   fff0fe10/25107c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fe10_25104000_4, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffc200)) == UINT32_C(0x25104000))
        return iemDecodeA64_brka_p_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffc210)) == UINT32_C(0x25184000))
        return iemDecodeA64_brkn_p_p_pp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc10/25004000 level 3
   mask=0x8100200 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_25004000_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_p_p_pp_z,
        iemDecodeA64_eor_p_p_pp_z,
        iemDecodeA64_fff0fe10_25104000_4,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_STP_S_ldstpair_off,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x08100200 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 19) & UINT32_C(0x00000002)) /* bit 20 L 1 -> 1 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000004)) /* bit 27 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc10/25004010 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc10_25004010_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2d000000))
        return iemDecodeA64_STP_S_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x25004010))
        return iemDecodeA64_bic_p_p_pp_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x25004210))
        return iemDecodeA64_sel_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffc200)) == UINT32_C(0x25104000))
        return iemDecodeA64_brka_p_p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/25004000 level 2
   mask=0x10 entries=0x2 children=0x2 valid=%100 (0x2) leaf=%0 (0x0) multi-if=%50 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_25004000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc10_25004000_3,
        iemDecodeA64_f7e0fc10_25004010_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x2);

    /* fMask=0x00000010 -> 0x00000001 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/35004000 level 2
   f7e0fc40/35008000 level 2
   f7e0fc40/35008040 level 2
   f7e0fc40/35008400 level 2
   f7e0fc40/35008440 level 2
   f7e0fc40/35008800 level 2
   f7e0fc40/35008840 level 2
   f7e0fc40/35008c00 level 2
   f7e0fc40/35008c40 level 2
   f7e0fc40/35009800 level 2
   f7e0fc40/35009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_35004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x35000000))
        return iemDecodeA64_CBNZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x3d000000))
        return iemDecodeA64_STR_B_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/45004000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_45004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d004000))
        return iemDecodeA64_ST1_asisdlso_H1_1h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x45004000))
        return iemDecodeA64_saddwb_z_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/65004000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_65004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x65004000))
        return iemDecodeA64_fcmge_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x65004010))
        return iemDecodeA64_fcmgt_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6d000000))
        return iemDecodeA64_STP_D_ldstpair_off(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/a5004000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_a5004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xad000000))
        return iemDecodeA64_STP_Q_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa5004000))
        return iemDecodeA64_ld1sh_z_p_br_s64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/b5004000 level 2
   f7e0fc40/b5008000 level 2
   f7e0fc40/b5008040 level 2
   f7e0fc40/b5008400 level 2
   f7e0fc40/b5008440 level 2
   f7e0fc40/b5008800 level 2
   f7e0fc40/b5008840 level 2
   f7e0fc40/b5008c00 level 2
   f7e0fc40/b5008c40 level 2
   f7e0fc40/b5009800 level 2
   f7e0fc40/b5009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_b5004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb5000000))
        return iemDecodeA64_CBNZ_64_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xbd000000))
        return iemDecodeA64_STR_S_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff8fc01/d5004001 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff8fc01_d5004001_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff8f01f)) == UINT32_C(0xd500401f))
        return iemDecodeA64_MSR_SI_pstate(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd500401f))
        return iemDecodeA64_CFINV_M_pstate(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd500403f))
        return iemDecodeA64_XAFLAG_M_pstate(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd500405f))
        return iemDecodeA64_AXFLAG_M_pstate(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/d5004000 level 2
   mask=0x8180001 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%38 (0x6) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_d5004000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_fff8fc01_d5004001_3,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x08180001 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >>  0) & UINT32_C(0x00000001)) /* bit  0 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/e5004000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_e5004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed000000))
        return iemDecodeA64_STTP_Q_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe5004000))
        return iemDecodeA64_st1w_z_p_br_u128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5004000/0xf0000000
   mask=0xf0000000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%44 (0x7) multi-if=%44 (0x7) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05004000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_05004000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_25004000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_f7e0fc00_45004000_2,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_f7e0fc00_65004000_2,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_f7e0fc00_a5004000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_f7e0fc00_d5004000_2,
        iemDecodeA64_f7e0fc00_e5004000_2,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05004400 level 2
   ffe0fc00/05004800 level 2
   ffe0fc00/05004c00 level 2
   ffe0fc00/05005000 level 2
   ffe0fc00/05005400 level 2
   ffe0fc00/05005800 level 2
   ffe0fc00/05005c00 level 2
   ffe0fc00/05006000 level 2
   ffe0fc00/05006400 level 2
   ffe0fc00/05006800 level 2
   ffe0fc00/05006c00 level 2
   ffe0fc00/05007000 level 2
   ffe0fc00/05007400 level 2
   ffe0fc00/05007800 level 2
   ffe0fc00/05007c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05004400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05104000))
        return iemDecodeA64_cpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05000000))
        return iemDecodeA64_orr_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/25004400 level 2
   ffe0fc00/25004800 level 2
   ffe0fc00/25004c00 level 2
   ffe0fc00/25005000 level 2
   ffe0fc00/25005400 level 2
   ffe0fc00/25005800 level 2
   ffe0fc00/25005c00 level 2
   ffe0fc00/25006000 level 2
   ffe0fc00/25006400 level 2
   ffe0fc00/25006800 level 2
   ffe0fc00/25006c00 level 2
   ffe0fc00/25007000 level 2
   ffe0fc00/25007400 level 2
   ffe0fc00/25007800 level 2
   ffe0fc00/25007c00 level 2
   mask=0x100210 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25004400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_p_p_pp_z,
        iemDecodeA64_bic_p_p_pp_z,
        iemDecodeA64_eor_p_p_pp_z,
        iemDecodeA64_sel_p_p_pp,
        iemDecodeA64_fff0fe10_25104000_4,
        iemDecodeA64_brka_p_p_p,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100210 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65004400 level 2
   ffe0fc00/65004800 level 2
   ffe0fc00/65004c00 level 2
   ffe0fc00/65005000 level 2
   ffe0fc00/65005400 level 2
   ffe0fc00/65005800 level 2
   ffe0fc00/65005c00 level 2
   ffe0fc00/65404000 level 2
   ffe0fc00/65404400 level 2
   ffe0fc00/65404800 level 2
   ffe0fc00/65404c00 level 2
   ffe0fc00/65405000 level 2
   ffe0fc00/65405400 level 2
   ffe0fc00/65405800 level 2
   ffe0fc00/65405c00 level 2
   ffe0fc00/65804000 level 2
   ffe0fc00/65804400 level 2
   ffe0fc00/65804800 level 2
   ffe0fc00/65804c00 level 2
   ffe0fc00/65805000 level 2
   ffe0fc00/65805400 level 2
   ffe0fc00/65805800 level 2
   ffe0fc00/65805c00 level 2
   ffe0fc00/65c04000 level 2
   ffe0fc00/65c04400 level 2
   ffe0fc00/65c04800 level 2
   ffe0fc00/65c04c00 level 2
   ffe0fc00/65c05000 level 2
   ffe0fc00/65c05400 level 2
   ffe0fc00/65c05800 level 2
   ffe0fc00/65c05c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65004400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x65004000))
        return iemDecodeA64_fcmge_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x65004010))
        return iemDecodeA64_fcmgt_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/d5004400 level 2
   ffe0fc00/d5004800 level 2
   ffe0fc00/d5004c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5004400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff8f01f)) == UINT32_C(0xd500401f))
        return iemDecodeA64_MSR_SI_pstate(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5004400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05004400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_saddwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWN_CPY_memcms,
        iemDecodeA64_ld1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5004400_2,
        iemDecodeA64_CPYPWN_CPY_memcms,
        iemDecodeA64_st1w_z_p_br_u128,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5004800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05004800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_ST1_asisdlso_H1_1h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uaddwb_z_zz,
        iemDecodeA64_ST1_asisdlso_H1_1h,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ld1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5004400_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_br_u128,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5004c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05004c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uaddwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5004400_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br_u128,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5005000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05005000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_ST1_asisdlso_H1_1h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ssubwb_z_zz,
        iemDecodeA64_ST1_asisdlso_H1_1h,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br_u128,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5005400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05005400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ssubwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTWN_CPY_memcms,
        iemDecodeA64_ld1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPWTWN_CPY_memcms,
        iemDecodeA64_st1w_z_p_br_u128,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5005800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05005800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_ST1_asisdlso_H1_1h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_usubwb_z_zz,
        iemDecodeA64_ST1_asisdlso_H1_1h,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ld1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_br_u128,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5005c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05005c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_usubwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br_u128,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65006000 level 2
   ffe0fc00/65006400 level 2
   ffe0fc00/65006800 level 2
   ffe0fc00/65006c00 level 2
   ffe0fc00/65007000 level 2
   ffe0fc00/65007400 level 2
   ffe0fc00/65007800 level 2
   ffe0fc00/65007c00 level 2
   ffe0fc00/65406000 level 2
   ffe0fc00/65406400 level 2
   ffe0fc00/65406800 level 2
   ffe0fc00/65406c00 level 2
   ffe0fc00/65407000 level 2
   ffe0fc00/65407400 level 2
   ffe0fc00/65407800 level 2
   ffe0fc00/65407c00 level 2
   ffe0fc00/65806000 level 2
   ffe0fc00/65806400 level 2
   ffe0fc00/65806800 level 2
   ffe0fc00/65806c00 level 2
   ffe0fc00/65807000 level 2
   ffe0fc00/65807400 level 2
   ffe0fc00/65807800 level 2
   ffe0fc00/65807c00 level 2
   ffe0fc00/65c06000 level 2
   ffe0fc00/65c06400 level 2
   ffe0fc00/65c06800 level 2
   ffe0fc00/65c06c00 level 2
   ffe0fc00/65c07000 level 2
   ffe0fc00/65c07400 level 2
   ffe0fc00/65c07800 level 2
   ffe0fc00/65c07c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65006000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x65006000))
        return iemDecodeA64_fcmeq_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x65006010))
        return iemDecodeA64_fcmne_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5006000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05006000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_ST3_asisdlso_H3_3h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqdmullb_z_zz,
        iemDecodeA64_ST3_asisdlso_H3_3h,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5006400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05006400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPRTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqdmullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPRTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPRTWN_CPY_memcms,
        iemDecodeA64_ldff1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPRTWN_CPY_memcms,
        iemDecodeA64_stnt1w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/45006800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_45006800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x45006800))
        return iemDecodeA64_pmullb_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x45006800))
        return iemDecodeA64_pmullb_z_zz_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5006800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%72 (0x17) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05006800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_ST3_asisdlso_H3_3h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45006800_2,
        iemDecodeA64_ST3_asisdlso_H3_3h,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ldff1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_stnt1w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/45006c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_45006c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x45006c00))
        return iemDecodeA64_pmullt_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x45006c00))
        return iemDecodeA64_pmullt_z_zz_q(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5006c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05006c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45006c00_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5007000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05007000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_ST3_asisdlso_H3_3h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_smullb_z_zz,
        iemDecodeA64_ST3_asisdlso_H3_3h,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5007400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05007400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_smullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPTWN_CPY_memcms,
        iemDecodeA64_ldff1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPTWN_CPY_memcms,
        iemDecodeA64_stnt1w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5007800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05007800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_ST3_asisdlso_H3_3h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_umullb_z_zz,
        iemDecodeA64_ST3_asisdlso_H3_3h,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ldff1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_stnt1w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5007c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05007c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05004400_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25004400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_umullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc40/05008000 level 2
   f7e0fc40/05008040 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_05008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d008000))
        return iemDecodeA64_ST1_asisdlso_S1_1s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05000000))
        return iemDecodeA64_orr_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/25008000 level 2
   f7e0fc40/25008040 level 2
   f7e0fc40/25008400 level 2
   f7e0fc40/25008440 level 2
   f7e0fc40/25008800 level 2
   f7e0fc40/25008840 level 2
   f7e0fc40/25008c00 level 2
   f7e0fc40/25008c40 level 2
   f7e0fc40/25009800 level 2
   f7e0fc40/25009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_25008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25008000))
        return iemDecodeA64_cmpeq_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25008010))
        return iemDecodeA64_cmpne_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2d000000))
        return iemDecodeA64_STP_S_ldstpair_off(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/45008000 level 2
   f7e0fc40/45008040 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_45008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d008000))
        return iemDecodeA64_ST1_asisdlso_S1_1s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x45008000))
        return iemDecodeA64_saddlbt_z_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65008000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65008000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff38fc00)) == UINT32_C(0x65108000))
        return iemDecodeA64_ftmad_z_zzi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65008000))
        return iemDecodeA64_fadd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65008000))
        return iemDecodeA64_bfadd_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65018000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65018000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff38fc00)) == UINT32_C(0x65108000))
        return iemDecodeA64_ftmad_z_zzi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65018000))
        return iemDecodeA64_fsub_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65018000))
        return iemDecodeA64_bfsub_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65028000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65028000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff38fc00)) == UINT32_C(0x65108000))
        return iemDecodeA64_ftmad_z_zzi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65028000))
        return iemDecodeA64_fmul_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65028000))
        return iemDecodeA64_bfmul_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65038000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65038000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff38fc00)) == UINT32_C(0x65108000))
        return iemDecodeA64_ftmad_z_zzi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65038000))
        return iemDecodeA64_fsubr_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65048000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65048000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff38fc00)) == UINT32_C(0x65108000))
        return iemDecodeA64_ftmad_z_zzi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65048000))
        return iemDecodeA64_fmaxnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65048000))
        return iemDecodeA64_bfmaxnm_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65058000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65058000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff38fc00)) == UINT32_C(0x65108000))
        return iemDecodeA64_ftmad_z_zzi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65058000))
        return iemDecodeA64_fminnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65058000))
        return iemDecodeA64_bfminnm_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65068000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65068000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff38fc00)) == UINT32_C(0x65108000))
        return iemDecodeA64_ftmad_z_zzi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65068000))
        return iemDecodeA64_fmax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65068000))
        return iemDecodeA64_bfmax_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65078000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65078000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff38fc00)) == UINT32_C(0x65108000))
        return iemDecodeA64_ftmad_z_zzi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65078000))
        return iemDecodeA64_fmin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65078000))
        return iemDecodeA64_bfmin_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65088000 level 3
   ffeffc00/65089000 level 3
   ffeffc00/65c88400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65088000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65088000))
        return iemDecodeA64_fabd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65188000))
        return iemDecodeA64_fadd_z_p_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65098000 level 3
   ffeffc00/65099000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65098000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_fscale_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65198000))
        return iemDecodeA64_fsub_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_bfscale_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/650a8000 level 3
   ffeffc00/650a9000 level 3
   ffeffc00/65ca8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_650a8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650a8000))
        return iemDecodeA64_fmulx_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651a8000))
        return iemDecodeA64_fmul_z_p_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/650c8000 level 3
   ffeffc00/650c9000 level 3
   ffeffc00/65cc8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_650c8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650c8000))
        return iemDecodeA64_fdivr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651c8000))
        return iemDecodeA64_fmaxnm_z_p_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/650d8000 level 3
   ffeffc00/650d9000 level 3
   ffeffc00/65cd8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_650d8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650d8000))
        return iemDecodeA64_fdiv_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651d8000))
        return iemDecodeA64_fminnm_z_p_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/650e8000 level 3
   ffeffc00/650e9000 level 3
   ffeffc00/65ce8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_650e8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650e8000))
        return iemDecodeA64_famax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651e8000))
        return iemDecodeA64_fmax_z_p_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/650f8000 level 3
   ffeffc00/650f9000 level 3
   ffeffc00/65cf8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_650f8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650f8000))
        return iemDecodeA64_famin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651f8000))
        return iemDecodeA64_fmin_z_p_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/65008000 level 2
   mask=0x80f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%53 (0x11) multi-if=%47 (0xf) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_65008000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc40_65008000_3,
        iemDecodeA64_ffeffc40_65018000_3,
        iemDecodeA64_ffeffc40_65028000_3,
        iemDecodeA64_ffeffc40_65038000_3,
        iemDecodeA64_ffeffc40_65048000_3,
        iemDecodeA64_ffeffc40_65058000_3,
        iemDecodeA64_ffeffc40_65068000_3,
        iemDecodeA64_ffeffc40_65078000_3,
        iemDecodeA64_ffeffc40_65088000_3,
        iemDecodeA64_ffeffc40_65098000_3,
        iemDecodeA64_ffeffc40_650a8000_3,
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_ffeffc40_650c8000_3,
        iemDecodeA64_ffeffc40_650d8000_3,
        iemDecodeA64_ffeffc40_650e8000_3,
        iemDecodeA64_ffeffc40_650f8000_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x080f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000010)) /* bit 27 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc40/65008040 level 3
   fff7fc40/65008400 level 3
   fff7fc40/65008800 level 3
   fff7fc40/65008c00 level 3
   fff7fc40/65009800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc40_65008040_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65008000))
        return iemDecodeA64_fadd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65088000))
        return iemDecodeA64_fabd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65008000))
        return iemDecodeA64_bfadd_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc40/65018040 level 3
   fff7fc40/65018400 level 3
   fff7fc40/65018800 level 3
   fff7fc40/65018c00 level 3
   fff7fc40/65019800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc40_65018040_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65018000))
        return iemDecodeA64_fsub_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_fscale_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65018000))
        return iemDecodeA64_bfsub_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_bfscale_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc40/65028040 level 3
   fff7fc40/65028400 level 3
   fff7fc40/65028800 level 3
   fff7fc40/65028c00 level 3
   fff7fc40/65029800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc40_65028040_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65028000))
        return iemDecodeA64_fmul_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650a8000))
        return iemDecodeA64_fmulx_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65028000))
        return iemDecodeA64_bfmul_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc40/65048040 level 3
   fff7fc40/65048400 level 3
   fff7fc40/65048800 level 3
   fff7fc40/65048c00 level 3
   fff7fc40/65049800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc40_65048040_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65048000))
        return iemDecodeA64_fmaxnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650c8000))
        return iemDecodeA64_fdivr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65048000))
        return iemDecodeA64_bfmaxnm_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc40/65058040 level 3
   fff7fc40/65058400 level 3
   fff7fc40/65058800 level 3
   fff7fc40/65058c00 level 3
   fff7fc40/65059800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc40_65058040_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65058000))
        return iemDecodeA64_fminnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650d8000))
        return iemDecodeA64_fdiv_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65058000))
        return iemDecodeA64_bfminnm_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc40/65068040 level 3
   fff7fc40/65068400 level 3
   fff7fc40/65068800 level 3
   fff7fc40/65068c00 level 3
   fff7fc40/65069800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc40_65068040_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65068000))
        return iemDecodeA64_fmax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650e8000))
        return iemDecodeA64_famax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65068000))
        return iemDecodeA64_bfmax_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc40/65078040 level 3
   fff7fc40/65078400 level 3
   fff7fc40/65078800 level 3
   fff7fc40/65078c00 level 3
   fff7fc40/65079800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc40_65078040_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65078000))
        return iemDecodeA64_fmin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650f8000))
        return iemDecodeA64_famin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65078000))
        return iemDecodeA64_bfmin_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/65008040 level 2
   mask=0x8170000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%78 (0x19) multi-if=%22 (0x7) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_65008040_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff7fc40_65008040_3,
        iemDecodeA64_fff7fc40_65018040_3,
        iemDecodeA64_fff7fc40_65028040_3,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fff7fc40_65048040_3,
        iemDecodeA64_fff7fc40_65058040_3,
        iemDecodeA64_fff7fc40_65068040_3,
        iemDecodeA64_fff7fc40_65078040_3,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x08170000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000010)) /* bit 27 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc40/75008000 level 2
   f7e0fc40/75008040 level 2
   f7e0fc40/75008400 level 2
   f7e0fc40/75008440 level 2
   f7e0fc40/75008800 level 2
   f7e0fc40/75008840 level 2
   f7e0fc40/75008c00 level 2
   f7e0fc40/75008c40 level 2
   f7e0fc40/75009800 level 2
   f7e0fc40/75009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_75008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x7d000000))
        return iemDecodeA64_STR_H_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe04000)) == UINT32_C(0x75000000))
        return iemDecodeA64_CBGT_32_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/a5008000 level 2
   f7e0fc40/a5008040 level 2
   f7e0fc40/a5008400 level 2
   f7e0fc40/a5008440 level 2
   f7e0fc40/a5008800 level 2
   f7e0fc40/a5008840 level 2
   f7e0fc40/a5008c00 level 2
   f7e0fc40/a5008c40 level 2
   f7e0fc40/a5009800 level 2
   f7e0fc40/a5009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_a5008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xad000000))
        return iemDecodeA64_STP_Q_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa5008000))
        return iemDecodeA64_ld1w_z_p_br_u128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/e5008000 level 2
   f7e0fc40/e5008040 level 2
   f7e0fc40/e5008400 level 2
   f7e0fc40/e5008440 level 2
   f7e0fc40/e5008800 level 2
   f7e0fc40/e5008840 level 2
   f7e0fc40/e5008c00 level 2
   f7e0fc40/e5008c40 level 2
   f7e0fc40/e5009800 level 2
   f7e0fc40/e5009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_e5008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed000000))
        return iemDecodeA64_STTP_Q_ldstpair_off(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5008000))
        return iemDecodeA64_st1w_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/f5008000 level 2
   f7e0fc40/f5008040 level 2
   f7e0fc40/f5008400 level 2
   f7e0fc40/f5008440 level 2
   f7e0fc40/f5008800 level 2
   f7e0fc40/f5008840 level 2
   f7e0fc40/f5008c00 level 2
   f7e0fc40/f5008c40 level 2
   f7e0fc40/f5009800 level 2
   f7e0fc40/f5009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_f5008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xfd000000))
        return iemDecodeA64_STR_D_ldst_pos(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe04000)) == UINT32_C(0xf5000000))
        return iemDecodeA64_CBGT_64_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5008000/0xf0000040
   mask=0xf0000040 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%25 (0x8) multi-if=%62 (0x14) reuse=%41 (0xd) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05008000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc40_05008000_2,
        iemDecodeA64_f7e0fc40_05008000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_f7e0fc40_45008000_2,
        iemDecodeA64_f7e0fc40_45008000_2,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_f7e0fc40_65008000_2,
        iemDecodeA64_f7e0fc40_65008040_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000040 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000001)) /* bit  6 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc40/05008400 level 2
   f7e0fc40/05008440 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_05008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d008400))
        return iemDecodeA64_ST1_asisdlso_D1_1d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d018400))
        return iemDecodeA64_STL1_asisdlso_D1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05000000))
        return iemDecodeA64_orr_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/15008400 level 2
   f7e0fc40/15008440 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_15008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1d008400))
        return iemDecodeA64_CPYPRN_CPY_memcms(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/45008400 level 2
   f7e0fc40/45008440 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_45008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d008400))
        return iemDecodeA64_ST1_asisdlso_D1_1d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d018400))
        return iemDecodeA64_STL1_asisdlso_D1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/55008400 level 2
   f7e0fc40/55008440 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_55008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1d008400))
        return iemDecodeA64_CPYPRN_CPY_memcms(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0x5500001f))
        return iemDecodeA64_RETAASPPC_only_miscbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/65008400 level 2
   f7e0fc40/65008800 level 2
   f7e0fc40/65008c00 level 2
   f7e0fc40/65009800 level 2
   mask=0x8170000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%78 (0x19) multi-if=%22 (0x7) reuse=%22 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_65008400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff7fc40_65008040_3,
        iemDecodeA64_fff7fc40_65018040_3,
        iemDecodeA64_fff7fc40_65028040_3,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fff7fc40_65048040_3,
        iemDecodeA64_fff7fc40_65058040_3,
        iemDecodeA64_fff7fc40_65068040_3,
        iemDecodeA64_fff7fc40_65078040_3,
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_fmin_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x08170000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000010)) /* bit 27 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc40/65008440 level 3
   ffeffc40/65008840 level 3
   ffeffc40/65008c40 level 3
   ffeffc00/65009000 level 3
   fffffc00/65009400 level 3
   ffeffc40/65009840 level 3
   fffffc00/65009c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65008440_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65008000))
        return iemDecodeA64_fadd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65008000))
        return iemDecodeA64_bfadd_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65018440 level 3
   ffeffc40/65018840 level 3
   ffeffc40/65018c40 level 3
   ffeffc00/65019000 level 3
   fffffc00/65019400 level 3
   ffeffc40/65019840 level 3
   fffffc00/65019c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65018440_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65018000))
        return iemDecodeA64_fsub_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65018000))
        return iemDecodeA64_bfsub_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65028440 level 3
   ffeffc40/65028840 level 3
   ffeffc40/65028c40 level 3
   ffeffc00/65029000 level 3
   fffffc00/65029400 level 3
   ffeffc40/65029840 level 3
   fffffc00/65029c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65028440_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65028000))
        return iemDecodeA64_fmul_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65028000))
        return iemDecodeA64_bfmul_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65048440 level 3
   ffeffc40/65048840 level 3
   ffeffc40/65048c40 level 3
   ffeffc00/65049000 level 3
   fffffc00/65049400 level 3
   ffeffc40/65049840 level 3
   fffffc00/65049c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65048440_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65048000))
        return iemDecodeA64_fmaxnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65048000))
        return iemDecodeA64_bfmaxnm_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65058440 level 3
   ffeffc40/65058840 level 3
   ffeffc40/65058c40 level 3
   ffeffc00/65059000 level 3
   fffffc00/65059400 level 3
   ffeffc40/65059840 level 3
   fffffc00/65059c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65058440_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65058000))
        return iemDecodeA64_fminnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65058000))
        return iemDecodeA64_bfminnm_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65068440 level 3
   ffeffc40/65068840 level 3
   ffeffc40/65068c40 level 3
   ffeffc00/65069000 level 3
   fffffc00/65069400 level 3
   ffeffc40/65069840 level 3
   fffffc00/65069c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65068440_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65068000))
        return iemDecodeA64_fmax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65068000))
        return iemDecodeA64_bfmax_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65078440 level 3
   ffeffc40/65078840 level 3
   ffeffc40/65078c40 level 3
   ffeffc00/65079000 level 3
   fffffc00/65079400 level 3
   ffeffc40/65079840 level 3
   fffffc00/65079c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65078440_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65078000))
        return iemDecodeA64_fmin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65078000))
        return iemDecodeA64_bfmin_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc40/65098440 level 3
   ffeffc40/65098840 level 3
   ffeffc40/65098c40 level 3
   fffffc00/65099400 level 3
   ffeffc40/65099840 level 3
   fffffc00/65099c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc40_65098440_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_fscale_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_bfscale_z_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/65008440 level 2
   f7e0fc40/65008840 level 2
   f7e0fc40/65008c40 level 2
   f7e0fc40/65009840 level 2
   mask=0x80f0000 entries=0x20 children=0x1f valid=%97 (0x1f) leaf=%72 (0x17) multi-if=%25 (0x8) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_65008440_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc40_65008440_3,
        iemDecodeA64_ffeffc40_65018440_3,
        iemDecodeA64_ffeffc40_65028440_3,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_ffeffc40_65048440_3,
        iemDecodeA64_ffeffc40_65058440_3,
        iemDecodeA64_ffeffc40_65068440_3,
        iemDecodeA64_ffeffc40_65078440_3,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_ffeffc40_65098440_3,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x080f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000010)) /* bit 27 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc40/95008400 level 2
   f7e0fc40/95008440 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_95008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1d008400))
        return iemDecodeA64_CPYPRN_CPY_memcms(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/d5008400 level 2
   f7e0fc40/d5008440 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_d5008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1d008400))
        return iemDecodeA64_CPYPRN_CPY_memcms(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5008400/0xf0000040
   mask=0xf0000040 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%6 (0x2) multi-if=%81 (0x1a) reuse=%62 (0x14) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05008400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc40_05008400_2,
        iemDecodeA64_f7e0fc40_05008400_2,
        iemDecodeA64_f7e0fc40_15008400_2,
        iemDecodeA64_f7e0fc40_15008400_2,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_f7e0fc40_45008400_2,
        iemDecodeA64_f7e0fc40_45008400_2,
        iemDecodeA64_f7e0fc40_55008400_2,
        iemDecodeA64_f7e0fc40_55008400_2,
        iemDecodeA64_f7e0fc40_65008400_2,
        iemDecodeA64_f7e0fc40_65008440_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e0fc40_95008400_2,
        iemDecodeA64_f7e0fc40_95008400_2,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_f7e0fc40_d5008400_2,
        iemDecodeA64_f7e0fc40_d5008400_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000040 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000001)) /* bit  6 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc40/15008800 level 2
   f7e0fc40/15008840 level 2
   f7e0fc40/15009800 level 2
   f7e0fc40/15009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_15008800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1d000800))
        return iemDecodeA64_STLUR_B_ldapstl_simd(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/55008800 level 2
   f7e0fc40/55008840 level 2
   f7e0fc40/55009800 level 2
   f7e0fc40/55009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_55008800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0001f)) == UINT32_C(0x5500001f))
        return iemDecodeA64_RETAASPPC_only_miscbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x5d000800))
        return iemDecodeA64_STLUR_H_ldapstl_simd(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/95008800 level 2
   f7e0fc40/95008840 level 2
   f7e0fc40/95009800 level 2
   f7e0fc40/95009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_95008800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x9d000800))
        return iemDecodeA64_STLUR_S_ldapstl_simd(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc40/d5008800 level 2
   f7e0fc40/d5008840 level 2
   f7e0fc40/d5009800 level 2
   f7e0fc40/d5009840 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc40_d5008800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0xdd000800))
        return iemDecodeA64_STLUR_D_ldapstl_simd(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5100000))
        return iemDecodeA64_MSR_SR_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5080000))
        return iemDecodeA64_SYS_CR_systeminstrs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5008800/0xf0000040
   mask=0xf0000040 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%19 (0x6) multi-if=%69 (0x16) reuse=%62 (0x14) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05008800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_f7e0fc40_15008800_2,
        iemDecodeA64_f7e0fc40_15008800_2,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_f7e0fc40_55008800_2,
        iemDecodeA64_f7e0fc40_55008800_2,
        iemDecodeA64_f7e0fc40_65008400_2,
        iemDecodeA64_f7e0fc40_65008440_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e0fc40_95008800_2,
        iemDecodeA64_f7e0fc40_95008800_2,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_f7e0fc40_d5008800_2,
        iemDecodeA64_f7e0fc40_d5008800_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000040 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000001)) /* bit  6 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5008c00/0xf0000040
   mask=0xf0000040 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%38 (0xc) multi-if=%50 (0x10) reuse=%56 (0x12) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05008c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_f7e0fc40_65008400_2,
        iemDecodeA64_f7e0fc40_65008440_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000040 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000001)) /* bit  6 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/25009000 level 3
   ffeffc00/25019000 level 3
   ffeffc00/25029000 level 3
   ffeffc00/25039000 level 3
   ffeffc00/25049000 level 3
   ffeffc00/25059000 level 3
   ffeffc00/25069000 level 3
   ffeffc00/25079000 level 3
   ffeffc00/25089000 level 3
   ffeffc00/25099000 level 3
   ffeffc00/250a9000 level 3
   ffeffc00/250b9000 level 3
   ffeffc00/250c9000 level 3
   ffeffc00/250d9000 level 3
   ffeffc00/250e9000 level 3
   ffeffc00/250f9000 level 3
   fffffc00/25009400 level 3
   fffffc00/25019400 level 3
   fffffc00/25029400 level 3
   fffffc00/25039400 level 3
   fffffc00/25049400 level 3
   fffffc00/25059400 level 3
   fffffc00/25069400 level 3
   fffffc00/25079400 level 3
   fffffc00/25089400 level 3
   fffffc00/25099400 level 3
   fffffc00/250a9400 level 3
   fffffc00/250b9400 level 3
   fffffc00/250c9400 level 3
   fffffc00/250d9400 level 3
   fffffc00/250e9400 level 3
   fffffc00/250f9400 level 3
   fffffc00/25109400 level 3
   fffffc00/25119400 level 3
   fffffc00/25129400 level 3
   fffffc00/25139400 level 3
   fffffc00/25149400 level 3
   fffffc00/25159400 level 3
   fffffc00/25169400 level 3
   fffffc00/25179400 level 3
   fffffc00/25189400 level 3
   fffffc00/25199400 level 3
   fffffc00/251a9400 level 3
   fffffc00/251b9400 level 3
   fffffc00/251c9400 level 3
   fffffc00/251d9400 level 3
   fffffc00/251e9400 level 3
   fffffc00/251f9400 level 3
   ffe4fc00/25009c00 level 2
   ffe4fc00/25049c00 level 2
   ffe0fc00/25408000 level 2
   ffe0fc00/25408400 level 2
   ffe0fc00/25408800 level 2
   ffe0fc00/25408c00 level 2
   ffe0fc00/25409000 level 2
   ffe0fc00/25409400 level 2
   ffe0fc00/25409800 level 2
   ffe0fc00/25409c00 level 2
   ffe1fc00/25808000 level 2
   ffe1fc00/25818000 level 2
   ffe6fc00/25808800 level 2
   ffe6fc00/25828800 level 2
   ffe6fc00/25848800 level 2
   ffe6fc00/25868800 level 2
   ffe3fc00/25808c00 level 2
   ffe3fc00/25818c00 level 2
   ffe3fc00/25828c00 level 2
   ffe3fc00/25838c00 level 2
   ffe4fc00/25809000 level 2
   ffe4fc00/25849000 level 2
   fffffc00/25809400 level 3
   fffffc00/25819400 level 3
   fffffc00/25829400 level 3
   fffffc00/25839400 level 3
   fffffc00/25849400 level 3
   fffffc00/25859400 level 3
   fffffc00/25869400 level 3
   fffffc00/25879400 level 3
   fffffc00/25889400 level 3
   fffffc00/25899400 level 3
   fffffc00/258a9400 level 3
   fffffc00/258b9400 level 3
   fffffc00/258c9400 level 3
   fffffc00/258d9400 level 3
   fffffc00/258e9400 level 3
   fffffc00/258f9400 level 3
   fffffc00/25909400 level 3
   fffffc00/25919400 level 3
   fffffc00/25929400 level 3
   fffffc00/25939400 level 3
   fffffc00/25949400 level 3
   fffffc00/25959400 level 3
   fffffc00/25969400 level 3
   fffffc00/25979400 level 3
   fffffc00/25989400 level 3
   fffffc00/25999400 level 3
   fffffc00/259a9400 level 3
   fffffc00/259b9400 level 3
   fffffc00/259c9400 level 3
   fffffc00/259d9400 level 3
   fffffc00/259e9400 level 3
   fffffc00/259f9400 level 3
   ffe6fc00/25809800 level 2
   ffe6fc00/25829800 level 2
   ffe6fc00/25849800 level 2
   ffe6fc00/25869800 level 2
   fffffc00/25c08000 level 3
   fffffc00/25c18000 level 3
   fffffc00/25c28000 level 3
   fffffc00/25c38000 level 3
   fffffc00/25c48000 level 3
   fffffc00/25c58000 level 3
   fffffc00/25c68000 level 3
   fffffc00/25c78000 level 3
   fffffc00/25c88000 level 3
   fffffc00/25c98000 level 3
   fffffc00/25ca8000 level 3
   fffffc00/25cb8000 level 3
   fffffc00/25cc8000 level 3
   fffffc00/25cd8000 level 3
   fffffc00/25ce8000 level 3
   fffffc00/25cf8000 level 3
   fffffc00/25d08000 level 3
   fffffc00/25d18000 level 3
   fffffc00/25d28000 level 3
   fffffc00/25d38000 level 3
   fffffc00/25d48000 level 3
   fffffc00/25d58000 level 3
   fffffc00/25d68000 level 3
   fffffc00/25d78000 level 3
   fffffc00/25d88000 level 3
   fffffc00/25d98000 level 3
   fffffc00/25da8000 level 3
   fffffc00/25db8000 level 3
   fffffc00/25dc8000 level 3
   fffffc00/25dd8000 level 3
   fffffc00/25de8000 level 3
   fffffc00/25df8000 level 3
   ffeffc00/25c08400 level 3
   ffeffc00/25c18400 level 3
   ffeffc00/25c28400 level 3
   ffeffc00/25c38400 level 3
   ffeffc00/25c48400 level 3
   ffeffc00/25c58400 level 3
   ffeffc00/25c68400 level 3
   ffeffc00/25c78400 level 3
   ffeffc00/25c88400 level 3
   ffeffc00/25c98400 level 3
   ffeffc00/25ca8400 level 3
   ffeffc00/25cb8400 level 3
   ffeffc00/25cc8400 level 3
   ffeffc00/25cd8400 level 3
   ffeffc00/25ce8400 level 3
   ffeffc00/25cf8400 level 3
   ffe4fc00/25c08800 level 2
   ffe4fc00/25c48800 level 2
   ffe6fc00/25c08c00 level 2
   ffe6fc00/25c28c00 level 2
   ffe6fc00/25c48c00 level 2
   ffe6fc00/25c68c00 level 2
   ffe4fc00/25c09800 level 2
   ffe4fc00/25c49800 level 2
   ffe3fc00/25c09c00 level 2
   ffe3fc00/25c19c00 level 2
   ffe3fc00/25c29c00 level 2
   ffe3fc00/25c39c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_25009000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25008000))
        return iemDecodeA64_cmpeq_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25008010))
        return iemDecodeA64_cmpne_p_p_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0feffc00/05009000 level 2
   mask=0xf0000000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%81 (0xd) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05009000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65008440_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05019000 level 2
   mask=0xf0000000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%81 (0xd) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05019000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65018440_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05029000 level 2
   mask=0xf0000000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%81 (0xd) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05029000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65028440_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05039000 level 2
   mask=0xf0000000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%88 (0xe) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05039000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05049000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05049000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65048440_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05059000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05059000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65058440_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05069000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05069000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65068440_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05079000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05079000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65078440_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05089000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%69 (0xb) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05089000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65088000_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05099000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%69 (0xb) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05099000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_65098000_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/050a9000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%69 (0xb) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_050a9000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_650a8000_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/050b9000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_050b9000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/050c9000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%69 (0xb) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_050c9000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_650c8000_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/050d9000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%69 (0xb) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_050d9000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_650d8000_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/050e9000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%69 (0xb) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_050e9000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_650e8000_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/050f9000 level 2
   mask=0xf0000000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%69 (0xb) multi-if=%19 (0x3) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_050f9000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_ffeffc40_650f8000_3,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_CBGT_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/0d009000 level 2
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%62 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_0d009000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ST1_asisdlso_S1_1s,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ST1_asisdlso_S1_1s,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/0d019000 level 2
   0feffc00/0d029000 level 2
   0feffc00/0d039000 level 2
   0feffc00/0d049000 level 2
   0feffc00/0d059000 level 2
   0feffc00/0d069000 level 2
   0feffc00/0d079000 level 2
   0feffc00/0d089000 level 2
   0feffc00/0d099000 level 2
   0feffc00/0d0a9000 level 2
   0feffc00/0d0b9000 level 2
   0feffc00/0d0c9000 level 2
   0feffc00/0d0d9000 level 2
   0feffc00/0d0e9000 level 2
   0feffc00/0d0f9000 level 2
   mask=0xf0000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%50 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_0d019000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5009000/0x80f0000
   mask=0x80f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05009000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_0feffc00_05009000_2,
        iemDecodeA64_0feffc00_05019000_2,
        iemDecodeA64_0feffc00_05029000_2,
        iemDecodeA64_0feffc00_05039000_2,
        iemDecodeA64_0feffc00_05049000_2,
        iemDecodeA64_0feffc00_05059000_2,
        iemDecodeA64_0feffc00_05069000_2,
        iemDecodeA64_0feffc00_05079000_2,
        iemDecodeA64_0feffc00_05089000_2,
        iemDecodeA64_0feffc00_05099000_2,
        iemDecodeA64_0feffc00_050a9000_2,
        iemDecodeA64_0feffc00_050b9000_2,
        iemDecodeA64_0feffc00_050c9000_2,
        iemDecodeA64_0feffc00_050d9000_2,
        iemDecodeA64_0feffc00_050e9000_2,
        iemDecodeA64_0feffc00_050f9000_2,
        iemDecodeA64_0feffc00_0d009000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
        iemDecodeA64_0feffc00_0d019000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x080f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000010)) /* bit 27 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05009400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05009400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc40_65008440_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05019400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05019400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc40_65018440_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05029400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05029400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc40_65028440_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05039400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05039400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05049400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05049400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc40_65048440_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05059400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05059400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc40_65058440_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05069400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05069400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc40_65068440_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05079400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05079400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc40_65078440_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05089400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05089400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05099400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%75 (0x18) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05099400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc40_65098440_3,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/050a9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_050a9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/050b9400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%75 (0x18) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_050b9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/050c9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_050c9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/050d9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_050d9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/050e9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_050e9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/050f9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_050f9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYS_CR_systeminstrs,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05109400 level 2
   07fffc00/05119400 level 2
   07fffc00/05129400 level 2
   07fffc00/05139400 level 2
   07fffc00/05149400 level 2
   07fffc00/05159400 level 2
   07fffc00/05169400 level 2
   07fffc00/05179400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%75 (0x18) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05109400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05189400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05189400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05199400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05199400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/051a9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_051a9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/051b9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_051b9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/051c9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_051c9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/051d9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_051d9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/051e9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_051e9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/051f9400 level 2
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%78 (0x19) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_051f9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_fmin_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSR_SR_systemmove,
        iemDecodeA64_CPYPWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5009400/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%22 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05009400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_05009400_2,
        iemDecodeA64_07fffc00_05019400_2,
        iemDecodeA64_07fffc00_05029400_2,
        iemDecodeA64_07fffc00_05039400_2,
        iemDecodeA64_07fffc00_05049400_2,
        iemDecodeA64_07fffc00_05059400_2,
        iemDecodeA64_07fffc00_05069400_2,
        iemDecodeA64_07fffc00_05079400_2,
        iemDecodeA64_07fffc00_05089400_2,
        iemDecodeA64_07fffc00_05099400_2,
        iemDecodeA64_07fffc00_050a9400_2,
        iemDecodeA64_07fffc00_050b9400_2,
        iemDecodeA64_07fffc00_050c9400_2,
        iemDecodeA64_07fffc00_050d9400_2,
        iemDecodeA64_07fffc00_050e9400_2,
        iemDecodeA64_07fffc00_050f9400_2,
        iemDecodeA64_07fffc00_05109400_2,
        iemDecodeA64_07fffc00_05109400_2,
        iemDecodeA64_07fffc00_05109400_2,
        iemDecodeA64_07fffc00_05109400_2,
        iemDecodeA64_07fffc00_05109400_2,
        iemDecodeA64_07fffc00_05109400_2,
        iemDecodeA64_07fffc00_05109400_2,
        iemDecodeA64_07fffc00_05109400_2,
        iemDecodeA64_07fffc00_05189400_2,
        iemDecodeA64_07fffc00_05199400_2,
        iemDecodeA64_07fffc00_051a9400_2,
        iemDecodeA64_07fffc00_051b9400_2,
        iemDecodeA64_07fffc00_051c9400_2,
        iemDecodeA64_07fffc00_051d9400_2,
        iemDecodeA64_07fffc00_051e9400_2,
        iemDecodeA64_07fffc00_051f9400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5009800/0xf0000040
   mask=0xf0000040 entries=0x20 children=0x1e valid=%94 (0x1e) leaf=%19 (0x6) multi-if=%69 (0x16) reuse=%75 (0x18) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05009800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_f7e0fc40_15008800_2,
        iemDecodeA64_f7e0fc40_15008800_2,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc40_25008000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_f7e0fc00_35004000_2,
        iemDecodeA64_smmla_z_zzz,
        iemDecodeA64_smmla_z_zzz,
        iemDecodeA64_f7e0fc40_55008800_2,
        iemDecodeA64_f7e0fc40_55008800_2,
        iemDecodeA64_f7e0fc40_65008400_2,
        iemDecodeA64_f7e0fc40_65008440_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_f7e0fc40_75008000_2,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e0fc40_95008800_2,
        iemDecodeA64_f7e0fc40_95008800_2,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc40_a5008000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_f7e0fc00_b5004000_2,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_f7e0fc40_d5008800_2,
        iemDecodeA64_f7e0fc40_d5008800_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_e5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
        iemDecodeA64_f7e0fc40_f5008000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000040 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000001)) /* bit  6 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe4fc00/65009c00 level 2
   mask=0x1b0000 entries=0x10 children=0xb valid=%69 (0xb) leaf=%44 (0x7) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_65009c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc40_65008440_3,
        iemDecodeA64_ffeffc40_65018440_3,
        iemDecodeA64_ffeffc40_65028440_3,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_ffeffc40_65098440_3,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_fsubr_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000c)) /* bit 19 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe4fc00/65049c00 level 2
   mask=0x1b0000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%50 (0x8) multi-if=%25 (0x4) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_65049c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc40_65048440_3,
        iemDecodeA64_ffeffc40_65058440_3,
        iemDecodeA64_ffeffc40_65068440_3,
        iemDecodeA64_ffeffc40_65078440_3,
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_fmin_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000c)) /* bit 19 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5009c00/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x2b valid=%67 (0x2b) leaf=%58 (0x25) multi-if=%6 (0x4) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05009c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe4fc00_65009c00_2,
        iemDecodeA64_ffe4fc00_65049c00_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_ld1w_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_ldnt1sw_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/6502a000 level 3
   fff7fc00/6502a400 level 3
   fff7fc00/6502a800 level 3
   fff7fc00/6502ac00 level 3
   fff7fc00/6502b000 level 3
   fff7fc00/6502b400 level 3
   fff7fc00/6502b800 level 3
   fff7fc00/6502bc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_6502a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6502a000))
        return iemDecodeA64_frintm_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x650aa000))
        return iemDecodeA64_fcvtx_z_p_z_d2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc00/6504a000 level 3
   fff7fc00/6504a400 level 3
   fff7fc00/6504a800 level 3
   fff7fc00/6504ac00 level 3
   fff7fc00/6504b000 level 3
   fff7fc00/6504b400 level 3
   fff7fc00/6504b800 level 3
   fff7fc00/6504bc00 level 3
   fff7fc00/65c4a400 level 3
   fff7fc00/65c4b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_6504a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6504a000))
        return iemDecodeA64_frinta_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650ca000))
        return iemDecodeA64_frecpx_z_p_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc00/6510a000 level 3
   fff7fc00/6512a000 level 3
   fff7fc00/6510a400 level 3
   fff7fc00/6512a400 level 3
   fff7fc00/6510a800 level 3
   fff7fc00/6512a800 level 3
   fff7fc00/6510ac00 level 3
   fff7fc00/6512ac00 level 3
   fff7fc00/6510b000 level 3
   fff7fc00/6512b000 level 3
   fff7fc00/6510b400 level 3
   fff7fc00/6512b400 level 3
   fff7fc00/6510b800 level 3
   fff7fc00/6512b800 level 3
   fff7fc00/6510bc00 level 3
   fff7fc00/6512bc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_6510a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff9e000)) == UINT32_C(0x6518a000))
        return iemDecodeA64_flogb_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffde000)) == UINT32_C(0x6510a000))
        return iemDecodeA64_frint32z_z_p_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc00/6514a000 level 3
   fff7fc00/6516a000 level 3
   fff7fc00/6514a400 level 3
   fff7fc00/6516a400 level 3
   fff7fc00/6514a800 level 3
   fff7fc00/6516a800 level 3
   fff7fc00/6514ac00 level 3
   fff7fc00/6516ac00 level 3
   fff7fc00/6514b000 level 3
   fff7fc00/6516b000 level 3
   fff7fc00/6514b400 level 3
   fff7fc00/6516b400 level 3
   fff7fc00/6514b800 level 3
   fff7fc00/6516b800 level 3
   fff7fc00/6514bc00 level 3
   fff7fc00/6516bc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_6514a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff9e000)) == UINT32_C(0x6518a000))
        return iemDecodeA64_flogb_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffde000)) == UINT32_C(0x6514a000))
        return iemDecodeA64_frint64z_z_p_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/6500a000 level 2
   ffe0fc00/6500a400 level 2
   ffe0fc00/6500a800 level 2
   ffe0fc00/6500ac00 level 2
   ffe0fc00/6500b000 level 2
   ffe0fc00/6500b400 level 2
   ffe0fc00/6500b800 level 2
   ffe0fc00/6500bc00 level 2
   mask=0x170000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%62 (0xa) multi-if=%38 (0x6) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6500a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_fff7fc00_6502a000_3,
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_fff7fc00_6504a000_3,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_fff7fc00_6510a000_3,
        iemDecodeA64_frint32x_z_p_z_m,
        iemDecodeA64_fff7fc00_6510a000_3,
        iemDecodeA64_frint32x_z_p_z_m,
        iemDecodeA64_fff7fc00_6514a000_3,
        iemDecodeA64_frint64x_z_p_z_m,
        iemDecodeA64_fff7fc00_6514a000_3,
        iemDecodeA64_frint64x_z_p_z_m,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00170000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a500a000 level 2
   ffe0fc00/a500a400 level 2
   ffe0fc00/a500a800 level 2
   ffe0fc00/a500ac00 level 2
   ffe0fc00/a500b000 level 2
   ffe0fc00/a500b400 level 2
   ffe0fc00/a500b800 level 2
   ffe0fc00/a500bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a500a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa500a000))
        return iemDecodeA64_ld1sh_z_p_bi_s64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa510a000))
        return iemDecodeA64_ldnf1sh_z_p_bi_s64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_ST3_asisdlso_S3_3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_ST3_asisdlso_S3_3s,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500a000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a500a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%78 (0x19) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_ST3_asisdlso_D3_3d,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_ST3_asisdlso_D3_3d,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPRTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_6500a000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPRTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a500a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500a800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ushllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_6500a000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ffe0fc00_a500a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500a000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a500a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_ST3_asisdlso_S3_3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_ST3_asisdlso_S3_3s,
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500a000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a500a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_6500a000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a500a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_bgrp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_6500a000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ffe0fc00_a500a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500a000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBGT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a500a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBGT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0500c000 level 2
   ffe0fc00/0500c400 level 2
   ffe0fc00/0500c800 level 2
   ffe0fc00/0500cc00 level 2
   ffe0fc00/0500d000 level 2
   ffe0fc00/0500d400 level 2
   ffe0fc00/0500d800 level 2
   ffe0fc00/0500dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0500c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30e000)) == UINT32_C(0x0510c000))
        return iemDecodeA64_fcpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05000000))
        return iemDecodeA64_orr_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/2500c000 level 2
   ffe0fc00/2500c800 level 2
   ffe0fc00/2500cc00 level 2
   ffe0fc00/2500d000 level 2
   ffe0fc00/2500d400 level 2
   ffe0fc00/2500d800 level 2
   ffe0fc00/2500dc00 level 2
   ffe0fc00/2500e800 level 2
   ffe0fc00/2500ec00 level 2
   ffe0fc00/2500f400 level 2
   ffe0fc00/2500f800 level 2
   ffe0fc00/2500fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2500c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c000))
        return iemDecodeA64_brkpa_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c010))
        return iemDecodeA64_brkpb_p_p_pp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/6500c000 level 2
   ffe0fc00/6500c400 level 2
   ffe0fc00/6500c800 level 2
   ffe0fc00/6500cc00 level 2
   ffe0fc00/6500d000 level 2
   ffe0fc00/6500d400 level 2
   ffe0fc00/6500d800 level 2
   ffe0fc00/6500dc00 level 2
   ffe0fc00/6540c000 level 2
   ffe0fc00/6540c400 level 2
   ffe0fc00/6540c800 level 2
   ffe0fc00/6540cc00 level 2
   ffe0fc00/6540d000 level 2
   ffe0fc00/6540d400 level 2
   ffe0fc00/6540d800 level 2
   ffe0fc00/6540dc00 level 2
   ffe0fc00/6580c000 level 2
   ffe0fc00/6580c400 level 2
   ffe0fc00/6580c800 level 2
   ffe0fc00/6580cc00 level 2
   ffe0fc00/6580d000 level 2
   ffe0fc00/6580d400 level 2
   ffe0fc00/6580d800 level 2
   ffe0fc00/6580dc00 level 2
   ffe0fc00/65c0c000 level 2
   ffe0fc00/65c0c400 level 2
   ffe0fc00/65c0c800 level 2
   ffe0fc00/65c0cc00 level 2
   ffe0fc00/65c0d000 level 2
   ffe0fc00/65c0d400 level 2
   ffe0fc00/65c0d800 level 2
   ffe0fc00/65c0dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6500c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x6500c000))
        return iemDecodeA64_fcmuo_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x6500c010))
        return iemDecodeA64_facge_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0500c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sabalb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2500c400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2500c400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe10)) == UINT32_C(0x2519c400))
        return iemDecodeA64_pnext_p_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c000))
        return iemDecodeA64_brkpa_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c010))
        return iemDecodeA64_brkpb_p_p_pp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0500c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPN_CPY_memcms,
        iemDecodeA64_ffe0fc00_2500c400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sabalt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPN_CPY_memcms,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPN_CPY_memcms,
        iemDecodeA64_ldnt1w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0500c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uabalb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ldnt1w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0500c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uabalt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0500c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_adclb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0500c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPWTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_adclt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPWTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPWTN_CPY_memcms,
        iemDecodeA64_ldnt1w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPWTN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/4500d800 level 2
   ffe0fc00/4500dc00 level 2
   ffe0fc00/4540d800 level 2
   ffe0fc00/4540dc00 level 2
   ffe0fc00/4580d800 level 2
   ffe0fc00/4580dc00 level 2
   ffe0fc00/45c0d800 level 2
   ffe0fc00/45c0dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_4500d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ff800)) == UINT32_C(0x4500d800))
        return iemDecodeA64_cadd_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ff800)) == UINT32_C(0x4501d800))
        return iemDecodeA64_sqcadd_z_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%66 (0x15) multi-if=%16 (0x5) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0500c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_4500d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ldnt1w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%53 (0x11) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0500c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_4500d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldnt1w_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2500e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2500e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc10)) == UINT32_C(0x2518e000))
        return iemDecodeA64_ptrue_p_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffc10)) == UINT32_C(0x2519e000))
        return iemDecodeA64_ptrues_p_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c000))
        return iemDecodeA64_brkpa_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c010))
        return iemDecodeA64_brkpb_p_p_pp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a500e000 level 2
   ffe0fc00/a500e400 level 2
   ffe0fc00/a500e800 level 2
   ffe0fc00/a500ec00 level 2
   ffe0fc00/a500f000 level 2
   ffe0fc00/a500f400 level 2
   ffe0fc00/a500f800 level 2
   ffe0fc00/a500fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a500e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa500e000))
        return iemDecodeA64_ldnt1w_z_p_bi_contiguous(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa510e000))
        return iemDecodeA64_ld3q_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/e500e000 level 2
   ffe0fc00/e500e400 level 2
   ffe0fc00/e500e800 level 2
   ffe0fc00/e500ec00 level 2
   ffe0fc00/e500f000 level 2
   ffe0fc00/e500f400 level 2
   ffe0fc00/e500f800 level 2
   ffe0fc00/e500fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e500e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe500e000))
        return iemDecodeA64_st1w_z_p_bi_u128(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe510e000))
        return iemDecodeA64_stnt1w_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2500e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ssra_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a500e000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e500e000_2,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2500e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2500e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c000))
        return iemDecodeA64_brkpa_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c010))
        return iemDecodeA64_brkpb_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffff0)) == UINT32_C(0x2518e400))
        return iemDecodeA64_pfalse_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPRTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_2500e400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_usra_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPRTN_CPY_memcms,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPRTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a500e000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPRTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_e500e000_2,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_srsra_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ffe0fc00_a500e000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_ffe0fc00_e500e000_2,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ursra_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a500e000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e500e000_2,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2500f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2500f000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c000))
        return iemDecodeA64_brkpa_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2500c010))
        return iemDecodeA64_brkpb_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffe10)) == UINT32_C(0x2518f000))
        return iemDecodeA64_rdffr_p_p_f(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffff0)) == UINT32_C(0x2519f000))
        return iemDecodeA64_rdffr_p_f(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2500f000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sri_z_zzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a500e000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e500e000_2,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYPTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sli_z_zzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_CPYPTN_CPY_memcms,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYPTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a500e000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_CPYPTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_e500e000_2,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_saba_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_STLUR_H_ldapstl_simd,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_STLUR_S_ldapstl_simd,
        iemDecodeA64_ffe0fc00_a500e000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_STLUR_D_ldapstl_simd,
        iemDecodeA64_ffe0fc00_e500e000_2,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x500fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0500fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2500c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uaba_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETAASPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a500e000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_prfw_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5000000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e500e000_2,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25200000 level 2
   ffe0fc00/25201000 level 2
   ffe0fc00/25600000 level 2
   ffe0fc00/25601000 level 2
   ffe0fc00/25a00000 level 2
   ffe0fc00/25a01000 level 2
   ffe0fc00/25e00000 level 2
   ffe0fc00/25e01000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25200000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20ec10)) == UINT32_C(0x25200000))
        return iemDecodeA64_whilege_p_p_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20ec10)) == UINT32_C(0x25200010))
        return iemDecodeA64_whilegt_p_p_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/65200000 level 2
   ffe0fc00/65200400 level 2
   ffe0fc00/65200800 level 2
   ffe0fc00/65200c00 level 2
   ffe0fc00/65201000 level 2
   ffe0fc00/65201400 level 2
   ffe0fc00/65201800 level 2
   ffe0fc00/65201c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65200000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e000)) == UINT32_C(0x65200000))
        return iemDecodeA64_fmla_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0x65200000))
        return iemDecodeA64_bfmla_z_p_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/d5200000 level 2
   ffe0fc00/d5200400 level 2
   ffe0fc00/d5200800 level 2
   ffe0fc00/d5200c00 level 2
   ffe0fc00/d5201000 level 2
   ffe0fc00/d5201400 level 2
   ffe0fc00/d5201800 level 2
   ffe0fc00/d5201c00 level 2
   ffe0fc00/d5202000 level 2
   ffe0fc00/d5202400 level 2
   ffe0fc00/d5202800 level 2
   ffe0fc00/d5202c00 level 2
   ffe0fc00/d5203400 level 2
   ffe0fc00/d5203800 level 2
   ffe0fc00/d5203c00 level 2
   ffe0fc00/d5204000 level 2
   ffe0fc00/d5204400 level 2
   ffe0fc00/d5204800 level 2
   ffe0fc00/d5204c00 level 2
   ffe0fc00/d5205000 level 2
   ffe0fc00/d5205400 level 2
   ffe0fc00/d5205800 level 2
   ffe0fc00/d5205c00 level 2
   ffe0fc00/d5206000 level 2
   ffe0fc00/d5206400 level 2
   ffe0fc00/d5206800 level 2
   ffe0fc00/d5206c00 level 2
   ffe0fc00/d5207000 level 2
   ffe0fc00/d5207400 level 2
   ffe0fc00/d5207800 level 2
   ffe0fc00/d5207c00 level 2
   ffe0fc00/d5208000 level 2
   ffe0fc00/d5208400 level 2
   ffe0fc00/d5208800 level 2
   ffe0fc00/d5208c00 level 2
   ffe0fc00/d5209000 level 2
   ffe0fc00/d5209400 level 2
   ffe0fc00/d5209800 level 2
   ffe0fc00/d5209c00 level 2
   ffe0fc00/d520a000 level 2
   ffe0fc00/d520a400 level 2
   ffe0fc00/d520a800 level 2
   ffe0fc00/d520ac00 level 2
   ffe0fc00/d520b000 level 2
   ffe0fc00/d520b400 level 2
   ffe0fc00/d520b800 level 2
   ffe0fc00/d520bc00 level 2
   ffe0fc00/d520c000 level 2
   ffe0fc00/d520c400 level 2
   ffe0fc00/d520c800 level 2
   ffe0fc00/d520cc00 level 2
   ffe0fc00/d520d000 level 2
   ffe0fc00/d520d400 level 2
   ffe0fc00/d520d800 level 2
   ffe0fc00/d520dc00 level 2
   ffe0fc00/d520e000 level 2
   ffe0fc00/d520e400 level 2
   ffe0fc00/d520e800 level 2
   ffe0fc00/d520ec00 level 2
   ffe0fc00/d520f000 level 2
   ffe0fc00/d520f400 level 2
   ffe0fc00/d520f800 level 2
   ffe0fc00/d520fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5200000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5300000))
        return iemDecodeA64_MRS_RS_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5280000))
        return iemDecodeA64_SYSL_RC_systeminstrs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5200000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05200000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_des,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqshrunb_z_zi,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65200000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25200400 level 2
   ffe0fc00/25201400 level 2
   ffe0fc00/25600400 level 2
   ffe0fc00/25601400 level 2
   ffe0fc00/25a00400 level 2
   ffe0fc00/25a01400 level 2
   ffe0fc00/25e00400 level 2
   ffe0fc00/25e01400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25200400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20ec10)) == UINT32_C(0x25200400))
        return iemDecodeA64_whilelt_p_p_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20ec10)) == UINT32_C(0x25200410))
        return iemDecodeA64_whilele_p_p_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5200400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05200400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_des,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqshrunt_z_zi,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65200000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25200800 level 2
   ffe0fc00/25201800 level 2
   ffe0fc00/25600800 level 2
   ffe0fc00/25601800 level 2
   ffe0fc00/25a00800 level 2
   ffe0fc00/25a01800 level 2
   ffe0fc00/25e00800 level 2
   ffe0fc00/25e01800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25200800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20ec10)) == UINT32_C(0x25200800))
        return iemDecodeA64_whilehs_p_p_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20ec10)) == UINT32_C(0x25200810))
        return iemDecodeA64_whilehi_p_p_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5200800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05200800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_des,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200800_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqrshrunb_z_zi,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65200000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25200c00 level 2
   ffe0fc00/25201c00 level 2
   ffe0fc00/25600c00 level 2
   ffe0fc00/25601c00 level 2
   ffe0fc00/25a00c00 level 2
   ffe0fc00/25a01c00 level 2
   ffe0fc00/25e00c00 level 2
   ffe0fc00/25e01c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25200c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20ec10)) == UINT32_C(0x25200c00))
        return iemDecodeA64_whilelo_p_p_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20ec10)) == UINT32_C(0x25200c10))
        return iemDecodeA64_whilels_p_p_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5200c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05200c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_des,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200c00_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqrshrunt_z_zi,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65200000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5201000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05201000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_des,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_shrnb_z_zi,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65200000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5201400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05201400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_des,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_shrnt_z_zi,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65200000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5201800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05201800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_des,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200800_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_rshrnb_z_zi,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65200000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5201c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05201c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_des,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200c00_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_rshrnt_z_zi,
        iemDecodeA64_ST2_asisdlso_B2_2b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65200000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65202000 level 2
   ffe0fc00/65202400 level 2
   ffe0fc00/65202800 level 2
   ffe0fc00/65202c00 level 2
   ffe0fc00/65203000 level 2
   ffe0fc00/65203400 level 2
   ffe0fc00/65203800 level 2
   ffe0fc00/65203c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65202000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e000)) == UINT32_C(0x65202000))
        return iemDecodeA64_fmls_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0x65202000))
        return iemDecodeA64_bfmls_z_p_zzz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5202000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05202000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dup_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqshrnb_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65202000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_bi_u32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5202400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05202400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupq_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqshrnt_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65202000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_bi_u32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5202800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05202800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbl_z_zz_2,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqrshrnb_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65202000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_bi_u32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5202c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05202c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbx_z_zz,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqrshrnt_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65202000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_bi_u32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25203000 level 2
   ffe0fc00/25603000 level 2
   ffe0fc00/25a03000 level 2
   ffe0fc00/25e03000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25203000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc10)) == UINT32_C(0x25203000))
        return iemDecodeA64_whilewr_p_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc10)) == UINT32_C(0x25203010))
        return iemDecodeA64_whilerw_p_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/d5203000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5203000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5300000))
        return iemDecodeA64_MRS_RS_systemmove(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5280000))
        return iemDecodeA64_SYSL_RC_systeminstrs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xd5233060))
        return iemDecodeA64_TSTART_BR_systemresult(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xd5233160))
        return iemDecodeA64_TTEST_BR_systemresult(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5203000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05203000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbl_z_zz_1,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25203000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uqshrnb_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65202000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_bi_u32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5203000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5203400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05203400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbxq_z_zz,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uqshrnt_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65202000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_bi_u32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05203800 level 2
   mask=0x1f0000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05203800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dup_z_r,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_insr_z_r,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_pmov_p_zi_b,
        iemDecodeA64_pmov_z_pi_b,
        iemDecodeA64_pmov_p_zi_h,
        iemDecodeA64_pmov_z_pi_h,
        iemDecodeA64_pmov_p_zi_h,
        iemDecodeA64_pmov_z_pi_h,
        iemDecodeA64_sunpklo_z_z,
        iemDecodeA64_sunpkhi_z_z,
        iemDecodeA64_uunpklo_z_z,
        iemDecodeA64_uunpkhi_z_z,
        iemDecodeA64_insr_z_v,
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_rev_z_z,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5203800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05203800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05203800_2,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uqrshrnb_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65202000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_bi_u32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5203c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05203c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uqrshrnt_z_zi,
        iemDecodeA64_ST4_asisdlso_B4_4b,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65202000_2,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1row_z_p_bi_u32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05204000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05204000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30fe10)) == UINT32_C(0x05204000))
        return iemDecodeA64_zip1_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe10)) == UINT32_C(0x05344000))
        return iemDecodeA64_rev_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffe10)) == UINT32_C(0x05304000))
        return iemDecodeA64_punpklo_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffe10)) == UINT32_C(0x05314000))
        return iemDecodeA64_punpkhi_p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/25204000 level 2
   ffe0fc00/25206000 level 2
   ffe0fc00/25604000 level 2
   ffe0fc00/25606000 level 2
   ffe0fc00/25a04000 level 2
   ffe0fc00/25a06000 level 2
   ffe0fc00/25e04000 level 2
   ffe0fc00/25e06000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25204000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20dc18)) == UINT32_C(0x25204010))
        return iemDecodeA64_whilege_pn_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20dc18)) == UINT32_C(0x25204018))
        return iemDecodeA64_whilegt_pn_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/45204000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_45204000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45204000))
        return iemDecodeA64_sqxtnb_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0x45314000))
        return iemDecodeA64_sqcvtn_z_mz2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5204000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05204000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05204000_2,
        iemDecodeA64_ST2_asisdlso_H2_2h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45204000_2,
        iemDecodeA64_ST2_asisdlso_H2_2h,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25204400 level 2
   ffe0fc00/25206400 level 2
   ffe0fc00/25604400 level 2
   ffe0fc00/25606400 level 2
   ffe0fc00/25a04400 level 2
   ffe0fc00/25a06400 level 2
   ffe0fc00/25e04400 level 2
   ffe0fc00/25e06400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25204400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20dc18)) == UINT32_C(0x25204410))
        return iemDecodeA64_whilelt_pn_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20dc18)) == UINT32_C(0x25204418))
        return iemDecodeA64_whilele_pn_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5204400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05204400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqxtnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25204800 level 2
   ffe0fc00/25206800 level 2
   ffe0fc00/25604800 level 2
   ffe0fc00/25606800 level 2
   ffe0fc00/25a04800 level 2
   ffe0fc00/25a06800 level 2
   ffe0fc00/25e04800 level 2
   ffe0fc00/25e06800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25204800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20dc18)) == UINT32_C(0x25204810))
        return iemDecodeA64_whilehs_pn_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20dc18)) == UINT32_C(0x25204818))
        return iemDecodeA64_whilehi_pn_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/45204800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_45204800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45204800))
        return iemDecodeA64_uqxtnb_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0x45314800))
        return iemDecodeA64_uqcvtn_z_mz2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5204800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05204800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_p_pp,
        iemDecodeA64_ST2_asisdlso_H2_2h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204800_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45204800_2,
        iemDecodeA64_ST2_asisdlso_H2_2h,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25204c00 level 2
   ffe0fc00/25206c00 level 2
   ffe0fc00/25604c00 level 2
   ffe0fc00/25606c00 level 2
   ffe0fc00/25a04c00 level 2
   ffe0fc00/25a06c00 level 2
   ffe0fc00/25e04c00 level 2
   ffe0fc00/25e06c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25204c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20dc18)) == UINT32_C(0x25204c10))
        return iemDecodeA64_whilelo_pn_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20dc18)) == UINT32_C(0x25204c18))
        return iemDecodeA64_whilels_pn_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5204c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05204c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204c00_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_uqxtnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25205000 level 2
   ffe0fc00/25605000 level 2
   ffe0fc00/25a05000 level 2
   ffe0fc00/25e05000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25205000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc11)) == UINT32_C(0x25205010))
        return iemDecodeA64_whilege_pp_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc11)) == UINT32_C(0x25205011))
        return iemDecodeA64_whilegt_pp_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/45205000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_45205000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa7fc00)) == UINT32_C(0x45205000))
        return iemDecodeA64_sqxtunb_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc20)) == UINT32_C(0x45315000))
        return iemDecodeA64_sqcvtun_z_mz2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5205000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05205000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_p_pp,
        iemDecodeA64_ST2_asisdlso_H2_2h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45205000_2,
        iemDecodeA64_ST2_asisdlso_H2_2h,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25205400 level 2
   ffe0fc00/25605400 level 2
   ffe0fc00/25a05400 level 2
   ffe0fc00/25e05400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25205400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc11)) == UINT32_C(0x25205410))
        return iemDecodeA64_whilelt_pp_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc11)) == UINT32_C(0x25205411))
        return iemDecodeA64_whilele_pp_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5205400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05205400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sqxtunt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25205800 level 2
   ffe0fc00/25605800 level 2
   ffe0fc00/25a05800 level 2
   ffe0fc00/25e05800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25205800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc11)) == UINT32_C(0x25205810))
        return iemDecodeA64_whilehs_pp_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc11)) == UINT32_C(0x25205811))
        return iemDecodeA64_whilehi_pp_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5205800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05205800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ST2_asisdlso_H2_2h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205800_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST2_asisdlso_H2_2h,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25205c00 level 2
   ffe0fc00/25605c00 level 2
   ffe0fc00/25a05c00 level 2
   ffe0fc00/25e05c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25205c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc11)) == UINT32_C(0x25205c10))
        return iemDecodeA64_whilelo_pp_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20fc11)) == UINT32_C(0x25205c11))
        return iemDecodeA64_whilels_pp_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5205c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05205c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205c00_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5206000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05206000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip1_z_zz,
        iemDecodeA64_ST4_asisdlso_H4_4h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_addhnb_z_zz,
        iemDecodeA64_ST4_asisdlso_H4_4h,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5206400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05206400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_addhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5206800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05206800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_z_zz,
        iemDecodeA64_ST4_asisdlso_H4_4h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204800_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_raddhnb_z_zz,
        iemDecodeA64_ST4_asisdlso_H4_4h,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5206c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05206c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204c00_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_raddhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25207000 level 2
   ffe0fc00/25607000 level 2
   ffe0fc00/25a07000 level 2
   ffe0fc00/25e07000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25207000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffc10)) == UINT32_C(0x25207010))
        return iemDecodeA64_pext_pn_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5207000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05207000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_z_zz,
        iemDecodeA64_ST4_asisdlso_H4_4h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_subhnb_z_zz,
        iemDecodeA64_ST4_asisdlso_H4_4h,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25207400 level 2
   ffe0fc00/25607400 level 2
   ffe0fc00/25a07400 level 2
   ffe0fc00/25e07400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25207400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe10)) == UINT32_C(0x25207410))
        return iemDecodeA64_pext_pp_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5207400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05207400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_subhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25207800 level 2
   ffe0fc00/25607800 level 2
   ffe0fc00/25a07800 level 2
   ffe0fc00/25e07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25207800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20c210)) == UINT32_C(0x25204000))
        return iemDecodeA64_psel_p_ppi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffff8)) == UINT32_C(0x25207810))
        return iemDecodeA64_ptrue_pn_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5207800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05207800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ST4_asisdlso_H4_4h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207800_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_rsubhnb_z_zz,
        iemDecodeA64_ST4_asisdlso_H4_4h,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5207c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05207c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_psel_p_ppi,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_rsubhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sh_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/05218000 level 3
   ffeffc00/05218400 level 3
   ffeffc00/05218800 level 3
   ffeffc00/05218c00 level 3
   ffeffc00/05219000 level 3
   ffeffc00/05219400 level 3
   ffeffc00/05219800 level 3
   ffeffc00/05219c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_05218000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05318000))
        return iemDecodeA64_expand_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbfe000)) == UINT32_C(0x05218000))
        return iemDecodeA64_compact_z_p_z_s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/05208000 level 2
   ffe0fc00/05208400 level 2
   ffe0fc00/05208800 level 2
   ffe0fc00/05208c00 level 2
   ffe0fc00/05209000 level 2
   ffe0fc00/05209400 level 2
   ffe0fc00/05209800 level 2
   ffe0fc00/05209c00 level 2
   mask=0xf0000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%88 (0xe) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05208000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cpy_z_p_v,
        iemDecodeA64_ffeffc00_05218000_3,
        iemDecodeA64_lasta_v_p_z,
        iemDecodeA64_lastb_v_p_z,
        iemDecodeA64_revb_z_z_m,
        iemDecodeA64_revh_z_z_m,
        iemDecodeA64_revw_z_z_m,
        iemDecodeA64_rbit_z_p_z_m,
        iemDecodeA64_clasta_z_p_zz,
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_splice_z_p_zz_des,
        iemDecodeA64_splice_z_p_zz_con,
        iemDecodeA64_revd_z_p_z_m,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/25208000 level 3
   ffeffc00/25608000 level 3
   fffffc00/25e08000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_25208000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffa00)) == UINT32_C(0x25208200))
        return iemDecodeA64_cntp_r_pn(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/25208000 level 2
   ffe0fc00/25608000 level 2
   mask=0xf0000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25208000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc00_25208000_3,
        iemDecodeA64_firstp_r_p_p,
        iemDecodeA64_lastp_r_p_p,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqincp_z_p_z,
        iemDecodeA64_uqincp_z_p_z,
        iemDecodeA64_sqdecp_z_p_z,
        iemDecodeA64_uqdecp_z_p_z,
        iemDecodeA64_incp_z_p_z,
        iemDecodeA64_decp_z_p_z,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/45208000 level 2
   ffe0fc00/45208400 level 2
   ffe0fc00/45208800 level 2
   ffe0fc00/45208c00 level 2
   ffe0fc00/45209000 level 2
   ffe0fc00/45209400 level 2
   ffe0fc00/45209800 level 2
   ffe0fc00/45209c00 level 2
   ffe0fc00/45608000 level 2
   ffe0fc00/45608400 level 2
   ffe0fc00/45608800 level 2
   ffe0fc00/45608c00 level 2
   ffe0fc00/45609000 level 2
   ffe0fc00/45609400 level 2
   ffe0fc00/45609800 level 2
   ffe0fc00/45609c00 level 2
   ffe0fe00/45a08000 level 2
   ffe0fe00/45a08200 level 2
   ffe3fc00/45a08800 level 2
   ffe3fc00/45a18800 level 2
   ffe3fc00/45a28800 level 2
   ffe3fc00/45a38800 level 2
   ffe1fc00/45a08c00 level 2
   ffe1fc00/45a18c00 level 2
   7fe0fe00/45a09000 level 2
   7fe0fe00/45a09200 level 2
   ffe1fc00/45a09400 level 2
   ffe1fc00/45a19400 level 2
   ffe1fc00/45a09800 level 2
   ffe1fc00/45a19800 level 2
   ffe1fc00/45a09c00 level 2
   ffe1fc00/45a19c00 level 2
   fffffc00/45e08000 level 3
   fffffc00/45e18000 level 3
   fffffc00/45e28000 level 3
   fffffc00/45e38000 level 3
   fffffc00/45e48000 level 3
   fffffc00/45e58000 level 3
   fffffc00/45e68000 level 3
   fffffc00/45e78000 level 3
   fffffc00/45e88000 level 3
   fffffc00/45e98000 level 3
   fffffc00/45ea8000 level 3
   fffffc00/45eb8000 level 3
   fffffc00/45ec8000 level 3
   fffffc00/45ed8000 level 3
   fffffc00/45ee8000 level 3
   fffffc00/45ef8000 level 3
   fffffc00/45f08000 level 3
   fffffc00/45f18000 level 3
   fffffc00/45f28000 level 3
   fffffc00/45f38000 level 3
   fffffc00/45f48000 level 3
   fffffc00/45f58000 level 3
   fffffc00/45f68000 level 3
   fffffc00/45f78000 level 3
   fffffc00/45f88000 level 3
   fffffc00/45f98000 level 3
   fffffc00/45fa8000 level 3
   fffffc00/45fb8000 level 3
   fffffc00/45fc8000 level 3
   fffffc00/45fd8000 level 3
   fffffc00/45fe8000 level 3
   fffffc00/45ff8000 level 3
   fff0fe00/45e08800 level 2
   fff0fe00/45e08a00 level 2
   fff0fe00/45f08800 level 2
   fff0fe00/45f08a00 level 2
   ffe6fc00/45e08c00 level 2
   ffe6fc00/45e28c00 level 2
   ffe6fc00/45e48c00 level 2
   ffe6fc00/45e68c00 level 2
   ffe6fc00/45e09400 level 2
   ffe6fc00/45e29400 level 2
   ffe6fc00/45e49400 level 2
   ffe6fc00/45e69400 level 2
   ffe6fc00/45e09800 level 2
   ffe6fc00/45e29800 level 2
   ffe6fc00/45e49800 level 2
   ffe6fc00/45e69800 level 2
   ffe6fc00/45e09c00 level 2
   ffe6fc00/45e29c00 level 2
   ffe6fc00/45e49c00 level 2
   ffe6fc00/45e69c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_45208000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208000))
        return iemDecodeA64_match_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208010))
        return iemDecodeA64_nmatch_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5208000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05208000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05208000_2,
        iemDecodeA64_ST2_asisdlso_S2_2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25208000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ST2_asisdlso_S2_2s,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25208400 level 2
   ffe0fc00/25608400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25208400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25228000))
        return iemDecodeA64_lastp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffa00)) == UINT32_C(0x25208200))
        return iemDecodeA64_cntp_r_pn(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5208400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05208400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05208000_2,
        iemDecodeA64_ST2_asisdlso_D2_2d,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25208400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ST2_asisdlso_D2_2d,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25208800 level 2
   ffe0fc00/25608800 level 2
   fff0fe00/25e08800 level 2
   mask=0xf0000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%56 (0x9) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25208800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cntp_r_p_p,
        iemDecodeA64_firstp_r_p_p,
        iemDecodeA64_lastp_r_p_p,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqincp_r_p_r_sx,
        iemDecodeA64_uqincp_r_p_r_uw,
        iemDecodeA64_sqdecp_r_p_r_sx,
        iemDecodeA64_uqdecp_r_p_r_uw,
        iemDecodeA64_incp_r_p_r,
        iemDecodeA64_decp_r_p_r,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5208800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05208800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05208000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25208800_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25208c00 level 2
   ffe0fc00/25608c00 level 2
   mask=0xb0000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%88 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25208c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cntp_r_p_p,
        iemDecodeA64_firstp_r_p_p,
        iemDecodeA64_lastp_r_p_p,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_sqincp_r_p_r_x,
        iemDecodeA64_uqincp_r_p_r_x,
        iemDecodeA64_sqdecp_r_p_r_x,
        iemDecodeA64_uqdecp_r_p_r_x,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x000b0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5208c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05208c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05208000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25208c00_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25209000 level 2
   mask=0xf0000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%31 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25209000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cntp_r_p_p,
        iemDecodeA64_firstp_r_p_p,
        iemDecodeA64_lastp_r_p_p,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_wrffr_f_p,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_setffr_f,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5209000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05209000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05208000_2,
        iemDecodeA64_ST2_asisdlso_S2_2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ST2_asisdlso_S2_2s,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/25209400 level 2
   ffe0fc00/25209800 level 2
   ffe0fc00/25209c00 level 2
   ffe0fc00/2520a000 level 2
   ffe0fc00/2520a400 level 2
   ffe0fc00/2520a800 level 2
   ffe0fc00/2520ac00 level 2
   ffe0fc00/2520b000 level 2
   ffe0fc00/2520b400 level 2
   ffe0fc00/2520b800 level 2
   ffe0fc00/2520bc00 level 2
   ffe0fc00/25609000 level 2
   ffe0fc00/25609400 level 2
   ffe0fc00/25609800 level 2
   ffe0fc00/25609c00 level 2
   ffe0fc00/2560a000 level 2
   ffe0fc00/2560a400 level 2
   ffe0fc00/2560a800 level 2
   ffe0fc00/2560ac00 level 2
   ffe0fc00/2560b000 level 2
   ffe0fc00/2560b400 level 2
   ffe0fc00/2560b800 level 2
   ffe0fc00/2560bc00 level 2
   ffe0fc00/25a0a000 level 2
   ffe0fc00/25a0a400 level 2
   ffe0fc00/25a0a800 level 2
   ffe0fc00/25a0ac00 level 2
   ffe0fc00/25a0b000 level 2
   ffe0fc00/25a0b400 level 2
   ffe0fc00/25a0b800 level 2
   ffe0fc00/25a0bc00 level 2
   ffe0fc00/25e0a000 level 2
   ffe0fc00/25e0a400 level 2
   ffe0fc00/25e0a800 level 2
   ffe0fc00/25e0ac00 level 2
   ffe0fc00/25e0b000 level 2
   ffe0fc00/25e0b400 level 2
   ffe0fc00/25e0b800 level 2
   ffe0fc00/25e0bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25209400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25228000))
        return iemDecodeA64_lastp_r_p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5209400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5209800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5209c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05209400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05208000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/0520a000 level 3
   ffeffc00/0520a400 level 3
   ffeffc00/0520a800 level 3
   ffeffc00/0520ac00 level 3
   ffeffc00/0520b000 level 3
   ffeffc00/0520b400 level 3
   ffeffc00/0520b800 level 3
   ffeffc00/0520bc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_0520a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0520a000))
        return iemDecodeA64_lasta_r_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0530a000))
        return iemDecodeA64_clasta_r_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/0521a000 level 3
   ffeffc00/0521a400 level 3
   ffeffc00/0521a800 level 3
   ffeffc00/0521ac00 level 3
   ffeffc00/0521b000 level 3
   ffeffc00/0521b400 level 3
   ffeffc00/0521b800 level 3
   ffeffc00/0521bc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_0521a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0521a000))
        return iemDecodeA64_lastb_r_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0531a000))
        return iemDecodeA64_clastb_r_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/0520a000 level 2
   ffe0fc00/0520a400 level 2
   ffe0fc00/0520a800 level 2
   ffe0fc00/0520ac00 level 2
   ffe0fc00/0520b000 level 2
   ffe0fc00/0520b400 level 2
   ffe0fc00/0520b800 level 2
   ffe0fc00/0520bc00 level 2
   mask=0xf0000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%38 (0x6) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0520a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc00_0520a000_3,
        iemDecodeA64_ffeffc00_0521a000_3,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_revb_z_z_z,
        iemDecodeA64_revh_z_z_z,
        iemDecodeA64_revw_z_z_z,
        iemDecodeA64_rbit_z_p_z_z,
        iemDecodeA64_cpy_z_p_r,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_revd_z_p_z_z,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a520a000 level 2
   ffe0fc00/a520a400 level 2
   ffe0fc00/a520a800 level 2
   ffe0fc00/a520ac00 level 2
   ffe0fc00/a520b000 level 2
   ffe0fc00/a520b400 level 2
   ffe0fc00/a520b800 level 2
   ffe0fc00/a520bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a520a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa520a000))
        return iemDecodeA64_ld1sh_z_p_bi_s32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa530a000))
        return iemDecodeA64_ldnf1sh_z_p_bi_s32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0520a000_2,
        iemDecodeA64_ST4_asisdlso_S4_4s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_histseg_z_zz,
        iemDecodeA64_ST4_asisdlso_S4_4s,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a520a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0520a000_2,
        iemDecodeA64_ST4_asisdlso_D4_4d,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ST4_asisdlso_D4_4d,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a520a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x520b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0520a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_luti2_z_zz_16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a520a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0520a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a520a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0520a000_2,
        iemDecodeA64_ST4_asisdlso_S4_4s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_luti2_z_zz_8,
        iemDecodeA64_ST4_asisdlso_S4_4s,
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a520a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0520a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_luti4_z_zz_2x16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a520a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0520a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_luti4_z_zz_1x16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_CBLT_32_imm,
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a520a000_2,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_CBLT_64_imm,
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2520c000 level 2
   ffe0fc00/2520c400 level 2
   ffe0fc00/2520c800 level 2
   ffe0fc00/2520cc00 level 2
   ffe0fc00/2520d000 level 2
   ffe0fc00/2520d400 level 2
   ffe0fc00/2520d800 level 2
   ffe0fc00/2520dc00 level 2
   ffe0fc00/2560c000 level 2
   ffe0fc00/2560c400 level 2
   ffe0fc00/2560c800 level 2
   ffe0fc00/2560cc00 level 2
   ffe0fc00/2560d000 level 2
   ffe0fc00/2560d400 level 2
   ffe0fc00/2560d800 level 2
   ffe0fc00/2560dc00 level 2
   ffe0fc00/25a0c000 level 2
   ffe0fc00/25a0c400 level 2
   ffe0fc00/25a0c800 level 2
   ffe0fc00/25a0cc00 level 2
   ffe0fc00/25a0d000 level 2
   ffe0fc00/25a0d400 level 2
   ffe0fc00/25a0d800 level 2
   ffe0fc00/25a0dc00 level 2
   ffe0fc00/25e0c000 level 2
   ffe0fc00/25e0c400 level 2
   ffe0fc00/25e0c800 level 2
   ffe0fc00/25e0cc00 level 2
   ffe0fc00/25e0d000 level 2
   ffe0fc00/25e0d400 level 2
   ffe0fc00/25e0d800 level 2
   ffe0fc00/25e0dc00 level 2
   mask=0x1f0000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2520c000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_add_z_zi,
        iemDecodeA64_sub_z_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_subr_z_zi,
        iemDecodeA64_sqadd_z_zi,
        iemDecodeA64_uqadd_z_zi,
        iemDecodeA64_sqsub_z_zi,
        iemDecodeA64_uqsub_z_zi,
        iemDecodeA64_smax_z_zi,
        iemDecodeA64_umax_z_zi,
        iemDecodeA64_smin_z_zi,
        iemDecodeA64_umin_z_zi,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_mul_z_zi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_dup_z_i,
        iemDecodeA64_fdup_z_i,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520c000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x520c400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x520c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x520cc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x520d000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x520d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x520d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x520dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520c000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_histcnt_z_p_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2520e000 level 2
   ffe0fc00/2520e400 level 2
   ffe0fc00/2520e800 level 2
   ffe0fc00/2520ec00 level 2
   ffe0fc00/2520f000 level 2
   ffe0fc00/2520f400 level 2
   ffe0fc00/2520f800 level 2
   ffe0fc00/2520fc00 level 2
   ffe0fc00/2560e000 level 2
   ffe0fc00/2560e400 level 2
   ffe0fc00/2560e800 level 2
   ffe0fc00/2560ec00 level 2
   ffe0fc00/2560f000 level 2
   ffe0fc00/2560f400 level 2
   ffe0fc00/2560f800 level 2
   ffe0fc00/2560fc00 level 2
   ffe0fc00/25a0e000 level 2
   ffe0fc00/25a0e400 level 2
   ffe0fc00/25a0e800 level 2
   ffe0fc00/25a0ec00 level 2
   ffe0fc00/25a0f000 level 2
   ffe0fc00/25a0f400 level 2
   ffe0fc00/25a0f800 level 2
   ffe0fc00/25a0fc00 level 2
   ffe0fc00/25e0e000 level 2
   ffe0fc00/25e0e400 level 2
   ffe0fc00/25e0e800 level 2
   ffe0fc00/25e0ec00 level 2
   ffe0fc00/25e0f000 level 2
   ffe0fc00/25e0f400 level 2
   ffe0fc00/25e0f800 level 2
   ffe0fc00/25e0fc00 level 2
   mask=0x170000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%50 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2520e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_add_z_zi,
        iemDecodeA64_sub_z_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_subr_z_zi,
        iemDecodeA64_sqadd_z_zi,
        iemDecodeA64_uqadd_z_zi,
        iemDecodeA64_sqsub_z_zi,
        iemDecodeA64_uqsub_z_zi,
        iemDecodeA64_dup_z_i,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00170000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/4520e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_4520e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x4522e000))
        return iemDecodeA64_aese_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x4523e000))
        return iemDecodeA64_sm4e_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0x4520e000))
        return iemDecodeA64_aesmc_z_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_4520e000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/4520e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_4520e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x4522e400))
        return iemDecodeA64_aesd_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0x4520e400))
        return iemDecodeA64_aesimc_z_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_4520e400_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/4520e800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_4520e800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe7fc01)) == UINT32_C(0x4522e800))
        return iemDecodeA64_aese_mz_zzi_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe7fc01)) == UINT32_C(0x4523e800))
        return iemDecodeA64_aesemc_mz_zzi_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe7fc03)) == UINT32_C(0x4526e800))
        return iemDecodeA64_aese_mz_zzi_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe7fc03)) == UINT32_C(0x4527e800))
        return iemDecodeA64_aesemc_mz_zzi_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_4520e800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/4520ec00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_4520ec00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe7fc01)) == UINT32_C(0x4522ec00))
        return iemDecodeA64_aesd_mz_zzi_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe7fc01)) == UINT32_C(0x4523ec00))
        return iemDecodeA64_aesdimc_mz_zzi_2x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe7fc03)) == UINT32_C(0x4526ec00))
        return iemDecodeA64_aesd_mz_zzi_4x1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe7fc03)) == UINT32_C(0x4527ec00))
        return iemDecodeA64_aesdimc_mz_zzi_4x1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_4520ec00_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_sm4ekey_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_rax1_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_pmull_mz_zzw_1x2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x520fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0520fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_B_ldst_pos,
        iemDecodeA64_pmlal_mz_zzzw_1x2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_RETABSPPC_only_miscbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_STR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2w_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_STR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5200000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2w_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_STR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05400000 level 2
   ffe0fc00/05400400 level 2
   ffe0fc00/05400800 level 2
   ffe0fc00/05400c00 level 2
   ffe0fc00/05401000 level 2
   ffe0fc00/05401400 level 2
   ffe0fc00/05401800 level 2
   ffe0fc00/05401c00 level 2
   ffe0fc00/05402000 level 2
   ffe0fc00/05402400 level 2
   ffe0fc00/05402800 level 2
   ffe0fc00/05402c00 level 2
   ffe0fc00/05403000 level 2
   ffe0fc00/05403400 level 2
   ffe0fc00/05403800 level 2
   ffe0fc00/05403c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05400000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05100000))
        return iemDecodeA64_cpy_z_o_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05400000))
        return iemDecodeA64_eor_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/d5400000 level 2
   ffe0fc00/d5400400 level 2
   ffe0fc00/d5400800 level 2
   ffe0fc00/d5400c00 level 2
   ffe0fc00/d5401000 level 2
   ffe0fc00/d5401400 level 2
   ffe0fc00/d5401800 level 2
   ffe0fc00/d5401c00 level 2
   ffe0fc00/d5402000 level 2
   ffe0fc00/d5402400 level 2
   ffe0fc00/d5402800 level 2
   ffe0fc00/d5402c00 level 2
   ffe0fc00/d5403000 level 2
   ffe0fc00/d5403400 level 2
   ffe0fc00/d5403800 level 2
   ffe0fc00/d5403c00 level 2
   ffe0fc00/d5404000 level 2
   ffe0fc00/d5404400 level 2
   ffe0fc00/d5404800 level 2
   ffe0fc00/d5404c00 level 2
   ffe0fc00/d5405000 level 2
   ffe0fc00/d5405400 level 2
   ffe0fc00/d5405800 level 2
   ffe0fc00/d5405c00 level 2
   ffe0fc00/d5406000 level 2
   ffe0fc00/d5406400 level 2
   ffe0fc00/d5406800 level 2
   ffe0fc00/d5406c00 level 2
   ffe0fc00/d5407000 level 2
   ffe0fc00/d5407400 level 2
   ffe0fc00/d5407800 level 2
   ffe0fc00/d5407c00 level 2
   ffe0fc00/d5408000 level 2
   ffe0fc00/d5408400 level 2
   ffe0fc00/d5408800 level 2
   ffe0fc00/d5408c00 level 2
   ffe0fc00/d5409000 level 2
   ffe0fc00/d5409400 level 2
   ffe0fc00/d5409800 level 2
   ffe0fc00/d5409c00 level 2
   ffe0fc00/d540a800 level 2
   ffe0fc00/d540b800 level 2
   ffe0fc00/d540c000 level 2
   ffe0fc00/d540c400 level 2
   ffe0fc00/d540c800 level 2
   ffe0fc00/d540cc00 level 2
   ffe0fc00/d540d000 level 2
   ffe0fc00/d540d400 level 2
   ffe0fc00/d540d800 level 2
   ffe0fc00/d540dc00 level 2
   ffe0fc00/d540e000 level 2
   ffe0fc00/d540e400 level 2
   ffe0fc00/d540e800 level 2
   ffe0fc00/d540ec00 level 2
   ffe0fc00/d540f000 level 2
   ffe0fc00/d540f400 level 2
   ffe0fc00/d540f800 level 2
   ffe0fc00/d540fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_d5400000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff00000)) == UINT32_C(0xd5500000))
        return iemDecodeA64_MSRR_SR_systemmovepr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff80000)) == UINT32_C(0xd5480000))
        return iemDecodeA64_SYSP_CR_syspairinstrs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5400000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05400000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_saddlb_z_zz,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fadd_z_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5400400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05400400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYM_CPY_memcms,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_saddlt_z_zz,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYM_CPY_memcms,
        iemDecodeA64_fsub_z_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYM_CPY_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYM_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5400800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05400800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uaddlb_z_zz,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_fmul_z_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5400c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05400c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uaddlt_z_zz,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ftsmul_z_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5401000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05401000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ssublb_z_zz,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5401400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05401400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMWT_CPY_memcms,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ssublt_z_zz,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMWT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMWT_CPY_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMWT_CPY_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5401800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05401800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_usublb_z_zz,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_frecps_z_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5401c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05401c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_usublt_z_zz,
        iemDecodeA64_LD1_asisdlso_B1_1b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frsqrts_z_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5402000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5402c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05402000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5402400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05402400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRT_CPY_memcms,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRT_CPY_memcms,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRT_CPY_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMRT_CPY_memcms,
        iemDecodeA64_stnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5402800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05402800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_stnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65403000 level 2
   ffe0fc00/65803000 level 2
   ffe0fc00/65c03000 level 2
   mask=0x1f0000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%31 (0xa) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65403000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_faddv_v_p_z,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fmaxnmv_v_p_z,
        iemDecodeA64_fminnmv_v_p_z,
        iemDecodeA64_fmaxv_v_p_z,
        iemDecodeA64_fminv_v_p_z,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_frecpe_z_z,
        iemDecodeA64_frsqrte_z_z,
        iemDecodeA64_fffffc00_65103400_3,
        iemDecodeA64_ffeffc00_65012400_3,
        iemDecodeA64_fcmeq_p_p_z0,
        iemDecodeA64_fcmne_p_p_z0,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fadda_v_p_z,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5403000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05403000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sabdlb_z_zz,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65403000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5403400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05403400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMT_CPY_memcms,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sabdlt_z_zz,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMT_CPY_memcms,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMT_CPY_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMT_CPY_memcms,
        iemDecodeA64_stnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5403800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05403800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uabdlb_z_zz,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_stnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5403c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05403c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05400000_2,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uabdlt_z_zz,
        iemDecodeA64_LD3_asisdlso_B3_3b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1w_z_p_ar_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05404000 level 2
   ffe0fc00/05404400 level 2
   ffe0fc00/05404800 level 2
   ffe0fc00/05404c00 level 2
   ffe0fc00/05405000 level 2
   ffe0fc00/05405400 level 2
   ffe0fc00/05405800 level 2
   ffe0fc00/05405c00 level 2
   ffe0fc00/05406000 level 2
   ffe0fc00/05406400 level 2
   ffe0fc00/05406800 level 2
   ffe0fc00/05406c00 level 2
   ffe0fc00/05407000 level 2
   ffe0fc00/05407400 level 2
   ffe0fc00/05407800 level 2
   ffe0fc00/05407c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05404000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05104000))
        return iemDecodeA64_cpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05400000))
        return iemDecodeA64_eor_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fe10/25504000 level 3
   fff0fe10/25504400 level 3
   fff0fe10/25504800 level 3
   fff0fe10/25504c00 level 3
   fff0fe10/25505000 level 3
   fff0fe10/25505400 level 3
   fff0fe10/25505800 level 3
   fff0fe10/25505c00 level 3
   fff0fe10/25506000 level 3
   fff0fe10/25506400 level 3
   fff0fe10/25506800 level 3
   fff0fe10/25506c00 level 3
   fff0fe10/25507000 level 3
   fff0fe10/25507400 level 3
   fff0fe10/25507800 level 3
   fff0fe10/25507c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fe10_25504000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffc210)) == UINT32_C(0x25504000))
        return iemDecodeA64_brkas_p_p_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffc210)) == UINT32_C(0x25584000))
        return iemDecodeA64_brkns_p_p_pp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/25404000 level 2
   ffe0fc00/25404400 level 2
   ffe0fc00/25404800 level 2
   ffe0fc00/25404c00 level 2
   ffe0fc00/25405000 level 2
   ffe0fc00/25405400 level 2
   ffe0fc00/25405800 level 2
   ffe0fc00/25405c00 level 2
   ffe0fc00/25406000 level 2
   ffe0fc00/25406400 level 2
   ffe0fc00/25406800 level 2
   ffe0fc00/25406c00 level 2
   ffe0fc00/25407000 level 2
   ffe0fc00/25407400 level 2
   ffe0fc00/25407800 level 2
   ffe0fc00/25407c00 level 2
   mask=0x100210 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%38 (0x3) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25404000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ands_p_p_pp_z,
        iemDecodeA64_bics_p_p_pp_z,
        iemDecodeA64_eors_p_p_pp_z,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fe10_25504000_3,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100210 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5404000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05404000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_LD1_asisdlso_H1_1h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_saddwb_z_zz,
        iemDecodeA64_LD1_asisdlso_H1_1h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5404400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05404400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_saddwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMWN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMWN_CPY_memcms,
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5404800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05404800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_LD1_asisdlso_H1_1h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uaddwb_z_zz,
        iemDecodeA64_LD1_asisdlso_H1_1h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ld1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5404c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05404c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uaddwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5405000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05405000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_LD1_asisdlso_H1_1h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ssubwb_z_zz,
        iemDecodeA64_LD1_asisdlso_H1_1h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5405400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05405400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ssubwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMWTWN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMWTWN_CPY_memcms,
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5405800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05405800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_LD1_asisdlso_H1_1h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_usubwb_z_zz,
        iemDecodeA64_LD1_asisdlso_H1_1h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ld1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5405c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05405c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_usubwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5406000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05406000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_LD3_asisdlso_H3_3h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqdmullb_z_zz,
        iemDecodeA64_LD3_asisdlso_H3_3h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5406400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05406400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqdmullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTWN_CPY_memcms,
        iemDecodeA64_ldff1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMRTWN_CPY_memcms,
        iemDecodeA64_st3w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5406800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05406800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_LD3_asisdlso_H3_3h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_pmullb_z_zz,
        iemDecodeA64_LD3_asisdlso_H3_3h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ldff1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st3w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5406c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05406c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_pmullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5407000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05407000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_LD3_asisdlso_H3_3h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_smullb_z_zz,
        iemDecodeA64_LD3_asisdlso_H3_3h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5407400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05407400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_smullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTWN_CPY_memcms,
        iemDecodeA64_ldff1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMTWN_CPY_memcms,
        iemDecodeA64_st3w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5407800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05407800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_LD3_asisdlso_H3_3h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_umullb_z_zz,
        iemDecodeA64_LD3_asisdlso_H3_3h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ldff1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st3w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5407c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%9 (0x3) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05407c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05404000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25404000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_umullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/65408000 level 2
   mask=0x1f0000 entries=0x20 children=0x1f valid=%97 (0x1f) leaf=%97 (0x1f) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65408000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_fmin_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5408000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05408000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD1_asisdlso_S1_1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlso_S1_1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65408000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0d408400 level 2
   ffe0fc00/4d408400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0d408400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d408400))
        return iemDecodeA64_LD1_asisdlso_D1_1d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d418400))
        return iemDecodeA64_LDAP1_asisdlso_D1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/65408400 level 2
   ffe0fc00/65408800 level 2
   ffe0fc00/65408c00 level 2
   ffe0fc00/65409000 level 2
   ffe0fc00/65409400 level 2
   ffe0fc00/65409800 level 2
   ffe0fc00/65409c00 level 2
   7fe0fcd0/65c09000 level 3
   7fe0fcd0/65c09010 level 3
   7fe0fcd0/65c09400 level 3
   7fe0fcd0/65c09410 level 3
   mask=0x1f0000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%72 (0x17) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_65408400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_fmin_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5408400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%69 (0x16) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05408400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_ffe0fc00_0d408400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0d408400_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65408400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRN_CPY_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5408800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05408800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65408400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5408c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05408c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65408400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5409000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05409000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD1_asisdlso_S1_1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_LD1_asisdlso_S1_1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65408400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5409400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05409400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMWTRN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65408400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMWTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5409800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05409800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_65408400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5409c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05409c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65408400_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0540a000 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%72 (0x17) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0540a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD3_asisdlso_S3_3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_LD3_asisdlso_S3_3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0541a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0541a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0542a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0542a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0543a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0543a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0544a000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0544a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0545a000 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0545a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0546a000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0546a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0547a000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0547a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0548a000 level 2
   07fffc00/0549a000 level 2
   07fffc00/054aa000 level 2
   07fffc00/054ba000 level 2
   07fffc00/054ea000 level 2
   07fffc00/054fa000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0548a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054ca000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054ca000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054da000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054da000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0550a000 level 2
   07fffc00/0551a000 level 2
   07fffc00/0558a000 level 2
   07fffc00/0559a000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0550a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0552a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0552a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0553a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0553a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0554a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0554a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0555a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0555a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0556a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0556a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0557a000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0557a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055aa000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055aa000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ba000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ba000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ca000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ca000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055da000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055da000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ea000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ea000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055fa000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055fa000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540a000/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_0540a000_2,
        iemDecodeA64_07fffc00_0541a000_2,
        iemDecodeA64_07fffc00_0542a000_2,
        iemDecodeA64_07fffc00_0543a000_2,
        iemDecodeA64_07fffc00_0544a000_2,
        iemDecodeA64_07fffc00_0545a000_2,
        iemDecodeA64_07fffc00_0546a000_2,
        iemDecodeA64_07fffc00_0547a000_2,
        iemDecodeA64_07fffc00_0548a000_2,
        iemDecodeA64_07fffc00_0548a000_2,
        iemDecodeA64_07fffc00_0548a000_2,
        iemDecodeA64_07fffc00_0548a000_2,
        iemDecodeA64_07fffc00_054ca000_2,
        iemDecodeA64_07fffc00_054da000_2,
        iemDecodeA64_07fffc00_0548a000_2,
        iemDecodeA64_07fffc00_0548a000_2,
        iemDecodeA64_07fffc00_0550a000_2,
        iemDecodeA64_07fffc00_0550a000_2,
        iemDecodeA64_07fffc00_0552a000_2,
        iemDecodeA64_07fffc00_0553a000_2,
        iemDecodeA64_07fffc00_0554a000_2,
        iemDecodeA64_07fffc00_0555a000_2,
        iemDecodeA64_07fffc00_0556a000_2,
        iemDecodeA64_07fffc00_0557a000_2,
        iemDecodeA64_07fffc00_0550a000_2,
        iemDecodeA64_07fffc00_0550a000_2,
        iemDecodeA64_07fffc00_055aa000_2,
        iemDecodeA64_07fffc00_055ba000_2,
        iemDecodeA64_07fffc00_055ca000_2,
        iemDecodeA64_07fffc00_055da000_2,
        iemDecodeA64_07fffc00_055ea000_2,
        iemDecodeA64_07fffc00_055fa000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0540a400 level 2
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%84 (0x1b) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0540a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD3_asisdlso_D3_3d,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_LD3_asisdlso_D3_3d,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0541a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0541a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0542a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0542a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0543a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0543a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0544a400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0544a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0545a400 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%72 (0x17) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0545a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0546a400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0546a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0547a400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0547a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0548a400 level 2
   07fffc00/0549a400 level 2
   07fffc00/054aa400 level 2
   07fffc00/054ba400 level 2
   07fffc00/054ea400 level 2
   07fffc00/054fa400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0548a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054ca400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054ca400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054da400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054da400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0550a400 level 2
   07fffc00/0551a400 level 2
   07fffc00/0558a400 level 2
   07fffc00/0559a400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0550a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0552a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0552a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_scvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0553a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0553a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ucvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0554a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0554a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_scvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0555a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0555a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ucvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0556a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0556a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_scvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0557a400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0557a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ucvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055aa400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055aa400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_fcvtzs_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ba400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ba400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_fcvtzu_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ca400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ca400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_fcvtzs_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055da400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055da400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_fcvtzu_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ea400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ea400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_fcvtzs_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055fa400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055fa400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sshllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_fcvtzu_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMRTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540a400/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_0540a400_2,
        iemDecodeA64_07fffc00_0541a400_2,
        iemDecodeA64_07fffc00_0542a400_2,
        iemDecodeA64_07fffc00_0543a400_2,
        iemDecodeA64_07fffc00_0544a400_2,
        iemDecodeA64_07fffc00_0545a400_2,
        iemDecodeA64_07fffc00_0546a400_2,
        iemDecodeA64_07fffc00_0547a400_2,
        iemDecodeA64_07fffc00_0548a400_2,
        iemDecodeA64_07fffc00_0548a400_2,
        iemDecodeA64_07fffc00_0548a400_2,
        iemDecodeA64_07fffc00_0548a400_2,
        iemDecodeA64_07fffc00_054ca400_2,
        iemDecodeA64_07fffc00_054da400_2,
        iemDecodeA64_07fffc00_0548a400_2,
        iemDecodeA64_07fffc00_0548a400_2,
        iemDecodeA64_07fffc00_0550a400_2,
        iemDecodeA64_07fffc00_0550a400_2,
        iemDecodeA64_07fffc00_0552a400_2,
        iemDecodeA64_07fffc00_0553a400_2,
        iemDecodeA64_07fffc00_0554a400_2,
        iemDecodeA64_07fffc00_0555a400_2,
        iemDecodeA64_07fffc00_0556a400_2,
        iemDecodeA64_07fffc00_0557a400_2,
        iemDecodeA64_07fffc00_0550a400_2,
        iemDecodeA64_07fffc00_0550a400_2,
        iemDecodeA64_07fffc00_055aa400_2,
        iemDecodeA64_07fffc00_055ba400_2,
        iemDecodeA64_07fffc00_055ca400_2,
        iemDecodeA64_07fffc00_055da400_2,
        iemDecodeA64_07fffc00_055ea400_2,
        iemDecodeA64_07fffc00_055fa400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/6540a800 level 2
   ffe0fc00/6540b800 level 2
   mask=0x1f0000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6540a800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_scvtf_z_p_z_h2fp16,
        iemDecodeA64_ucvtf_z_p_z_h2fp16,
        iemDecodeA64_scvtf_z_p_z_w2fp16,
        iemDecodeA64_ucvtf_z_p_z_w2fp16,
        iemDecodeA64_scvtf_z_p_z_x2fp16,
        iemDecodeA64_ucvtf_z_p_z_x2fp16,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_fcvtzs_z_p_z_fp162h,
        iemDecodeA64_fcvtzu_z_p_z_fp162h,
        iemDecodeA64_fcvtzs_z_p_z_fp162w,
        iemDecodeA64_fcvtzu_z_p_z_fp162w,
        iemDecodeA64_fcvtzs_z_p_z_fp162x,
        iemDecodeA64_fcvtzu_z_p_z_fp162x,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a540a800 level 2
   ffe0fc00/a540b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a540a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa540a000))
        return iemDecodeA64_ld1w_z_p_bi_u32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa550a000))
        return iemDecodeA64_ldnf1w_z_p_bi_u32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540a800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllb_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_6540a800_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ffe0fc00_a540a800_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0540ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0540ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0541ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0541ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0542ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0542ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0543ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0543ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0544ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0544ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0545ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0545ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0546ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0546ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0547ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0547ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0548ac00 level 2
   07fffc00/0549ac00 level 2
   07fffc00/054aac00 level 2
   07fffc00/054bac00 level 2
   07fffc00/054eac00 level 2
   07fffc00/054fac00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0548ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054cac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054cac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054dac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054dac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0550ac00 level 2
   07fffc00/0551ac00 level 2
   07fffc00/0558ac00 level 2
   07fffc00/0559ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0550ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0552ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0552ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0553ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0553ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0554ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0554ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0555ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0555ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0556ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0556ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0557ac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0557ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055aac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055aac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055bac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055bac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055cac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055cac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055dac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055dac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055eac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055eac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055fac00 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055fac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ushllt_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540ac00/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_0540ac00_2,
        iemDecodeA64_07fffc00_0541ac00_2,
        iemDecodeA64_07fffc00_0542ac00_2,
        iemDecodeA64_07fffc00_0543ac00_2,
        iemDecodeA64_07fffc00_0544ac00_2,
        iemDecodeA64_07fffc00_0545ac00_2,
        iemDecodeA64_07fffc00_0546ac00_2,
        iemDecodeA64_07fffc00_0547ac00_2,
        iemDecodeA64_07fffc00_0548ac00_2,
        iemDecodeA64_07fffc00_0548ac00_2,
        iemDecodeA64_07fffc00_0548ac00_2,
        iemDecodeA64_07fffc00_0548ac00_2,
        iemDecodeA64_07fffc00_054cac00_2,
        iemDecodeA64_07fffc00_054dac00_2,
        iemDecodeA64_07fffc00_0548ac00_2,
        iemDecodeA64_07fffc00_0548ac00_2,
        iemDecodeA64_07fffc00_0550ac00_2,
        iemDecodeA64_07fffc00_0550ac00_2,
        iemDecodeA64_07fffc00_0552ac00_2,
        iemDecodeA64_07fffc00_0553ac00_2,
        iemDecodeA64_07fffc00_0554ac00_2,
        iemDecodeA64_07fffc00_0555ac00_2,
        iemDecodeA64_07fffc00_0556ac00_2,
        iemDecodeA64_07fffc00_0557ac00_2,
        iemDecodeA64_07fffc00_0550ac00_2,
        iemDecodeA64_07fffc00_0550ac00_2,
        iemDecodeA64_07fffc00_055aac00_2,
        iemDecodeA64_07fffc00_055bac00_2,
        iemDecodeA64_07fffc00_055cac00_2,
        iemDecodeA64_07fffc00_055dac00_2,
        iemDecodeA64_07fffc00_055eac00_2,
        iemDecodeA64_07fffc00_055fac00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0540b000 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%72 (0x17) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0540b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD3_asisdlso_S3_3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlso_S3_3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0541b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0541b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0542b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0542b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0543b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0543b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0544b000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0544b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0545b000 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0545b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0546b000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0546b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0547b000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0547b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0548b000 level 2
   07fffc00/0549b000 level 2
   07fffc00/054ab000 level 2
   07fffc00/054bb000 level 2
   07fffc00/054eb000 level 2
   07fffc00/054fb000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0548b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054cb000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054cb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054db000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054db000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0550b000 level 2
   07fffc00/0551b000 level 2
   07fffc00/0558b000 level 2
   07fffc00/0559b000 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0550b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0552b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0552b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0553b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0553b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0554b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0554b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0555b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0555b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0556b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0556b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0557b000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0557b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ab000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ab000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055bb000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055bb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055cb000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055cb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055db000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055db000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055eb000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055eb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055fb000 level 2
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055fb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540b000/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_0540b000_2,
        iemDecodeA64_07fffc00_0541b000_2,
        iemDecodeA64_07fffc00_0542b000_2,
        iemDecodeA64_07fffc00_0543b000_2,
        iemDecodeA64_07fffc00_0544b000_2,
        iemDecodeA64_07fffc00_0545b000_2,
        iemDecodeA64_07fffc00_0546b000_2,
        iemDecodeA64_07fffc00_0547b000_2,
        iemDecodeA64_07fffc00_0548b000_2,
        iemDecodeA64_07fffc00_0548b000_2,
        iemDecodeA64_07fffc00_0548b000_2,
        iemDecodeA64_07fffc00_0548b000_2,
        iemDecodeA64_07fffc00_054cb000_2,
        iemDecodeA64_07fffc00_054db000_2,
        iemDecodeA64_07fffc00_0548b000_2,
        iemDecodeA64_07fffc00_0548b000_2,
        iemDecodeA64_07fffc00_0550b000_2,
        iemDecodeA64_07fffc00_0550b000_2,
        iemDecodeA64_07fffc00_0552b000_2,
        iemDecodeA64_07fffc00_0553b000_2,
        iemDecodeA64_07fffc00_0554b000_2,
        iemDecodeA64_07fffc00_0555b000_2,
        iemDecodeA64_07fffc00_0556b000_2,
        iemDecodeA64_07fffc00_0557b000_2,
        iemDecodeA64_07fffc00_0550b000_2,
        iemDecodeA64_07fffc00_0550b000_2,
        iemDecodeA64_07fffc00_055ab000_2,
        iemDecodeA64_07fffc00_055bb000_2,
        iemDecodeA64_07fffc00_055cb000_2,
        iemDecodeA64_07fffc00_055db000_2,
        iemDecodeA64_07fffc00_055eb000_2,
        iemDecodeA64_07fffc00_055fb000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0540b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0540b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0541b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0541b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0542b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0542b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0543b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0543b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0544b400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0544b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0545b400 level 2
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%72 (0x17) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0545b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0546b400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0546b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0547b400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0547b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0548b400 level 2
   07fffc00/0549b400 level 2
   07fffc00/054ab400 level 2
   07fffc00/054bb400 level 2
   07fffc00/054eb400 level 2
   07fffc00/054fb400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0548b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054cb400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054cb400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054db400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054db400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0550b400 level 2
   07fffc00/0551b400 level 2
   07fffc00/0558b400 level 2
   07fffc00/0559b400 level 2
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%75 (0x18) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0550b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0552b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0552b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_scvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0553b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0553b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ucvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0554b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0554b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_scvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0555b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0555b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ucvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0556b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0556b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_scvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0557b400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0557b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ucvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ab400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ab400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_fcvtzs_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055bb400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055bb400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_fcvtzu_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055cb400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055cb400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_fcvtzs_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055db400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055db400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_fcvtzu_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055eb400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055eb400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_fcvtzs_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055fb400 level 2
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%78 (0x19) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055fb400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_fcvtzu_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_CPYMTRN_CPY_memcms,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540b400/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_0540b400_2,
        iemDecodeA64_07fffc00_0541b400_2,
        iemDecodeA64_07fffc00_0542b400_2,
        iemDecodeA64_07fffc00_0543b400_2,
        iemDecodeA64_07fffc00_0544b400_2,
        iemDecodeA64_07fffc00_0545b400_2,
        iemDecodeA64_07fffc00_0546b400_2,
        iemDecodeA64_07fffc00_0547b400_2,
        iemDecodeA64_07fffc00_0548b400_2,
        iemDecodeA64_07fffc00_0548b400_2,
        iemDecodeA64_07fffc00_0548b400_2,
        iemDecodeA64_07fffc00_0548b400_2,
        iemDecodeA64_07fffc00_054cb400_2,
        iemDecodeA64_07fffc00_054db400_2,
        iemDecodeA64_07fffc00_0548b400_2,
        iemDecodeA64_07fffc00_0548b400_2,
        iemDecodeA64_07fffc00_0550b400_2,
        iemDecodeA64_07fffc00_0550b400_2,
        iemDecodeA64_07fffc00_0552b400_2,
        iemDecodeA64_07fffc00_0553b400_2,
        iemDecodeA64_07fffc00_0554b400_2,
        iemDecodeA64_07fffc00_0555b400_2,
        iemDecodeA64_07fffc00_0556b400_2,
        iemDecodeA64_07fffc00_0557b400_2,
        iemDecodeA64_07fffc00_0550b400_2,
        iemDecodeA64_07fffc00_0550b400_2,
        iemDecodeA64_07fffc00_055ab400_2,
        iemDecodeA64_07fffc00_055bb400_2,
        iemDecodeA64_07fffc00_055cb400_2,
        iemDecodeA64_07fffc00_055db400_2,
        iemDecodeA64_07fffc00_055eb400_2,
        iemDecodeA64_07fffc00_055fb400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%72 (0x17) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_bgrp_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_6540a800_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ffe0fc00_a540a800_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0540bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0540bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0541bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0541bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0542bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0542bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0543bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0543bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0544bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0544bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0545bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0545bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0546bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0546bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0547bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0547bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0548bc00 level 2
   07fffc00/0549bc00 level 2
   07fffc00/054abc00 level 2
   07fffc00/054bbc00 level 2
   07fffc00/054ebc00 level 2
   07fffc00/054fbc00 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0548bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054cbc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054cbc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/054dbc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_054dbc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SYSP_CR_syspairinstrs,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0550bc00 level 2
   07fffc00/0551bc00 level 2
   07fffc00/0558bc00 level 2
   07fffc00/0559bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0550bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0552bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0552bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0553bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0553bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_h2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0554bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0554bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0555bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0555bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_w2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0556bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0556bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/0557bc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_0557bc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_x2fp16,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055abc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055abc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055bbc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055bbc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162h,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055cbc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055cbc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055dbc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055dbc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162w,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055ebc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055ebc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/055fbc00 level 2
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_055fbc00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_fp162x,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBHI_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1w_z_p_bi_u32,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MSRR_SR_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBHI_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540bc00/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_0540bc00_2,
        iemDecodeA64_07fffc00_0541bc00_2,
        iemDecodeA64_07fffc00_0542bc00_2,
        iemDecodeA64_07fffc00_0543bc00_2,
        iemDecodeA64_07fffc00_0544bc00_2,
        iemDecodeA64_07fffc00_0545bc00_2,
        iemDecodeA64_07fffc00_0546bc00_2,
        iemDecodeA64_07fffc00_0547bc00_2,
        iemDecodeA64_07fffc00_0548bc00_2,
        iemDecodeA64_07fffc00_0548bc00_2,
        iemDecodeA64_07fffc00_0548bc00_2,
        iemDecodeA64_07fffc00_0548bc00_2,
        iemDecodeA64_07fffc00_054cbc00_2,
        iemDecodeA64_07fffc00_054dbc00_2,
        iemDecodeA64_07fffc00_0548bc00_2,
        iemDecodeA64_07fffc00_0548bc00_2,
        iemDecodeA64_07fffc00_0550bc00_2,
        iemDecodeA64_07fffc00_0550bc00_2,
        iemDecodeA64_07fffc00_0552bc00_2,
        iemDecodeA64_07fffc00_0553bc00_2,
        iemDecodeA64_07fffc00_0554bc00_2,
        iemDecodeA64_07fffc00_0555bc00_2,
        iemDecodeA64_07fffc00_0556bc00_2,
        iemDecodeA64_07fffc00_0557bc00_2,
        iemDecodeA64_07fffc00_0550bc00_2,
        iemDecodeA64_07fffc00_0550bc00_2,
        iemDecodeA64_07fffc00_055abc00_2,
        iemDecodeA64_07fffc00_055bbc00_2,
        iemDecodeA64_07fffc00_055cbc00_2,
        iemDecodeA64_07fffc00_055dbc00_2,
        iemDecodeA64_07fffc00_055ebc00_2,
        iemDecodeA64_07fffc00_055fbc00_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0540c000 level 2
   ffe0fc00/0540c400 level 2
   ffe0fc00/0540c800 level 2
   ffe0fc00/0540cc00 level 2
   ffe0fc00/0540d000 level 2
   ffe0fc00/0540d400 level 2
   ffe0fc00/0540d800 level 2
   ffe0fc00/0540dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0540c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30e000)) == UINT32_C(0x0510c000))
        return iemDecodeA64_fcpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05400000))
        return iemDecodeA64_eor_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/2540c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2540c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2540c000))
        return iemDecodeA64_brkpas_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2540c010))
        return iemDecodeA64_brkpbs_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffc21f)) == UINT32_C(0x2550c000))
        return iemDecodeA64_ptest__p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffe10)) == UINT32_C(0x2558c000))
        return iemDecodeA64_pfirst_p_p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540c000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0540c000_2,
        iemDecodeA64_LD1R_asisdlso_R1,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2540c000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sabalb_z_zzz,
        iemDecodeA64_LD1R_asisdlso_R1,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2540c400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2540c400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffe10)) == UINT32_C(0x2519c400))
        return iemDecodeA64_pnext_p_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2540c000))
        return iemDecodeA64_brkpas_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2540c010))
        return iemDecodeA64_brkpbs_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffc21f)) == UINT32_C(0x2550c000))
        return iemDecodeA64_ptest__p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0540c000_2,
        iemDecodeA64_LD1R_asisdlso_R1,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMN_CPY_memcms,
        iemDecodeA64_ffe0fc00_2540c400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sabalt_z_zzz,
        iemDecodeA64_LD1R_asisdlso_R1,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMN_CPY_memcms,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMN_CPY_memcms,
        iemDecodeA64_ld3w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2540c800 level 2
   ffe0fc00/2540cc00 level 2
   ffe0fc00/2540d000 level 2
   ffe0fc00/2540d400 level 2
   ffe0fc00/2540d800 level 2
   ffe0fc00/2540dc00 level 2
   ffe0fc00/2540e400 level 2
   ffe0fc00/2540e800 level 2
   ffe0fc00/2540ec00 level 2
   ffe0fc00/2540f400 level 2
   ffe0fc00/2540f800 level 2
   ffe0fc00/2540fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2540c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2540c000))
        return iemDecodeA64_brkpas_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2540c010))
        return iemDecodeA64_brkpbs_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffc21f)) == UINT32_C(0x2550c000))
        return iemDecodeA64_ptest__p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%72 (0x17) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0540c000_2,
        iemDecodeA64_LD1R_asisdlso_R1,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uabalb_z_zzz,
        iemDecodeA64_LD1R_asisdlso_R1,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ld3w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%59 (0x13) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0540c000_2,
        iemDecodeA64_LD1R_asisdlso_R1,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uabalt_z_zzz,
        iemDecodeA64_LD1R_asisdlso_R1,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540d000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0540c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_adclb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540d400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%66 (0x15) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0540c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMWTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_adclt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMWTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMWTN_CPY_memcms,
        iemDecodeA64_ld3w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMWTN_CPY_memcms,
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%62 (0x14) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0540c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_4500d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ld3w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%50 (0x10) multi-if=%16 (0x5) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0540c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_4500d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_unscaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fe10/2550e000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fe10_2550e000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc10)) == UINT32_C(0x2518e000))
        return iemDecodeA64_ptrue_p_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffc10)) == UINT32_C(0x2519e000))
        return iemDecodeA64_ptrues_p_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffc21f)) == UINT32_C(0x2550c000))
        return iemDecodeA64_ptest__p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff0fe10/2550e200 level 3
   ffe0fc00/2580e000 level 2
   ffe0fc00/25c0e000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_fff0fe10_2550e200_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc10)) == UINT32_C(0x2518e000))
        return iemDecodeA64_ptrue_p_s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffc10)) == UINT32_C(0x2519e000))
        return iemDecodeA64_ptrues_p_s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/2540e000 level 2
   mask=0x100210 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%25 (0x2) multi-if=%25 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2540e000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_brkpas_p_p_pp,
        iemDecodeA64_brkpbs_p_p_pp,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fe10_2550e000_3,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fff0fe10_2550e200_3,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100210 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/e540e000 level 2
   ffe0fc00/e540e400 level 2
   ffe0fc00/e540e800 level 2
   ffe0fc00/e540ec00 level 2
   ffe0fc00/e540f000 level 2
   ffe0fc00/e540f400 level 2
   ffe0fc00/e540f800 level 2
   ffe0fc00/e540fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e540e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffd0e000)) == UINT32_C(0xe540e000))
        return iemDecodeA64_st1w_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe550e000))
        return iemDecodeA64_st3w_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD3R_asisdlso_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2540e000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ssra_z_zi,
        iemDecodeA64_LD3R_asisdlso_R3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e540e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540e400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD3R_asisdlso_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMRTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_usra_z_zi,
        iemDecodeA64_LD3R_asisdlso_R3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMRTN_CPY_memcms,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMRTN_CPY_memcms,
        iemDecodeA64_ld3w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMRTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_e540e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x1b valid=%84 (0x1b) leaf=%75 (0x18) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD3R_asisdlso_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_srsra_z_zi,
        iemDecodeA64_LD3R_asisdlso_R3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ld3w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_ffe0fc00_e540e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_LD3R_asisdlso_R3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ursra_z_zi,
        iemDecodeA64_LD3R_asisdlso_R3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e540e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2540f000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2540f000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2540c000))
        return iemDecodeA64_brkpas_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0c210)) == UINT32_C(0x2540c010))
        return iemDecodeA64_brkpbs_p_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffc21f)) == UINT32_C(0x2550c000))
        return iemDecodeA64_ptest__p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffe10)) == UINT32_C(0x2558f000))
        return iemDecodeA64_rdffrs_p_p_f(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540f000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2540f000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sri_z_zzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e540e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540f400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYMTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sli_z_zzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYMTN_CPY_memcms,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYMTN_CPY_memcms,
        iemDecodeA64_ld3w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_CPYMTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_e540e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540f800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_B_ldapstl_simd,
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_saba_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_LDAPUR_H_ldapstl_simd,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDAPUR_S_ldapstl_simd,
        iemDecodeA64_ld3w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_LDAPUR_D_ldapstl_simd,
        iemDecodeA64_ffe0fc00_e540e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x540fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0540fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_eor_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2540c800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uaba_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_ffe0fc00_d5400000_2,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e540e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5600000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05600000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_con,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqshrunb_z_zi,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5600400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05600400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_con,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqshrunt_z_zi,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5600800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05600800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_con,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqrshrunb_z_zi,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5600c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05600c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_con,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200c00_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqrshrunt_z_zi,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5601000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05601000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_con,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_shrnb_z_zi,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5601400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05601400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_con,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_shrnt_z_zi,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5601800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05601800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_con,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_rshrnb_z_zi,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5601c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05601c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ext_z_zi_con,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200c00_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_rshrnt_z_zi,
        iemDecodeA64_LD2_asisdlso_B2_2b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5602000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05602000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dup_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqshrnb_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5602400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05602400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_extq_z_zi_des,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqshrnt_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5602800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05602800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbl_z_zz_2,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqrshrnb_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5602c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05602c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbx_z_zz,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqrshrnt_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5603000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05603000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbl_z_zz_1,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25203000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uqshrnb_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5603400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%66 (0x15) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05603400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbxq_z_zz,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uqshrnt_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/05603800 level 3
   ffeffc00/05a03800 level 3
   ffeffc00/05e03800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_05603800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05203800))
        return iemDecodeA64_dup_z_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05303800))
        return iemDecodeA64_sunpklo_z_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/05643800 level 3
   ffeffc00/05a43800 level 3
   ffeffc00/05e43800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_05643800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05243800))
        return iemDecodeA64_insr_z_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05343800))
        return iemDecodeA64_insr_z_v(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/05683800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_05683800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05383800))
        return iemDecodeA64_rev_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff9fc10)) == UINT32_C(0x05683800))
        return iemDecodeA64_pmov_p_zi_s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/05603800 level 2
   mask=0xf0000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%62 (0xa) multi-if=%19 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05603800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc00_05603800_3,
        iemDecodeA64_sunpkhi_z_z,
        iemDecodeA64_uunpklo_z_z,
        iemDecodeA64_uunpkhi_z_z,
        iemDecodeA64_ffeffc00_05643800_3,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffeffc00_05683800_3,
        iemDecodeA64_pmov_z_pi_s,
        iemDecodeA64_pmov_p_zi_s,
        iemDecodeA64_pmov_z_pi_s,
        iemDecodeA64_pmov_p_zi_s,
        iemDecodeA64_pmov_z_pi_s,
        iemDecodeA64_pmov_p_zi_s,
        iemDecodeA64_pmov_z_pi_s,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5603800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05603800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05603800_2,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uqrshrnb_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05603c00 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05603c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uqrshrnt_z_zi,
        iemDecodeA64_LD4_asisdlso_B4_4b,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05604000 level 2
   ffe0fc00/05a04000 level 2
   ffe0fc00/05e04000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05604000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30fe10)) == UINT32_C(0x05204000))
        return iemDecodeA64_zip1_p_pp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe10)) == UINT32_C(0x05344000))
        return iemDecodeA64_rev_p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5604000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05604000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05604000_2,
        iemDecodeA64_LD2_asisdlso_H2_2h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqxtnb_z_zz,
        iemDecodeA64_LD2_asisdlso_H2_2h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5604400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05604400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqxtnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5604800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05604800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_p_pp,
        iemDecodeA64_LD2_asisdlso_H2_2h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uqxtnb_z_zz,
        iemDecodeA64_LD2_asisdlso_H2_2h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5604c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05604c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204c00_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_uqxtnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5605000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05605000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_p_pp,
        iemDecodeA64_LD2_asisdlso_H2_2h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqxtunb_z_zz,
        iemDecodeA64_LD2_asisdlso_H2_2h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5605400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05605400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_sqxtunt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5605800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05605800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD2_asisdlso_H2_2h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD2_asisdlso_H2_2h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5605c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05605c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205c00_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5606000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05606000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip1_z_zz,
        iemDecodeA64_LD4_asisdlso_H4_4h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_addhnb_z_zz,
        iemDecodeA64_LD4_asisdlso_H4_4h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5606400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05606400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_addhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5606800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05606800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_z_zz,
        iemDecodeA64_LD4_asisdlso_H4_4h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_raddhnb_z_zz,
        iemDecodeA64_LD4_asisdlso_H4_4h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5606c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05606c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204c00_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_raddhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5607000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05607000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_z_zz,
        iemDecodeA64_LD4_asisdlso_H4_4h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_subhnb_z_zz,
        iemDecodeA64_LD4_asisdlso_H4_4h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5607400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05607400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_subhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5607800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05607800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD4_asisdlso_H4_4h,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_rsubhnb_z_zz,
        iemDecodeA64_LD4_asisdlso_H4_4h,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5607c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05607c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_psel_p_ppi,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_rsubhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1w_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4w_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05608000 level 2
   ffe0fc00/05608400 level 2
   ffe0fc00/05608800 level 2
   ffe0fc00/05608c00 level 2
   ffe0fc00/05609000 level 2
   ffe0fc00/05609400 level 2
   ffe0fc00/05609800 level 2
   ffe0fc00/05609c00 level 2
   mask=0x1f0000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%47 (0xf) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05608000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cpy_z_p_v,
        iemDecodeA64_compact_z_p_z_s,
        iemDecodeA64_lasta_v_p_z,
        iemDecodeA64_lastb_v_p_z,
        iemDecodeA64_revb_z_z_m,
        iemDecodeA64_revh_z_z_m,
        iemDecodeA64_revw_z_z_m,
        iemDecodeA64_rbit_z_p_z_m,
        iemDecodeA64_clasta_z_p_zz,
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_splice_z_p_zz_des,
        iemDecodeA64_splice_z_p_zz_con,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_expand_z_p_z,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5608000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05608000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05608000_2,
        iemDecodeA64_LD2_asisdlso_S2_2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25208000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlso_S2_2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5608400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05608400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05608000_2,
        iemDecodeA64_LD2_asisdlso_D2_2d,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25208400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlso_D2_2d,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5608800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05608800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05608000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25208800_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5608c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05608c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05608000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25208c00_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5609000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%66 (0x15) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05609000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05608000_2,
        iemDecodeA64_LD2_asisdlso_S2_2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlso_S2_2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5609400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5609800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5609c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05609400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05608000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/0560a000 level 3
   fff7fc00/0560a400 level 3
   fff7fc00/0560a800 level 3
   fff7fc00/0560ac00 level 3
   fff7fc00/0560b000 level 3
   fff7fc00/0560b400 level 3
   fff7fc00/0560b800 level 3
   fff7fc00/0560bc00 level 3
   fff7fc00/05a0a000 level 3
   fff7fc00/05a0a400 level 3
   fff7fc00/05a0a800 level 3
   fff7fc00/05a0ac00 level 3
   fff7fc00/05a0b000 level 3
   fff7fc00/05a0b400 level 3
   fff7fc00/05a0b800 level 3
   fff7fc00/05a0bc00 level 3
   fff7fc00/05e0a000 level 3
   fff7fc00/05e0a400 level 3
   fff7fc00/05e0a800 level 3
   fff7fc00/05e0ac00 level 3
   fff7fc00/05e0b000 level 3
   fff7fc00/05e0b400 level 3
   fff7fc00/05e0b800 level 3
   fff7fc00/05e0bc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_0560a000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0520a000))
        return iemDecodeA64_lasta_r_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x0528a000))
        return iemDecodeA64_cpy_z_p_r(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/0560a000 level 2
   ffe0fc00/0560a400 level 2
   ffe0fc00/0560a800 level 2
   ffe0fc00/0560ac00 level 2
   ffe0fc00/0560b000 level 2
   ffe0fc00/0560b400 level 2
   ffe0fc00/0560b800 level 2
   ffe0fc00/0560bc00 level 2
   ffe0fc00/05a0a000 level 2
   ffe0fc00/05a0a400 level 2
   ffe0fc00/05a0a800 level 2
   ffe0fc00/05a0ac00 level 2
   ffe0fc00/05a0b000 level 2
   ffe0fc00/05a0b400 level 2
   ffe0fc00/05a0b800 level 2
   ffe0fc00/05a0bc00 level 2
   ffe0fc00/05e0a000 level 2
   ffe0fc00/05e0a400 level 2
   ffe0fc00/05e0a800 level 2
   ffe0fc00/05e0ac00 level 2
   ffe0fc00/05e0b000 level 2
   ffe0fc00/05e0b400 level 2
   ffe0fc00/05e0b800 level 2
   ffe0fc00/05e0bc00 level 2
   mask=0x170000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0560a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff7fc00_0560a000_3,
        iemDecodeA64_lastb_r_p_z,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_revb_z_z_z,
        iemDecodeA64_revh_z_z_z,
        iemDecodeA64_revw_z_z_z,
        iemDecodeA64_rbit_z_p_z_z,
        iemDecodeA64_clasta_r_p_z,
        iemDecodeA64_clastb_r_p_z,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x00170000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a560a000 level 2
   ffe0fc00/a560a400 level 2
   ffe0fc00/a560a800 level 2
   ffe0fc00/a560ac00 level 2
   ffe0fc00/a560b000 level 2
   ffe0fc00/a560b400 level 2
   ffe0fc00/a560b800 level 2
   ffe0fc00/a560bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a560a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa560a000))
        return iemDecodeA64_ld1w_z_p_bi_u64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa570a000))
        return iemDecodeA64_ldnf1w_z_p_bi_u64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_LD4_asisdlso_S4_4s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_histseg_z_zz,
        iemDecodeA64_LD4_asisdlso_S4_4s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a560a000_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_LD4_asisdlso_D4_4d,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_luti4_z_zz_8,
        iemDecodeA64_LD4_asisdlso_D4_4d,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a560a000_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_luti2_z_zz_16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a560a000_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a560a000_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%69 (0x16) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_LD4_asisdlso_S4_4s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_luti2_z_zz_8,
        iemDecodeA64_LD4_asisdlso_S4_4s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a560a000_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_luti4_z_zz_2x16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a560a000_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%62 (0x14) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_luti4_z_zz_1x16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_CBLO_32_imm,
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rsh_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a560a000_2,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1sw_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_ai_s,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_CBLO_64_imm,
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560c000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560c400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x17 valid=%72 (0x17) leaf=%69 (0x16) multi-if=%0 (0x0) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_LD2R_asisdlso_R2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520c000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_histcnt_z_p_zz,
        iemDecodeA64_LD2R_asisdlso_R2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld4w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560d000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%62 (0x14) multi-if=%0 (0x0) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520c000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_histcnt_z_p_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld4w_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ld1w_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1w_z_p_bz_s_x32_scaled,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/e560e000 level 2
   ffe0fc00/e560e400 level 2
   ffe0fc00/e560e800 level 2
   ffe0fc00/e560ec00 level 2
   ffe0fc00/e560f000 level 2
   ffe0fc00/e560f400 level 2
   ffe0fc00/e560f800 level 2
   ffe0fc00/e560fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e560e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffd0e000)) == UINT32_C(0xe540e000))
        return iemDecodeA64_st1w_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe570e000))
        return iemDecodeA64_st4w_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560e000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560e400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560e800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%62 (0x14) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_LD4R_asisdlso_R4,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_LD4R_asisdlso_R4,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld4w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e560e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x560f000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560f400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560f800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x560fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0560f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_LDP_S_ldstpair_off,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_B_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_off,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_LDR_H_ldst_pos,
        iemDecodeA64_ld1rw_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld4w_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_off,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_LDR_S_ldst_pos,
        iemDecodeA64_ldff1w_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_MRRS_RS_systemmovepr,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e560e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_off,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_LDR_D_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05800000 level 2
   ffe0fc00/05800400 level 2
   ffe0fc00/05800800 level 2
   ffe0fc00/05800c00 level 2
   ffe0fc00/05801000 level 2
   ffe0fc00/05801400 level 2
   ffe0fc00/05801800 level 2
   ffe0fc00/05801c00 level 2
   ffe0fc00/05802000 level 2
   ffe0fc00/05802400 level 2
   ffe0fc00/05802800 level 2
   ffe0fc00/05802c00 level 2
   ffe0fc00/05803000 level 2
   ffe0fc00/05803400 level 2
   ffe0fc00/05803800 level 2
   ffe0fc00/05803c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05100000))
        return iemDecodeA64_cpy_z_o_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05800000))
        return iemDecodeA64_and_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/0d800000 level 2
   ffe0fc00/4d800000 level 2
   ffe0fc00/0d800400 level 2
   ffe0fc00/4d800400 level 2
   ffe0fc00/0d800800 level 2
   ffe0fc00/4d800800 level 2
   ffe0fc00/0d800c00 level 2
   ffe0fc00/4d800c00 level 2
   ffe0fc00/0d801000 level 2
   ffe0fc00/4d801000 level 2
   ffe0fc00/0d801400 level 2
   ffe0fc00/4d801400 level 2
   ffe0fc00/0d801800 level 2
   ffe0fc00/4d801800 level 2
   ffe0fc00/0d801c00 level 2
   ffe0fc00/4d801c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0d800000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e000)) == UINT32_C(0x0d800000))
        return iemDecodeA64_ST1_asisdlsop_BX1_r1b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d9f0000))
        return iemDecodeA64_ST1_asisdlsop_B1_i1b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5800000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05800000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_saddlb_z_zz,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fadd_z_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqd_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5800400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05800400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYE_CPY_memcms,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_saddlt_z_zz,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYE_CPY_memcms,
        iemDecodeA64_fsub_z_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYE_CPY_memcms,
        iemDecodeA64_ld1rqd_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYE_CPY_memcms,
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5800800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05800800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uaddlb_z_zz,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmul_z_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqd_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5800c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05800c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uaddlt_z_zz,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ftsmul_z_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqd_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05801000 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05801000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ssublb_z_zz,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqd_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5801400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05801400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWT_CPY_memcms,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ssublt_z_zz,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWT_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWT_CPY_memcms,
        iemDecodeA64_ld1rqd_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWT_CPY_memcms,
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5801800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05801800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_usublb_z_zz,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frecps_z_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqd_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5801c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05801c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_usublt_z_zz,
        iemDecodeA64_ffe0fc00_0d800000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frsqrts_z_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rqd_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0d802000 level 2
   ffe0fc00/4d802000 level 2
   ffe0fc00/0d802400 level 2
   ffe0fc00/4d802400 level 2
   ffe0fc00/0d802800 level 2
   ffe0fc00/4d802800 level 2
   ffe0fc00/0d802c00 level 2
   ffe0fc00/4d802c00 level 2
   ffe0fc00/0d803000 level 2
   ffe0fc00/4d803000 level 2
   ffe0fc00/0d803400 level 2
   ffe0fc00/4d803400 level 2
   ffe0fc00/0d803800 level 2
   ffe0fc00/4d803800 level 2
   ffe0fc00/0d803c00 level 2
   ffe0fc00/4d803c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0d802000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e000)) == UINT32_C(0x0d802000))
        return iemDecodeA64_ST3_asisdlsop_BX3_r3b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0d9f2000))
        return iemDecodeA64_ST3_asisdlsop_B3_i3b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a5802000 level 2
   ffe0fc00/a5802400 level 2
   ffe0fc00/a5802800 level 2
   ffe0fc00/a5802c00 level 2
   ffe0fc00/a5803000 level 2
   ffe0fc00/a5803400 level 2
   ffe0fc00/a5803800 level 2
   ffe0fc00/a5803c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a5802000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5802000))
        return iemDecodeA64_ld1rqd_z_p_bi_u64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5902000))
        return iemDecodeA64_ld1d_z_p_bi_u128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5802000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5802c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%31 (0xa) multi-if=%16 (0x5) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05802000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5802000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5802400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%44 (0xe) multi-if=%16 (0x5) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05802400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYERT_CPY_memcms,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYERT_CPY_memcms,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYERT_CPY_memcms,
        iemDecodeA64_ffe0fc00_a5802000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYERT_CPY_memcms,
        iemDecodeA64_stnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5802800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%34 (0xb) multi-if=%16 (0x5) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05802800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5802000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5803000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%34 (0xb) multi-if=%16 (0x5) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05803000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sabdlb_z_zz,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65403000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5802000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5803400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%47 (0xf) multi-if=%16 (0x5) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05803400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYET_CPY_memcms,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sabdlt_z_zz,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYET_CPY_memcms,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYET_CPY_memcms,
        iemDecodeA64_ffe0fc00_a5802000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYET_CPY_memcms,
        iemDecodeA64_stnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5803800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%38 (0xc) multi-if=%16 (0x5) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05803800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uabdlb_z_zz,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5802000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5803c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%34 (0xb) multi-if=%16 (0x5) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05803c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05800000_2,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uabdlt_z_zz,
        iemDecodeA64_ffe0fc00_0d802000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5802000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05804000 level 2
   ffe0fc00/05804400 level 2
   ffe0fc00/05804800 level 2
   ffe0fc00/05804c00 level 2
   ffe0fc00/05805000 level 2
   ffe0fc00/05805400 level 2
   ffe0fc00/05805800 level 2
   ffe0fc00/05805c00 level 2
   ffe0fc00/05806000 level 2
   ffe0fc00/05806400 level 2
   ffe0fc00/05806800 level 2
   ffe0fc00/05806c00 level 2
   ffe0fc00/05807000 level 2
   ffe0fc00/05807400 level 2
   ffe0fc00/05807800 level 2
   ffe0fc00/05807c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05804000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05104000))
        return iemDecodeA64_cpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05800000))
        return iemDecodeA64_and_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/0d804000 level 2
   ffe0fc00/4d804000 level 2
   ffe0fc00/0d804800 level 2
   ffe0fc00/4d804800 level 2
   ffe0fc00/0d805000 level 2
   ffe0fc00/4d805000 level 2
   ffe0fc00/0d805800 level 2
   ffe0fc00/4d805800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0d804000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e400)) == UINT32_C(0x0d804000))
        return iemDecodeA64_ST1_asisdlsop_HX1_r1h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d9f4000))
        return iemDecodeA64_ST1_asisdlsop_H1_i1h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/25804000 level 2
   ffe0fc00/25804400 level 2
   ffe0fc00/25804800 level 2
   ffe0fc00/25804c00 level 2
   ffe0fc00/25805000 level 2
   ffe0fc00/25805400 level 2
   ffe0fc00/25805800 level 2
   ffe0fc00/25805c00 level 2
   ffe0fc00/25806000 level 2
   ffe0fc00/25806400 level 2
   ffe0fc00/25806800 level 2
   ffe0fc00/25806c00 level 2
   ffe0fc00/25807000 level 2
   ffe0fc00/25807400 level 2
   ffe0fc00/25807800 level 2
   ffe0fc00/25807c00 level 2
   mask=0x100210 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25804000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orr_p_p_pp_z,
        iemDecodeA64_orn_p_p_pp_z,
        iemDecodeA64_nor_p_p_pp_z,
        iemDecodeA64_nand_p_p_pp_z,
        iemDecodeA64_brkb_p_p_p,
        iemDecodeA64_brkb_p_p_p,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100210 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5804000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05804000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_ffe0fc00_0d804000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_saddwb_z_zz,
        iemDecodeA64_ffe0fc00_0d804000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5804400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05804400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_saddwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWN_CPY_memcms,
        iemDecodeA64_ld1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWN_CPY_memcms,
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5804800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05804800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_ffe0fc00_0d804000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uaddwb_z_zz,
        iemDecodeA64_ffe0fc00_0d804000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5804c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05804c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uaddwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5805000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05805000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_ffe0fc00_0d804000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ssubwb_z_zz,
        iemDecodeA64_ffe0fc00_0d804000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5805400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05805400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ssubwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTWN_CPY_memcms,
        iemDecodeA64_ld1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTWN_CPY_memcms,
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5805800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05805800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_ffe0fc00_0d804000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_usubwb_z_zz,
        iemDecodeA64_ffe0fc00_0d804000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5805c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05805c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_usubwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0d806000 level 2
   ffe0fc00/4d806000 level 2
   ffe0fc00/0d806800 level 2
   ffe0fc00/4d806800 level 2
   ffe0fc00/0d807000 level 2
   ffe0fc00/4d807000 level 2
   ffe0fc00/0d807800 level 2
   ffe0fc00/4d807800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0d806000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e400)) == UINT32_C(0x0d806000))
        return iemDecodeA64_ST3_asisdlsop_HX3_r3h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0d9f6000))
        return iemDecodeA64_ST3_asisdlsop_H3_i3h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5806000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05806000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_ffe0fc00_0d806000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sqdmullb_z_zz,
        iemDecodeA64_ffe0fc00_0d806000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5806400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05806400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYERTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sqdmullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYERTWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYERTWN_CPY_memcms,
        iemDecodeA64_ldff1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYERTWN_CPY_memcms,
        iemDecodeA64_stnt1d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5806800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05806800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_ffe0fc00_0d806000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_pmullb_z_zz,
        iemDecodeA64_ffe0fc00_0d806000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5806c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05806c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_pmullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5807000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05807000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_ffe0fc00_0d806000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_smullb_z_zz,
        iemDecodeA64_ffe0fc00_0d806000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5807400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%53 (0x11) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05807400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYETWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_smullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYETWN_CPY_memcms,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYETWN_CPY_memcms,
        iemDecodeA64_ldff1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYETWN_CPY_memcms,
        iemDecodeA64_stnt1d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5807800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05807800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_ffe0fc00_0d806000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_umullb_z_zz,
        iemDecodeA64_ffe0fc00_0d806000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5807c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05807c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05804000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25804000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_umullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/0d818000 level 2
   ffe1fc00/4d818000 level 2
   ffe4fc00/0d849000 level 2
   ffe4fc00/4d849000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_0d818000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0d808000))
        return iemDecodeA64_ST1_asisdlsop_SX1_r1s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d9f8000))
        return iemDecodeA64_ST1_asisdlsop_S1_i1s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fc00/65808000 level 2
   mask=0x1e0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%100 (0x10) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_65808000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_fmax_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/65818000 level 2
   mask=0x1e0000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%94 (0xf) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_65818000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_fmin_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5808000/0xf8010000
   mask=0xf8010000 entries=0x40 children=0x22 valid=%53 (0x22) leaf=%44 (0x1c) multi-if=%6 (0x4) reuse=%5 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05808000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_ST1_asisdlsop_SX1_r1s,
        iemDecodeA64_ffe1fc00_0d818000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_ST1_asisdlsop_SX1_r1s,
        iemDecodeA64_ffe1fc00_0d818000_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe1fc00_65808000_2,
        iemDecodeA64_ffe1fc00_65818000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8010000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fcc0/05808400 level 2
   77e0fcc0/05808440 level 2
   77e0fcc0/05808480 level 2
   77e0fcc0/058084c0 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fcc0_05808400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0d808400))
        return iemDecodeA64_ST1_asisdlsop_DX1_r1d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d9f8400))
        return iemDecodeA64_ST1_asisdlsop_D1_i1d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05800000))
        return iemDecodeA64_and_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e0fcc0/15808400 level 2
   77e0fcc0/15808440 level 2
   77e0fcc0/15808480 level 2
   77e0fcc0/158084c0 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fcc0_15808400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1d808400))
        return iemDecodeA64_CPYERN_CPY_memcms(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e0fcc0/25808400 level 2
   77e0fcc0/25808440 level 2
   77e0fcc0/25808480 level 2
   77e0fcc0/258084c0 level 2
   mask=0x88000010 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77e0fcc0_25808400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpeq_p_p_zi,
        iemDecodeA64_cmpne_p_p_zi,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x88000010 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000002)) /* bit 27 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fcc0/35808400 level 2
   77e0fcc0/35808440 level 2
   77e0fcc0/35808480 level 2
   77e0fcc0/358084c0 level 2
   77ecfc00/3580b400 level 2
   77ecfc00/3584b400 level 2
   77ecfc00/3588b400 level 2
   77ecfc00/358cb400 level 2
   77e1fe00/35a08400 level 2
   77e1fe00/35a08600 level 2
   77e1fe00/35a18400 level 2
   77e1fe00/35a18600 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fcc0_35808400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x35000000))
        return iemDecodeA64_CBNZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb5000000))
        return iemDecodeA64_CBNZ_64_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x3d800000))
        return iemDecodeA64_STR_Q_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e0fcc0/45808400 level 2
   77e0fcc0/45808440 level 2
   77e0fcc0/45808480 level 2
   77e0fcc0/458084c0 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fcc0_45808400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0d808400))
        return iemDecodeA64_ST1_asisdlsop_DX1_r1d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d9f8400))
        return iemDecodeA64_ST1_asisdlsop_D1_i1d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65808400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65808400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65008000))
        return iemDecodeA64_fadd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65818400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65818400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65018000))
        return iemDecodeA64_fsub_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65828400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65828400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65028000))
        return iemDecodeA64_fmul_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65838400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65838400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65038000))
        return iemDecodeA64_fsubr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65848400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65848400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65048000))
        return iemDecodeA64_fmaxnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65858400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65858400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65058000))
        return iemDecodeA64_fminnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65868400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65868400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65068000))
        return iemDecodeA64_fmax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65878400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65878400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65078000))
        return iemDecodeA64_fmin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65888400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65888400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65088000))
        return iemDecodeA64_fabd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65188000))
        return iemDecodeA64_fadd_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/65898400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_65898400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_fscale_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65198000))
        return iemDecodeA64_fsub_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/658a8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_658a8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650a8000))
        return iemDecodeA64_fmulx_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651a8000))
        return iemDecodeA64_fmul_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/658b8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_658b8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651b8000))
        return iemDecodeA64_fsubr_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/658c8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_658c8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650c8000))
        return iemDecodeA64_fdivr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651c8000))
        return iemDecodeA64_fmaxnm_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/658d8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_658d8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650d8000))
        return iemDecodeA64_fdiv_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651d8000))
        return iemDecodeA64_fminnm_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/658e8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_658e8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650e8000))
        return iemDecodeA64_famax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651e8000))
        return iemDecodeA64_fmax_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/658f8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_658f8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650f8000))
        return iemDecodeA64_famin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651f8000))
        return iemDecodeA64_fmin_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7feffcc0/6d808400 level 3
   7feffcc0/6d818400 level 3
   7feffcc0/6d828400 level 3
   7feffcc0/6d838400 level 3
   7feffcc0/6d848400 level 3
   7feffcc0/6d858400 level 3
   7feffcc0/6d868400 level 3
   7feffcc0/6d878400 level 3
   7feffcc0/6d888400 level 3
   7feffcc0/6d898400 level 3
   7feffcc0/6d8a8400 level 3
   7feffcc0/6d8b8400 level 3
   7feffcc0/6d8c8400 level 3
   7feffcc0/6d8d8400 level 3
   7feffcc0/6d8e8400 level 3
   7feffcc0/6d8f8400 level 3
   7fe7fc00/6d809c00 level 2
   7fe7fc00/6d819c00 level 2
   7fe7fc00/6d829c00 level 2
   7fe7fc00/6d839c00 level 2
   7fe7fc00/6d849c00 level 2
   7fe7fc00/6d859c00 level 2
   7fe7fc00/6d869c00 level 2
   7fe7fc00/6d879c00 level 2
   7fe1fc00/6d80a400 level 2
   7fe1fc00/6d81a400 level 2
   7fe6fc00/6d80ac00 level 2
   7fe6fc00/6d82ac00 level 2
   7fe6fc00/6d84ac00 level 2
   7fe6fc00/6d86ac00 level 2
   7fe6fc00/6d80bc00 level 2
   7fe6fc00/6d82bc00 level 2
   7fe6fc00/6d84bc00 level 2
   7fe6fc00/6d86bc00 level 2
   7fe0fe00/6da09000 level 2
   7fe0fe00/6da09200 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7feffcc0_6d808400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6d800000))
        return iemDecodeA64_STP_D_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed800000))
        return iemDecodeA64_STTP_Q_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e0fcc0/65808400 level 2
   mask=0x80f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%100 (0x20) reuse=%47 (0xf) */
FNIEMOP_DEF_1(iemDecodeA64_77e0fcc0_65808400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_7feffcc0_65808400_3,
        iemDecodeA64_7feffcc0_65818400_3,
        iemDecodeA64_7feffcc0_65828400_3,
        iemDecodeA64_7feffcc0_65838400_3,
        iemDecodeA64_7feffcc0_65848400_3,
        iemDecodeA64_7feffcc0_65858400_3,
        iemDecodeA64_7feffcc0_65868400_3,
        iemDecodeA64_7feffcc0_65878400_3,
        iemDecodeA64_7feffcc0_65888400_3,
        iemDecodeA64_7feffcc0_65898400_3,
        iemDecodeA64_7feffcc0_658a8400_3,
        iemDecodeA64_7feffcc0_658b8400_3,
        iemDecodeA64_7feffcc0_658c8400_3,
        iemDecodeA64_7feffcc0_658d8400_3,
        iemDecodeA64_7feffcc0_658e8400_3,
        iemDecodeA64_7feffcc0_658f8400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x080f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000010)) /* bit 27 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff8fcc0/65808440 level 3
   fff8fcc0/65808480 level 3
   fff8fcc0/658084c0 level 3
   mask=0x70000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_fff8fcc0_65808440_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_fmin_z_p_zz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff8fcc0/65888440 level 3
   fff8fcc0/65888480 level 3
   fff8fcc0/658884c0 level 3
   mask=0x70000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%88 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_fff8fcc0_65888440_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00070000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fcc0/65808440 level 2
   77e0fcc0/65808480 level 2
   77e0fcc0/658084c0 level 2
   mask=0x88180000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77e0fcc0_65808440_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff8fcc0_65808440_3,
        iemDecodeA64_fff8fcc0_65888440_3,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x88180000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 19) & UINT32_C(0x00000003)) /* bit 19 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000004)) /* bit 27 L 1 -> 2 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5808400/0x700000c0
   mask=0x700000c0 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%12 (0x4) multi-if=%50 (0x10) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05808400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_77e0fcc0_05808400_2,
        iemDecodeA64_77e0fcc0_05808400_2,
        iemDecodeA64_77e0fcc0_05808400_2,
        iemDecodeA64_77e0fcc0_05808400_2,
        iemDecodeA64_77e0fcc0_15808400_2,
        iemDecodeA64_77e0fcc0_15808400_2,
        iemDecodeA64_77e0fcc0_15808400_2,
        iemDecodeA64_77e0fcc0_15808400_2,
        iemDecodeA64_77e0fcc0_25808400_2,
        iemDecodeA64_77e0fcc0_25808400_2,
        iemDecodeA64_77e0fcc0_25808400_2,
        iemDecodeA64_77e0fcc0_25808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_45808400_2,
        iemDecodeA64_77e0fcc0_45808400_2,
        iemDecodeA64_77e0fcc0_45808400_2,
        iemDecodeA64_77e0fcc0_45808400_2,
        iemDecodeA64_CPYERN_CPY_memcms,
        iemDecodeA64_CPYERN_CPY_memcms,
        iemDecodeA64_CPYERN_CPY_memcms,
        iemDecodeA64_CPYERN_CPY_memcms,
        iemDecodeA64_77e0fcc0_65808400_2,
        iemDecodeA64_77e0fcc0_65808440_2,
        iemDecodeA64_77e0fcc0_65808440_2,
        iemDecodeA64_77e0fcc0_65808440_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x700000c0 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000003)) /* bit  6 L 2 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001c)) /* bit 28 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/65808800 level 2
   ffe6fc00/65809800 level 2
   ffe6fc00/65c08c00 level 2
   mask=0x190000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_65808800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_fsub_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/65828800 level 2
   ffe6fc00/65829800 level 2
   ffe6fc00/65c28c00 level 2
   mask=0x190000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_65828800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_fsubr_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/65848800 level 2
   ffe6fc00/65849800 level 2
   ffe6fc00/65c48c00 level 2
   mask=0x190000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_65848800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_fminnm_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/65868800 level 2
   ffe6fc00/65869800 level 2
   ffe6fc00/65c68c00 level 2
   mask=0x190000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_65868800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_fmin_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5808800/0xf8060000
   mask=0xf8060000 entries=0x80 children=0x3e valid=%48 (0x3e) leaf=%42 (0x36) multi-if=%3 (0x4) reuse=%3 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05808800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe6fc00_65808800_2,
        iemDecodeA64_ffe6fc00_65828800_2,
        iemDecodeA64_ffe6fc00_65848800_2,
        iemDecodeA64_ffe6fc00_65868800_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_Invalid, // 64
        iemDecodeA64_Invalid, // 65
        iemDecodeA64_Invalid, // 66
        iemDecodeA64_Invalid, // 67
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 120
        iemDecodeA64_Invalid, // 121
        iemDecodeA64_Invalid, // 122
        iemDecodeA64_Invalid, // 123
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8060000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fc00/65808c00 level 2
   ffe3fc00/65c09c00 level 2
   mask=0x1c0000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_65808c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_fmaxnm_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fc00/65818c00 level 2
   ffe3fc00/65c19c00 level 2
   mask=0x1c0000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_65818c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_fminnm_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fc00/65828c00 level 2
   ffe3fc00/65c29c00 level 2
   mask=0x1c0000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_65828c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_fmax_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fc00/65838c00 level 2
   ffe3fc00/65c39c00 level 2
   mask=0x1c0000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_65838c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_fmin_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5808c00/0xf8030000
   mask=0xf8030000 entries=0x80 children=0x3c valid=%47 (0x3c) leaf=%41 (0x34) multi-if=%3 (0x4) reuse=%3 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05808c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe3fc00_65808c00_2,
        iemDecodeA64_ffe3fc00_65818c00_2,
        iemDecodeA64_ffe3fc00_65828c00_2,
        iemDecodeA64_ffe3fc00_65838c00_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_Invalid, // 64
        iemDecodeA64_Invalid, // 65
        iemDecodeA64_Invalid, // 66
        iemDecodeA64_Invalid, // 67
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 120
        iemDecodeA64_Invalid, // 121
        iemDecodeA64_Invalid, // 122
        iemDecodeA64_Invalid, // 123
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8030000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe4fc00/65809000 level 2
   ffe4fc00/65c08800 level 2
   ffe4fc00/65c09800 level 2
   mask=0x1b0000 entries=0x10 children=0xb valid=%69 (0xb) leaf=%69 (0xb) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_65809000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_fsubr_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000c)) /* bit 19 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe4fc00/65849000 level 2
   ffe4fc00/65c48800 level 2
   ffe4fc00/65c49800 level 2
   mask=0x1b0000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_65849000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_fmin_z_p_zs,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000c)) /* bit 19 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5809000/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x21 valid=%52 (0x21) leaf=%42 (0x1b) multi-if=%6 (0x4) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05809000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ST1_asisdlsop_SX1_r1s,
        iemDecodeA64_ffe1fc00_0d818000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_eorbt_z_zz,
        iemDecodeA64_ST1_asisdlsop_SX1_r1s,
        iemDecodeA64_ffe1fc00_0d818000_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe4fc00_65809000_2,
        iemDecodeA64_ffe4fc00_65849000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05809400 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05809400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05819400 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05819400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05829400 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05829400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05839400 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%56 (0x12) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05839400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05849400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05849400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05859400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05859400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05869400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05869400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05879400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05879400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05889400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05889400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05899400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05899400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/058a9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_058a9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/058b9400 level 2
   07fffc00/05909400 level 2
   07fffc00/05919400 level 2
   07fffc00/05929400 level 2
   07fffc00/05939400 level 2
   07fffc00/05949400 level 2
   07fffc00/05959400 level 2
   07fffc00/05969400 level 2
   07fffc00/05979400 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_058b9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/058c9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_058c9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/058d9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_058d9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/058e9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_058e9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/058f9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_058f9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05989400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05989400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05999400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05999400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/059a9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_059a9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/059b9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_059b9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/059c9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_059c9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/059d9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_059d9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/059e9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_059e9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/059f9400 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_059f9400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_eortb_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_fmin_z_p_zs,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTRN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5809400/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05809400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_05809400_2,
        iemDecodeA64_07fffc00_05819400_2,
        iemDecodeA64_07fffc00_05829400_2,
        iemDecodeA64_07fffc00_05839400_2,
        iemDecodeA64_07fffc00_05849400_2,
        iemDecodeA64_07fffc00_05859400_2,
        iemDecodeA64_07fffc00_05869400_2,
        iemDecodeA64_07fffc00_05879400_2,
        iemDecodeA64_07fffc00_05889400_2,
        iemDecodeA64_07fffc00_05899400_2,
        iemDecodeA64_07fffc00_058a9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_058c9400_2,
        iemDecodeA64_07fffc00_058d9400_2,
        iemDecodeA64_07fffc00_058e9400_2,
        iemDecodeA64_07fffc00_058f9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_058b9400_2,
        iemDecodeA64_07fffc00_05989400_2,
        iemDecodeA64_07fffc00_05999400_2,
        iemDecodeA64_07fffc00_059a9400_2,
        iemDecodeA64_07fffc00_059b9400_2,
        iemDecodeA64_07fffc00_059c9400_2,
        iemDecodeA64_07fffc00_059d9400_2,
        iemDecodeA64_07fffc00_059e9400_2,
        iemDecodeA64_07fffc00_059f9400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5809800/0xf8060000
   mask=0xf8060000 entries=0x80 children=0x3e valid=%48 (0x3e) leaf=%42 (0x36) multi-if=%3 (0x4) reuse=%6 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05809800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_usmmla_z_zzz,
        iemDecodeA64_usmmla_z_zzz,
        iemDecodeA64_usmmla_z_zzz,
        iemDecodeA64_usmmla_z_zzz,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe6fc00_65808800_2,
        iemDecodeA64_ffe6fc00_65828800_2,
        iemDecodeA64_ffe6fc00_65848800_2,
        iemDecodeA64_ffe6fc00_65868800_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_Invalid, // 64
        iemDecodeA64_Invalid, // 65
        iemDecodeA64_Invalid, // 66
        iemDecodeA64_Invalid, // 67
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_ld1d_z_p_br_u128,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 120
        iemDecodeA64_Invalid, // 121
        iemDecodeA64_Invalid, // 122
        iemDecodeA64_Invalid, // 123
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8060000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe7fc00/15809c00 level 2
   7fe7fc00/15819c00 level 2
   7fe7fc00/15829c00 level 2
   7fe7fc00/15839c00 level 2
   7fe7fc00/15849c00 level 2
   7fe7fc00/15859c00 level 2
   7fe7fc00/15869c00 level 2
   7fe7fc00/15879c00 level 2
   7fe1fc00/1580a400 level 2
   7fe1fc00/1581a400 level 2
   7fe6fc00/1580ac00 level 2
   7fe6fc00/1582ac00 level 2
   7fe6fc00/1584ac00 level 2
   7fe6fc00/1586ac00 level 2
   7fe6fc00/1580bc00 level 2
   7fe6fc00/1582bc00 level 2
   7fe6fc00/1584bc00 level 2
   7fe6fc00/1586bc00 level 2
   77e1fe00/15a08400 level 2
   77e1fe00/15a08600 level 2
   77e1fe00/15a18400 level 2
   77e1fe00/15a18600 level 2
   7fe0fe00/15a09000 level 2
   7fe0fe00/15a09200 level 2
   3fe0fcc0/15c09000 level 2
   3fe0fcc0/15c09040 level 2
   3fe0fcc0/15c09080 level 2
   3fe0fcc0/15c090c0 level 2
   3fe0fcc0/15c09400 level 2
   3fe0fcc0/15c09440 level 2
   3fe0fcc0/15c09480 level 2
   3fe0fcc0/15c094c0 level 2
   7fe5fc00/16000000 level 2
   7fe5fc00/16010000 level 2
   7fe5fc00/16040000 level 2
   7fe5fc00/16050000 level 2
   7fe1fc00/16000400 level 2
   7fe1fc00/16010400 level 2
   7fe6fc00/16001000 level 2
   7fe6fc00/16021000 level 2
   7fe6fc00/16041000 level 2
   7fe6fc00/16061000 level 2
   7fe1fc00/16001800 level 2
   7fe1fc00/16011800 level 2
   7fe6fc00/16002000 level 2
   7fe6fc00/16022000 level 2
   7fe6fc00/16042000 level 2
   7fe6fc00/16062000 level 2
   7fe1fc00/16002800 level 2
   7fe1fc00/16012800 level 2
   7fe6fc00/16003000 level 2
   7fe6fc00/16023000 level 2
   7fe6fc00/16043000 level 2
   7fe6fc00/16063000 level 2
   7fe1fc00/16003800 level 2
   7fe1fc00/16013800 level 2
   7fe6fc00/16004000 level 2
   7fe6fc00/16024000 level 2
   7fe6fc00/16044000 level 2
   7fe6fc00/16064000 level 2
   7fe6fc00/16005000 level 2
   7fe6fc00/16025000 level 2
   7fe6fc00/16045000 level 2
   7fe6fc00/16065000 level 2
   7fe1fc00/16005800 level 2
   7fe1fc00/16015800 level 2
   7fe6fc00/16006000 level 2
   7fe6fc00/16026000 level 2
   7fe6fc00/16046000 level 2
   7fe6fc00/16066000 level 2
   7fe1fc00/16006800 level 2
   7fe1fc00/16016800 level 2
   7fe1fc00/16007000 level 2
   7fe1fc00/16017000 level 2
   7fe1fc00/16007800 level 2
   7fe1fc00/16017800 level 2
   7fe1fc00/16009400 level 2
   7fe1fc00/16019400 level 2
   7fe1fc00/1600c400 level 2
   7fe1fc00/1601c400 level 2
   3fe6fc00/1600cc00 level 2
   3fe6fc00/1602cc00 level 2
   3fe6fc00/1604cc00 level 2
   3fe6fc00/1606cc00 level 2
   3fe6fc00/1600d400 level 2
   3fe6fc00/1602d400 level 2
   3fe6fc00/1604d400 level 2
   3fe6fc00/1606d400 level 2
   3fe6fc00/1600dc00 level 2
   3fe6fc00/1602dc00 level 2
   3fe6fc00/1604dc00 level 2
   3fe6fc00/1606dc00 level 2
   3fe6fc00/1600e400 level 2
   3fe6fc00/1602e400 level 2
   3fe6fc00/1604e400 level 2
   3fe6fc00/1606e400 level 2
   3fe6fc00/1600ec00 level 2
   3fe6fc00/1602ec00 level 2
   3fe6fc00/1604ec00 level 2
   3fe6fc00/1606ec00 level 2
   7fe1fc00/1600f400 level 2
   7fe1fc00/1601f400 level 2
   3fe6fc00/1600fc00 level 2
   3fe6fc00/1602fc00 level 2
   3fe6fc00/1604fc00 level 2
   3fe6fc00/1606fc00 level 2
   7fe0fc00/16206000 level 2
   7fe0fc00/16208800 level 2
   3fe0fc00/16208c00 level 2
   7fe0fc00/16209000 level 2
   7fe0fc00/16209800 level 2
   3fe0fc00/16209c00 level 2
   3fe0fc00/1620ac00 level 2
   7fe0fc00/1620b000 level 2
   7fe0fc00/1620bc00 level 2
   6fe3fc00/0620c800 level 2
   6fe3fc00/0621c800 level 2
   6fe3fc00/0622c800 level 2
   6fe3fc00/0623c800 level 2
   3fe0fc00/1620cc00 level 2
   7fe0fc00/1620d000 level 2
   3fe3fc00/1620d800 level 2
   3fe3fc00/1621d800 level 2
   3fe3fc00/1622d800 level 2
   3fe3fc00/1623d800 level 2
   7fe0fc00/1620e800 level 2
   3fe0fc00/1620ec00 level 2
   77e0fc00/1620f800 level 2
   3fe6fc00/16400000 level 2
   3fe6fc00/16420000 level 2
   3fe6fc00/16440000 level 2
   7fe1fc00/16400400 level 2
   7fe1fc00/16410400 level 2
   3fe6fc00/16400800 level 2
   3fe6fc00/16420800 level 2
   3fe6fc00/16440800 level 2
   3fe6fc00/16400c00 level 2
   3fe6fc00/16420c00 level 2
   3fe6fc00/16440c00 level 2
   3fe6fc00/16401000 level 2
   3fe6fc00/16421000 level 2
   3fe6fc00/16441000 level 2
   3fe6fc00/16461000 level 2
   7fe1fc00/16401400 level 2
   7fe1fc00/16411400 level 2
   3fe6fc00/16401800 level 2
   3fe6fc00/16421800 level 2
   3fe6fc00/16441800 level 2
   3fe6fc00/16461800 level 2
   7fe6fc00/16401c00 level 2
   7fe6fc00/16421c00 level 2
   7fe6fc00/16441c00 level 2
   7fe6fc00/16461c00 level 2
   3fe6fc00/16402000 level 2
   3fe6fc00/16422000 level 2
   3fe6fc00/16442000 level 2
   3fe6fc00/16462000 level 2
   3fe6fc00/16402800 level 2
   3fe6fc00/16422800 level 2
   3fe6fc00/16442800 level 2
   3fe6fc00/16462800 level 2
   7fe1fc00/16402c00 level 2
   7fe1fc00/16412c00 level 2
   3fe6fc00/16403000 level 2
   3fe6fc00/16423000 level 2
   3fe6fc00/16443000 level 2
   3fe6fc00/16463000 level 2
   7fe1fc00/16403400 level 2
   7fe1fc00/16413400 level 2
   3fe6fc00/16403800 level 2
   3fe6fc00/16423800 level 2
   3fe6fc00/16443800 level 2
   3fe6fc00/16463800 level 2
   7fe6fc00/16403c00 level 2
   7fe6fc00/16423c00 level 2
   7fe6fc00/16443c00 level 2
   7fe6fc00/16463c00 level 2
   3fe6fc00/16404000 level 2
   3fe6fc00/16424000 level 2
   3fe6fc00/16444000 level 2
   3fe6fc00/16464000 level 2
   3fe6fc00/16404400 level 2
   3fe6fc00/16424400 level 2
   3fe6fc00/16444400 level 2
   3fe6fc00/16464400 level 2
   3fe6fc00/16404800 level 2
   3fe6fc00/16424800 level 2
   3fe6fc00/16444800 level 2
   3fe6fc00/16464800 level 2
   3fe6fc00/16404c00 level 2
   3fe6fc00/16424c00 level 2
   3fe6fc00/16444c00 level 2
   3fe6fc00/16464c00 level 2
   3fe6fc00/16405000 level 2
   3fe6fc00/16425000 level 2
   3fe6fc00/16445000 level 2
   3fe6fc00/16465000 level 2
   3fe6fc00/16405400 level 2
   3fe6fc00/16425400 level 2
   3fe6fc00/16445400 level 2
   3fe6fc00/16465400 level 2
   3fe6fc00/16405800 level 2
   3fe6fc00/16425800 level 2
   3fe6fc00/16445800 level 2
   3fe6fc00/16465800 level 2
   3fe6fc00/16405c00 level 2
   3fe6fc00/16425c00 level 2
   3fe6fc00/16445c00 level 2
   3fe6fc00/16465c00 level 2
   3fe6fc00/16406000 level 2
   3fe6fc00/16426000 level 2
   3fe6fc00/16446000 level 2
   3fe6fc00/16466000 level 2
   3fe6fc00/16406400 level 2
   3fe6fc00/16426400 level 2
   3fe6fc00/16446400 level 2
   3fe6fc00/16466400 level 2
   3fe6fc00/16406800 level 2
   3fe6fc00/16426800 level 2
   3fe6fc00/16446800 level 2
   3fe6fc00/16466800 level 2
   3fe6fc00/16406c00 level 2
   3fe6fc00/16426c00 level 2
   3fe6fc00/16446c00 level 2
   3fe6fc00/16466c00 level 2
   3fe6fc00/16407000 level 2
   3fe6fc00/16427000 level 2
   3fe6fc00/16447000 level 2
   3fe6fc00/16467000 level 2
   3fe6fc00/16407400 level 2
   3fe6fc00/16427400 level 2
   3fe6fc00/16447400 level 2
   3fe6fc00/16467400 level 2
   3fe6fc00/16407800 level 2
   3fe6fc00/16427800 level 2
   3fe6fc00/16447800 level 2
   3fe6fc00/16467800 level 2
   3fe6fc00/16407c00 level 2
   3fe6fc00/16427c00 level 2
   3fe6fc00/16447c00 level 2
   3fe6fc00/16467c00 level 2
   3fe6fc00/16408000 level 2
   3fe6fc00/16428000 level 2
   3fe6fc00/16448000 level 2
   3fe6fc00/16468000 level 2
   7fe1fc00/16408400 level 2
   7fe1fc00/16418400 level 2
   3fe6fc00/16408800 level 2
   3fe6fc00/16428800 level 2
   3fe6fc00/16448800 level 2
   3fe6fc00/16468800 level 2
   7fe1fc00/16408c00 level 2
   7fe1fc00/16418c00 level 2
   3fe6fc00/16409000 level 2
   3fe6fc00/16429000 level 2
   3fe6fc00/16449000 level 2
   3fe6fc00/16469000 level 2
   7fe1fc00/16409400 level 2
   7fe1fc00/16419400 level 2
   3fe6fc00/16409800 level 2
   3fe6fc00/16429800 level 2
   3fe6fc00/16449800 level 2
   3fe6fc00/16469800 level 2
   3fe6fc00/16409c00 level 2
   3fe6fc00/16429c00 level 2
   3fe6fc00/16449c00 level 2
   3fe6fc00/16469c00 level 2
   3fe6fc00/1640a000 level 2
   3fe6fc00/1642a000 level 2
   3fe6fc00/1644a000 level 2
   3fe6fc00/1646a000 level 2
   3fe6fc00/1640a400 level 2
   3fe6fc00/1642a400 level 2
   3fe6fc00/1644a400 level 2
   3fe6fc00/1646a400 level 2
   3fe6fc00/1640a800 level 2
   3fe6fc00/1642a800 level 2
   3fe6fc00/1644a800 level 2
   3fe6fc00/1646a800 level 2
   3fe6fc00/1640ac00 level 2
   3fe6fc00/1642ac00 level 2
   3fe6fc00/1644ac00 level 2
   3fe6fc00/1646ac00 level 2
   3fe6fc00/1640b000 level 2
   3fe6fc00/1642b000 level 2
   3fe6fc00/1644b000 level 2
   3fe6fc00/1646b000 level 2
   3fe6fc00/1640b400 level 2
   3fe6fc00/1642b400 level 2
   3fe6fc00/1644b400 level 2
   3fe6fc00/1646b400 level 2
   3fe6fc00/1640b800 level 2
   3fe6fc00/1642b800 level 2
   3fe6fc00/1644b800 level 2
   3fe6fc00/1646b800 level 2
   3fe6fc00/1640bc00 level 2
   3fe6fc00/1642bc00 level 2
   3fe6fc00/1644bc00 level 2
   3fe6fc00/1646bc00 level 2
   7fe1fc00/1640c400 level 2
   7fe1fc00/1641c400 level 2
   3fe6fc00/1640cc00 level 2
   3fe6fc00/1642cc00 level 2
   3fe6fc00/1644cc00 level 2
   3fe6fc00/1646cc00 level 2
   3fe6fc00/1640d400 level 2
   3fe6fc00/1642d400 level 2
   3fe6fc00/1644d400 level 2
   3fe6fc00/1646d400 level 2
   3fe6fc00/1640dc00 level 2
   3fe6fc00/1642dc00 level 2
   3fe6fc00/1644dc00 level 2
   3fe6fc00/1646dc00 level 2
   3fe6fc00/1640e400 level 2
   3fe6fc00/1642e400 level 2
   3fe6fc00/1644e400 level 2
   3fe6fc00/1646e400 level 2
   3fe6fc00/1640ec00 level 2
   3fe6fc00/1642ec00 level 2
   3fe6fc00/1644ec00 level 2
   3fe6fc00/1646ec00 level 2
   7fe1fc00/1640f400 level 2
   7fe1fc00/1641f400 level 2
   7fe1fc00/1640fc00 level 2
   7fe1fc00/1641fc00 level 2
   3fe0fc00/16600800 level 2
   3fe0fc00/16601000 level 2
   7fe0fc00/16601800 level 2
   3fe0fc00/16601c00 level 2
   3fe0fc00/16602000 level 2
   7fe0fc00/16602800 level 2
   3fe0fc00/16603000 level 2
   3fe0fc00/16603c00 level 2
   7fe0fc00/16604800 level 2
   3fe0fc00/16605000 level 2
   3fe0fc00/16605800 level 2
   7fe0fc00/16606800 level 2
   3fe0fc00/16606c00 level 2
   3fe0fc00/16607000 level 2
   7fe0fc00/16607800 level 2
   3fe0fc00/16607c00 level 2
   7fe0fc00/16608000 level 2
   7fe0fc00/16609000 level 2
   3fe9fc00/16609800 level 2
   3fe9fc00/16619800 level 2
   3fe9fc00/16689800 level 2
   3fe9fc00/16699800 level 2
   3fe0fc00/16609c00 level 2
   77e6fc00/1660a800 level 2
   77e6fc00/1662a800 level 2
   77e6fc00/1664a800 level 2
   77e6fc00/1666a800 level 2
   3fe0fc00/1660ac00 level 2
   7fe0fc00/1660b000 level 2
   3fe3fc00/1660b800 level 2
   3fe3fc00/1661b800 level 2
   3fe3fc00/1662b800 level 2
   3fe3fc00/1663b800 level 2
   7fe0fc00/1660bc00 level 2
   3febfc00/1660c800 level 2
   3febfc00/1661c800 level 2
   3febfc00/1662c800 level 2
   3febfc00/1663c800 level 2
   3febfc00/1668c800 level 2
   3febfc00/1669c800 level 2
   3febfc00/166ac800 level 2
   3febfc00/166bc800 level 2
   7fe0fc00/1660cc00 level 2
   7fe0fc00/1660d000 level 2
   7fe0fc00/1660e800 level 2
   3fe0fc00/1660ec00 level 2
   77e0fc00/1660f800 level 2
   3fe0fc00/16808400 level 2
   3fe0fc00/16808c00 level 2
   7fe0fc00/16809400 level 2
   7fe0fc00/16a00800 level 2
   7fe0fc00/16a02800 level 2
   3ff1fc00/16a03800 level 2
   3ff1fc00/16a13800 level 2
   3ff1fc00/16b03800 level 2
   3ff1fc00/16b13800 level 2
   3fe3fc00/16a04800 level 2
   3fe3fc00/16a14800 level 2
   3fe3fc00/16a24800 level 2
   3fe3fc00/16a34800 level 2
   7fe0fc00/16a06800 level 2
   77e0fc00/16a07800 level 2
   7fe0fc00/16a08800 level 2
   7fe0fc00/16a09000 level 2
   7fe0fc00/16a09800 level 2
   7fe0fc00/16a0b000 level 2
   3fe3fc00/16a0c800 level 2
   3fe3fc00/16a1c800 level 2
   3fe3fc00/16a2c800 level 2
   3fe3fc00/16a3c800 level 2
   7fe0fc00/16a0d000 level 2
   3fe0fc00/16a0d400 level 2
   7fe0fc00/16a0e400 level 2
   7fe0fc00/16a0e800 level 2
   3fe0fc00/16a0ec00 level 2
   3fe0fc00/16a0fc00 level 2
   3fe6fc00/16c00000 level 2
   3fe6fc00/16c20000 level 2
   3fe6fc00/16c40000 level 2
   3fe6fc00/16c60000 level 2
   7fe1fc00/16c00400 level 2
   7fe1fc00/16c10400 level 2
   3fe6fc00/16c00c00 level 2
   3fe6fc00/16c20c00 level 2
   3fe6fc00/16c40c00 level 2
   3fe6fc00/16c60c00 level 2
   3fe6fc00/16c01000 level 2
   3fe6fc00/16c21000 level 2
   3fe6fc00/16c41000 level 2
   3fe6fc00/16c61000 level 2
   7fe6fc00/16c01400 level 2
   7fe6fc00/16c21400 level 2
   7fe6fc00/16c41400 level 2
   7fe6fc00/16c61400 level 2
   3fe6fc00/16c01800 level 2
   3fe6fc00/16c21800 level 2
   3fe6fc00/16c41800 level 2
   3fe6fc00/16c61800 level 2
   7fe1fc00/16c01c00 level 2
   7fe1fc00/16c11c00 level 2
   3fe6fc00/16c02000 level 2
   3fe6fc00/16c22000 level 2
   3fe6fc00/16c42000 level 2
   3fe6fc00/16c62000 level 2
   3fe6fc00/16c02800 level 2
   3fe6fc00/16c22800 level 2
   3fe6fc00/16c42800 level 2
   3fe6fc00/16c62800 level 2
   3fe6fc00/16c03000 level 2
   3fe6fc00/16c23000 level 2
   3fe6fc00/16c43000 level 2
   3fe6fc00/16c63000 level 2
   7fe1fc00/16c03400 level 2
   7fe1fc00/16c13400 level 2
   3fe6fc00/16c03800 level 2
   3fe6fc00/16c23800 level 2
   3fe6fc00/16c43800 level 2
   3fe6fc00/16c63800 level 2
   7fe6fc00/16c03c00 level 2
   7fe6fc00/16c23c00 level 2
   7fe6fc00/16c43c00 level 2
   7fe6fc00/16c63c00 level 2
   3fe6fc00/16c04000 level 2
   3fe6fc00/16c24000 level 2
   3fe6fc00/16c44000 level 2
   3fe6fc00/16c64000 level 2
   3fe6fc00/16c05000 level 2
   3fe6fc00/16c25000 level 2
   3fe6fc00/16c45000 level 2
   3fe6fc00/16c65000 level 2
   3fe6fc00/16c05800 level 2
   3fe6fc00/16c25800 level 2
   3fe6fc00/16c45800 level 2
   3fe6fc00/16c65800 level 2
   3fe6fc00/16c06000 level 2
   3fe6fc00/16c26000 level 2
   3fe6fc00/16c46000 level 2
   3fe6fc00/16c66000 level 2
   3fe6fc00/16c06800 level 2
   3fe6fc00/16c26800 level 2
   3fe6fc00/16c46800 level 2
   3fe6fc00/16c66800 level 2
   3fe6fc00/16c07000 level 2
   3fe6fc00/16c27000 level 2
   3fe6fc00/16c47000 level 2
   3fe6fc00/16c67000 level 2
   3fe6fc00/16c07800 level 2
   3fe6fc00/16c27800 level 2
   3fe6fc00/16c47800 level 2
   3fe6fc00/16c67800 level 2
   7fe1fc00/16c09400 level 2
   7fe1fc00/16c19400 level 2
   3fe6fc00/16c0c400 level 2
   3fe6fc00/16c2c400 level 2
   3fe6fc00/16c4c400 level 2
   3fe6fc00/16c6c400 level 2
   3fe6fc00/16c0cc00 level 2
   3fe6fc00/16c2cc00 level 2
   3fe6fc00/16c4cc00 level 2
   3fe6fc00/16c6cc00 level 2
   3fe6fc00/16c0d400 level 2
   3fe6fc00/16c2d400 level 2
   3fe6fc00/16c4d400 level 2
   3fe6fc00/16c6d400 level 2
   3fe6fc00/16c0dc00 level 2
   3fe6fc00/16c2dc00 level 2
   3fe6fc00/16c4dc00 level 2
   3fe6fc00/16c6dc00 level 2
   3fe6fc00/16c0e400 level 2
   3fe6fc00/16c2e400 level 2
   3fe6fc00/16c4e400 level 2
   3fe6fc00/16c6e400 level 2
   3fe6fc00/16c0f400 level 2
   3fe6fc00/16c2f400 level 2
   3fe6fc00/16c4f400 level 2
   3fe6fc00/16c6f400 level 2
   7fe1fc00/16c0fc00 level 2
   7fe1fc00/16c1fc00 level 2
   3fe0fc00/16e00800 level 2
   3fe0fc00/16e01000 level 2
   7fe0fc00/16e01800 level 2
   3fe0fc00/16e01c00 level 2
   3fe0fc00/16e02000 level 2
   7fe0fc00/16e02800 level 2
   3fe0fc00/16e03000 level 2
   7fe0fc00/16e04800 level 2
   3fe0fc00/16e05000 level 2
   7fe0fc00/16e05800 level 2
   3fe0fc00/16e06800 level 2
   3fe0fc00/16e06c00 level 2
   3fe0fc00/16e07000 level 2
   3fe0fc00/16e07c00 level 2
   7fe0fc00/16e08800 level 2
   7fe0fc00/16e09000 level 2
   3fe0fc00/16e09c00 level 2
   67f8fc00/06e8a800 level 2
   3fe0fc00/16e0ac00 level 2
   7fe0fc00/16e0b000 level 2
   3ff9fc00/16e0b800 level 2
   3ff9fc00/16e1b800 level 2
   3ff9fc00/16e8b800 level 2
   3ff9fc00/16e9b800 level 2
   3ff9fc00/16f0b800 level 2
   3ff9fc00/16f1b800 level 2
   3ff9fc00/16f8b800 level 2
   3ff9fc00/16f9b800 level 2
   7fe0fc00/16e0bc00 level 2
   7fe1fc00/16e0c000 level 2
   7fe1fc00/16e1c000 level 2
   3fe3fc00/16e0c800 level 2
   3fe3fc00/16e1c800 level 2
   3fe3fc00/16e2c800 level 2
   3fe3fc00/16e3c800 level 2
   7fe0fc00/16e0cc00 level 2
   7fe0fc00/16e0d000 level 2
   37e3fc00/16e2d800 level 2
   37e3fc00/16e3d800 level 2
   3fe0fc00/16e0dc00 level 2
   3fe0fc00/16e0ec00 level 2
   3fe0fc00/17000000 level 2
   3fe0fc00/17002000 level 2
   3fe0fc00/17002800 level 2
   3fe0fc00/17006000 level 2
   3fe0fc00/17006800 level 2
   3fe0fc00/17008c00 level 2
   3fe0fc00/1700a000 level 2
   3fe0fc00/1700a800 level 2
   7fe0fc00/1700b000 level 2
   3fe0fc00/1700b400 level 2
   7fe0fc00/1700b800 level 2
   7fe0fc00/1700c000 level 2
   3fe0fc00/1700c400 level 2
   7fe0fc00/1700c800 level 2
   3fe0fc00/1700d400 level 2
   3fe0fc00/1700e000 level 2
   3fe0fc00/1700e800 level 2
   3fe0fc00/1700f000 level 2
   3fe0fc00/1700f400 level 2
   3fe0fc00/1700f800 level 2
   3fe0fc00/17200000 level 2
   3fe0fc00/17202000 level 2
   3fe0fc00/17202800 level 2
   3fe0fc00/17204400 level 2
   3fe0fc00/17206000 level 2
   3fe0fc00/17206400 level 2
   3fe0fc00/17206800 level 2
   3fe0fc00/17208400 level 2
   3fe0fc00/17208c00 level 2
   3fe0fc00/1720a000 level 2
   3fe0fc00/1720a400 level 2
   3fe0fc00/1720a800 level 2
   7fe0fc00/1720b000 level 2
   7fe0fc00/1720b800 level 2
   7fe0fc00/1720c000 level 2
   7fe0fc00/1720c800 level 2
   3fe0fc00/1720e000 level 2
   3fe0fc00/1720e800 level 2
   3fe0fc00/1720f000 level 2
   3fe0fc00/1720f800 level 2
   3fe0fc00/17400000 level 2
   3fe0fc00/17400800 level 2
   3fe0fc00/17402000 level 2
   3fe0fc00/17402800 level 2
   3fe0fc00/17404400 level 2
   3fe0fc00/17406000 level 2
   3fe0fc00/17406400 level 2
   3fe0fc00/17406800 level 2
   3fe0fc00/17408400 level 2
   3fe0fc00/17408c00 level 2
   3fe0fc00/1740a000 level 2
   3fe0fc00/1740a400 level 2
   3fe0fc00/1740a800 level 2
   7fe0fc00/1740b000 level 2
   7fe0fc00/1740b800 level 2
   7fe0fc00/1740c000 level 2
   7fe0fc00/1740c800 level 2
   3fe0fc00/1740e000 level 2
   3fe0fc00/1740e800 level 2
   3fe0fc00/1740f000 level 2
   3fe0fc00/1740f800 level 2
   3fe0fc00/17600000 level 2
   3fe0fc00/17600800 level 2
   3fe0fc00/17602000 level 2
   3fe0fc00/17602800 level 2
   3fe0fc00/17604400 level 2
   3fe0fc00/17606000 level 2
   3fe0fc00/17606400 level 2
   3fe0fc00/17606800 level 2
   3fe0fc00/17608400 level 2
   3fe0fc00/17608c00 level 2
   3fe0fc00/1760a000 level 2
   3fe0fc00/1760a400 level 2
   3fe0fc00/1760a800 level 2
   7fe0fc00/1760b000 level 2
   7fe0fc00/1760b800 level 2
   7fe0fc00/1760c000 level 2
   7fe0fc00/1760c800 level 2
   3fe0fc00/1760e000 level 2
   3fe0fc00/1760e800 level 2
   3fe0fc00/1760f000 level 2
   3fe0fc00/1760f800 level 2
   3fe0fc00/17801000 level 2
   3fe0fc00/17801800 level 2
   3fe0fc00/17803000 level 2
   3fe0fc00/17803800 level 2
   3fe0fc00/17805000 level 2
   3fe0fc00/17805800 level 2
   3fe0fc00/17807000 level 2
   3fe0fc00/17807800 level 2
   7fe0fc00/1780b000 level 2
   7fe0fc00/1780b800 level 2
   3fe0fc00/1780c000 level 2
   3fe0fc00/1780c800 level 2
   3fe0fc00/1780f000 level 2
   3fe0fc00/1780f800 level 2
   3fe0fc00/17a01000 level 2
   3fe0fc00/17a01800 level 2
   3fe0fc00/17a03000 level 2
   3fe0fc00/17a03800 level 2
   3fe0fc00/17a05000 level 2
   3fe0fc00/17a05800 level 2
   3fe0fc00/17a07000 level 2
   3fe0fc00/17a07800 level 2
   7fe0fc00/17a0b000 level 2
   7fe0fc00/17a0b800 level 2
   3fe0fc00/17a0c000 level 2
   3fe0fc00/17a0c800 level 2
   3fe0fc00/17a0f000 level 2
   3fe0fc00/17a0f800 level 2
   3fe0fc00/17c02000 level 2
   3fe0fc00/17c02800 level 2
   3fe0fc00/17c06000 level 2
   3fe0fc00/17c06800 level 2
   7fe0fc00/17c08000 level 2
   7fe0fc00/17c08800 level 2
   3fe0fc00/17c0a000 level 2
   3fe0fc00/17c0a800 level 2
   7fe0fc00/17c0b000 level 2
   7fe0fc00/17c0b800 level 2
   7fe0fc00/17c0c000 level 2
   7fe0fc00/17c0c800 level 2
   3fe0fc00/17c0e000 level 2
   3fe0fc00/17c0e800 level 2
   3fe0fc00/17c0f000 level 2
   3fe0fc00/17c0f800 level 2
   3fe0fc00/17e02000 level 2
   3fe0fc00/17e02800 level 2
   3fe0fc00/17e06000 level 2
   3fe0fc00/17e06800 level 2
   7fe0fc00/17e08000 level 2
   7fe0fc00/17e08800 level 2
   3fe0fc00/17e0a000 level 2
   3fe0fc00/17e0a800 level 2
   7fe0fc00/17e0b000 level 2
   7fe0fc00/17e0b800 level 2
   7fe0fc00/17e0c000 level 2
   7fe0fc00/17e0c800 level 2
   3fe0fc00/17e0e000 level 2
   3fe0fc00/17e0e800 level 2
   3fe0fc00/17e0f000 level 2
   3fe0fc00/17e0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_15809c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/25809c00 level 2
   7fe7fc00/25819c00 level 2
   7fe7fc00/25829c00 level 2
   7fe7fc00/25839c00 level 2
   7fe7fc00/25849c00 level 2
   7fe7fc00/25859c00 level 2
   7fe7fc00/25869c00 level 2
   7fe7fc00/25879c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_25809c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25008000))
        return iemDecodeA64_cmpeq_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x25008010))
        return iemDecodeA64_cmpne_p_p_zi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa5808000))
        return iemDecodeA64_ld1d_z_p_br_u128(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/2d809c00 level 2
   7fe7fc00/2d819c00 level 2
   7fe7fc00/2d829c00 level 2
   7fe7fc00/2d839c00 level 2
   7fe7fc00/2d849c00 level 2
   7fe7fc00/2d859c00 level 2
   7fe7fc00/2d869c00 level 2
   7fe7fc00/2d879c00 level 2
   7fe1fc00/2d80a400 level 2
   7fe1fc00/2d81a400 level 2
   7fe6fc00/2d80ac00 level 2
   7fe6fc00/2d82ac00 level 2
   7fe6fc00/2d84ac00 level 2
   7fe6fc00/2d86ac00 level 2
   7fe6fc00/2d80bc00 level 2
   7fe6fc00/2d82bc00 level 2
   7fe6fc00/2d84bc00 level 2
   7fe6fc00/2d86bc00 level 2
   7fe0fe00/2da09000 level 2
   7fe0fe00/2da09200 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_2d809c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2d800000))
        return iemDecodeA64_STP_S_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xad800000))
        return iemDecodeA64_STP_Q_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/35809c00 level 2
   7fe7fc00/35819c00 level 2
   7fe7fc00/35829c00 level 2
   7fe7fc00/35839c00 level 2
   7fe7fc00/35849c00 level 2
   7fe7fc00/35859c00 level 2
   7fe7fc00/35869c00 level 2
   7fe7fc00/35879c00 level 2
   7fe1fc00/3580a400 level 2
   7fe1fc00/3581a400 level 2
   7fe6fc00/3580ac00 level 2
   7fe6fc00/3582ac00 level 2
   7fe6fc00/3584ac00 level 2
   7fe6fc00/3586ac00 level 2
   7fe6fc00/3580bc00 level 2
   7fe6fc00/3582bc00 level 2
   7fe6fc00/3584bc00 level 2
   7fe6fc00/3586bc00 level 2
   7fe0fe00/35a09000 level 2
   7fe0fe00/35a09200 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_35809c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x35000000))
        return iemDecodeA64_CBNZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb5000000))
        return iemDecodeA64_CBNZ_64_compbranch(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/65809c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_65809c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65008000))
        return iemDecodeA64_fadd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65088000))
        return iemDecodeA64_fabd_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65188000))
        return iemDecodeA64_fadd_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/65819c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_65819c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65018000))
        return iemDecodeA64_fsub_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_fscale_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65198000))
        return iemDecodeA64_fsub_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/65829c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_65829c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65028000))
        return iemDecodeA64_fmul_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650a8000))
        return iemDecodeA64_fmulx_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651a8000))
        return iemDecodeA64_fmul_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/65839c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_65839c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65038000))
        return iemDecodeA64_fsubr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651b8000))
        return iemDecodeA64_fsubr_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/65849c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_65849c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65048000))
        return iemDecodeA64_fmaxnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650c8000))
        return iemDecodeA64_fdivr_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651c8000))
        return iemDecodeA64_fmaxnm_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/65859c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_65859c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65058000))
        return iemDecodeA64_fminnm_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650d8000))
        return iemDecodeA64_fdiv_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651d8000))
        return iemDecodeA64_fminnm_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/65869c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_65869c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65068000))
        return iemDecodeA64_fmax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650e8000))
        return iemDecodeA64_famax_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651e8000))
        return iemDecodeA64_fmax_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe7fc00/65879c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe7fc00_65879c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65078000))
        return iemDecodeA64_fmin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650f8000))
        return iemDecodeA64_famin_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x651f8000))
        return iemDecodeA64_fmin_z_p_zs(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5808000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5809c00/0x78070000
   mask=0x78070000 entries=0x80 children=0x3c valid=%47 (0x3c) leaf=%9 (0xc) multi-if=%38 (0x30) reuse=%28 (0x24) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05809c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_7fe7fc00_25809c00_2,
        iemDecodeA64_7fe7fc00_25809c00_2,
        iemDecodeA64_7fe7fc00_25809c00_2,
        iemDecodeA64_7fe7fc00_25809c00_2,
        iemDecodeA64_7fe7fc00_25809c00_2,
        iemDecodeA64_7fe7fc00_25809c00_2,
        iemDecodeA64_7fe7fc00_25809c00_2,
        iemDecodeA64_7fe7fc00_25809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 64
        iemDecodeA64_Invalid, // 65
        iemDecodeA64_Invalid, // 66
        iemDecodeA64_Invalid, // 67
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_Invalid, // 72
        iemDecodeA64_Invalid, // 73
        iemDecodeA64_Invalid, // 74
        iemDecodeA64_Invalid, // 75
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_Invalid, // 80
        iemDecodeA64_Invalid, // 81
        iemDecodeA64_Invalid, // 82
        iemDecodeA64_Invalid, // 83
        iemDecodeA64_Invalid, // 84
        iemDecodeA64_Invalid, // 85
        iemDecodeA64_Invalid, // 86
        iemDecodeA64_Invalid, // 87
        iemDecodeA64_Invalid, // 88
        iemDecodeA64_Invalid, // 89
        iemDecodeA64_Invalid, // 90
        iemDecodeA64_Invalid, // 91
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_7fe7fc00_65809c00_2,
        iemDecodeA64_7fe7fc00_65819c00_2,
        iemDecodeA64_7fe7fc00_65829c00_2,
        iemDecodeA64_7fe7fc00_65839c00_2,
        iemDecodeA64_7fe7fc00_65849c00_2,
        iemDecodeA64_7fe7fc00_65859c00_2,
        iemDecodeA64_7fe7fc00_65869c00_2,
        iemDecodeA64_7fe7fc00_65879c00_2,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_Invalid, // 112
        iemDecodeA64_Invalid, // 113
        iemDecodeA64_Invalid, // 114
        iemDecodeA64_Invalid, // 115
        iemDecodeA64_Invalid, // 116
        iemDecodeA64_Invalid, // 117
        iemDecodeA64_Invalid, // 118
        iemDecodeA64_Invalid, // 119
        iemDecodeA64_Invalid, // 120
        iemDecodeA64_Invalid, // 121
        iemDecodeA64_Invalid, // 122
        iemDecodeA64_Invalid, // 123
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0x78070000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000078)) /* bit 27 L 4 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/0d81a000 level 2
   ffe1fc00/4d81a000 level 2
   ffe6fc00/0d86b000 level 2
   ffe6fc00/4d86b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_0d81a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0d80a000))
        return iemDecodeA64_ST3_asisdlsop_SX3_r3s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0d9fa000))
        return iemDecodeA64_ST3_asisdlsop_S3_i3s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fc00/6580a000 level 2
   ffe1fc00/6580a800 level 2
   ffe1fc00/6580b800 level 2
   mask=0x1e0000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%56 (0x9) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_6580a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_fcvt_z_p_z_s2h,
        iemDecodeA64_bfcvt_z_p_z_s2bf,
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_scvtf_z_p_z_w2s,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_fcvtzs_z_p_z_s2w,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/6581a000 level 2
   ffe1fc00/6581a800 level 2
   ffe1fc00/6581b800 level 2
   mask=0x1e0000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%44 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_6581a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_fcvt_z_p_z_h2s,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ucvtf_z_p_z_w2s,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_fcvtzu_z_p_z_s2w,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/a580a000 level 2
   ffe1fc00/a581a000 level 2
   7fe1fc00/2580a400 level 2
   7fe1fc00/2581a400 level 2
   ffe1fc00/a580a800 level 2
   ffe1fc00/a581a800 level 2
   7fe6fc00/2580ac00 level 2
   7fe6fc00/2582ac00 level 2
   7fe6fc00/2584ac00 level 2
   7fe6fc00/2586ac00 level 2
   ffe6fc00/a580b000 level 2
   ffe6fc00/a582b000 level 2
   ffe6fc00/a584b000 level 2
   ffe6fc00/a586b000 level 2
   ffe1fc00/a580b800 level 2
   ffe1fc00/a581b800 level 2
   7fe6fc00/2580bc00 level 2
   7fe6fc00/2582bc00 level 2
   7fe6fc00/2584bc00 level 2
   7fe6fc00/2586bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_a580a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa580a000))
        return iemDecodeA64_ld1sb_z_p_bi_s64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa590a000))
        return iemDecodeA64_ldnf1sb_z_p_bi_s64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580a000/0xf8010000
   mask=0xf8010000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%38 (0x18) multi-if=%6 (0x4) reuse=%3 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_ST3_asisdlsop_SX3_r3s,
        iemDecodeA64_ffe1fc00_0d81a000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ST3_asisdlsop_SX3_r3s,
        iemDecodeA64_ffe1fc00_0d81a000_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe1fc00_6580a000_2,
        iemDecodeA64_ffe1fc00_6581a000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8010000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/0d81a400 level 2
   7fe1fc00/4d81a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_0d81a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0d80a400))
        return iemDecodeA64_ST3_asisdlsop_DX3_r3d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0d9fa400))
        return iemDecodeA64_ST3_asisdlsop_D3_i3d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/6584a400 level 3
   ffeffc00/6584ac00 level 3
   ffeffc00/6584bc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_6584a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6504a000))
        return iemDecodeA64_frinta_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6594a000))
        return iemDecodeA64_scvtf_z_p_z_w2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/658ca400 level 3
   ffeffc00/658cac00 level 3
   ffeffc00/658cbc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_658ca400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650ca000))
        return iemDecodeA64_frecpx_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x659ca000))
        return iemDecodeA64_fcvtzs_z_p_z_s2w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe1fc00/6580a400 level 2
   mask=0x800e0000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%81 (0xd) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_6580a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_ffeffc00_6584a400_3,
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_fcvt_z_p_z_s2h,
        iemDecodeA64_bfcvt_z_p_z_s2bf,
        iemDecodeA64_ffeffc00_658ca400_3,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x800e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000007)) /* bit 17 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffebfc00/6581a400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc00_6581a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6501a000))
        return iemDecodeA64_frintp_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6595a000))
        return iemDecodeA64_ucvtf_z_p_z_w2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc00/6583a400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc00_6583a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6503a000))
        return iemDecodeA64_frintz_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6507a000))
        return iemDecodeA64_frinti_z_p_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfc00/6589a400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfc00_6589a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650da000))
        return iemDecodeA64_fsqrt_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6589a000))
        return iemDecodeA64_fcvt_z_p_z_h2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x659da000))
        return iemDecodeA64_fcvtzu_z_p_z_s2w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe1fc00/6581a400 level 2
   mask=0x800a0000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%50 (0x4) multi-if=%38 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_6581a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffebfc00_6581a400_3,
        iemDecodeA64_ffebfc00_6583a400_3,
        iemDecodeA64_ffebfc00_6589a400_3,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x800a0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000001)) /* bit 17 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000002)) /* bit 19 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580a400/0x78010000
   mask=0x78010000 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%31 (0xa) multi-if=%38 (0xc) reuse=%34 (0xb) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_ST3_asisdlsop_DX3_r3d,
        iemDecodeA64_7fe1fc00_0d81a400_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_CPYERTRN_CPY_memcms,
        iemDecodeA64_CPYERTRN_CPY_memcms,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_ST3_asisdlsop_DX3_r3d,
        iemDecodeA64_7fe1fc00_0d81a400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_CPYERTRN_CPY_memcms,
        iemDecodeA64_CPYERTRN_CPY_memcms,
        iemDecodeA64_7fe1fc00_6580a400_2,
        iemDecodeA64_7fe1fc00_6581a400_2,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580a800/0xf8010000
   mask=0xf8010000 entries=0x40 children=0x1c valid=%44 (0x1c) leaf=%38 (0x18) multi-if=%3 (0x2) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe1fc00_6580a000_2,
        iemDecodeA64_ffe1fc00_6581a000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8010000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/6580ac00 level 2
   7fe6fc00/6580bc00 level 2
   mask=0x80090000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_6580ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_fcvt_z_p_z_s2h,
        iemDecodeA64_fcvt_z_p_z_h2s,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x80090000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000002)) /* bit 19 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/6582ac00 level 2
   7fe6fc00/6582bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_6582ac00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6502a000))
        return iemDecodeA64_frintm_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6503a000))
        return iemDecodeA64_frintz_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe580a000))
        return iemDecodeA64_st1d_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x658aa000))
        return iemDecodeA64_bfcvt_z_p_z_s2bf(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffc00/658dac00 level 3
   ffeffc00/658dbc00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_658dac00_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650da000))
        return iemDecodeA64_fsqrt_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x659da000))
        return iemDecodeA64_fcvtzu_z_p_z_s2w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe6fc00/6584ac00 level 2
   7fe6fc00/6584bc00 level 2
   mask=0x80090000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%62 (0x5) multi-if=%38 (0x3) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_6584ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc00_6584a400_3,
        iemDecodeA64_ucvtf_z_p_z_w2s,
        iemDecodeA64_ffeffc00_658ca400_3,
        iemDecodeA64_ffeffc00_658dac00_3,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x80090000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000002)) /* bit 19 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/6586ac00 level 2
   7fe6fc00/6586bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_6586ac00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6506a000))
        return iemDecodeA64_frintx_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6507a000))
        return iemDecodeA64_frinti_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe580a000))
        return iemDecodeA64_st1d_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580ac00/0x78060000
   --decoder-hint1 0x7e0fc00/0x580bc00/0x78060000
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%9 (0x6) multi-if=%34 (0x16) reuse=%31 (0x14) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_7fe6fc00_6580ac00_2,
        iemDecodeA64_7fe6fc00_6582ac00_2,
        iemDecodeA64_7fe6fc00_6584ac00_2,
        iemDecodeA64_7fe6fc00_6586ac00_2,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/6580b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_6580b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6500a000))
        return iemDecodeA64_frintn_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6501a000))
        return iemDecodeA64_frintp_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6588a000))
        return iemDecodeA64_fcvt_z_p_z_s2h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6589a000))
        return iemDecodeA64_fcvt_z_p_z_h2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe6fc00/6582b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_6582b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6502a000))
        return iemDecodeA64_frintm_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6503a000))
        return iemDecodeA64_frintz_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x658aa000))
        return iemDecodeA64_bfcvt_z_p_z_s2bf(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe6fc00/6584b000 level 2
   mask=0x190000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%88 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_6584b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_scvtf_z_p_z_w2s,
        iemDecodeA64_ucvtf_z_p_z_w2s,
        iemDecodeA64_fcvtzs_z_p_z_s2w,
        iemDecodeA64_fcvtzu_z_p_z_s2w,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/6586b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_6586b000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6506a000))
        return iemDecodeA64_frintx_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6507a000))
        return iemDecodeA64_frinti_z_p_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580b000/0xf8060000
   mask=0xf8060000 entries=0x80 children=0x3e valid=%48 (0x3e) leaf=%41 (0x34) multi-if=%7 (0x9) reuse=%5 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ST3_asisdlsop_SX3_r3s,
        iemDecodeA64_ST3_asisdlsop_SX3_r3s,
        iemDecodeA64_ST3_asisdlsop_SX3_r3s,
        iemDecodeA64_ffe1fc00_0d81a000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_ST3_asisdlsop_SX3_r3s,
        iemDecodeA64_ST3_asisdlsop_SX3_r3s,
        iemDecodeA64_ST3_asisdlsop_SX3_r3s,
        iemDecodeA64_ffe1fc00_0d81a000_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe6fc00_6580b000_2,
        iemDecodeA64_ffe6fc00_6582b000_2,
        iemDecodeA64_ffe6fc00_6584b000_2,
        iemDecodeA64_ffe6fc00_6586b000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_Invalid, // 64
        iemDecodeA64_Invalid, // 65
        iemDecodeA64_Invalid, // 66
        iemDecodeA64_Invalid, // 67
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 120
        iemDecodeA64_Invalid, // 121
        iemDecodeA64_Invalid, // 122
        iemDecodeA64_Invalid, // 123
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8060000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77ecfc00/1580b400 level 2
   77ecfc00/1584b400 level 2
   77ecfc00/1588b400 level 2
   77ecfc00/158cb400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77ecfc00_1580b400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1d80b400))
        return iemDecodeA64_CPYETRN_CPY_memcms(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77ecfc00/2580b400 level 2
   77ecfc00/2584b400 level 2
   77ecfc00/2588b400 level 2
   77ecfc00/258cb400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77ecfc00_2580b400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2d800000))
        return iemDecodeA64_STP_S_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xad800000))
        return iemDecodeA64_STP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa580a000))
        return iemDecodeA64_ld1sb_z_p_bi_s64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa590a000))
        return iemDecodeA64_ldnf1sb_z_p_bi_s64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77fdfc00/6580b400 level 3
   mask=0x88020000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77fdfc00_6580b400_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x88020000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000001)) /* bit 17 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000002)) /* bit 27 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77fdfc00/6581b400 level 3
   mask=0x88020000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77fdfc00_6581b400_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x88020000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000001)) /* bit 17 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000002)) /* bit 27 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77fdfc00/6590b400 level 3
   77fdfc00/6591b400 level 3
   77effc00/658eb400 level 3
   77effc00/658fb400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_77fdfc00_6590b400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6d800000))
        return iemDecodeA64_STP_D_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed800000))
        return iemDecodeA64_STTP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe580a000))
        return iemDecodeA64_st1d_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77ecfc00/6580b400 level 2
   mask=0x110000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%0 (0x0) multi-if=%50 (0x2) reuse=%25 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_77ecfc00_6580b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_77fdfc00_6580b400_3,
        iemDecodeA64_77fdfc00_6581b400_3,
        iemDecodeA64_77fdfc00_6590b400_3,
        iemDecodeA64_77fdfc00_6590b400_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x00110000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 19) & UINT32_C(0x00000002)) /* bit 20 L 1 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77effc00/6584b400 level 3
   mask=0x88100000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77effc00_6584b400_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_scvtf_z_p_z_w2s,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x88100000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000002)) /* bit 27 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77effc00/6585b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_77effc00_6585b400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6d800000))
        return iemDecodeA64_STP_D_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed800000))
        return iemDecodeA64_STTP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe580a000))
        return iemDecodeA64_st1d_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6595a000))
        return iemDecodeA64_ucvtf_z_p_z_w2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77effc00/6586b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_77effc00_6586b400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6506a000))
        return iemDecodeA64_frintx_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6d800000))
        return iemDecodeA64_STP_D_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed800000))
        return iemDecodeA64_STTP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe580a000))
        return iemDecodeA64_st1d_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77effc00/6587b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_77effc00_6587b400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6507a000))
        return iemDecodeA64_frinti_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6d800000))
        return iemDecodeA64_STP_D_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed800000))
        return iemDecodeA64_STTP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe580a000))
        return iemDecodeA64_st1d_z_p_bz_d_64_unscaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77ecfc00/6584b400 level 2
   mask=0x30000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%0 (0x0) multi-if=%75 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77ecfc00_6584b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_77effc00_6584b400_3,
        iemDecodeA64_77effc00_6585b400_3,
        iemDecodeA64_77effc00_6586b400_3,
        iemDecodeA64_77effc00_6587b400_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x00030000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffecfc00/6588b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffecfc00_6588b400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6588a000))
        return iemDecodeA64_fcvt_z_p_z_s2h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x6589a000))
        return iemDecodeA64_fcvt_z_p_z_h2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x658aa000))
        return iemDecodeA64_bfcvt_z_p_z_s2bf(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77ecfc00/6588b400 level 2
   mask=0x88000000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%75 (0x3) multi-if=%25 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77ecfc00_6588b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffecfc00_6588b400_3,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x88000000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 30) & UINT32_C(0x00000002)) /* bit 31 L 1 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77effc00/658cb400 level 3
   mask=0x88100000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77effc00_658cb400_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_fcvtzs_z_p_z_s2w,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x88100000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000002)) /* bit 27 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77effc00/658db400 level 3
   mask=0x88100000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77effc00_658db400_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_fcvtzu_z_p_z_s2w,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x88100000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 20) & UINT32_C(0x00000001)) /* bit 20 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000002)) /* bit 27 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77ecfc00/658cb400 level 2
   mask=0x30000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%0 (0x0) multi-if=%50 (0x2) reuse=%50 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_77ecfc00_658cb400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_77effc00_658cb400_3,
        iemDecodeA64_77effc00_658db400_3,
        iemDecodeA64_77fdfc00_6590b400_3,
        iemDecodeA64_77fdfc00_6590b400_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x00030000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580b400/0x700c0000
   mask=0x700c0000 entries=0x20 children=0x19 valid=%78 (0x19) leaf=%28 (0x9) multi-if=%38 (0xc) reuse=%31 (0xa) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_77ecfc00_1580b400_2,
        iemDecodeA64_77ecfc00_1580b400_2,
        iemDecodeA64_77ecfc00_1580b400_2,
        iemDecodeA64_77ecfc00_1580b400_2,
        iemDecodeA64_77ecfc00_2580b400_2,
        iemDecodeA64_77ecfc00_2580b400_2,
        iemDecodeA64_77ecfc00_2580b400_2,
        iemDecodeA64_77ecfc00_2580b400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_CPYETRN_CPY_memcms,
        iemDecodeA64_CPYETRN_CPY_memcms,
        iemDecodeA64_CPYETRN_CPY_memcms,
        iemDecodeA64_CPYETRN_CPY_memcms,
        iemDecodeA64_77ecfc00_6580b400_2,
        iemDecodeA64_77ecfc00_6584b400_2,
        iemDecodeA64_77ecfc00_6588b400_2,
        iemDecodeA64_77ecfc00_658cb400_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x700c0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000003)) /* bit 18 L 2 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001c)) /* bit 28 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580b800/0xf8010000
   mask=0xf8010000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%41 (0x1a) multi-if=%3 (0x2) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_bgrp_z_zz,
        iemDecodeA64_bgrp_z_zz,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe1fc00_6580a000_2,
        iemDecodeA64_ffe1fc00_6581a000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_ffe1fc00_a580a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_st1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8010000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0580c000 level 2
   ffe0fc00/0580c400 level 2
   ffe0fc00/0580c800 level 2
   ffe0fc00/0580cc00 level 2
   ffe0fc00/0580d000 level 2
   ffe0fc00/0580d400 level 2
   ffe0fc00/0580d800 level 2
   ffe0fc00/0580dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0580c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30e000)) == UINT32_C(0x0510c000))
        return iemDecodeA64_fcpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05800000))
        return iemDecodeA64_and_z_zi(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0580c000 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0580c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sabalb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%59 (0x13) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0580c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEN_CPY_memcms,
        iemDecodeA64_pnext_p_p_p,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sabalt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEN_CPY_memcms,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEN_CPY_memcms,
        iemDecodeA64_ldnt1d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580c800 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%47 (0xf) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0580c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uabalb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580cc00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0580c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uabalt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580d000 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0580c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sbclb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580d400 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0580c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYEWTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sbclt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYEWTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYEWTN_CPY_memcms,
        iemDecodeA64_ldnt1d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYEWTN_CPY_memcms,
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x580d800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0580c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_4500d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580dc00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0580c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_4500d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_br_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnt1d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldnt1d_z_p_ar_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/a580e000 level 2
   ffe0fc00/a580e400 level 2
   ffe0fc00/a580e800 level 2
   ffe0fc00/a580ec00 level 2
   ffe0fc00/a580f000 level 2
   ffe0fc00/a580f400 level 2
   ffe0fc00/a580f800 level 2
   ffe0fc00/a580fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a580e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa580e000))
        return iemDecodeA64_ldnt1d_z_p_bi_contiguous(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa590e000))
        return iemDecodeA64_ld4q_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0580e000 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%47 (0xf) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fe10_2550e200_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ssra_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a580e000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580e400 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYERTN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_usra_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYERTN_CPY_memcms,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYERTN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a580e000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYERTN_CPY_memcms,
        iemDecodeA64_stnt1d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580e800 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_srsra_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a580e000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580ec00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ursra_z_zi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a580e000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580f000 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sri_z_zzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a580e000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580f400 level 1
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%59 (0x13) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CPYETN_CPY_memcms,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sli_z_zzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CPYETN_CPY_memcms,
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CPYETN_CPY_memcms,
        iemDecodeA64_ffe0fc00_a580e000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_CPYETN_CPY_memcms,
        iemDecodeA64_stnt1d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580f800 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_STLUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_saba_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a580e000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0580fc00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0580fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_and_z_zi,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uaba_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_ai_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a580e000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_prfd_i_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_stnt1d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0da00000 level 2
   ffe0fc00/4da00000 level 2
   ffe0fc00/0da00400 level 2
   ffe0fc00/4da00400 level 2
   ffe0fc00/0da00800 level 2
   ffe0fc00/4da00800 level 2
   ffe0fc00/0da00c00 level 2
   ffe0fc00/4da00c00 level 2
   ffe0fc00/0da01000 level 2
   ffe0fc00/4da01000 level 2
   ffe0fc00/0da01400 level 2
   ffe0fc00/4da01400 level 2
   ffe0fc00/0da01800 level 2
   ffe0fc00/4da01800 level 2
   ffe0fc00/0da01c00 level 2
   ffe0fc00/4da01c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0da00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e000)) == UINT32_C(0x0da00000))
        return iemDecodeA64_ST2_asisdlsop_BX2_r2b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0dbf0000))
        return iemDecodeA64_ST2_asisdlsop_B2_i2b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/05a00000 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip1_z_zz_q,
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a00400 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_z_zz_q,
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a00800 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_z_zz_q,
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200800_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sqrshrun_z_mz2,
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a00c00 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_z_zz_q,
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200c00_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a01000 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a01400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a01800 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_z_zz_q,
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200800_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a01c00 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_z_zz_q,
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200c00_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_p_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_p_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0da02000 level 2
   ffe0fc00/4da02000 level 2
   ffe0fc00/0da02400 level 2
   ffe0fc00/4da02400 level 2
   ffe0fc00/0da02800 level 2
   ffe0fc00/4da02800 level 2
   ffe0fc00/0da02c00 level 2
   ffe0fc00/4da02c00 level 2
   ffe0fc00/0da03000 level 2
   ffe0fc00/4da03000 level 2
   ffe0fc00/0da03400 level 2
   ffe0fc00/4da03400 level 2
   ffe0fc00/0da03800 level 2
   ffe0fc00/4da03800 level 2
   ffe0fc00/0da03c00 level 2
   ffe0fc00/4da03c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0da02000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e000)) == UINT32_C(0x0da02000))
        return iemDecodeA64_ST4_asisdlsop_BX4_r4b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0dbf2000))
        return iemDecodeA64_ST4_asisdlsop_B4_i4b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/25a02000 level 2
   ffe0fc00/25e02000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25a02000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0fc1f)) == UINT32_C(0x25a02000))
        return iemDecodeA64_ctermeq_rr(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0fc1f)) == UINT32_C(0x25a02010))
        return iemDecodeA64_ctermne_rr(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/05a02000 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%9 (0x3) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dup_z_zi,
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25a02000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_bi_u64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a02400 level 1
   07e0fc00/05a03c00 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_bi_u64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a02800 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbl_z_zz_2,
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_sqrshrn_z_mz2,
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_bi_u64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a02c00 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbx_z_zz,
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_bi_u64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a03000 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbl_z_zz_1,
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25203000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_bi_u64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a03400 level 1
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbxq_z_zz,
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_bi_u64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/05a83800 level 3
   ffeffc00/05e83800 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_05a83800_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x05383800))
        return iemDecodeA64_rev_z_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffb9fc10)) == UINT32_C(0x05a83800))
        return iemDecodeA64_pmov_p_zi_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/05a03800 level 2
   ffe0fc00/05e03800 level 2
   mask=0xf0000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%62 (0xa) multi-if=%19 (0x3) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05a03800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffc00_05603800_3,
        iemDecodeA64_sunpkhi_z_z,
        iemDecodeA64_uunpklo_z_z,
        iemDecodeA64_uunpkhi_z_z,
        iemDecodeA64_ffeffc00_05643800_3,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffeffc00_05a83800_3,
        iemDecodeA64_pmov_z_pi_d,
        iemDecodeA64_pmov_p_zi_d,
        iemDecodeA64_pmov_z_pi_d,
        iemDecodeA64_pmov_p_zi_d,
        iemDecodeA64_pmov_z_pi_d,
        iemDecodeA64_pmov_p_zi_d,
        iemDecodeA64_pmov_z_pi_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a03800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05a03800_2,
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_uqrshrn_z_mz2,
        iemDecodeA64_ffe0fc00_0da02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1rod_z_p_bi_u64,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0da04000 level 2
   ffe0fc00/4da04000 level 2
   ffe0fc00/0da04800 level 2
   ffe0fc00/4da04800 level 2
   ffe0fc00/0da05000 level 2
   ffe0fc00/4da05000 level 2
   ffe0fc00/0da05800 level 2
   ffe0fc00/4da05800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0da04000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e400)) == UINT32_C(0x0da04000))
        return iemDecodeA64_ST2_asisdlsop_HX2_r2h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0dbf4000))
        return iemDecodeA64_ST2_asisdlsop_H2_i2h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a04000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05604000_2,
        iemDecodeA64_ffe0fc00_0da04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a04400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a04800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_p_pp,
        iemDecodeA64_ffe0fc00_0da04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204800_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a04c00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204c00_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a05000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_p_pp,
        iemDecodeA64_ffe0fc00_0da04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a05400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a05800 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0da04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205800_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a05c00 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%44 (0xe) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205c00_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ldr_z_bi,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_str_z_bi,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0da06000 level 2
   ffe0fc00/4da06000 level 2
   ffe0fc00/0da06800 level 2
   ffe0fc00/4da06800 level 2
   ffe0fc00/0da07000 level 2
   ffe0fc00/4da07000 level 2
   ffe0fc00/0da07800 level 2
   ffe0fc00/4da07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0da06000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e400)) == UINT32_C(0x0da06000))
        return iemDecodeA64_ST4_asisdlsop_HX4_r4h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0dbf6000))
        return iemDecodeA64_ST4_asisdlsop_H4_i4h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a06000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip1_z_zz,
        iemDecodeA64_ffe0fc00_0da06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_addhnb_z_zz,
        iemDecodeA64_ffe0fc00_0da06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a06400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_addhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a06800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_z_zz,
        iemDecodeA64_ffe0fc00_0da06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204800_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_raddhnb_z_zz,
        iemDecodeA64_ffe0fc00_0da06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a06c00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204c00_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_raddhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a07000 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_z_zz,
        iemDecodeA64_ffe0fc00_0da06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_subhnb_z_zz,
        iemDecodeA64_ffe0fc00_0da06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a07400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_subhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a07800 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0da06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207800_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_rsubhnb_z_zz,
        iemDecodeA64_ffe0fc00_0da06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05a07c00 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%47 (0xf) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_psel_p_ppi,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_rsubhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s32,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_br_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fe00/05a08000 level 2
   ffe0fe00/05a08200 level 2
   7fe0fe00/05a09000 level 2
   7fe0fe00/05a09200 level 2
   mask=0x1f0000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%47 (0xf) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fe00_05a08000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cpy_z_p_v,
        iemDecodeA64_compact_z_p_z,
        iemDecodeA64_lasta_v_p_z,
        iemDecodeA64_lastb_v_p_z,
        iemDecodeA64_revb_z_z_m,
        iemDecodeA64_revh_z_z_m,
        iemDecodeA64_revw_z_z_m,
        iemDecodeA64_rbit_z_p_z_m,
        iemDecodeA64_clasta_z_p_zz,
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_splice_z_p_zz_des,
        iemDecodeA64_splice_z_p_zz_con,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_expand_z_p_z,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fe00/0da08000 level 2
   ffe0fe00/0da08200 level 2
   ffe0fe00/4da08000 level 2
   ffe0fe00/4da08200 level 2
   7fe0fe00/0da09000 level 2
   7fe0fe00/0da09200 level 2
   7fe0fe00/4da09000 level 2
   7fe0fe00/4da09200 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fe00_0da08000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0da08000))
        return iemDecodeA64_ST2_asisdlsop_SX2_r2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0dbf8000))
        return iemDecodeA64_ST2_asisdlsop_S2_i2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fe00/25a08000 level 2
   mask=0xf0000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%56 (0x9) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fe00_25a08000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cntp_r_p_p,
        iemDecodeA64_firstp_r_p_p,
        iemDecodeA64_lastp_r_p_p,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_sqincp_z_p_z,
        iemDecodeA64_uqincp_z_p_z,
        iemDecodeA64_sqdecp_z_p_z,
        iemDecodeA64_uqdecp_z_p_z,
        iemDecodeA64_incp_z_p_z,
        iemDecodeA64_decp_z_p_z,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a08000/0xf8000200
   mask=0xf8000200 entries=0x40 children=0x22 valid=%53 (0x22) leaf=%39 (0x19) multi-if=%9 (0x6) reuse=%9 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fe00_05a08000_2,
        iemDecodeA64_ffe0fe00_05a08000_2,
        iemDecodeA64_ffe0fe00_0da08000_2,
        iemDecodeA64_ffe0fe00_0da08000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe0fe00_25a08000_2,
        iemDecodeA64_cntp_r_pn,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fe00_0da08000_2,
        iemDecodeA64_ffe0fe00_0da08000_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8000200 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e1fe00/05a08400 level 2
   77e1fe00/05a08600 level 2
   mask=0x880e0000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%47 (0xf) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_05a08400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cpy_z_p_v,
        iemDecodeA64_lasta_v_p_z,
        iemDecodeA64_revb_z_z_m,
        iemDecodeA64_revw_z_z_m,
        iemDecodeA64_clasta_z_p_zz,
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_splice_z_p_zz_des,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x880e0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000007)) /* bit 17 L 3 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffe00/05a18400 level 3
   ffeffe00/05a18600 level 3
   ffeffc00/05a18c00 level 3
   ffeffc00/05a19400 level 3
   ffeffc00/05a19800 level 3
   ffeffc00/05a19c00 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffe00_05a18400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05318000))
        return iemDecodeA64_expand_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbfe000)) == UINT32_C(0x05a18000))
        return iemDecodeA64_compact_z_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffeffe00/0daf8400 level 3
   ffeffe00/0daf8600 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffe00_0daf8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0da08400))
        return iemDecodeA64_ST2_asisdlsop_DX2_r2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0dbf8400))
        return iemDecodeA64_ST2_asisdlsop_D2_i2d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e1fe00/05a18400 level 2
   77e1fe00/05a18600 level 2
   mask=0x880e0000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_05a18400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffe00_05a18400_3,
        iemDecodeA64_lastb_v_p_z,
        iemDecodeA64_revh_z_z_m,
        iemDecodeA64_rbit_z_p_z_m,
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_splice_z_p_zz_con,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ST2_asisdlsop_DX2_r2d,
        iemDecodeA64_ffeffe00_0daf8400_3,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x880e0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000007)) /* bit 17 L 3 -> 0 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fe00/25a08400 level 3
   ffe1fc00/25a09400 level 2
   ffe1fc00/25a09800 level 2
   ffe1fc00/25a09c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fe00_25a08400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25228000))
        return iemDecodeA64_lastp_r_p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e1fe00/25a08400 level 2
   mask=0x88000000 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%75 (0x3) multi-if=%25 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_25a08400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe1fe00_25a08400_3,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x88000000 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 30) & UINT32_C(0x00000002)) /* bit 31 L 1 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e1fe00/25a08600 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_25a08600_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffa00)) == UINT32_C(0x25208200))
        return iemDecodeA64_cntp_r_pn(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2d800000))
        return iemDecodeA64_STP_S_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xad800000))
        return iemDecodeA64_STP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa5a08000))
        return iemDecodeA64_ld4q_z_p_br_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e1fe00/25a18400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_25a18400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2d800000))
        return iemDecodeA64_STP_S_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xad800000))
        return iemDecodeA64_STP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa5a08000))
        return iemDecodeA64_ld4q_z_p_br_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e1fe00/25a18600 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_25a18600_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2d800000))
        return iemDecodeA64_STP_S_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xad800000))
        return iemDecodeA64_STP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa5a08000))
        return iemDecodeA64_ld4q_z_p_br_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e1fe00/45a08400 level 2
   77e1fe00/45a08600 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_45a08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0da08400))
        return iemDecodeA64_ST2_asisdlsop_DX2_r2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208000))
        return iemDecodeA64_match_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208010))
        return iemDecodeA64_nmatch_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e1fe00/45a18400 level 2
   77e1fe00/45a18600 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_45a18400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0da08400))
        return iemDecodeA64_ST2_asisdlsop_DX2_r2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0dbf8400))
        return iemDecodeA64_ST2_asisdlsop_D2_i2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208000))
        return iemDecodeA64_match_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208010))
        return iemDecodeA64_nmatch_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e1fe00/65a08400 level 2
   77e1fe00/65a08600 level 2
   77e1fe00/65a18400 level 2
   77e1fe00/65a18600 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e1fe00_65a08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e000)) == UINT32_C(0x65208000))
        return iemDecodeA64_fmad_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6d800000))
        return iemDecodeA64_STP_D_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xed800000))
        return iemDecodeA64_STTP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5a08000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_scaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a08400/0x70010200
   mask=0x70010200 entries=0x20 children=0x18 valid=%75 (0x18) leaf=%0 (0x0) multi-if=%59 (0x13) reuse=%47 (0xf) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_77e1fe00_05a08400_2,
        iemDecodeA64_77e1fe00_05a08400_2,
        iemDecodeA64_77e1fe00_05a18400_2,
        iemDecodeA64_77e1fe00_05a18400_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_77e1fe00_25a08400_2,
        iemDecodeA64_77e1fe00_25a08600_2,
        iemDecodeA64_77e1fe00_25a18400_2,
        iemDecodeA64_77e1fe00_25a18600_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e0fcc0_35808400_2,
        iemDecodeA64_77e1fe00_45a08400_2,
        iemDecodeA64_77e1fe00_45a08400_2,
        iemDecodeA64_77e1fe00_45a18400_2,
        iemDecodeA64_77e1fe00_45a18400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_77e1fe00_65a08400_2,
        iemDecodeA64_77e1fe00_65a08400_2,
        iemDecodeA64_77e1fe00_65a08400_2,
        iemDecodeA64_77e1fe00_65a08400_2,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x70010200 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 15) & UINT32_C(0x00000002)) /* bit 16 L 1 -> 1 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001c)) /* bit 28 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fc00/05a08800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_05a08800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05208000))
        return iemDecodeA64_cpy_z_p_v(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05248000))
        return iemDecodeA64_revb_z_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05288000))
        return iemDecodeA64_clasta_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052c8000))
        return iemDecodeA64_splice_z_p_zz_des(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fc00/05a18800 level 2
   mask=0x1c0000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_05a18800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_compact_z_p_z,
        iemDecodeA64_revh_z_z_m,
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_splice_z_p_zz_con,
        iemDecodeA64_expand_z_p_z,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x001c0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000007)) /* bit 18 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe3fc00/05a28800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_05a28800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05228000))
        return iemDecodeA64_lasta_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05268000))
        return iemDecodeA64_revw_z_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052a8000))
        return iemDecodeA64_clasta_v_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fc00/05a38800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_05a38800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05238000))
        return iemDecodeA64_lastb_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05278000))
        return iemDecodeA64_rbit_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052b8000))
        return iemDecodeA64_clastb_v_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fc00/25a08800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_25a08800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x25288800))
        return iemDecodeA64_sqincp_r_p_r_sx(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252c8800))
        return iemDecodeA64_incp_r_p_r(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fc00/25a18800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_25a18800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x25298800))
        return iemDecodeA64_uqincp_r_p_r_uw(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252d8800))
        return iemDecodeA64_decp_r_p_r(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe3fc00/25a28800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe3fc00_25a28800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25228000))
        return iemDecodeA64_lastp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252a8800))
        return iemDecodeA64_sqdecp_r_p_r_sx(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a08800/0xf8030000
   mask=0xf8030000 entries=0x80 children=0x3c valid=%47 (0x3c) leaf=%38 (0x31) multi-if=%8 (0xa) reuse=%3 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe3fc00_05a08800_2,
        iemDecodeA64_ffe3fc00_05a18800_2,
        iemDecodeA64_ffe3fc00_05a28800_2,
        iemDecodeA64_ffe3fc00_05a38800_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe3fc00_25a08800_2,
        iemDecodeA64_ffe3fc00_25a18800_2,
        iemDecodeA64_ffe3fc00_25a28800_2,
        iemDecodeA64_uqdecp_r_p_r_uw,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_Invalid, // 64
        iemDecodeA64_Invalid, // 65
        iemDecodeA64_Invalid, // 66
        iemDecodeA64_Invalid, // 67
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 120
        iemDecodeA64_Invalid, // 121
        iemDecodeA64_Invalid, // 122
        iemDecodeA64_Invalid, // 123
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8030000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/05a08c00 level 2
   ffe1fc00/05a09400 level 2
   ffe1fc00/05a09800 level 2
   ffe1fc00/05a09c00 level 2
   mask=0x1e0000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%44 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_05a08c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cpy_z_p_v,
        iemDecodeA64_lasta_v_p_z,
        iemDecodeA64_revb_z_z_m,
        iemDecodeA64_revw_z_z_m,
        iemDecodeA64_clasta_z_p_zz,
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_splice_z_p_zz_des,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/05a18c00 level 2
   ffe1fc00/05a19400 level 2
   ffe1fc00/05a19800 level 2
   ffe1fc00/05a19c00 level 2
   mask=0xe0000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_05a18c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffeffe00_05a18400_3,
        iemDecodeA64_lastb_v_p_z,
        iemDecodeA64_revh_z_z_m,
        iemDecodeA64_rbit_z_p_z_m,
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_splice_z_p_zz_con,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x000e0000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000007)) /* bit 17 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/25a08c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_25a08c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25228000))
        return iemDecodeA64_lastp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x25288c00))
        return iemDecodeA64_sqincp_r_p_r_x(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252a8c00))
        return iemDecodeA64_sqdecp_r_p_r_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe1fc00/25a18c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_25a18c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x25298c00))
        return iemDecodeA64_uqincp_r_p_r_x(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252b8c00))
        return iemDecodeA64_uqdecp_r_p_r_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a08c00/0xf8010000
   mask=0xf8010000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%38 (0x18) multi-if=%6 (0x4) reuse=%3 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe1fc00_05a08c00_2,
        iemDecodeA64_ffe1fc00_05a18c00_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe1fc00_25a08c00_2,
        iemDecodeA64_ffe1fc00_25a18c00_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8010000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fe00/25a09000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe00_25a09000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25228000))
        return iemDecodeA64_lastp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xa5a08000))
        return iemDecodeA64_ld4q_z_p_br_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fe00/65a09000 level 2
   7fe0fe00/65a09200 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fe00_65a09000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e000)) == UINT32_C(0x65208000))
        return iemDecodeA64_fmad_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0a000)) == UINT32_C(0xe5a08000))
        return iemDecodeA64_st1d_z_p_bz_d_x32_scaled(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a09000/0x78000200
   mask=0x78000200 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%9 (0x3) multi-if=%53 (0x11) reuse=%53 (0x11) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fe00_05a08000_2,
        iemDecodeA64_ffe0fe00_05a08000_2,
        iemDecodeA64_ffe0fe00_0da08000_2,
        iemDecodeA64_ffe0fe00_0da08000_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe0fe00_25a09000_2,
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_2d809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_7fe7fc00_35809c00_2,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fe00_0da08000_2,
        iemDecodeA64_ffe0fe00_0da08000_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_7fe0fe00_65a09000_2,
        iemDecodeA64_7fe0fe00_65a09000_2,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_7feffcc0_6d808400_3,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78000200 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a09400/0xf8010000
   --decoder-hint1 0x7e0fc00/0x5a09800/0xf8010000
   --decoder-hint1 0x7e0fc00/0x5a09c00/0xf8010000
   mask=0xf8010000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%39 (0x19) multi-if=%5 (0x3) reuse=%8 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe1fc00_05a08c00_2,
        iemDecodeA64_ffe1fc00_05a18c00_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ffe1fe00_25a08400_3,
        iemDecodeA64_firstp_r_p_p,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_ld4q_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8010000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0da0a000 level 2
   ffe0fc00/4da0a000 level 2
   ffe0fc00/0da0b000 level 2
   ffe0fc00/4da0b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0da0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0da0a000))
        return iemDecodeA64_ST4_asisdlsop_SX4_r4s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0dbfa000))
        return iemDecodeA64_ST4_asisdlsop_S4_i4s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a5a0a000 level 2
   ffe0fc00/a5a0a400 level 2
   ffe0fc00/a5a0a800 level 2
   ffe0fc00/a5a0ac00 level 2
   ffe0fc00/a5a0b000 level 2
   ffe0fc00/a5a0b400 level 2
   ffe0fc00/a5a0b800 level 2
   ffe0fc00/a5a0bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a5a0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5a0a000))
        return iemDecodeA64_ld1sb_z_p_bi_s32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5b0a000))
        return iemDecodeA64_ldnf1sb_z_p_bi_s32(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%38 (0xc) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_ffe0fc00_0da0a000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_histseg_z_zz,
        iemDecodeA64_ffe0fc00_0da0a000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0da0a400 level 2
   ffe0fc00/4da0a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0da0a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0da0a400))
        return iemDecodeA64_ST4_asisdlsop_DX4_r4d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0dbfa400))
        return iemDecodeA64_ST4_asisdlsop_D4_i4d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%34 (0xb) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_ffe0fc00_0da0a400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0da0a400_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_luti2_z_zz_16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%34 (0xb) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%38 (0xc) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_ffe0fc00_0da0a000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_luti2_z_zz_8,
        iemDecodeA64_ffe0fc00_0da0a000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_luti4_z_zz_2x16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_luti4_z_zz_1x16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5a0a000_2,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_64_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0c000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0c400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0cc00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0d000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%0 (0x0) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520c000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_histcnt_z_p_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmad_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2d_z_p_br_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5a0e000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0e400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0e800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0ec00/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0f000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0f400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0f800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5a0fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%44 (0xe) multi-if=%0 (0x0) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05a0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_STP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_STR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_STP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld2d_z_p_bi_contiguous,
        iemDecodeA64_STP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_ai_d,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st2d_z_p_bi_contiguous,
        iemDecodeA64_STTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05c00000 level 2
   ffe0fc00/05c00400 level 2
   ffe0fc00/05c00800 level 2
   ffe0fc00/05c00c00 level 2
   ffe0fc00/05c01000 level 2
   ffe0fc00/05c01400 level 2
   ffe0fc00/05c01800 level 2
   ffe0fc00/05c01c00 level 2
   ffe0fc00/05c02000 level 2
   ffe0fc00/05c02400 level 2
   ffe0fc00/05c02800 level 2
   ffe0fc00/05c02c00 level 2
   ffe0fc00/05c03000 level 2
   ffe0fc00/05c03400 level 2
   ffe0fc00/05c03800 level 2
   ffe0fc00/05c03c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05c00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05100000))
        return iemDecodeA64_cpy_z_o_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05c00000))
        return iemDecodeA64_dupm_z_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/0dc00000 level 2
   ffe0fc00/4dc00000 level 2
   ffe0fc00/0dc00400 level 2
   ffe0fc00/4dc00400 level 2
   ffe0fc00/0dc00800 level 2
   ffe0fc00/4dc00800 level 2
   ffe0fc00/0dc00c00 level 2
   ffe0fc00/4dc00c00 level 2
   ffe0fc00/0dc01000 level 2
   ffe0fc00/4dc01000 level 2
   ffe0fc00/0dc01400 level 2
   ffe0fc00/4dc01400 level 2
   ffe0fc00/0dc01800 level 2
   ffe0fc00/4dc01800 level 2
   ffe0fc00/0dc01c00 level 2
   ffe0fc00/4dc01c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0dc00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e000)) == UINT32_C(0x0dc00000))
        return iemDecodeA64_LD1_asisdlsop_BX1_r1b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0ddf0000))
        return iemDecodeA64_LD1_asisdlsop_B1_i1b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c00000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlb_z_zz,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fadd_z_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c00400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%56 (0x12) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SETGP_SET_memcms,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlt_z_zz,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SETGP_SET_memcms,
        iemDecodeA64_fsub_z_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SETGP_SET_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_SETGP_SET_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c00800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uaddlb_z_zz,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmul_z_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c00c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uaddlt_z_zz,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ftsmul_z_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c01000 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ssublb_z_zz,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c01400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SETGPT_SET_memcms,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ssublt_z_zz,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SETGPT_SET_memcms,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SETGPT_SET_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_SETGPT_SET_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c01800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_usublb_z_zz,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frecps_z_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c01c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25000000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_usublt_z_zz,
        iemDecodeA64_ffe0fc00_0dc00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frsqrts_z_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0dc02000 level 2
   ffe0fc00/4dc02000 level 2
   ffe0fc00/0dc02400 level 2
   ffe0fc00/4dc02400 level 2
   ffe0fc00/0dc02800 level 2
   ffe0fc00/4dc02800 level 2
   ffe0fc00/0dc02c00 level 2
   ffe0fc00/4dc02c00 level 2
   ffe0fc00/0dc03000 level 2
   ffe0fc00/4dc03000 level 2
   ffe0fc00/0dc03400 level 2
   ffe0fc00/4dc03400 level 2
   ffe0fc00/0dc03800 level 2
   ffe0fc00/4dc03800 level 2
   ffe0fc00/0dc03c00 level 2
   ffe0fc00/4dc03c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0dc02000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e000)) == UINT32_C(0x0dc02000))
        return iemDecodeA64_LD3_asisdlsop_BX3_r3b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0ddf2000))
        return iemDecodeA64_LD3_asisdlsop_B3_i3b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c02000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5c02c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%38 (0xc) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c02400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%50 (0x10) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SETGPN_SET_memcms,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SETGPN_SET_memcms,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SETGPN_SET_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_SETGPN_SET_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c02800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c03000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sabdlb_z_zz,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65403000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c03400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x16 valid=%69 (0x16) leaf=%53 (0x11) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SETGPTN_SET_memcms,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sabdlt_z_zz,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SETGPTN_SET_memcms,
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SETGPTN_SET_memcms,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_SETGPTN_SET_memcms,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c03800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uabdlb_z_zz,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c03c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c03c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c00000_2,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe7fc00_25002000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uabdlt_z_zz,
        iemDecodeA64_ffe0fc00_0dc02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65002400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05c04000 level 2
   ffe0fc00/05c04400 level 2
   ffe0fc00/05c04800 level 2
   ffe0fc00/05c04c00 level 2
   ffe0fc00/05c05000 level 2
   ffe0fc00/05c05400 level 2
   ffe0fc00/05c05800 level 2
   ffe0fc00/05c05c00 level 2
   ffe0fc00/05c06000 level 2
   ffe0fc00/05c06400 level 2
   ffe0fc00/05c06800 level 2
   ffe0fc00/05c06c00 level 2
   ffe0fc00/05c07000 level 2
   ffe0fc00/05c07400 level 2
   ffe0fc00/05c07800 level 2
   ffe0fc00/05c07c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05c04000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30c000)) == UINT32_C(0x05104000))
        return iemDecodeA64_cpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05c00000))
        return iemDecodeA64_dupm_z_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/0dc04000 level 2
   ffe0fc00/4dc04000 level 2
   ffe0fc00/0dc04800 level 2
   ffe0fc00/4dc04800 level 2
   ffe0fc00/0dc05000 level 2
   ffe0fc00/4dc05000 level 2
   ffe0fc00/0dc05800 level 2
   ffe0fc00/4dc05800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0dc04000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e400)) == UINT32_C(0x0dc04000))
        return iemDecodeA64_LD1_asisdlsop_HX1_r1h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0ddf4000))
        return iemDecodeA64_LD1_asisdlsop_H1_i1h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/25c04000 level 2
   ffe0fc00/25c04400 level 2
   ffe0fc00/25c04800 level 2
   ffe0fc00/25c04c00 level 2
   ffe0fc00/25c05000 level 2
   ffe0fc00/25c05400 level 2
   ffe0fc00/25c05800 level 2
   ffe0fc00/25c05c00 level 2
   ffe0fc00/25c06000 level 2
   ffe0fc00/25c06400 level 2
   ffe0fc00/25c06800 level 2
   ffe0fc00/25c06c00 level 2
   ffe0fc00/25c07000 level 2
   ffe0fc00/25c07400 level 2
   ffe0fc00/25c07800 level 2
   ffe0fc00/25c07c00 level 2
   mask=0x100210 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_25c04000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_orrs_p_p_pp_z,
        iemDecodeA64_orns_p_p_pp_z,
        iemDecodeA64_nors_p_p_pp_z,
        iemDecodeA64_nands_p_p_pp_z,
        iemDecodeA64_brkbs_p_p_p_z,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00100210 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >>  8) & UINT32_C(0x00000002)) /* bit  9 L 1 -> 1 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000004)) /* bit 20 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c04000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_ffe0fc00_0dc04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddwb_z_zz,
        iemDecodeA64_ffe0fc00_0dc04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br_u128,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c04400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SETGM_SET_memcms,
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SETGM_SET_memcms,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SETGM_SET_memcms,
        iemDecodeA64_ld1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_SETGM_SET_memcms,
        iemDecodeA64_st1d_z_p_br_u128,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c04800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_ffe0fc00_0dc04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uaddwb_z_zz,
        iemDecodeA64_ffe0fc00_0dc04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br_u128,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c04c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uaddwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br_u128,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c05000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_ffe0fc00_0dc04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ssubwb_z_zz,
        iemDecodeA64_ffe0fc00_0dc04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br_u128,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c05400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SETGMT_SET_memcms,
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ssubwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SETGMT_SET_memcms,
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SETGMT_SET_memcms,
        iemDecodeA64_ld1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_SETGMT_SET_memcms,
        iemDecodeA64_st1d_z_p_br_u128,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c05800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_ffe0fc00_0dc04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_usubwb_z_zz,
        iemDecodeA64_ffe0fc00_0dc04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br_u128,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c05c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_usubwt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65004400_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br_u128,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0dc06000 level 2
   ffe0fc00/4dc06000 level 2
   ffe0fc00/0dc06800 level 2
   ffe0fc00/4dc06800 level 2
   ffe0fc00/0dc07000 level 2
   ffe0fc00/4dc07000 level 2
   ffe0fc00/0dc07800 level 2
   ffe0fc00/4dc07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0dc06000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e400)) == UINT32_C(0x0dc06000))
        return iemDecodeA64_LD3_asisdlsop_HX3_r3h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0ddf6000))
        return iemDecodeA64_LD3_asisdlsop_H3_i3h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c06000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_ffe0fc00_0dc06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sqdmullb_z_zz,
        iemDecodeA64_ffe0fc00_0dc06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c06400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SETGMN_SET_memcms,
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sqdmullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SETGMN_SET_memcms,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SETGMN_SET_memcms,
        iemDecodeA64_ldff1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_SETGMN_SET_memcms,
        iemDecodeA64_st3d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c06800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_ffe0fc00_0dc06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_pmullb_z_zz,
        iemDecodeA64_ffe0fc00_0dc06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c06c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_pmullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c07000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_ffe0fc00_0dc06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_smullb_z_zz,
        iemDecodeA64_ffe0fc00_0dc06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c07400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x15 valid=%66 (0x15) leaf=%56 (0x12) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SETGMTN_SET_memcms,
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_smullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SETGMTN_SET_memcms,
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SETGMTN_SET_memcms,
        iemDecodeA64_ldff1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_SETGMTN_SET_memcms,
        iemDecodeA64_st3d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c07800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x14 valid=%62 (0x14) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_ffe0fc00_0dc06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_umullb_z_zz,
        iemDecodeA64_ffe0fc00_0dc06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c07c00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c04000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25c04000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_umullt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_65006000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1sb_z_p_br_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st3d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c08000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c08000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c18000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c18000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c28000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c28000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c38000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c38000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c48000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c48000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c58000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c58000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c68000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c68000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c78000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c78000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c88000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c88000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c98000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c98000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05ca8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ca8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05cb8000 level 2
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05cb8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05cc8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05cc8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05cd8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05cd8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05ce8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ce8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05cf8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05cf8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_famin_z_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d08000 level 2
   07fffc00/05d18000 level 2
   07fffc00/05d28000 level 2
   07fffc00/05d38000 level 2
   07fffc00/05d48000 level 2
   07fffc00/05d58000 level 2
   07fffc00/05d68000 level 2
   07fffc00/05d78000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d08000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ftmad_z_zzi,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d88000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d88000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fadd_z_p_zs,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d98000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d98000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsub_z_p_zs,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05da8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05da8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmul_z_p_zs,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05db8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05db8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05dc8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05dc8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmaxnm_z_p_zs,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05dd8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05dd8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fminnm_z_p_zs,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05de8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05de8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_LD1_asisdlsop_SX1_r1s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmax_z_p_zs,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffffc00/0ddf8000 level 3
   fffffc00/4ddf8000 level 3
   3fe0fcc0/0dc09000 level 2
   3fe0fcc0/0dc09040 level 2
   3fe0fcc0/0dc09080 level 2
   3fe0fcc0/0dc090c0 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_fffffc00_0ddf8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0dc08000))
        return iemDecodeA64_LD1_asisdlsop_SX1_r1s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0ddf8000))
        return iemDecodeA64_LD1_asisdlsop_S1_i1s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07fffc00/05df8000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05df8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_fffffc00_0ddf8000_3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saddlbt_z_zz,
        iemDecodeA64_fffffc00_0ddf8000_3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmin_z_p_zs,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c08000/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%22 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_05c08000_2,
        iemDecodeA64_07fffc00_05c18000_2,
        iemDecodeA64_07fffc00_05c28000_2,
        iemDecodeA64_07fffc00_05c38000_2,
        iemDecodeA64_07fffc00_05c48000_2,
        iemDecodeA64_07fffc00_05c58000_2,
        iemDecodeA64_07fffc00_05c68000_2,
        iemDecodeA64_07fffc00_05c78000_2,
        iemDecodeA64_07fffc00_05c88000_2,
        iemDecodeA64_07fffc00_05c98000_2,
        iemDecodeA64_07fffc00_05ca8000_2,
        iemDecodeA64_07fffc00_05cb8000_2,
        iemDecodeA64_07fffc00_05cc8000_2,
        iemDecodeA64_07fffc00_05cd8000_2,
        iemDecodeA64_07fffc00_05ce8000_2,
        iemDecodeA64_07fffc00_05cf8000_2,
        iemDecodeA64_07fffc00_05d08000_2,
        iemDecodeA64_07fffc00_05d08000_2,
        iemDecodeA64_07fffc00_05d08000_2,
        iemDecodeA64_07fffc00_05d08000_2,
        iemDecodeA64_07fffc00_05d08000_2,
        iemDecodeA64_07fffc00_05d08000_2,
        iemDecodeA64_07fffc00_05d08000_2,
        iemDecodeA64_07fffc00_05d08000_2,
        iemDecodeA64_07fffc00_05d88000_2,
        iemDecodeA64_07fffc00_05d98000_2,
        iemDecodeA64_07fffc00_05da8000_2,
        iemDecodeA64_07fffc00_05db8000_2,
        iemDecodeA64_07fffc00_05dc8000_2,
        iemDecodeA64_07fffc00_05dd8000_2,
        iemDecodeA64_07fffc00_05de8000_2,
        iemDecodeA64_07fffc00_05df8000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c08400 level 2
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%56 (0x9) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c08400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c18400 level 2
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%56 (0x9) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c18400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c28400 level 2
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%56 (0x9) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c28400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c38400 level 2
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%56 (0x9) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c38400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c48400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c48400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c58400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c58400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c68400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c68400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c78400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c78400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05c88400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c88400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc40_65088000_3,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffeffc00/65c98400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffeffc00_65c98400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x65098000))
        return iemDecodeA64_fscale_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe3c0)) == UINT32_C(0x65198000))
        return iemDecodeA64_fsub_z_p_zs(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0feffc00/05c98400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05c98400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc00_65c98400_3,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05ca8400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05ca8400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc40_650a8000_3,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05cb8400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%50 (0x8) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05cb8400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_fsubr_z_p_zs,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05cc8400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05cc8400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc40_650c8000_3,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05cd8400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05cd8400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc40_650d8000_3,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05ce8400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05ce8400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc40_650e8000_3,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0feffc00/05cf8400 level 2
   mask=0xf0000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%44 (0x7) multi-if=%12 (0x2) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_05cf8400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_ffeffc40_650f8000_3,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfeffc00/2dc08400 level 3
   bfeffc00/2dc18400 level 3
   bfeffc00/2dc28400 level 3
   bfeffc00/2dc38400 level 3
   bfeffc00/2dc48400 level 3
   bfeffc00/2dc58400 level 3
   bfeffc00/2dc68400 level 3
   bfeffc00/2dc78400 level 3
   bfeffc00/2dc88400 level 3
   bfeffc00/2dc98400 level 3
   bfeffc00/2dca8400 level 3
   bfeffc00/2dcb8400 level 3
   bfeffc00/2dcc8400 level 3
   bfeffc00/2dcd8400 level 3
   bfeffc00/2dce8400 level 3
   bfeffc00/2dcf8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_bfeffc00_2dc08400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2dc00000))
        return iemDecodeA64_LDP_S_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6dc00000))
        return iemDecodeA64_LDP_D_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfeffc00/adc08400 level 3
   bfeffc00/adc18400 level 3
   bfeffc00/adc28400 level 3
   bfeffc00/adc38400 level 3
   bfeffc00/adc48400 level 3
   bfeffc00/adc58400 level 3
   bfeffc00/adc68400 level 3
   bfeffc00/adc78400 level 3
   bfeffc00/adc88400 level 3
   bfeffc00/adc98400 level 3
   bfeffc00/adca8400 level 3
   bfeffc00/adcb8400 level 3
   bfeffc00/adcc8400 level 3
   bfeffc00/adcd8400 level 3
   bfeffc00/adce8400 level 3
   bfeffc00/adcf8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_bfeffc00_adc08400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xadc00000))
        return iemDecodeA64_LDP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xedc00000))
        return iemDecodeA64_LDTP_Q_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0feffc00/0dc08400 level 2
   0feffc00/0dc18400 level 2
   0feffc00/0dc28400 level 2
   0feffc00/0dc38400 level 2
   0feffc00/0dc48400 level 2
   0feffc00/0dc58400 level 2
   0feffc00/0dc68400 level 2
   0feffc00/0dc78400 level 2
   0feffc00/0dc88400 level 2
   0feffc00/0dc98400 level 2
   0feffc00/0dca8400 level 2
   0feffc00/0dcb8400 level 2
   0feffc00/0dcc8400 level 2
   0feffc00/0dcd8400 level 2
   0feffc00/0dce8400 level 2
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_0dc08400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LD1_asisdlsop_DX1_r1d,
        iemDecodeA64_SETGE_SET_memcms,
        iemDecodeA64_bfeffc00_2dc08400_3,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SETGE_SET_memcms,
        iemDecodeA64_bfeffc00_adc08400_3,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfeffc00/0dcf8400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_bfeffc00_0dcf8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0dc08400))
        return iemDecodeA64_LD1_asisdlsop_DX1_r1d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ddf8400))
        return iemDecodeA64_LD1_asisdlsop_D1_i1d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0feffc00/0dcf8400 level 2
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%38 (0x3) multi-if=%38 (0x3) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_0feffc00_0dcf8400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_bfeffc00_0dcf8400_3,
        iemDecodeA64_SETGE_SET_memcms,
        iemDecodeA64_bfeffc00_2dc08400_3,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SETGE_SET_memcms,
        iemDecodeA64_bfeffc00_adc08400_3,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c08400/0x80f0000
   mask=0x80f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%44 (0xe) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_0feffc00_05c08400_2,
        iemDecodeA64_0feffc00_05c18400_2,
        iemDecodeA64_0feffc00_05c28400_2,
        iemDecodeA64_0feffc00_05c38400_2,
        iemDecodeA64_0feffc00_05c48400_2,
        iemDecodeA64_0feffc00_05c58400_2,
        iemDecodeA64_0feffc00_05c68400_2,
        iemDecodeA64_0feffc00_05c78400_2,
        iemDecodeA64_0feffc00_05c88400_2,
        iemDecodeA64_0feffc00_05c98400_2,
        iemDecodeA64_0feffc00_05ca8400_2,
        iemDecodeA64_0feffc00_05cb8400_2,
        iemDecodeA64_0feffc00_05cc8400_2,
        iemDecodeA64_0feffc00_05cd8400_2,
        iemDecodeA64_0feffc00_05ce8400_2,
        iemDecodeA64_0feffc00_05cf8400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dc08400_2,
        iemDecodeA64_0feffc00_0dcf8400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x080f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000010)) /* bit 27 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c08800/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x21 valid=%52 (0x21) leaf=%45 (0x1d) multi-if=%3 (0x2) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_ssublbt_z_zz,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe4fc00_65809000_2,
        iemDecodeA64_ffe4fc00_65849000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c08c00/0xf8060000
   mask=0xf8060000 entries=0x80 children=0x3e valid=%48 (0x3e) leaf=%42 (0x36) multi-if=%3 (0x4) reuse=%6 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_ssubltb_z_zz,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe6fc00_65808800_2,
        iemDecodeA64_ffe6fc00_65828800_2,
        iemDecodeA64_ffe6fc00_65848800_2,
        iemDecodeA64_ffe6fc00_65868800_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_Invalid, // 80
        iemDecodeA64_Invalid, // 81
        iemDecodeA64_Invalid, // 82
        iemDecodeA64_Invalid, // 83
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_Invalid, // 112
        iemDecodeA64_Invalid, // 113
        iemDecodeA64_Invalid, // 114
        iemDecodeA64_Invalid, // 115
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8060000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0fcc0/05c09000 level 2
   3fe0fcc0/05c09040 level 2
   3fe0fcc0/05c09080 level 2
   3fe0fcc0/05c090c0 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fcc0_05c09000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x45009000))
        return iemDecodeA64_eorbt_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x85c08000))
        return iemDecodeA64_ld1rsb_z_p_bi_s64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05c00000))
        return iemDecodeA64_dupm_z_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fcc0/25c09000 level 2
   3fe0fcc0/25c09400 level 2
   mask=0x40000010 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%50 (0x2) multi-if=%0 (0x0) reuse=%50 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fcc0_25c09000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpeq_p_p_zi,
        iemDecodeA64_cmpne_p_p_zi,
        iemDecodeA64_ffe0fc00_65408400_2,
        iemDecodeA64_ffe0fc00_65408400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x40000010 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000002)) /* bit 30 L 1 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fcd0/65c09040 level 3
   7fe0fcd0/65c09050 level 3
   7fe0fcd0/65c09080 level 3
   7fe0fcd0/65c09090 level 3
   7fe0fcd0/65c090c0 level 3
   7fe0fcd0/65c090d0 level 3
   7fe0fcd0/65c09440 level 3
   7fe0fcd0/65c09450 level 3
   7fe0fcd0/65c09480 level 3
   7fe0fcd0/65c09490 level 3
   7fe0fcd0/65c094c0 level 3
   7fe0fcd0/65c094d0 level 3
   mask=0xf0000 entries=0x10 children=0xf valid=%94 (0xf) leaf=%94 (0xf) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fcd0_65c09040_3, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fadd_z_p_zz,
        iemDecodeA64_fsub_z_p_zz,
        iemDecodeA64_fmul_z_p_zz,
        iemDecodeA64_fsubr_z_p_zz,
        iemDecodeA64_fmaxnm_z_p_zz,
        iemDecodeA64_fminnm_z_p_zz,
        iemDecodeA64_fmax_z_p_zz,
        iemDecodeA64_fmin_z_p_zz,
        iemDecodeA64_fabd_z_p_zz,
        iemDecodeA64_fscale_z_p_zz,
        iemDecodeA64_fmulx_z_p_zz,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fdivr_z_p_zz,
        iemDecodeA64_fdiv_z_p_zz,
        iemDecodeA64_famax_z_p_zz,
        iemDecodeA64_famin_z_p_zz,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0fcc0/25c09040 level 2
   3fe0fcc0/25c09080 level 2
   3fe0fcc0/25c090c0 level 2
   3fe0fcc0/25c09440 level 2
   3fe0fcc0/25c09480 level 2
   3fe0fcc0/25c094c0 level 2
   mask=0x40000010 entries=0x4 children=0x4 valid=%100 (0x4) leaf=%50 (0x2) multi-if=%0 (0x0) reuse=%25 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fcc0_25c09040_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cmpeq_p_p_zi,
        iemDecodeA64_cmpne_p_p_zi,
        iemDecodeA64_7fe0fcd0_65c09040_3,
        iemDecodeA64_7fe0fcd0_65c09040_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x4);

    /* fMask=0x40000010 -> 0x00000003 */
    uintptr_t const idx = ((uOpcode >>  4) & UINT32_C(0x00000001)) /* bit  4 L 1 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000002)) /* bit 30 L 1 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0fcc0/2dc09000 level 2
   3fe0fcc0/2dc09040 level 2
   3fe0fcc0/2dc09080 level 2
   3fe0fcc0/2dc090c0 level 2
   3fe0fcc0/2dc09400 level 2
   3fe0fcc0/2dc09440 level 2
   3fe0fcc0/2dc09480 level 2
   3fe0fcc0/2dc094c0 level 2
   1ff7fc00/0dc0b400 level 2
   1ff7fc00/0dc1b400 level 2
   1ff7fc00/0dc2b400 level 2
   1ff7fc00/0dc3b400 level 2
   1ff7fc00/0dc4b400 level 2
   1ff7fc00/0dc5b400 level 2
   1ff7fc00/0dc6b400 level 2
   1ff7fc00/0dc7b400 level 2
   1ff7fc00/0dd0b400 level 2
   1ff7fc00/0dd1b400 level 2
   1ff7fc00/0dd2b400 level 2
   1ff7fc00/0dd3b400 level 2
   1ff7fc00/0dd4b400 level 2
   1ff7fc00/0dd5b400 level 2
   1ff7fc00/0dd6b400 level 2
   1ff7fc00/0dd7b400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fcc0_2dc09000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2dc00000))
        return iemDecodeA64_LDP_S_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6dc00000))
        return iemDecodeA64_LDP_D_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xadc00000))
        return iemDecodeA64_LDP_Q_ldstpair_pre(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0xedc00000))
        return iemDecodeA64_LDTP_Q_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe0fcc0/35c09000 level 2
   3fe0fcc0/35c09040 level 2
   3fe0fcc0/35c09080 level 2
   3fe0fcc0/35c090c0 level 2
   3fe0fcc0/35c09400 level 2
   3fe0fcc0/35c09440 level 2
   3fe0fcc0/35c09480 level 2
   3fe0fcc0/35c094c0 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fcc0_35c09000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x35000000))
        return iemDecodeA64_CBNZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0xb5000000))
        return iemDecodeA64_CBNZ_64_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe04000)) == UINT32_C(0x75c00000))
        return iemDecodeA64_CBEQ_32_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe04000)) == UINT32_C(0xf5c00000))
        return iemDecodeA64_CBEQ_64_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c09000/0x380000c0
   mask=0x380000c0 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%12 (0x4) multi-if=%62 (0x14) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_3fe0fcc0_05c09000_2,
        iemDecodeA64_3fe0fcc0_05c09000_2,
        iemDecodeA64_3fe0fcc0_05c09000_2,
        iemDecodeA64_3fe0fcc0_05c09000_2,
        iemDecodeA64_fffffc00_0ddf8000_3,
        iemDecodeA64_fffffc00_0ddf8000_3,
        iemDecodeA64_fffffc00_0ddf8000_3,
        iemDecodeA64_fffffc00_0ddf8000_3,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_3fe0fcc0_25c09000_2,
        iemDecodeA64_3fe0fcc0_25c09040_2,
        iemDecodeA64_3fe0fcc0_25c09040_2,
        iemDecodeA64_3fe0fcc0_25c09040_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_35c09000_2,
        iemDecodeA64_3fe0fcc0_35c09000_2,
        iemDecodeA64_3fe0fcc0_35c09000_2,
        iemDecodeA64_3fe0fcc0_35c09000_2,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x380000c0 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000003)) /* bit  6 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0fcc0/05c09400 level 2
   3fe0fcc0/05c09440 level 2
   3fe0fcc0/05c09480 level 2
   3fe0fcc0/05c094c0 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fcc0_05c09400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x45009400))
        return iemDecodeA64_eortb_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x85c08000))
        return iemDecodeA64_ld1rsb_z_p_bi_s64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05c00000))
        return iemDecodeA64_dupm_z_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c09400/0x380000c0
   mask=0x380000c0 entries=0x20 children=0x1c valid=%88 (0x1c) leaf=%25 (0x8) multi-if=%50 (0x10) reuse=%59 (0x13) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_3fe0fcc0_05c09400_2,
        iemDecodeA64_3fe0fcc0_05c09400_2,
        iemDecodeA64_3fe0fcc0_05c09400_2,
        iemDecodeA64_3fe0fcc0_05c09400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_SETGET_SET_memcms,
        iemDecodeA64_SETGET_SET_memcms,
        iemDecodeA64_SETGET_SET_memcms,
        iemDecodeA64_SETGET_SET_memcms,
        iemDecodeA64_3fe0fcc0_25c09000_2,
        iemDecodeA64_3fe0fcc0_25c09040_2,
        iemDecodeA64_3fe0fcc0_25c09040_2,
        iemDecodeA64_3fe0fcc0_25c09040_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_35c09000_2,
        iemDecodeA64_3fe0fcc0_35c09000_2,
        iemDecodeA64_3fe0fcc0_35c09000_2,
        iemDecodeA64_3fe0fcc0_35c09000_2,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x380000c0 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  6) & UINT32_C(0x00000003)) /* bit  6 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c09800/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x21 valid=%52 (0x21) leaf=%45 (0x1d) multi-if=%3 (0x2) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c09800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ummla_z_zzz,
        iemDecodeA64_ummla_z_zzz,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe4fc00_65809000_2,
        iemDecodeA64_ffe4fc00_65849000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c09c00/0xf8030000
   mask=0xf8030000 entries=0x80 children=0x3c valid=%47 (0x3c) leaf=%41 (0x34) multi-if=%3 (0x4) reuse=%6 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c09c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_ffeffc00_25009000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe3fc00_65808c00_2,
        iemDecodeA64_ffe3fc00_65818c00_2,
        iemDecodeA64_ffe3fc00_65828c00_2,
        iemDecodeA64_ffe3fc00_65838c00_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_Invalid, // 80
        iemDecodeA64_Invalid, // 81
        iemDecodeA64_Invalid, // 82
        iemDecodeA64_Invalid, // 83
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_Invalid, // 112
        iemDecodeA64_Invalid, // 113
        iemDecodeA64_Invalid, // 114
        iemDecodeA64_Invalid, // 115
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8030000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe4fc00/0dc4a000 level 2
   ffe4fc00/4dc4a000 level 2
   fffffc00/0ddfb000 level 3
   fffffc00/4ddfb000 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_0dc4a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0dc0a000))
        return iemDecodeA64_LD3_asisdlsop_SX3_r3s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0ddfa000))
        return iemDecodeA64_LD3_asisdlsop_S3_i3s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe4fc00/65c0a000 level 2
   ffe4fc00/65c0b800 level 2
   mask=0x1b0000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_65c0a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_fcvt_z_p_z_d2h,
        iemDecodeA64_fcvt_z_p_z_h2d,
        iemDecodeA64_fcvt_z_p_z_d2s,
        iemDecodeA64_fcvt_z_p_z_s2d,
        iemDecodeA64_scvtf_z_p_z_w2d,
        iemDecodeA64_ucvtf_z_p_z_w2d,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_d2w,
        iemDecodeA64_fcvtzu_z_p_z_d2w,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000c)) /* bit 19 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe4fc00/65c4a000 level 2
   ffe4fc00/65c4b800 level 2
   mask=0x1b0000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%81 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_65c4a000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_scvtf_z_p_z_x2s,
        iemDecodeA64_ucvtf_z_p_z_x2s,
        iemDecodeA64_scvtf_z_p_z_x2d,
        iemDecodeA64_ucvtf_z_p_z_x2d,
        iemDecodeA64_fcvtzs_z_p_z_s2x,
        iemDecodeA64_fcvtzu_z_p_z_s2x,
        iemDecodeA64_fcvtzs_z_p_z_d2x,
        iemDecodeA64_fcvtzu_z_p_z_d2x,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x0000000c)) /* bit 19 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe4fc00/a5c0a000 level 2
   ffe4fc00/a5c4a000 level 2
   ffe1fc00/a5c0a800 level 2
   ffe1fc00/a5c1a800 level 2
   ffe6fc00/a5c0ac00 level 2
   ffe6fc00/a5c2ac00 level 2
   ffe6fc00/a5c4ac00 level 2
   ffe6fc00/a5c6ac00 level 2
   ffe4fc00/a5c0b800 level 2
   ffe4fc00/a5c4b800 level 2
   ffe6fc00/a5c0bc00 level 2
   ffe6fc00/a5c2bc00 level 2
   ffe6fc00/a5c4bc00 level 2
   ffe6fc00/a5c6bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe4fc00_a5c0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5c0a000))
        return iemDecodeA64_ld1sb_z_p_bi_s16(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5d0a000))
        return iemDecodeA64_ldnf1sb_z_p_bi_s16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0a000/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x23 valid=%55 (0x23) leaf=%45 (0x1d) multi-if=%6 (0x4) reuse=%3 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_ffe4fc00_0dc4a000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_ffe4fc00_0dc4a000_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe4fc00_65c0a000_2,
        iemDecodeA64_ffe4fc00_65c4a000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/65c0a400 level 3
   fff7fc00/65c0b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65c0a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6500a000))
        return iemDecodeA64_frintn_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65c8a000))
        return iemDecodeA64_fcvt_z_p_z_d2h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05c0a400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c0a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65c0a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/65c1a400 level 3
   fff7fc00/65c1b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65c1a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6501a000))
        return iemDecodeA64_frintp_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65c9a000))
        return iemDecodeA64_fcvt_z_p_z_h2d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05c1a400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c1a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65c1a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/65c2a400 level 3
   fff7fc00/65c2b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65c2a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6502a000))
        return iemDecodeA64_frintm_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65caa000))
        return iemDecodeA64_fcvt_z_p_z_d2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05c2a400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c2a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65c2a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/65c3a400 level 3
   fff7fc00/65c3b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65c3a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6503a000))
        return iemDecodeA64_frintz_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65cba000))
        return iemDecodeA64_fcvt_z_p_z_s2d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05c3a400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c3a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65c3a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c4a400 level 2
   mask=0xe0000000 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%38 (0x3) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c4a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_6504a000_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c5a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c5a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x650da000))
        return iemDecodeA64_fsqrt_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x85c0a000))
        return iemDecodeA64_ld1rsb_z_p_bi_s32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe5c0a000))
        return iemDecodeA64_st1d_z_p_ai_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5c0a000))
        return iemDecodeA64_ld1sb_z_p_bi_s16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05c6a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c6a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6506a000))
        return iemDecodeA64_frintx_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x85c0a000))
        return iemDecodeA64_ld1rsb_z_p_bi_s32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe5c0a000))
        return iemDecodeA64_st1d_z_p_ai_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5c0a000))
        return iemDecodeA64_ld1sb_z_p_bi_s16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05c7a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c7a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6507a000))
        return iemDecodeA64_frinti_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x85c0a000))
        return iemDecodeA64_ld1rsb_z_p_bi_s32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe5c0a000))
        return iemDecodeA64_st1d_z_p_ai_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5c0a000))
        return iemDecodeA64_ld1sb_z_p_bi_s16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc00/65d0a400 level 3
   fff7fc00/65d0b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65d0a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65d0a000))
        return iemDecodeA64_scvtf_z_p_z_w2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65d8a000))
        return iemDecodeA64_fcvtzs_z_p_z_d2w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05d0a400 level 2
   mask=0xe0000000 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%38 (0x3) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d0a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65d0a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/65d1a400 level 3
   fff7fc00/65d1b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65d1a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65d1a000))
        return iemDecodeA64_ucvtf_z_p_z_w2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65d9a000))
        return iemDecodeA64_fcvtzu_z_p_z_d2w(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05d1a400 level 2
   mask=0xe0000000 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%38 (0x3) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d1a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65d1a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05d2a400 level 2
   1ff7fc00/05d3a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d2a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x85c0a000))
        return iemDecodeA64_ld1rsb_z_p_bi_s32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe5c0a000))
        return iemDecodeA64_st1d_z_p_ai_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5d0a000))
        return iemDecodeA64_ldnf1sb_z_p_bi_s16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* fff7fc00/65d4a400 level 3
   fff7fc00/65d4b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65d4a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65d4a000))
        return iemDecodeA64_scvtf_z_p_z_x2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65dca000))
        return iemDecodeA64_fcvtzs_z_p_z_s2x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05d4a400 level 2
   mask=0xe0000000 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%38 (0x3) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d4a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65d4a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/65d5a400 level 3
   fff7fc00/65d5b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65d5a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65d5a000))
        return iemDecodeA64_ucvtf_z_p_z_x2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65dda000))
        return iemDecodeA64_fcvtzu_z_p_z_s2x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05d5a400 level 2
   mask=0xe0000000 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%38 (0x3) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d5a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65d5a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/65d6a400 level 3
   fff7fc00/65d6b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65d6a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65d6a000))
        return iemDecodeA64_scvtf_z_p_z_x2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65dea000))
        return iemDecodeA64_fcvtzs_z_p_z_d2x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05d6a400 level 2
   mask=0xe0000000 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%38 (0x3) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d6a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65d6a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/65d7a400 level 3
   fff7fc00/65d7b400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_65d7a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65d7a000))
        return iemDecodeA64_ucvtf_z_p_z_x2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65dfa000))
        return iemDecodeA64_fcvtzu_z_p_z_d2x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05d7a400 level 2
   mask=0xe0000000 entries=0x8 children=0x4 valid=%50 (0x4) leaf=%38 (0x3) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d7a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_fff7fc00_65d7a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/0dc0a400 level 2
   1ff7fc00/0dc1a400 level 2
   1ff7fc00/0dc2a400 level 2
   1ff7fc00/0dc3a400 level 2
   1ff7fc00/0dc4a400 level 2
   1ff7fc00/0dc5a400 level 2
   1ff7fc00/0dc6a400 level 2
   1ff7fc00/0dc7a400 level 2
   1ff7fc00/0dd0a400 level 2
   1ff7fc00/0dd1a400 level 2
   1ff7fc00/0dd2a400 level 2
   1ff7fc00/0dd3a400 level 2
   1ff7fc00/0dd4a400 level 2
   1ff7fc00/0dd5a400 level 2
   1ff7fc00/0dd6a400 level 2
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_0dc0a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_LD3_asisdlsop_DX3_r3d,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LD3_asisdlsop_DX3_r3d,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff7fc00/0dd7a400 level 3
   fff7fc00/4dd7a400 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fff7fc00_0dd7a400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0dc0a400))
        return iemDecodeA64_LD3_asisdlsop_DX3_r3d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ddfa400))
        return iemDecodeA64_LD3_asisdlsop_D3_i3d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/0dd7a400 level 2
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_0dd7a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff7fc00_0dd7a400_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_fff7fc00_0dd7a400_3,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_LDTP_Q_ldstpair_pre,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/15c0a400 level 2
   1ff7fc00/15c1a400 level 2
   1ff7fc00/15c2a400 level 2
   1ff7fc00/15c3a400 level 2
   1ff7fc00/15c4a400 level 2
   1ff7fc00/15c5a400 level 2
   1ff7fc00/15c6a400 level 2
   1ff7fc00/15c7a400 level 2
   1ff7fc00/15d0a400 level 2
   1ff7fc00/15d1a400 level 2
   1ff7fc00/15d2a400 level 2
   1ff7fc00/15d3a400 level 2
   1ff7fc00/15d4a400 level 2
   1ff7fc00/15d5a400 level 2
   1ff7fc00/15d6a400 level 2
   1ff7fc00/15d7a400 level 2
   1ff7fc00/15c0b400 level 2
   1ff7fc00/15c1b400 level 2
   1ff7fc00/15c2b400 level 2
   1ff7fc00/15c3b400 level 2
   1ff7fc00/15c4b400 level 2
   1ff7fc00/15c5b400 level 2
   1ff7fc00/15c6b400 level 2
   1ff7fc00/15c7b400 level 2
   1ff7fc00/15d0b400 level 2
   1ff7fc00/15d1b400 level 2
   1ff7fc00/15d2b400 level 2
   1ff7fc00/15d3b400 level 2
   1ff7fc00/15d4b400 level 2
   1ff7fc00/15d5b400 level 2
   1ff7fc00/15d6b400 level 2
   1ff7fc00/15d7b400 level 2
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_15c0a400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_CBEQ_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/1dc0a400 level 2
   1ff7fc00/1dc1a400 level 2
   1ff7fc00/1dc2a400 level 2
   1ff7fc00/1dc3a400 level 2
   1ff7fc00/1dc4a400 level 2
   1ff7fc00/1dc5a400 level 2
   1ff7fc00/1dc6a400 level 2
   1ff7fc00/1dc7a400 level 2
   1ff7fc00/1dd0a400 level 2
   1ff7fc00/1dd1a400 level 2
   1ff7fc00/1dd2a400 level 2
   1ff7fc00/1dd3a400 level 2
   1ff7fc00/1dd4a400 level 2
   1ff7fc00/1dd5a400 level 2
   1ff7fc00/1dd6a400 level 2
   1ff7fc00/1dd7a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1dc0a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1dc0a400))
        return iemDecodeA64_SETGEN_SET_memcms(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x3dc00000))
        return iemDecodeA64_LDR_Q_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0a400/0x18170000
   mask=0x18170000 entries=0x40 children=0x40 valid=%100 (0x40) leaf=%0 (0x0) multi-if=%33 (0x15) reuse=%70 (0x2d) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_1ff7fc00_05c0a400_2,
        iemDecodeA64_1ff7fc00_05c1a400_2,
        iemDecodeA64_1ff7fc00_05c2a400_2,
        iemDecodeA64_1ff7fc00_05c3a400_2,
        iemDecodeA64_1ff7fc00_05c4a400_2,
        iemDecodeA64_1ff7fc00_05c5a400_2,
        iemDecodeA64_1ff7fc00_05c6a400_2,
        iemDecodeA64_1ff7fc00_05c7a400_2,
        iemDecodeA64_1ff7fc00_05d0a400_2,
        iemDecodeA64_1ff7fc00_05d1a400_2,
        iemDecodeA64_1ff7fc00_05d2a400_2,
        iemDecodeA64_1ff7fc00_05d2a400_2,
        iemDecodeA64_1ff7fc00_05d4a400_2,
        iemDecodeA64_1ff7fc00_05d5a400_2,
        iemDecodeA64_1ff7fc00_05d6a400_2,
        iemDecodeA64_1ff7fc00_05d7a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dc0a400_2,
        iemDecodeA64_1ff7fc00_0dd7a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
        iemDecodeA64_1ff7fc00_1dc0a400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x18170000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000030)) /* bit 27 L 2 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/65c0a800 level 2
   mask=0x1e0000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%81 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_65c0a800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_fcvt_z_p_z_d2h,
        iemDecodeA64_fcvt_z_p_z_d2s,
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_scvtf_z_p_z_w2d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_scvtf_z_p_z_x2s,
        iemDecodeA64_scvtf_z_p_z_x2d,
        iemDecodeA64_fcvtzs_z_p_z_d2w,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_fcvtzs_z_p_z_s2x,
        iemDecodeA64_fcvtzs_z_p_z_d2x,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe1fc00/65c1a800 level 2
   mask=0x1e0000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%75 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe1fc00_65c1a800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_fcvt_z_p_z_h2d,
        iemDecodeA64_fcvt_z_p_z_s2d,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ucvtf_z_p_z_w2d,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_ucvtf_z_p_z_x2s,
        iemDecodeA64_ucvtf_z_p_z_x2d,
        iemDecodeA64_fcvtzu_z_p_z_d2w,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_fcvtzu_z_p_z_s2x,
        iemDecodeA64_fcvtzu_z_p_z_d2x,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x001e0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x0000000f)) /* bit 17 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0a800/0xf8010000
   mask=0xf8010000 entries=0x40 children=0x22 valid=%53 (0x22) leaf=%47 (0x1e) multi-if=%3 (0x2) reuse=%3 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe1fc00_65c0a800_2,
        iemDecodeA64_ffe1fc00_65c1a800_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8010000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/65c0ac00 level 2
   ffe6fc00/65c0bc00 level 2
   mask=0x190000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%100 (0x8) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_65c0ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_fcvt_z_p_z_d2h,
        iemDecodeA64_fcvt_z_p_z_h2d,
        iemDecodeA64_scvtf_z_p_z_w2d,
        iemDecodeA64_ucvtf_z_p_z_w2d,
        iemDecodeA64_fcvtzs_z_p_z_d2w,
        iemDecodeA64_fcvtzu_z_p_z_d2w,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/65c2ac00 level 2
   ffe6fc00/65c2bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_65c2ac00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6502a000))
        return iemDecodeA64_frintm_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x6503a000))
        return iemDecodeA64_frintz_z_p_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65caa000))
        return iemDecodeA64_fcvt_z_p_z_d2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffe000)) == UINT32_C(0x65cba000))
        return iemDecodeA64_fcvt_z_p_z_s2d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe6fc00/65c4ac00 level 2
   ffe6fc00/65c4bc00 level 2
   mask=0x190000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%88 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_65c4ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_scvtf_z_p_z_x2s,
        iemDecodeA64_ucvtf_z_p_z_x2s,
        iemDecodeA64_fcvtzs_z_p_z_s2x,
        iemDecodeA64_fcvtzu_z_p_z_s2x,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/65c6ac00 level 2
   ffe6fc00/65c6bc00 level 2
   mask=0x190000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_65c6ac00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_scvtf_z_p_z_x2d,
        iemDecodeA64_ucvtf_z_p_z_x2d,
        iemDecodeA64_fcvtzs_z_p_z_d2x,
        iemDecodeA64_fcvtzu_z_p_z_d2x,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0ac00/0xf8060000
   --decoder-hint1 0x7e0fc00/0x5c0bc00/0xf8060000
   mask=0xf8060000 entries=0x80 children=0x3e valid=%48 (0x3e) leaf=%42 (0x36) multi-if=%4 (0x5) reuse=%3 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_ffe6fc00_65c0ac00_2,
        iemDecodeA64_ffe6fc00_65c2ac00_2,
        iemDecodeA64_ffe6fc00_65c4ac00_2,
        iemDecodeA64_ffe6fc00_65c6ac00_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8060000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c0b000 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c0b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintn_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c1b000 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c1b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintp_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c2b000 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c2b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintm_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c3b000 level 2
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%59 (0x13) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c3b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintz_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c4b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c4b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinta_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c5b000 level 2
   07fffc00/05ceb000 level 2
   07fffc00/05cfb000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%53 (0x11) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c5b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c6b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c6b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c7b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c7b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c8b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c8b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvt_z_p_z_d2h,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05c9b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05c9b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvt_z_p_z_h2d,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05cab000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05cab000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvt_z_p_z_d2s,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05cbb000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05cbb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvt_z_p_z_s2d,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05ccb000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ccb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_frecpx_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05cdb000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05cdb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d0b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d0b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_w2d,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d1b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d1b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_w2d,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d2b000 level 2
   07fffc00/05d3b000 level 2
   07fffc00/05dab000 level 2
   07fffc00/05dbb000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%53 (0x11) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d2b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d4b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d4b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_x2s,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d5b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d5b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_x2s,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d6b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d6b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_scvtf_z_p_z_x2d,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d7b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d7b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ucvtf_z_p_z_x2d,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d8b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d8b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_d2w,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05d9b000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05d9b000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_d2w,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05dcb000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05dcb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_s2x,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05ddb000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ddb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_s2x,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05deb000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%56 (0x12) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05deb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_LD3_asisdlsop_SX3_r3s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzs_z_p_z_d2x,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05dfb000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05dfb000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe4fc00_0dc4a000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bext_z_zz,
        iemDecodeA64_ffe4fc00_0dc4a000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fcvtzu_z_p_z_d2x,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0b000/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_05c0b000_2,
        iemDecodeA64_07fffc00_05c1b000_2,
        iemDecodeA64_07fffc00_05c2b000_2,
        iemDecodeA64_07fffc00_05c3b000_2,
        iemDecodeA64_07fffc00_05c4b000_2,
        iemDecodeA64_07fffc00_05c5b000_2,
        iemDecodeA64_07fffc00_05c6b000_2,
        iemDecodeA64_07fffc00_05c7b000_2,
        iemDecodeA64_07fffc00_05c8b000_2,
        iemDecodeA64_07fffc00_05c9b000_2,
        iemDecodeA64_07fffc00_05cab000_2,
        iemDecodeA64_07fffc00_05cbb000_2,
        iemDecodeA64_07fffc00_05ccb000_2,
        iemDecodeA64_07fffc00_05cdb000_2,
        iemDecodeA64_07fffc00_05c5b000_2,
        iemDecodeA64_07fffc00_05c5b000_2,
        iemDecodeA64_07fffc00_05d0b000_2,
        iemDecodeA64_07fffc00_05d1b000_2,
        iemDecodeA64_07fffc00_05d2b000_2,
        iemDecodeA64_07fffc00_05d2b000_2,
        iemDecodeA64_07fffc00_05d4b000_2,
        iemDecodeA64_07fffc00_05d5b000_2,
        iemDecodeA64_07fffc00_05d6b000_2,
        iemDecodeA64_07fffc00_05d7b000_2,
        iemDecodeA64_07fffc00_05d8b000_2,
        iemDecodeA64_07fffc00_05d9b000_2,
        iemDecodeA64_07fffc00_05d2b000_2,
        iemDecodeA64_07fffc00_05d2b000_2,
        iemDecodeA64_07fffc00_05dcb000_2,
        iemDecodeA64_07fffc00_05ddb000_2,
        iemDecodeA64_07fffc00_05deb000_2,
        iemDecodeA64_07fffc00_05dfb000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c0b400 level 2
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c0b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65c0a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c1b400 level 2
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c1b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65c1a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c2b400 level 2
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c2b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65c2a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c3b400 level 2
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c3b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65c3a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c4b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c4b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_6504a000_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c5b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c5b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fsqrt_z_p_z_m,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c6b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c6b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_frintx_z_p_z_m,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05c7b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05c7b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_frinti_z_p_z_m,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05d0b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d0b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65d0a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05d1b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d1b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65d1a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05d2b400 level 2
   1ff7fc00/05d3b400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d2b400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x4500b400))
        return iemDecodeA64_bdep_z_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0e000)) == UINT32_C(0x85c0a000))
        return iemDecodeA64_ld1rsb_z_p_bi_s32(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0e000)) == UINT32_C(0xe5c0a000))
        return iemDecodeA64_st1d_z_p_ai_d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5d0a000))
        return iemDecodeA64_ldnf1sb_z_p_bi_s16(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/05d4b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d4b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65d4a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05d5b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d5b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65d5a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05d6b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d6b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65d6a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/05d7b400 level 2
   mask=0xe0000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_05d7b400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bdep_z_zz,
        iemDecodeA64_fff7fc00_65d7a400_3,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ldnf1sb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_st1d_z_p_ai_d,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/1dc0b400 level 2
   1ff7fc00/1dc1b400 level 2
   1ff7fc00/1dc2b400 level 2
   1ff7fc00/1dc3b400 level 2
   1ff7fc00/1dc4b400 level 2
   1ff7fc00/1dc5b400 level 2
   1ff7fc00/1dc6b400 level 2
   1ff7fc00/1dc7b400 level 2
   1ff7fc00/1dd0b400 level 2
   1ff7fc00/1dd1b400 level 2
   1ff7fc00/1dd2b400 level 2
   1ff7fc00/1dd3b400 level 2
   1ff7fc00/1dd4b400 level 2
   1ff7fc00/1dd5b400 level 2
   1ff7fc00/1dd6b400 level 2
   1ff7fc00/1dd7b400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1dc0b400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x3fe0fc00)) == UINT32_C(0x1dc0b400))
        return iemDecodeA64_SETGETN_SET_memcms(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x3dc00000))
        return iemDecodeA64_LDR_Q_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0b400/0x18170000
   mask=0x18170000 entries=0x40 children=0x40 valid=%100 (0x40) leaf=%0 (0x0) multi-if=%53 (0x22) reuse=%75 (0x30) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_1ff7fc00_05c0b400_2,
        iemDecodeA64_1ff7fc00_05c1b400_2,
        iemDecodeA64_1ff7fc00_05c2b400_2,
        iemDecodeA64_1ff7fc00_05c3b400_2,
        iemDecodeA64_1ff7fc00_05c4b400_2,
        iemDecodeA64_1ff7fc00_05c5b400_2,
        iemDecodeA64_1ff7fc00_05c6b400_2,
        iemDecodeA64_1ff7fc00_05c7b400_2,
        iemDecodeA64_1ff7fc00_05d0b400_2,
        iemDecodeA64_1ff7fc00_05d1b400_2,
        iemDecodeA64_1ff7fc00_05d2b400_2,
        iemDecodeA64_1ff7fc00_05d2b400_2,
        iemDecodeA64_1ff7fc00_05d4b400_2,
        iemDecodeA64_1ff7fc00_05d5b400_2,
        iemDecodeA64_1ff7fc00_05d6b400_2,
        iemDecodeA64_1ff7fc00_05d7b400_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_3fe0fcc0_2dc09000_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_15c0a400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
        iemDecodeA64_1ff7fc00_1dc0b400_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x18170000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000030)) /* bit 27 L 2 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0b800/0xf8040000
   mask=0xf8040000 entries=0x40 children=0x23 valid=%55 (0x23) leaf=%48 (0x1f) multi-if=%3 (0x2) reuse=%6 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_bgrp_z_zz,
        iemDecodeA64_bgrp_z_zz,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ffe4fc00_65c0a000_2,
        iemDecodeA64_ffe4fc00_65c4a000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_CBEQ_32_imm,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_ffe4fc00_a5c0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_Invalid, // 52
        iemDecodeA64_Invalid, // 53
        iemDecodeA64_Invalid, // 54
        iemDecodeA64_Invalid, // 55
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_st1d_z_p_ai_d,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_CBEQ_64_imm,
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xf8040000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000003e)) /* bit 27 L 5 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/05c0c000 level 2
   ffe0fc00/05c0c400 level 2
   ffe0fc00/05c0c800 level 2
   ffe0fc00/05c0cc00 level 2
   ffe0fc00/05c0d000 level 2
   ffe0fc00/05c0d400 level 2
   ffe0fc00/05c0d800 level 2
   ffe0fc00/05c0dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_05c0c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff30e000)) == UINT32_C(0x0510c000))
        return iemDecodeA64_fcpy_z_p_i(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffc0000)) == UINT32_C(0x05c00000))
        return iemDecodeA64_dupm_z_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/0dc0c000 level 2
   ffe0fc00/4dc0c000 level 2
   ffe0fc00/0dc0c400 level 2
   ffe0fc00/4dc0c400 level 2
   ffe0fc00/0dc0c800 level 2
   ffe0fc00/4dc0c800 level 2
   ffe0fc00/0dc0cc00 level 2
   ffe0fc00/4dc0cc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0dc0c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0dc0c000))
        return iemDecodeA64_LD1R_asisdlsop_RX1_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0ddfc000))
        return iemDecodeA64_LD1R_asisdlsop_R1_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/05c0c000 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c0c000_2,
        iemDecodeA64_ffe0fc00_0dc0c000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sabalb_z_zzz,
        iemDecodeA64_ffe0fc00_0dc0c000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0c400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c0c000_2,
        iemDecodeA64_ffe0fc00_0dc0c000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_pnext_p_p_p,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sabalt_z_zzz,
        iemDecodeA64_ffe0fc00_0dc0c000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0c800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c0c000_2,
        iemDecodeA64_ffe0fc00_0dc0c000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uabalb_z_zzz,
        iemDecodeA64_ffe0fc00_0dc0c000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0cc00 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%41 (0xd) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c0c000_2,
        iemDecodeA64_ffe0fc00_0dc0c000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uabalt_z_zzz,
        iemDecodeA64_ffe0fc00_0dc0c000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0d000 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c0c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sbclb_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0d400 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c0c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sbclt_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0d800 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c0c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_4500d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0dc00 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05c0c000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_4500d800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ffe0fc00_6500c000_2,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0dc0e000 level 2
   ffe0fc00/4dc0e000 level 2
   ffe0fc00/0dc0e400 level 2
   ffe0fc00/4dc0e400 level 2
   ffe0fc00/0dc0e800 level 2
   ffe0fc00/4dc0e800 level 2
   ffe0fc00/0dc0ec00 level 2
   ffe0fc00/4dc0ec00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0dc0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0dc0e000))
        return iemDecodeA64_LD3R_asisdlsop_RX3_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0ddfe000))
        return iemDecodeA64_LD3R_asisdlsop_R3_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/e5c0e000 level 2
   ffe0fc00/e5c0e400 level 2
   ffe0fc00/e5c0e800 level 2
   ffe0fc00/e5c0ec00 level 2
   ffe0fc00/e5c0f000 level 2
   ffe0fc00/e5c0f400 level 2
   ffe0fc00/e5c0f800 level 2
   ffe0fc00/e5c0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e5c0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe5c0e000))
        return iemDecodeA64_st1d_z_p_bi_u128(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe5d0e000))
        return iemDecodeA64_st3d_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0e000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%47 (0xf) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_ffe0fc00_0dc0e000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_fff0fe10_2550e200_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ssra_z_zi,
        iemDecodeA64_ffe0fc00_0dc0e000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0e400 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_ffe0fc00_0dc0e000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_usra_z_zi,
        iemDecodeA64_ffe0fc00_0dc0e000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5c0e800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_ffe0fc00_0dc0e000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_srsra_z_zi,
        iemDecodeA64_ffe0fc00_0dc0e000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0ec00 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_ffe0fc00_0dc0e000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ursra_z_zi,
        iemDecodeA64_ffe0fc00_0dc0e000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0f000 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sri_z_zzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0f400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_sli_z_zzi,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0f800 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_LDAPUR_Q_ldapstl_simd,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_saba_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05c0fc00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05c0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dupm_z_i,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_uaba_z_zzz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_facgt_p_p_zz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld3d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_unscaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5c0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0de00000 level 2
   ffe0fc00/4de00000 level 2
   ffe0fc00/0de00400 level 2
   ffe0fc00/4de00400 level 2
   ffe0fc00/0de00800 level 2
   ffe0fc00/4de00800 level 2
   ffe0fc00/0de00c00 level 2
   ffe0fc00/4de00c00 level 2
   ffe0fc00/0de01000 level 2
   ffe0fc00/4de01000 level 2
   ffe0fc00/0de01400 level 2
   ffe0fc00/4de01400 level 2
   ffe0fc00/0de01800 level 2
   ffe0fc00/4de01800 level 2
   ffe0fc00/0de01c00 level 2
   ffe0fc00/4de01c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0de00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e000)) == UINT32_C(0x0de00000))
        return iemDecodeA64_LD2_asisdlsop_BX2_r2b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0dff0000))
        return iemDecodeA64_LD2_asisdlsop_B2_i2b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/05e00000 level 1
   07e0fc00/05e01000 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0de00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e00400 level 1
   07e0fc00/05e01400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0de00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e00800 level 1
   07e0fc00/05e01800 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0de00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200800_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e00c00 level 1
   07e0fc00/05e01c00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0de00000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25200c00_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de00000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfb_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0de02000 level 2
   ffe0fc00/4de02000 level 2
   ffe0fc00/0de02400 level 2
   ffe0fc00/4de02400 level 2
   ffe0fc00/0de02800 level 2
   ffe0fc00/4de02800 level 2
   ffe0fc00/0de02c00 level 2
   ffe0fc00/4de02c00 level 2
   ffe0fc00/0de03000 level 2
   ffe0fc00/4de03000 level 2
   ffe0fc00/0de03400 level 2
   ffe0fc00/4de03400 level 2
   ffe0fc00/0de03800 level 2
   ffe0fc00/4de03800 level 2
   ffe0fc00/0de03c00 level 2
   ffe0fc00/4de03c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0de02000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e000)) == UINT32_C(0x0de02000))
        return iemDecodeA64_LD4_asisdlsop_BX4_r4b(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe000)) == UINT32_C(0x0dff2000))
        return iemDecodeA64_LD4_asisdlsop_B4_i4b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/05e02000 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_dup_z_zi,
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25a02000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e02400 level 1
   07e0fc00/05e03c00 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e02800 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbl_z_zz_2,
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e02c00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbx_z_zz,
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e03000 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbl_z_zz_1,
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25203000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e03400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_tbxq_z_zz,
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e03800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05a03800_2,
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de02000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfh_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0de04000 level 2
   ffe0fc00/4de04000 level 2
   ffe0fc00/0de04800 level 2
   ffe0fc00/4de04800 level 2
   ffe0fc00/0de05000 level 2
   ffe0fc00/4de05000 level 2
   ffe0fc00/0de05800 level 2
   ffe0fc00/4de05800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0de04000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e400)) == UINT32_C(0x0de04000))
        return iemDecodeA64_LD2_asisdlsop_HX2_r2h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0dff4000))
        return iemDecodeA64_LD2_asisdlsop_H2_i2h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e04000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_05604000_2,
        iemDecodeA64_ffe0fc00_0de04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e04400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e04800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_p_pp,
        iemDecodeA64_ffe0fc00_0de04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204800_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e04c00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204c00_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e05000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_p_pp,
        iemDecodeA64_ffe0fc00_0de04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e05400 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_p_pp,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e05800 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0de04000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205800_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de04000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e05c00 level 1
   mask=0xf8000000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%44 (0xe) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25205c00_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmla_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfw_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st1d_z_p_br,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0de06000 level 2
   ffe0fc00/4de06000 level 2
   ffe0fc00/0de06800 level 2
   ffe0fc00/4de06800 level 2
   ffe0fc00/0de07000 level 2
   ffe0fc00/4de07000 level 2
   ffe0fc00/0de07800 level 2
   ffe0fc00/4de07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0de06000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0e400)) == UINT32_C(0x0de06000))
        return iemDecodeA64_LD4_asisdlsop_HX4_r4h(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffe400)) == UINT32_C(0x0dff6000))
        return iemDecodeA64_LD4_asisdlsop_H4_i4h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e06000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip1_z_zz,
        iemDecodeA64_ffe0fc00_0de06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_addhnb_z_zz,
        iemDecodeA64_ffe0fc00_0de06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e06400 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_zip2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_addhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e06800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp1_z_zz,
        iemDecodeA64_ffe0fc00_0de06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204800_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_raddhnb_z_zz,
        iemDecodeA64_ffe0fc00_0de06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e06c00 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_uzp2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25204c00_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_raddhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e07000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%50 (0x10) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn1_z_zz,
        iemDecodeA64_ffe0fc00_0de06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_subhnb_z_zz,
        iemDecodeA64_ffe0fc00_0de06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e07400 level 1
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_trn2_z_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_subhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e07800 level 1
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%9 (0x3) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0de06000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25207800_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_rsubhnb_z_zz,
        iemDecodeA64_ffe0fc00_0de06000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/05e07c00 level 1
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%50 (0x10) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_psel_p_ppi,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_rsubhnt_z_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmls_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_prfd_i_p_bi_s,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ldff1d_z_p_br_u64,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_x32_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_st4d_z_p_br_contiguous,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e08000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%50 (0x10) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e08000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cpy_z_p_v,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffeffc00_25208000_3,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e18000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e18000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_compact_z_p_z,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_firstp_r_p_p,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e28000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e28000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lasta_v_p_z,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_lastp_r_p_p,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e38000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e38000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_lastb_v_p_z,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e48000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e48000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_revb_z_z_m,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e58000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e58000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_revh_z_z_m,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e68000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e68000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_revw_z_z_m,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e78000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e78000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_rbit_z_p_z_m,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e88000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e88000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_clasta_z_p_zz,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_sqincp_z_p_z,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05e98000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05e98000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_uqincp_z_p_z,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05ea8000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ea8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_sqdecp_z_p_z,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05eb8000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05eb8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_uqdecp_z_p_z,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05ec8000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ec8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_splice_z_p_zz_des,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_incp_z_p_z,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05ed8000 level 2
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%53 (0x11) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ed8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_splice_z_p_zz_con,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_decp_z_p_z,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05ee8000 level 2
   07fffc00/05ef8000 level 2
   07fffc00/05f08000 level 2
   07fffc00/05f28000 level 2
   07fffc00/05f38000 level 2
   07fffc00/05f48000 level 2
   07fffc00/05f58000 level 2
   07fffc00/05f68000 level 2
   07fffc00/05f78000 level 2
   07fffc00/05f88000 level 2
   07fffc00/05f98000 level 2
   07fffc00/05fa8000 level 2
   07fffc00/05fb8000 level 2
   07fffc00/05fc8000 level 2
   07fffc00/05fd8000 level 2
   07fffc00/05fe8000 level 2
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ee8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07fffc00/05f18000 level 2
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%50 (0x10) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05f18000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_expand_z_p_z,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fffffc00/0dff8000 level 3
   fffffc00/4dff8000 level 3
   ffebfe00/0deb9000 level 3
   ffebfe00/0deb9200 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_fffffc00_0dff8000_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0de08000))
        return iemDecodeA64_LD2_asisdlsop_SX2_r2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0dff8000))
        return iemDecodeA64_LD2_asisdlsop_S2_i2s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07fffc00/05ff8000 level 2
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07fffc00_05ff8000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_fffffc00_0dff8000_3,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_fffffc00_0dff8000_3,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e08000/0x1f0000
   mask=0x1f0000 entries=0x20 children=0x20 valid=%100 (0x20) leaf=%0 (0x0) multi-if=%0 (0x0) reuse=%47 (0xf) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_07fffc00_05e08000_2,
        iemDecodeA64_07fffc00_05e18000_2,
        iemDecodeA64_07fffc00_05e28000_2,
        iemDecodeA64_07fffc00_05e38000_2,
        iemDecodeA64_07fffc00_05e48000_2,
        iemDecodeA64_07fffc00_05e58000_2,
        iemDecodeA64_07fffc00_05e68000_2,
        iemDecodeA64_07fffc00_05e78000_2,
        iemDecodeA64_07fffc00_05e88000_2,
        iemDecodeA64_07fffc00_05e98000_2,
        iemDecodeA64_07fffc00_05ea8000_2,
        iemDecodeA64_07fffc00_05eb8000_2,
        iemDecodeA64_07fffc00_05ec8000_2,
        iemDecodeA64_07fffc00_05ed8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05f18000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ee8000_2,
        iemDecodeA64_07fffc00_05ff8000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x001f0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000001f)) /* bit 16 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffebfe00/05e08400 level 3
   ffebfe00/05e08600 level 3
   ffebfe00/05e09000 level 3
   ffebfe00/05e09200 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfe00_05e08400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05208000))
        return iemDecodeA64_cpy_z_p_v(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05248000))
        return iemDecodeA64_revb_z_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfe00/05e18400 level 3
   ffebfe00/05e18600 level 3
   ffebfe00/05e19000 level 3
   ffebfe00/05e19200 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfe00_05e18400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05258000))
        return iemDecodeA64_revh_z_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05318000))
        return iemDecodeA64_expand_z_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbfe000)) == UINT32_C(0x05a18000))
        return iemDecodeA64_compact_z_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfe00/05e28400 level 3
   ffebfe00/05e28600 level 3
   ffebfe00/05e29000 level 3
   ffebfe00/05e29200 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfe00_05e28400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05228000))
        return iemDecodeA64_lasta_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05268000))
        return iemDecodeA64_revw_z_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfe00/05e38400 level 3
   ffebfe00/05e38600 level 3
   ffebfe00/05e39000 level 3
   ffebfe00/05e39200 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfe00_05e38400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05238000))
        return iemDecodeA64_lastb_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05278000))
        return iemDecodeA64_rbit_z_p_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfe00/05e88400 level 3
   ffebfe00/05e88600 level 3
   ffebfe00/05e89000 level 3
   ffebfe00/05e89200 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfe00_05e88400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05288000))
        return iemDecodeA64_clasta_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052c8000))
        return iemDecodeA64_splice_z_p_zz_des(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfe00/05e98400 level 3
   ffebfe00/05e98600 level 3
   ffebfe00/05e99000 level 3
   ffebfe00/05e99200 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfe00_05e98400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05298000))
        return iemDecodeA64_clastb_z_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052d8000))
        return iemDecodeA64_splice_z_p_zz_con(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffebfe00/0deb8400 level 3
   ffebfe00/0deb8600 level 3 */
FNIEMOP_DEF_1(iemDecodeA64_ffebfe00_0deb8400_3, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0de08400))
        return iemDecodeA64_LD2_asisdlsop_DX2_r2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0dff8400))
        return iemDecodeA64_LD2_asisdlsop_D2_i2d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fe00/05e08400 level 2
   f7e0fe00/05e08600 level 2
   mask=0x80b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%56 (0x9) multi-if=%44 (0x7) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fe00_05e08400_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffebfe00_05e08400_3,
        iemDecodeA64_ffebfe00_05e18400_3,
        iemDecodeA64_ffebfe00_05e28400_3,
        iemDecodeA64_ffebfe00_05e38400_3,
        iemDecodeA64_ffebfe00_05e88400_3,
        iemDecodeA64_ffebfe00_05e98400_3,
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_LD2_asisdlsop_DX2_r2d,
        iemDecodeA64_LD2_asisdlsop_DX2_r2d,
        iemDecodeA64_LD2_asisdlsop_DX2_r2d,
        iemDecodeA64_LD2_asisdlsop_DX2_r2d,
        iemDecodeA64_LD2_asisdlsop_DX2_r2d,
        iemDecodeA64_LD2_asisdlsop_DX2_r2d,
        iemDecodeA64_LD2_asisdlsop_DX2_r2d,
        iemDecodeA64_ffebfe00_0deb8400_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fe00/25e08400 level 2
   f7e0fe00/25e09000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fe00_25e08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25228000))
        return iemDecodeA64_lastp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2dc00000))
        return iemDecodeA64_LDP_S_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fe00/25e08600 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fe00_25e08600_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffa00)) == UINT32_C(0x25208200))
        return iemDecodeA64_cntp_r_pn(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x2dc00000))
        return iemDecodeA64_LDP_S_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fe00/35e08400 level 2
   f7e0fe00/35e08600 level 2
   f7e0fe00/35e09000 level 2
   f7e0fe00/35e09200 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fe00_35e08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff000000)) == UINT32_C(0x35000000))
        return iemDecodeA64_CBNZ_32_compbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x3dc00000))
        return iemDecodeA64_LDR_Q_ldst_pos(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fe00/45e08400 level 2
   f7e0fe00/45e08600 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fe00_45e08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0de08400))
        return iemDecodeA64_LD2_asisdlsop_DX2_r2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0dff8400))
        return iemDecodeA64_LD2_asisdlsop_D2_i2d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208000))
        return iemDecodeA64_match_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208010))
        return iemDecodeA64_nmatch_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fe00/65e08400 level 2
   f7e0fe00/65e08600 level 2
   f7e0fe00/65e09000 level 2
   f7e0fe00/65e09200 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fe00_65e08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20e000)) == UINT32_C(0x65208000))
        return iemDecodeA64_fmad_z_p_zzz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc00000)) == UINT32_C(0x6dc00000))
        return iemDecodeA64_LDP_D_ldstpair_pre(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e08400/0xf0000200
   mask=0xf0000200 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%50 (0x10) multi-if=%25 (0x8) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fe00_05e08400_2,
        iemDecodeA64_f7e0fe00_05e08400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fe00_25e08400_2,
        iemDecodeA64_f7e0fe00_25e08600_2,
        iemDecodeA64_f7e0fe00_35e08400_2,
        iemDecodeA64_f7e0fe00_35e08400_2,
        iemDecodeA64_f7e0fe00_45e08400_2,
        iemDecodeA64_f7e0fe00_45e08400_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_f7e0fe00_65e08400_2,
        iemDecodeA64_f7e0fe00_65e08400_2,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000200 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* fff0fe00/05e08800 level 2
   fff0fe00/05e08a00 level 2
   mask=0xf0000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%88 (0xe) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_fff0fe00_05e08800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cpy_z_p_v,
        iemDecodeA64_compact_z_p_z,
        iemDecodeA64_lasta_v_p_z,
        iemDecodeA64_lastb_v_p_z,
        iemDecodeA64_revb_z_z_m,
        iemDecodeA64_revh_z_z_m,
        iemDecodeA64_revw_z_z_m,
        iemDecodeA64_rbit_z_p_z_m,
        iemDecodeA64_clasta_z_p_zz,
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_splice_z_p_zz_des,
        iemDecodeA64_splice_z_p_zz_con,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x000f0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x0000000f)) /* bit 16 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e08800/0xf8100200
   mask=0xf8100200 entries=0x80 children=0x3d valid=%48 (0x3d) leaf=%42 (0x36) multi-if=%3 (0x4) reuse=%5 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_fff0fe00_05e08800_2,
        iemDecodeA64_fff0fe00_05e08800_2,
        iemDecodeA64_expand_z_p_z,
        iemDecodeA64_expand_z_p_z,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe0fc00_25208800_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_Invalid, // 80
        iemDecodeA64_Invalid, // 81
        iemDecodeA64_Invalid, // 82
        iemDecodeA64_Invalid, // 83
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_Invalid, // 112
        iemDecodeA64_Invalid, // 113
        iemDecodeA64_Invalid, // 114
        iemDecodeA64_Invalid, // 115
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8100200 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 19) & UINT32_C(0x00000002)) /* bit 20 L 1 -> 1 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/05e08c00 level 2
   ffe6fc00/05e09400 level 2
   ffe6fc00/05e09800 level 2
   ffe6fc00/05e09c00 level 2
   mask=0x190000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_05e08c00_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_cpy_z_p_v,
        iemDecodeA64_compact_z_p_z,
        iemDecodeA64_clasta_z_p_zz,
        iemDecodeA64_clastb_z_p_zz,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_expand_z_p_z,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/05e28c00 level 2
   ffe6fc00/05e29400 level 2
   ffe6fc00/05e29800 level 2
   ffe6fc00/05e29c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_05e28c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05228000))
        return iemDecodeA64_lasta_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05238000))
        return iemDecodeA64_lastb_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052a8000))
        return iemDecodeA64_clasta_v_p_z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052b8000))
        return iemDecodeA64_clastb_v_p_z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe6fc00/05e48c00 level 2
   ffe6fc00/05e49400 level 2
   ffe6fc00/05e49800 level 2
   ffe6fc00/05e49c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_05e48c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05248000))
        return iemDecodeA64_revb_z_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05258000))
        return iemDecodeA64_revh_z_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052c8000))
        return iemDecodeA64_splice_z_p_zz_des(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x052d8000))
        return iemDecodeA64_splice_z_p_zz_con(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe6fc00/05e68c00 level 2
   ffe6fc00/05e69400 level 2
   ffe6fc00/05e69800 level 2
   ffe6fc00/05e69c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_05e68c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05268000))
        return iemDecodeA64_revw_z_z_m(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fe000)) == UINT32_C(0x05278000))
        return iemDecodeA64_rbit_z_p_z_m(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe6fc00/25e08c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_25e08c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x25288c00))
        return iemDecodeA64_sqincp_r_p_r_x(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x25298c00))
        return iemDecodeA64_uqincp_r_p_r_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe6fc00/25e28c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_25e28c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25228000))
        return iemDecodeA64_lastp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252a8c00))
        return iemDecodeA64_sqdecp_r_p_r_x(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3ffe00)) == UINT32_C(0x252b8c00))
        return iemDecodeA64_uqdecp_r_p_r_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e08c00/0xf8060000
   mask=0xf8060000 entries=0x80 children=0x3e valid=%48 (0x3e) leaf=%41 (0x34) multi-if=%7 (0x9) reuse=%3 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe6fc00_05e08c00_2,
        iemDecodeA64_ffe6fc00_05e28c00_2,
        iemDecodeA64_ffe6fc00_05e48c00_2,
        iemDecodeA64_ffe6fc00_05e68c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe6fc00_25e08c00_2,
        iemDecodeA64_ffe6fc00_25e28c00_2,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_Invalid, // 80
        iemDecodeA64_Invalid, // 81
        iemDecodeA64_Invalid, // 82
        iemDecodeA64_Invalid, // 83
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_Invalid, // 112
        iemDecodeA64_Invalid, // 113
        iemDecodeA64_Invalid, // 114
        iemDecodeA64_Invalid, // 115
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8060000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fe00/05e09000 level 2
   f7e0fe00/05e09200 level 2
   mask=0x80b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%56 (0x9) multi-if=%44 (0x7) reuse=%44 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fe00_05e09000_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffebfe00_05e08400_3,
        iemDecodeA64_ffebfe00_05e18400_3,
        iemDecodeA64_ffebfe00_05e28400_3,
        iemDecodeA64_ffebfe00_05e38400_3,
        iemDecodeA64_ffebfe00_05e88400_3,
        iemDecodeA64_ffebfe00_05e98400_3,
        iemDecodeA64_clasta_v_p_z,
        iemDecodeA64_clastb_v_p_z,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_LD2_asisdlsop_SX2_r2s,
        iemDecodeA64_fffffc00_0dff8000_3,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fe00/45e09000 level 2
   f7e0fe00/45e09200 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fe00_45e09000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0de08000))
        return iemDecodeA64_LD2_asisdlsop_SX2_r2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0dff8000))
        return iemDecodeA64_LD2_asisdlsop_S2_i2s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208000))
        return iemDecodeA64_match_p_p_zz(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff20e010)) == UINT32_C(0x45208010))
        return iemDecodeA64_nmatch_p_p_zz(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e09000/0xf0000200
   mask=0xf0000200 entries=0x20 children=0x1a valid=%81 (0x1a) leaf=%53 (0x11) multi-if=%22 (0x7) reuse=%22 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fe00_05e09000_2,
        iemDecodeA64_f7e0fe00_05e09000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fe00_25e08400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_f7e0fe00_35e08400_2,
        iemDecodeA64_f7e0fe00_35e08400_2,
        iemDecodeA64_f7e0fe00_45e09000_2,
        iemDecodeA64_f7e0fe00_45e09000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_f7e0fe00_65e08400_2,
        iemDecodeA64_f7e0fe00_65e08400_2,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0000200 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >>  9) & UINT32_C(0x00000001)) /* bit  9 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe6fc00/25e09400 level 2
   ffe6fc00/25e09800 level 2
   ffe6fc00/25e09c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe6fc00_25e09400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25208000))
        return iemDecodeA64_cntp_r_p_p(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff3fc200)) == UINT32_C(0x25218000))
        return iemDecodeA64_firstp_r_p_p(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e09400/0xf8060000
   --decoder-hint1 0x7e0fc00/0x5e09800/0xf8060000
   --decoder-hint1 0x7e0fc00/0x5e09c00/0xf8060000
   mask=0xf8060000 entries=0x80 children=0x3e valid=%48 (0x3e) leaf=%41 (0x35) multi-if=%6 (0x8) reuse=%6 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe6fc00_05e08c00_2,
        iemDecodeA64_ffe6fc00_05e28c00_2,
        iemDecodeA64_ffe6fc00_05e48c00_2,
        iemDecodeA64_ffe6fc00_05e68c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ffe6fc00_25e09400_2,
        iemDecodeA64_lastp_r_p_p,
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_ffe0fc00_45208000_2,
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_fmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_ld1rsb_z_p_bi_s64,
        iemDecodeA64_Invalid, // 68
        iemDecodeA64_Invalid, // 69
        iemDecodeA64_Invalid, // 70
        iemDecodeA64_Invalid, // 71
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 76
        iemDecodeA64_Invalid, // 77
        iemDecodeA64_Invalid, // 78
        iemDecodeA64_Invalid, // 79
        iemDecodeA64_Invalid, // 80
        iemDecodeA64_Invalid, // 81
        iemDecodeA64_Invalid, // 82
        iemDecodeA64_Invalid, // 83
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 92
        iemDecodeA64_Invalid, // 93
        iemDecodeA64_Invalid, // 94
        iemDecodeA64_Invalid, // 95
        iemDecodeA64_Invalid, // 96
        iemDecodeA64_Invalid, // 97
        iemDecodeA64_Invalid, // 98
        iemDecodeA64_Invalid, // 99
        iemDecodeA64_Invalid, // 100
        iemDecodeA64_Invalid, // 101
        iemDecodeA64_Invalid, // 102
        iemDecodeA64_Invalid, // 103
        iemDecodeA64_Invalid, // 104
        iemDecodeA64_Invalid, // 105
        iemDecodeA64_Invalid, // 106
        iemDecodeA64_Invalid, // 107
        iemDecodeA64_Invalid, // 108
        iemDecodeA64_Invalid, // 109
        iemDecodeA64_Invalid, // 110
        iemDecodeA64_Invalid, // 111
        iemDecodeA64_Invalid, // 112
        iemDecodeA64_Invalid, // 113
        iemDecodeA64_Invalid, // 114
        iemDecodeA64_Invalid, // 115
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 124
        iemDecodeA64_Invalid, // 125
        iemDecodeA64_Invalid, // 126
        iemDecodeA64_Invalid, // 127
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x80);

    /* fMask=0xf8060000 -> 0x0000007f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000007c)) /* bit 27 L 5 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0de0a000 level 2
   ffe0fc00/4de0a000 level 2
   ffe0fc00/0de0b000 level 2
   ffe0fc00/4de0b000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0de0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0ec00)) == UINT32_C(0x0de0a000))
        return iemDecodeA64_LD4_asisdlsop_SX4_r4s(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfffec00)) == UINT32_C(0x0dffa000))
        return iemDecodeA64_LD4_asisdlsop_S4_i4s(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/a5e0a000 level 2
   ffe0fc00/a5e0a400 level 2
   ffe0fc00/a5e0a800 level 2
   ffe0fc00/a5e0ac00 level 2
   ffe0fc00/a5e0b000 level 2
   ffe0fc00/a5e0b400 level 2
   ffe0fc00/a5e0b800 level 2
   ffe0fc00/a5e0bc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_a5e0a000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5e0a000))
        return iemDecodeA64_ld1d_z_p_bi_u64(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xa5f0a000))
        return iemDecodeA64_ldnf1d_z_p_bi_u64(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0a000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_ffe0fc00_0de0a000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_histseg_z_zz,
        iemDecodeA64_ffe0fc00_0de0a000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0de0a400 level 2
   ffe0fc00/4de0a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0de0a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0de0a400))
        return iemDecodeA64_LD4_asisdlsop_DX4_r4d(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0dffa400))
        return iemDecodeA64_LD4_asisdlsop_D4_i4d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0a400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_ffe0fc00_0de0a400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_luti4_z_zz_8,
        iemDecodeA64_ffe0fc00_0de0a400_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0a800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0b800/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_luti2_z_zz_16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0ac00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0b000/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x13 valid=%59 (0x13) leaf=%44 (0xe) multi-if=%12 (0x4) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_ffe0fc00_0de0a000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_luti2_z_zz_8,
        iemDecodeA64_ffe0fc00_0de0a000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0b400/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_luti4_z_zz_2x16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0bc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x11 valid=%53 (0x11) leaf=%44 (0xe) multi-if=%6 (0x2) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ffe0fc00_0560a000_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_25209400_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_luti4_z_zz_1x16,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_CBNE_32_imm,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s32,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ffe0fc00_a5e0a000_2,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_CBNE_64_imm,
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0de0c000 level 2
   ffe0fc00/4de0c000 level 2
   ffe0fc00/0de0c400 level 2
   ffe0fc00/4de0c400 level 2
   ffe0fc00/0de0c800 level 2
   ffe0fc00/4de0c800 level 2
   ffe0fc00/0de0cc00 level 2
   ffe0fc00/4de0cc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0de0c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0de0c000))
        return iemDecodeA64_LD2R_asisdlsop_RX2_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0dffc000))
        return iemDecodeA64_LD2R_asisdlsop_R2_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0c000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0c400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0c800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0cc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%47 (0xf) multi-if=%6 (0x2) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_ffe0fc00_0de0c000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520c000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_histcnt_z_p_zz,
        iemDecodeA64_ffe0fc00_0de0c000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld4d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0d000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0d400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0d800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0dc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%47 (0xf) multi-if=%0 (0x0) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520c000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_histcnt_z_p_zz,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmad_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rsb_z_p_bi_s16,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld4d_z_p_br_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ld1d_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0de0e000 level 2
   ffe0fc00/4de0e000 level 2
   ffe0fc00/0de0e400 level 2
   ffe0fc00/4de0e400 level 2
   ffe0fc00/0de0e800 level 2
   ffe0fc00/4de0e800 level 2
   ffe0fc00/0de0ec00 level 2
   ffe0fc00/4de0ec00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0de0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0f000)) == UINT32_C(0x0de0e000))
        return iemDecodeA64_LD4R_asisdlsop_RX4_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffff000)) == UINT32_C(0x0dffe000))
        return iemDecodeA64_LD4R_asisdlsop_R4_i(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/e5e0e000 level 2
   ffe0fc00/e5e0e400 level 2
   ffe0fc00/e5e0e800 level 2
   ffe0fc00/e5e0ec00 level 2
   ffe0fc00/e5e0f000 level 2
   ffe0fc00/e5e0f400 level 2
   ffe0fc00/e5e0f800 level 2
   ffe0fc00/e5e0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_e5e0e000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe5e0e000))
        return iemDecodeA64_st1d_z_p_bi(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff0e000)) == UINT32_C(0xe5f0e000))
        return iemDecodeA64_st4d_z_p_bi_contiguous(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0e000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0e400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0e800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0ec00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x12 valid=%56 (0x12) leaf=%44 (0xe) multi-if=%9 (0x3) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_ffe0fc00_0de0e000_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0de0e000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld4d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x5e0f000/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0f400/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0f800/0xf8000000
   --decoder-hint1 0x7e0fc00/0x5e0fc00/0xf8000000
   mask=0xf8000000 entries=0x20 children=0x10 valid=%50 (0x10) leaf=%44 (0xe) multi-if=%3 (0x1) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_05e0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_sel_z_p_zz,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ffe0fc00_2520e000_2,
        iemDecodeA64_LDP_S_ldstpair_pre,
        iemDecodeA64_CBNZ_32_compbranch,
        iemDecodeA64_LDR_Q_ldst_pos,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_fnmsb_z_p_zzz,
        iemDecodeA64_LDP_D_ldstpair_pre,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_ld1rd_z_p_bi_u64,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_ld4d_z_p_bi_contiguous,
        iemDecodeA64_LDP_Q_ldstpair_pre,
        iemDecodeA64_CBNZ_64_compbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_ldff1d_z_p_bz_d_64_scaled,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_ffe0fc00_e5e0e000_2,
        iemDecodeA64_LDTP_Q_ldstpair_pre,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe5fc00/1e000000 level 2
   7fe1fc00/1e000400 level 2
   7fe1fc00/1e001800 level 2
   7fe1fc00/1e002800 level 2
   7fe1fc00/1e003800 level 2
   7fe1fc00/1e005800 level 2
   7fe1fc00/1e006800 level 2
   7fe1fc00/1e007000 level 2
   7fe1fc00/1e007800 level 2
   7fe1fc00/1e009400 level 2
   7fe1fc00/1e00c400 level 2
   7fe1fc00/1e00f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe5fc00_1e000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e020000))
        return iemDecodeA64_SCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e180000))
        return iemDecodeA64_FCVTZS_32S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e020000))
        return iemDecodeA64_SCVTF_S64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e180000))
        return iemDecodeA64_FCVTZS_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe5fc00/1e010000 level 2
   7fe1fc00/1e010400 level 2
   7fe1fc00/1e011800 level 2
   7fe1fc00/1e012800 level 2
   7fe1fc00/1e013800 level 2
   7fe1fc00/1e015800 level 2
   7fe1fc00/1e016800 level 2
   7fe1fc00/1e017000 level 2
   7fe1fc00/1e017800 level 2
   7fe1fc00/1e019400 level 2
   7fe1fc00/1e01c400 level 2
   7fe1fc00/1e01f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe5fc00_1e010000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e030000))
        return iemDecodeA64_UCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e190000))
        return iemDecodeA64_FCVTZU_32S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e030000))
        return iemDecodeA64_UCVTF_S64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e190000))
        return iemDecodeA64_FCVTZU_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe5fc00/4e000000 level 2
   7fe5fc00/4e010000 level 2
   7fe5fc00/4e040000 level 2
   7fe5fc00/4e050000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe5fc00_4e000000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e000000))
        return iemDecodeA64_TBL_asimdtbl_L1_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06000000 level 1
   mask=0x78050000 entries=0x40 children=0x1f valid=%48 (0x1f) leaf=%33 (0x15) multi-if=%16 (0xa) reuse=%11 (0x7) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06000000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TBL_asimdtbl_L1_1,
        iemDecodeA64_TBL_asimdtbl_L1_1,
        iemDecodeA64_TBL_asimdtbl_L1_1,
        iemDecodeA64_TBL_asimdtbl_L1_1,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe5fc00_4e000000_2,
        iemDecodeA64_7fe5fc00_4e000000_2,
        iemDecodeA64_7fe5fc00_4e000000_2,
        iemDecodeA64_7fe5fc00_4e000000_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_BR_64_branch_reg,
        iemDecodeA64_SHA1C_QSV_cryptosha3,
        iemDecodeA64_SHA1C_QSV_cryptosha3,
        iemDecodeA64_SHA1C_QSV_cryptosha3,
        iemDecodeA64_SHA1C_QSV_cryptosha3,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78050000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000002)) /* bit 18 L 1 -> 1 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e000400 level 2
   7fe1fc00/4e010400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e000400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e000400))
        return iemDecodeA64_DUP_asimdins_DV_v(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06000400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06000400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_DUP_asimdins_DV_v,
        iemDecodeA64_DUP_asimdins_DV_v,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e000400_2,
        iemDecodeA64_7fe1fc00_4e000400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_DUP_asisdone_only,
        iemDecodeA64_DUP_asisdone_only,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe6fc00/16000800 level 2
   5fe6fc00/16020800 level 2
   5fe6fc00/16040800 level 2
   5fe6fc00/16060800 level 2
   5fe6fc00/16000c00 level 2
   5fe6fc00/16020c00 level 2
   5fe6fc00/16040c00 level 2
   5fe6fc00/16060c00 level 2
   5fe6fc00/16002c00 level 2
   5fe6fc00/16022c00 level 2
   5fe6fc00/16042c00 level 2
   5fe6fc00/16062c00 level 2
   0febfc00/06008000 level 2
   0febfc00/06018000 level 2
   0febfc00/06028000 level 2
   0febfc00/06038000 level 2
   0febfc00/06088000 level 2
   0febfc00/06098000 level 2
   0febfc00/060a8000 level 2
   0febfc00/060b8000 level 2
   0febfc00/06008800 level 2
   0febfc00/06018800 level 2
   0febfc00/06028800 level 2
   0febfc00/06038800 level 2
   0febfc00/06088800 level 2
   0febfc00/06098800 level 2
   0febfc00/060a8800 level 2
   0febfc00/060b8800 level 2
   0febfc00/06009000 level 2
   0febfc00/06019000 level 2
   0febfc00/06029000 level 2
   0febfc00/06039000 level 2
   0febfc00/06089000 level 2
   0febfc00/06099000 level 2
   0febfc00/060a9000 level 2
   0febfc00/060b9000 level 2
   0febfc00/06009800 level 2
   0febfc00/06019800 level 2
   0febfc00/06029800 level 2
   0febfc00/06039800 level 2
   0febfc00/06089800 level 2
   0febfc00/06099800 level 2
   0febfc00/060a9800 level 2
   0febfc00/060b9800 level 2
   0febfc00/06009c00 level 2
   0febfc00/06019c00 level 2
   0febfc00/06029c00 level 2
   0febfc00/06039c00 level 2
   0febfc00/06089c00 level 2
   0febfc00/06099c00 level 2
   0febfc00/060a9c00 level 2
   0febfc00/060b9c00 level 2
   0febfc00/0600a000 level 2
   0febfc00/0601a000 level 2
   0febfc00/0602a000 level 2
   0febfc00/0603a000 level 2
   0febfc00/0608a000 level 2
   0febfc00/0609a000 level 2
   0febfc00/060aa000 level 2
   0febfc00/060ba000 level 2
   0febfc00/0600a400 level 2
   0febfc00/0601a400 level 2
   0febfc00/0602a400 level 2
   0febfc00/0603a400 level 2
   0febfc00/0608a400 level 2
   0febfc00/0609a400 level 2
   0febfc00/060aa400 level 2
   0febfc00/060ba400 level 2
   0febfc00/0600a800 level 2
   0febfc00/0601a800 level 2
   0febfc00/0602a800 level 2
   0febfc00/0603a800 level 2
   0febfc00/0608a800 level 2
   0febfc00/0609a800 level 2
   0febfc00/060aa800 level 2
   0febfc00/060ba800 level 2
   0febfc00/0600ac00 level 2
   0febfc00/0601ac00 level 2
   0febfc00/0602ac00 level 2
   0febfc00/0603ac00 level 2
   0febfc00/0608ac00 level 2
   0febfc00/0609ac00 level 2
   0febfc00/060aac00 level 2
   0febfc00/060bac00 level 2
   0febfc00/0600b000 level 2
   0febfc00/0601b000 level 2
   0febfc00/0602b000 level 2
   0febfc00/0603b000 level 2
   0febfc00/0608b000 level 2
   0febfc00/0609b000 level 2
   0febfc00/060ab000 level 2
   0febfc00/060bb000 level 2
   0febfc00/0600b400 level 2
   0febfc00/0601b400 level 2
   0febfc00/0602b400 level 2
   0febfc00/0603b400 level 2
   0febfc00/0608b400 level 2
   0febfc00/0609b400 level 2
   0febfc00/060ab400 level 2
   0febfc00/060bb400 level 2
   0febfc00/0600b800 level 2
   0febfc00/0601b800 level 2
   0febfc00/0602b800 level 2
   0febfc00/0603b800 level 2
   0febfc00/0608b800 level 2
   0febfc00/0609b800 level 2
   0febfc00/060ab800 level 2
   0febfc00/060bb800 level 2
   0febfc00/0600bc00 level 2
   0febfc00/0601bc00 level 2
   0febfc00/0602bc00 level 2
   0febfc00/0603bc00 level 2
   0febfc00/0608bc00 level 2
   0febfc00/0609bc00 level 2
   0febfc00/060abc00 level 2
   0febfc00/060bbc00 level 2
   0febfc00/0600c000 level 2
   0febfc00/0601c000 level 2
   0febfc00/0602c000 level 2
   0febfc00/0603c000 level 2
   0febfc00/0608c000 level 2
   0febfc00/0609c000 level 2
   0febfc00/060ac000 level 2
   0febfc00/060bc000 level 2
   0febfc00/0600c800 level 2
   0febfc00/0601c800 level 2
   0febfc00/0602c800 level 2
   0febfc00/0603c800 level 2
   0febfc00/0608c800 level 2
   0febfc00/0609c800 level 2
   0febfc00/060ac800 level 2
   0febfc00/060bc800 level 2
   0febfc00/0600d000 level 2
   0febfc00/0601d000 level 2
   0febfc00/0602d000 level 2
   0febfc00/0603d000 level 2
   0febfc00/0608d000 level 2
   0febfc00/0609d000 level 2
   0febfc00/060ad000 level 2
   0febfc00/060bd000 level 2
   0febfc00/0600d800 level 2
   0febfc00/0601d800 level 2
   0febfc00/0602d800 level 2
   0febfc00/0603d800 level 2
   0febfc00/0608d800 level 2
   0febfc00/0609d800 level 2
   0febfc00/060ad800 level 2
   0febfc00/060bd800 level 2
   0febfc00/0600e000 level 2
   0febfc00/0601e000 level 2
   0febfc00/0602e000 level 2
   0febfc00/0603e000 level 2
   0febfc00/0608e000 level 2
   0febfc00/0609e000 level 2
   0febfc00/060ae000 level 2
   0febfc00/060be000 level 2
   0febfc00/0600e800 level 2
   0febfc00/0601e800 level 2
   0febfc00/0602e800 level 2
   0febfc00/0603e800 level 2
   0febfc00/0608e800 level 2
   0febfc00/0609e800 level 2
   0febfc00/060ae800 level 2
   0febfc00/060be800 level 2
   0febfc00/0600f000 level 2
   0febfc00/0601f000 level 2
   0febfc00/0602f000 level 2
   0febfc00/0603f000 level 2
   0febfc00/0608f000 level 2
   0febfc00/0609f000 level 2
   0febfc00/060af000 level 2
   0febfc00/060bf000 level 2
   0febfc00/0600f800 level 2
   0febfc00/0601f800 level 2
   0febfc00/0602f800 level 2
   0febfc00/0603f800 level 2
   0febfc00/0608f800 level 2
   0febfc00/0609f800 level 2
   0febfc00/060af800 level 2
   0febfc00/060bf800 level 2
   1ff7fc00/16200000 level 2
   1ff7fc00/16210000 level 2
   1ff7fc00/16220000 level 2
   1ff7fc00/16230000 level 2
   1ff7fc00/16240000 level 2
   1ff7fc00/16250000 level 2
   1ff7fc00/16260000 level 2
   1ff7fc00/16270000 level 2
   1ff7fc00/16300000 level 2
   1ff7fc00/16310000 level 2
   1ff7fc00/16320000 level 2
   1ff7fc00/16330000 level 2
   1ff7fc00/16340000 level 2
   1ff7fc00/16350000 level 2
   1ff7fc00/16360000 level 2
   5fe6fc00/16204000 level 2
   5fe6fc00/16224000 level 2
   5fe6fc00/16244000 level 2
   5fe6fc00/16264000 level 2
   0febfc00/0620c000 level 2
   0febfc00/0621c000 level 2
   0febfc00/0622c000 level 2
   0febfc00/0623c000 level 2
   0febfc00/0628c000 level 2
   0febfc00/0629c000 level 2
   0febfc00/062ac000 level 2
   0febfc00/062bc000 level 2
   0febfc00/0640c000 level 2
   0febfc00/0641c000 level 2
   0febfc00/0642c000 level 2
   0febfc00/0643c000 level 2
   0febfc00/0648c000 level 2
   0febfc00/0649c000 level 2
   0febfc00/064ac000 level 2
   0febfc00/064bc000 level 2
   0febfc00/0640c800 level 2
   0febfc00/0641c800 level 2
   0febfc00/0642c800 level 2
   0febfc00/0643c800 level 2
   0febfc00/0648c800 level 2
   0febfc00/0649c800 level 2
   0febfc00/064ac800 level 2
   0febfc00/064bc800 level 2
   0febfc00/0640d000 level 2
   0febfc00/0641d000 level 2
   0febfc00/0642d000 level 2
   0febfc00/0643d000 level 2
   0febfc00/0648d000 level 2
   0febfc00/0649d000 level 2
   0febfc00/064ad000 level 2
   0febfc00/064bd000 level 2
   0febfc00/0640d800 level 2
   0febfc00/0641d800 level 2
   0febfc00/0642d800 level 2
   0febfc00/0643d800 level 2
   0febfc00/0648d800 level 2
   0febfc00/0649d800 level 2
   0febfc00/064ad800 level 2
   0febfc00/064bd800 level 2
   0febfc00/0640e000 level 2
   0febfc00/0641e000 level 2
   0febfc00/0642e000 level 2
   0febfc00/0643e000 level 2
   0febfc00/0648e000 level 2
   0febfc00/0649e000 level 2
   0febfc00/064ae000 level 2
   0febfc00/064be000 level 2
   0febfc00/0640e800 level 2
   0febfc00/0641e800 level 2
   0febfc00/0642e800 level 2
   0febfc00/0643e800 level 2
   0febfc00/0648e800 level 2
   0febfc00/0649e800 level 2
   0febfc00/064ae800 level 2
   0febfc00/064be800 level 2
   0febfc00/0640f000 level 2
   0febfc00/0641f000 level 2
   0febfc00/0642f000 level 2
   0febfc00/0643f000 level 2
   0febfc00/0648f000 level 2
   0febfc00/0649f000 level 2
   0febfc00/064af000 level 2
   0febfc00/064bf000 level 2
   0febfc00/0640f800 level 2
   0febfc00/0641f800 level 2
   0febfc00/0642f800 level 2
   0febfc00/0643f800 level 2
   0febfc00/0648f800 level 2
   0febfc00/0649f800 level 2
   0febfc00/064af800 level 2
   0febfc00/064bf800 level 2
   1ff7fc00/16600000 level 2
   1ff7fc00/16610000 level 2
   1ff7fc00/16620000 level 2
   1ff7fc00/16630000 level 2
   1ff7fc00/16640000 level 2
   1ff7fc00/16650000 level 2
   1ff7fc00/16660000 level 2
   1ff7fc00/16670000 level 2
   1ff7fc00/16700000 level 2
   1ff7fc00/16710000 level 2
   1ff7fc00/16720000 level 2
   1ff7fc00/16730000 level 2
   1ff7fc00/16740000 level 2
   1ff7fc00/16750000 level 2
   1ff7fc00/16760000 level 2
   1ff7fc00/16770000 level 2
   5fecfc00/16604000 level 2
   5fecfc00/16644000 level 2
   5fecfc00/16684000 level 2
   5fecfc00/166c4000 level 2
   5fe3fc00/1660c000 level 2
   5fe3fc00/1661c000 level 2
   5fe3fc00/1662c000 level 2
   5fe3fc00/1663c000 level 2
   0febfc00/0660d800 level 2
   0febfc00/0661d800 level 2
   0febfc00/0662d800 level 2
   0febfc00/0663d800 level 2
   0febfc00/0668d800 level 2
   0febfc00/0669d800 level 2
   0febfc00/066ad800 level 2
   0febfc00/066bd800 level 2
   07e0fc00/06a0f000 level 1
   0febfc00/06c00800 level 2
   0febfc00/06c10800 level 2
   0febfc00/06c20800 level 2
   0febfc00/06c30800 level 2
   0febfc00/06c80800 level 2
   0febfc00/06c90800 level 2
   0febfc00/06ca0800 level 2
   0febfc00/06cb0800 level 2
   0febfc00/06c04400 level 2
   0febfc00/06c14400 level 2
   0febfc00/06c24400 level 2
   0febfc00/06c34400 level 2
   0febfc00/06c84400 level 2
   0febfc00/06c94400 level 2
   0febfc00/06ca4400 level 2
   0febfc00/06cb4400 level 2
   0febfc00/06c04800 level 2
   0febfc00/06c14800 level 2
   0febfc00/06c24800 level 2
   0febfc00/06c34800 level 2
   0febfc00/06c84800 level 2
   0febfc00/06c94800 level 2
   0febfc00/06ca4800 level 2
   0febfc00/06cb4800 level 2
   0febfc00/06c04c00 level 2
   0febfc00/06c14c00 level 2
   0febfc00/06c24c00 level 2
   0febfc00/06c34c00 level 2
   0febfc00/06c84c00 level 2
   0febfc00/06c94c00 level 2
   0febfc00/06ca4c00 level 2
   0febfc00/06cb4c00 level 2
   0febfc00/06c05400 level 2
   0febfc00/06c15400 level 2
   0febfc00/06c25400 level 2
   0febfc00/06c35400 level 2
   0febfc00/06c85400 level 2
   0febfc00/06c95400 level 2
   0febfc00/06ca5400 level 2
   0febfc00/06cb5400 level 2
   0febfc00/06c05c00 level 2
   0febfc00/06c15c00 level 2
   0febfc00/06c25c00 level 2
   0febfc00/06c35c00 level 2
   0febfc00/06c85c00 level 2
   0febfc00/06c95c00 level 2
   0febfc00/06ca5c00 level 2
   0febfc00/06cb5c00 level 2
   0febfc00/06c06400 level 2
   0febfc00/06c16400 level 2
   0febfc00/06c26400 level 2
   0febfc00/06c36400 level 2
   0febfc00/06c86400 level 2
   0febfc00/06c96400 level 2
   0febfc00/06ca6400 level 2
   0febfc00/06cb6400 level 2
   0febfc00/06c06c00 level 2
   0febfc00/06c16c00 level 2
   0febfc00/06c26c00 level 2
   0febfc00/06c36c00 level 2
   0febfc00/06c86c00 level 2
   0febfc00/06c96c00 level 2
   0febfc00/06ca6c00 level 2
   0febfc00/06cb6c00 level 2
   0febfc00/06c07400 level 2
   0febfc00/06c17400 level 2
   0febfc00/06c27400 level 2
   0febfc00/06c37400 level 2
   0febfc00/06c87400 level 2
   0febfc00/06c97400 level 2
   0febfc00/06ca7400 level 2
   0febfc00/06cb7400 level 2
   0febfc00/06c07c00 level 2
   0febfc00/06c17c00 level 2
   0febfc00/06c27c00 level 2
   0febfc00/06c37c00 level 2
   0febfc00/06c87c00 level 2
   0febfc00/06c97c00 level 2
   0febfc00/06ca7c00 level 2
   0febfc00/06cb7c00 level 2
   0febfc00/06c08000 level 2
   0febfc00/06c18000 level 2
   0febfc00/06c28000 level 2
   0febfc00/06c38000 level 2
   0febfc00/06c88000 level 2
   0febfc00/06c98000 level 2
   0febfc00/06ca8000 level 2
   0febfc00/06cb8000 level 2
   0febfc00/06c08800 level 2
   0febfc00/06c18800 level 2
   0febfc00/06c28800 level 2
   0febfc00/06c38800 level 2
   0febfc00/06c88800 level 2
   0febfc00/06c98800 level 2
   0febfc00/06ca8800 level 2
   0febfc00/06cb8800 level 2
   0febfc00/06c09000 level 2
   0febfc00/06c19000 level 2
   0febfc00/06c29000 level 2
   0febfc00/06c39000 level 2
   0febfc00/06c89000 level 2
   0febfc00/06c99000 level 2
   0febfc00/06ca9000 level 2
   0febfc00/06cb9000 level 2
   0febfc00/06c09800 level 2
   0febfc00/06c19800 level 2
   0febfc00/06c29800 level 2
   0febfc00/06c39800 level 2
   0febfc00/06c89800 level 2
   0febfc00/06c99800 level 2
   0febfc00/06ca9800 level 2
   0febfc00/06cb9800 level 2
   0febfc00/06c09c00 level 2
   0febfc00/06c19c00 level 2
   0febfc00/06c29c00 level 2
   0febfc00/06c39c00 level 2
   0febfc00/06c89c00 level 2
   0febfc00/06c99c00 level 2
   0febfc00/06ca9c00 level 2
   0febfc00/06cb9c00 level 2
   0febfc00/06c0a000 level 2
   0febfc00/06c1a000 level 2
   0febfc00/06c2a000 level 2
   0febfc00/06c3a000 level 2
   0febfc00/06c8a000 level 2
   0febfc00/06c9a000 level 2
   0febfc00/06caa000 level 2
   0febfc00/06cba000 level 2
   0febfc00/06c0a400 level 2
   0febfc00/06c1a400 level 2
   0febfc00/06c2a400 level 2
   0febfc00/06c3a400 level 2
   0febfc00/06c8a400 level 2
   0febfc00/06c9a400 level 2
   0febfc00/06caa400 level 2
   0febfc00/06cba400 level 2
   0febfc00/06c0a800 level 2
   0febfc00/06c1a800 level 2
   0febfc00/06c2a800 level 2
   0febfc00/06c3a800 level 2
   0febfc00/06c8a800 level 2
   0febfc00/06c9a800 level 2
   0febfc00/06caa800 level 2
   0febfc00/06cba800 level 2
   0febfc00/06c0ac00 level 2
   0febfc00/06c1ac00 level 2
   0febfc00/06c2ac00 level 2
   0febfc00/06c3ac00 level 2
   0febfc00/06c8ac00 level 2
   0febfc00/06c9ac00 level 2
   0febfc00/06caac00 level 2
   0febfc00/06cbac00 level 2
   0febfc00/06c0b000 level 2
   0febfc00/06c1b000 level 2
   0febfc00/06c2b000 level 2
   0febfc00/06c3b000 level 2
   0febfc00/06c8b000 level 2
   0febfc00/06c9b000 level 2
   0febfc00/06cab000 level 2
   0febfc00/06cbb000 level 2
   0febfc00/06c0b400 level 2
   0febfc00/06c1b400 level 2
   0febfc00/06c2b400 level 2
   0febfc00/06c3b400 level 2
   0febfc00/06c8b400 level 2
   0febfc00/06c9b400 level 2
   0febfc00/06cab400 level 2
   0febfc00/06cbb400 level 2
   0febfc00/06c0b800 level 2
   0febfc00/06c1b800 level 2
   0febfc00/06c2b800 level 2
   0febfc00/06c3b800 level 2
   0febfc00/06c8b800 level 2
   0febfc00/06c9b800 level 2
   0febfc00/06cab800 level 2
   0febfc00/06cbb800 level 2
   0febfc00/06c0bc00 level 2
   0febfc00/06c1bc00 level 2
   0febfc00/06c2bc00 level 2
   0febfc00/06c3bc00 level 2
   0febfc00/06c8bc00 level 2
   0febfc00/06c9bc00 level 2
   0febfc00/06cabc00 level 2
   0febfc00/06cbbc00 level 2
   0febfc00/06c0c000 level 2
   0febfc00/06c1c000 level 2
   0febfc00/06c2c000 level 2
   0febfc00/06c3c000 level 2
   0febfc00/06c8c000 level 2
   0febfc00/06c9c000 level 2
   0febfc00/06cac000 level 2
   0febfc00/06cbc000 level 2
   0febfc00/06c0c800 level 2
   0febfc00/06c1c800 level 2
   0febfc00/06c2c800 level 2
   0febfc00/06c3c800 level 2
   0febfc00/06c8c800 level 2
   0febfc00/06c9c800 level 2
   0febfc00/06cac800 level 2
   0febfc00/06cbc800 level 2
   0febfc00/06c0d000 level 2
   0febfc00/06c1d000 level 2
   0febfc00/06c2d000 level 2
   0febfc00/06c3d000 level 2
   0febfc00/06c8d000 level 2
   0febfc00/06c9d000 level 2
   0febfc00/06cad000 level 2
   0febfc00/06cbd000 level 2
   0febfc00/06c0d800 level 2
   0febfc00/06c1d800 level 2
   0febfc00/06c2d800 level 2
   0febfc00/06c3d800 level 2
   0febfc00/06c8d800 level 2
   0febfc00/06c9d800 level 2
   0febfc00/06cad800 level 2
   0febfc00/06cbd800 level 2
   0febfc00/06c0e000 level 2
   0febfc00/06c1e000 level 2
   0febfc00/06c2e000 level 2
   0febfc00/06c3e000 level 2
   0febfc00/06c8e000 level 2
   0febfc00/06c9e000 level 2
   0febfc00/06cae000 level 2
   0febfc00/06cbe000 level 2
   0febfc00/06c0e800 level 2
   0febfc00/06c1e800 level 2
   0febfc00/06c2e800 level 2
   0febfc00/06c3e800 level 2
   0febfc00/06c8e800 level 2
   0febfc00/06c9e800 level 2
   0febfc00/06cae800 level 2
   0febfc00/06cbe800 level 2
   0febfc00/06c0ec00 level 2
   0febfc00/06c1ec00 level 2
   0febfc00/06c2ec00 level 2
   0febfc00/06c3ec00 level 2
   0febfc00/06c8ec00 level 2
   0febfc00/06c9ec00 level 2
   0febfc00/06caec00 level 2
   0febfc00/06cbec00 level 2
   0febfc00/06c0f000 level 2
   0febfc00/06c1f000 level 2
   0febfc00/06c2f000 level 2
   0febfc00/06c3f000 level 2
   0febfc00/06c8f000 level 2
   0febfc00/06c9f000 level 2
   0febfc00/06caf000 level 2
   0febfc00/06cbf000 level 2
   0febfc00/06c0f800 level 2
   0febfc00/06c1f800 level 2
   0febfc00/06c2f800 level 2
   0febfc00/06c3f800 level 2
   0febfc00/06c8f800 level 2
   0febfc00/06c9f800 level 2
   0febfc00/06caf800 level 2
   0febfc00/06cbf800 level 2
   1ff7fc00/16e00000 level 2
   1ff7fc00/16e10000 level 2
   1ff7fc00/16e20000 level 2
   1ff7fc00/16e30000 level 2
   1ff7fc00/16e40000 level 2
   1ff7fc00/16e50000 level 2
   1ff7fc00/16e60000 level 2
   1ff7fc00/16e70000 level 2
   1ff7fc00/16f00000 level 2
   1ff7fc00/16f10000 level 2
   1ff7fc00/16f20000 level 2
   1ff7fc00/16f30000 level 2
   1ff7fc00/16f40000 level 2
   1ff7fc00/16f50000 level 2
   1ff7fc00/16f60000 level 2
   1ff7fc00/16f70000 level 2
   0febfc00/06e04000 level 2
   0febfc00/06e14000 level 2
   0febfc00/06e24000 level 2
   0febfc00/06e34000 level 2
   0febfc00/06e84000 level 2
   0febfc00/06e94000 level 2
   0febfc00/06ea4000 level 2
   0febfc00/06eb4000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_16000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe6fc00/1e000800 level 2
   5fe6fc00/1e000c00 level 2
   7fe6fc00/1e001000 level 2
   7fe6fc00/1e002000 level 2
   5fe6fc00/1e002c00 level 2
   7fe6fc00/1e003000 level 2
   7fe6fc00/1e004000 level 2
   7fe6fc00/1e005000 level 2
   7fe6fc00/1e006000 level 2
   3fe6fc00/1e00cc00 level 2
   3fe6fc00/1e00d400 level 2
   3fe6fc00/1e00dc00 level 2
   3fe6fc00/1e00e400 level 2
   3fe6fc00/1e00ec00 level 2
   3fe6fc00/1e00fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_1e000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e180000))
        return iemDecodeA64_FCVTZS_32S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e190000))
        return iemDecodeA64_FCVTZU_32S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e180000))
        return iemDecodeA64_FCVTZS_64S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e190000))
        return iemDecodeA64_FCVTZU_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe6fc00/1e020800 level 2
   5fe6fc00/1e020c00 level 2
   7fe6fc00/1e021000 level 2
   7fe6fc00/1e022000 level 2
   5fe6fc00/1e022c00 level 2
   7fe6fc00/1e023000 level 2
   7fe6fc00/1e024000 level 2
   7fe6fc00/1e025000 level 2
   7fe6fc00/1e026000 level 2
   3fe6fc00/1e02cc00 level 2
   3fe6fc00/1e02d400 level 2
   3fe6fc00/1e02dc00 level 2
   3fe6fc00/1e02e400 level 2
   3fe6fc00/1e02ec00 level 2
   3fe6fc00/1e02fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_1e020800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e020000))
        return iemDecodeA64_SCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e030000))
        return iemDecodeA64_UCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e020000))
        return iemDecodeA64_SCVTF_S64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e030000))
        return iemDecodeA64_UCVTF_S64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe6fc00/4e000800 level 2
   5fe6fc00/4e020800 level 2
   5fe6fc00/4e040800 level 2
   5fe6fc00/4e060800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_4e000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe08400)) == UINT32_C(0x2e000000))
        return iemDecodeA64_EXT_asimdext_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06000800 level 1
   mask=0x58060000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%16 (0x5) multi-if=%31 (0xa) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06000800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_5fe6fc00_4e000800_2,
        iemDecodeA64_5fe6fc00_4e000800_2,
        iemDecodeA64_5fe6fc00_4e000800_2,
        iemDecodeA64_5fe6fc00_4e000800_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_BRAAZ_64_branch_reg,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x58060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000000c)) /* bit 27 L 2 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe6fc00/4e000c00 level 2
   5fe6fc00/4e020c00 level 2
   5fe6fc00/4e040c00 level 2
   5fe6fc00/4e060c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_4e000c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e000c00))
        return iemDecodeA64_DUP_asimdins_DR_r(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08400)) == UINT32_C(0x6e000400))
        return iemDecodeA64_INS_asimdins_IV_v(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06000c00 level 1
   mask=0x58060000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%16 (0x5) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06000c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_DUP_asimdins_DR_r,
        iemDecodeA64_DUP_asimdins_DR_r,
        iemDecodeA64_DUP_asimdins_DR_r,
        iemDecodeA64_DUP_asimdins_DR_r,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_5fe6fc00_4e000c00_2,
        iemDecodeA64_5fe6fc00_4e000c00_2,
        iemDecodeA64_5fe6fc00_4e000c00_2,
        iemDecodeA64_5fe6fc00_4e000c00_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_BRABZ_64_branch_reg,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x58060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000000c)) /* bit 27 L 2 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/4e001000 level 2
   7fe6fc00/4e021000 level 2
   7fe6fc00/4e041000 level 2
   7fe6fc00/4e061000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_4e001000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e001000))
        return iemDecodeA64_TBX_asimdtbl_L1_1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06001000 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%31 (0x14) multi-if=%16 (0xa) reuse=%14 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06001000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TBX_asimdtbl_L1_1,
        iemDecodeA64_TBX_asimdtbl_L1_1,
        iemDecodeA64_TBX_asimdtbl_L1_1,
        iemDecodeA64_TBX_asimdtbl_L1_1,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe6fc00_4e001000_2,
        iemDecodeA64_7fe6fc00_4e001000_2,
        iemDecodeA64_7fe6fc00_4e001000_2,
        iemDecodeA64_7fe6fc00_4e001000_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_SHA1P_QSV_cryptosha3,
        iemDecodeA64_SHA1P_QSV_cryptosha3,
        iemDecodeA64_SHA1P_QSV_cryptosha3,
        iemDecodeA64_SHA1P_QSV_cryptosha3,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe4fc00/1e001400 level 2
   bfe4fc00/1e002400 level 2
   bfe4fc00/1e003400 level 2
   bfe4fc00/1e004400 level 2
   bfe4fc00/1e004c00 level 2
   bfe4fc00/1e005400 level 2
   bfe4fc00/1e005c00 level 2
   bfe4fc00/1e006400 level 2
   bfe4fc00/1e006c00 level 2
   bfe4fc00/1e007400 level 2
   bfe4fc00/1e007c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe4fc00_1e001400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e020000))
        return iemDecodeA64_SCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e030000))
        return iemDecodeA64_UCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e180000))
        return iemDecodeA64_FCVTZS_32S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e190000))
        return iemDecodeA64_FCVTZU_32S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe4fc00/9e001400 level 2
   bfe4fc00/9e002400 level 2
   bfe4fc00/9e003400 level 2
   bfe4fc00/9e004400 level 2
   bfe4fc00/9e004c00 level 2
   bfe4fc00/9e005400 level 2
   bfe4fc00/9e005c00 level 2
   bfe4fc00/9e006400 level 2
   bfe4fc00/9e006c00 level 2
   bfe4fc00/9e007400 level 2
   bfe4fc00/9e007c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe4fc00_9e001400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e020000))
        return iemDecodeA64_SCVTF_S64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e030000))
        return iemDecodeA64_UCVTF_S64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e180000))
        return iemDecodeA64_FCVTZS_64S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e190000))
        return iemDecodeA64_FCVTZU_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06001400 level 1
   07e0fc00/06002400 level 1
   07e0fc00/06003400 level 1
   07e0fc00/06004400 level 1
   07e0fc00/06004c00 level 1
   07e0fc00/06005400 level 1
   07e0fc00/06005c00 level 1
   07e0fc00/06006400 level 1
   07e0fc00/06006c00 level 1
   07e0fc00/06007400 level 1
   07e0fc00/06007c00 level 1
   mask=0xb8040000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06001400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe4fc00_1e001400_2,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_bfe4fc00_9e001400_2,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8040000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e001800 level 2
   7fe1fc00/4e011800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e001800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e001800))
        return iemDecodeA64_UZP1_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06001800 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06001800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_UZP1_asimdperm_only,
        iemDecodeA64_UZP1_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e001800_2,
        iemDecodeA64_7fe1fc00_4e001800_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e1fc00/16001c00 level 2
   f7e1fc00/16004800 level 2
   f7e1fc00/16008400 level 2
   f7e1fc00/16008c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e1fc00_16001c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e020000))
        return iemDecodeA64_SCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e180000))
        return iemDecodeA64_FCVTZS_32S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e1fc00/16011c00 level 2
   f7e1fc00/16014800 level 2
   f7e1fc00/16018400 level 2
   f7e1fc00/16018c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e1fc00_16011c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e030000))
        return iemDecodeA64_UCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e190000))
        return iemDecodeA64_FCVTZU_32S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e1fc00/96001c00 level 2
   f7e1fc00/96004800 level 2
   f7e1fc00/96008400 level 2
   f7e1fc00/96008c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e1fc00_96001c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e020000))
        return iemDecodeA64_SCVTF_S64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e180000))
        return iemDecodeA64_FCVTZS_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e1fc00/96011c00 level 2
   f7e1fc00/96014800 level 2
   f7e1fc00/96018400 level 2
   f7e1fc00/96018c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e1fc00_96011c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e030000))
        return iemDecodeA64_UCVTF_S64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e190000))
        return iemDecodeA64_FCVTZU_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06001c00 level 1
   mask=0xf0010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06001c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_f7e1fc00_16001c00_2,
        iemDecodeA64_f7e1fc00_16011c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_INS_asimdins_IR_r,
        iemDecodeA64_INS_asimdins_IR_r,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e1fc00_96001c00_2,
        iemDecodeA64_f7e1fc00_96011c00_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/4e002000 level 2
   7fe6fc00/4e022000 level 2
   7fe6fc00/4e042000 level 2
   7fe6fc00/4e062000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_4e002000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e002000))
        return iemDecodeA64_TBL_asimdtbl_L2_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06002000 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%31 (0x14) multi-if=%16 (0xa) reuse=%14 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06002000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TBL_asimdtbl_L2_2,
        iemDecodeA64_TBL_asimdtbl_L2_2,
        iemDecodeA64_TBL_asimdtbl_L2_2,
        iemDecodeA64_TBL_asimdtbl_L2_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe6fc00_4e002000_2,
        iemDecodeA64_7fe6fc00_4e002000_2,
        iemDecodeA64_7fe6fc00_4e002000_2,
        iemDecodeA64_7fe6fc00_4e002000_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_SHA1M_QSV_cryptosha3,
        iemDecodeA64_SHA1M_QSV_cryptosha3,
        iemDecodeA64_SHA1M_QSV_cryptosha3,
        iemDecodeA64_SHA1M_QSV_cryptosha3,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e002800 level 2
   7fe1fc00/4e012800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e002800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e002800))
        return iemDecodeA64_TRN1_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06002800 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06002800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_TRN1_asimdperm_only,
        iemDecodeA64_TRN1_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e002800_2,
        iemDecodeA64_7fe1fc00_4e002800_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe6fc00/4e002c00 level 2
   5fe6fc00/4e022c00 level 2
   5fe6fc00/4e042c00 level 2
   5fe6fc00/4e062c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_4e002c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08400)) == UINT32_C(0x6e000400))
        return iemDecodeA64_INS_asimdins_IV_v(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x4e002c00))
        return iemDecodeA64_SMOV_asimdins_X_x(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06002c00 level 1
   mask=0x58060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06002c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SMOV_asimdins_W_w,
        iemDecodeA64_SMOV_asimdins_W_w,
        iemDecodeA64_SMOV_asimdins_W_w,
        iemDecodeA64_SMOV_asimdins_W_w,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_5fe6fc00_4e002c00_2,
        iemDecodeA64_5fe6fc00_4e002c00_2,
        iemDecodeA64_5fe6fc00_4e002c00_2,
        iemDecodeA64_5fe6fc00_4e002c00_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x58060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000000c)) /* bit 27 L 2 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/4e003000 level 2
   7fe6fc00/4e023000 level 2
   7fe6fc00/4e043000 level 2
   7fe6fc00/4e063000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_4e003000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e003000))
        return iemDecodeA64_TBX_asimdtbl_L2_2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06003000 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%31 (0x14) multi-if=%16 (0xa) reuse=%14 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06003000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TBX_asimdtbl_L2_2,
        iemDecodeA64_TBX_asimdtbl_L2_2,
        iemDecodeA64_TBX_asimdtbl_L2_2,
        iemDecodeA64_TBX_asimdtbl_L2_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe6fc00_4e003000_2,
        iemDecodeA64_7fe6fc00_4e003000_2,
        iemDecodeA64_7fe6fc00_4e003000_2,
        iemDecodeA64_7fe6fc00_4e003000_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_SHA1SU0_VVV_cryptosha3,
        iemDecodeA64_SHA1SU0_VVV_cryptosha3,
        iemDecodeA64_SHA1SU0_VVV_cryptosha3,
        iemDecodeA64_SHA1SU0_VVV_cryptosha3,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e003800 level 2
   7fe1fc00/4e013800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e003800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e003800))
        return iemDecodeA64_ZIP1_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06003800 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06003800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ZIP1_asimdperm_only,
        iemDecodeA64_ZIP1_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e003800_2,
        iemDecodeA64_7fe1fc00_4e003800_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* efe6fc00/0e003c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe6fc00_0e003c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0e003c00))
        return iemDecodeA64_UMOV_asimdins_W_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e180000))
        return iemDecodeA64_FCVTZS_32S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e190000))
        return iemDecodeA64_FCVTZU_32S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe6fc00/0e023c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe6fc00_0e023c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x0e003c00))
        return iemDecodeA64_UMOV_asimdins_W_w(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e020000))
        return iemDecodeA64_SCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e030000))
        return iemDecodeA64_UCVTF_S32_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe6fc00/8e003c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe6fc00_8e003c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e180000))
        return iemDecodeA64_FCVTZS_64S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e190000))
        return iemDecodeA64_FCVTZU_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* efe6fc00/8e023c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_efe6fc00_8e023c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e020000))
        return iemDecodeA64_SCVTF_S64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e030000))
        return iemDecodeA64_UCVTF_S64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06003c00 level 1
   mask=0xe8060000 entries=0x40 children=0x1f valid=%48 (0x1f) leaf=%42 (0x1b) multi-if=%6 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06003c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_efe6fc00_0e003c00_2,
        iemDecodeA64_efe6fc00_0e023c00_2,
        iemDecodeA64_UMOV_asimdins_W_w,
        iemDecodeA64_UMOV_asimdins_W_w,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_UMOV_asimdins_X_x,
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_INS_asimdins_IV_v,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_efe6fc00_8e003c00_2,
        iemDecodeA64_efe6fc00_8e023c00_2,
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0xe8060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000004)) /* bit 27 L 1 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000038)) /* bit 29 L 3 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/4e004000 level 2
   7fe6fc00/4e024000 level 2
   7fe6fc00/4e044000 level 2
   7fe6fc00/4e064000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_4e004000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e004000))
        return iemDecodeA64_TBL_asimdtbl_L3_3(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06004000 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%31 (0x14) multi-if=%16 (0xa) reuse=%14 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06004000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TBL_asimdtbl_L3_3,
        iemDecodeA64_TBL_asimdtbl_L3_3,
        iemDecodeA64_TBL_asimdtbl_L3_3,
        iemDecodeA64_TBL_asimdtbl_L3_3,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe6fc00_4e004000_2,
        iemDecodeA64_7fe6fc00_4e004000_2,
        iemDecodeA64_7fe6fc00_4e004000_2,
        iemDecodeA64_7fe6fc00_4e004000_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_SHA256H_QQV_cryptosha3,
        iemDecodeA64_SHA256H_QQV_cryptosha3,
        iemDecodeA64_SHA256H_QQV_cryptosha3,
        iemDecodeA64_SHA256H_QQV_cryptosha3,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06004800 level 1
   mask=0xf0010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06004800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_f7e1fc00_16001c00_2,
        iemDecodeA64_f7e1fc00_16011c00_2,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e1fc00_96001c00_2,
        iemDecodeA64_f7e1fc00_96011c00_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_EOR3_VVV16_crypto4,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/4e005000 level 2
   7fe6fc00/4e025000 level 2
   7fe6fc00/4e045000 level 2
   7fe6fc00/4e065000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_4e005000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e005000))
        return iemDecodeA64_TBX_asimdtbl_L3_3(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06005000 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%31 (0x14) multi-if=%16 (0xa) reuse=%14 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06005000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TBX_asimdtbl_L3_3,
        iemDecodeA64_TBX_asimdtbl_L3_3,
        iemDecodeA64_TBX_asimdtbl_L3_3,
        iemDecodeA64_TBX_asimdtbl_L3_3,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe6fc00_4e005000_2,
        iemDecodeA64_7fe6fc00_4e005000_2,
        iemDecodeA64_7fe6fc00_4e005000_2,
        iemDecodeA64_7fe6fc00_4e005000_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_SHA256H2_QQV_cryptosha3,
        iemDecodeA64_SHA256H2_QQV_cryptosha3,
        iemDecodeA64_SHA256H2_QQV_cryptosha3,
        iemDecodeA64_SHA256H2_QQV_cryptosha3,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e005800 level 2
   7fe1fc00/4e015800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e005800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e005800))
        return iemDecodeA64_UZP2_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06005800 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06005800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_UZP2_asimdperm_only,
        iemDecodeA64_UZP2_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e005800_2,
        iemDecodeA64_7fe1fc00_4e005800_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/4e006000 level 2
   7fe6fc00/4e026000 level 2
   7fe6fc00/4e046000 level 2
   7fe6fc00/4e066000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_4e006000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e006000))
        return iemDecodeA64_TBL_asimdtbl_L4_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06006000 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%31 (0x14) multi-if=%16 (0xa) reuse=%14 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06006000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TBL_asimdtbl_L4_4,
        iemDecodeA64_TBL_asimdtbl_L4_4,
        iemDecodeA64_TBL_asimdtbl_L4_4,
        iemDecodeA64_TBL_asimdtbl_L4_4,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe6fc00_4e006000_2,
        iemDecodeA64_7fe6fc00_4e006000_2,
        iemDecodeA64_7fe6fc00_4e006000_2,
        iemDecodeA64_7fe6fc00_4e006000_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_SHA256SU1_VVV_cryptosha3,
        iemDecodeA64_SHA256SU1_VVV_cryptosha3,
        iemDecodeA64_SHA256SU1_VVV_cryptosha3,
        iemDecodeA64_SHA256SU1_VVV_cryptosha3,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e006800 level 2
   7fe1fc00/4e016800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e006800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e006800))
        return iemDecodeA64_TRN2_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06006800 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06006800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_TRN2_asimdperm_only,
        iemDecodeA64_TRN2_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e006800_2,
        iemDecodeA64_7fe1fc00_4e006800_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e007000 level 2
   7fe1fc00/4e017000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e007000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e007000))
        return iemDecodeA64_TBX_asimdtbl_L4_4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06007000 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06007000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_TBX_asimdtbl_L4_4,
        iemDecodeA64_TBX_asimdtbl_L4_4,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e007000_2,
        iemDecodeA64_7fe1fc00_4e007000_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e007800 level 2
   7fe1fc00/4e017800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e007800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e007800))
        return iemDecodeA64_ZIP2_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce000000))
        return iemDecodeA64_EOR3_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06007800 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06007800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_ZIP2_asimdperm_only,
        iemDecodeA64_ZIP2_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e007800_2,
        iemDecodeA64_7fe1fc00_4e007800_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_EXT_asimdext_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0febfc00/0e028000 level 2
   0febfc00/0e028800 level 2
   0febfc00/0e029000 level 2
   0febfc00/0e029800 level 2
   0febfc00/0e029c00 level 2
   0febfc00/0e02a000 level 2
   0febfc00/0e02a400 level 2
   0febfc00/0e02a800 level 2
   0febfc00/0e02ac00 level 2
   0febfc00/0e02b000 level 2
   0febfc00/0e02b400 level 2
   0febfc00/0e02b800 level 2
   0febfc00/0e02bc00 level 2
   0febfc00/0e02c000 level 2
   0febfc00/0e02c800 level 2
   0febfc00/0e02d000 level 2
   0febfc00/0e02d800 level 2
   0febfc00/0e02e000 level 2
   0febfc00/0e02e800 level 2
   0febfc00/0e02f000 level 2
   0febfc00/0e02f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e028000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e020000))
        return iemDecodeA64_SCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e020000))
        return iemDecodeA64_SCVTF_S64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e038000 level 2
   0febfc00/0e038800 level 2
   0febfc00/0e039000 level 2
   0febfc00/0e039800 level 2
   0febfc00/0e039c00 level 2
   0febfc00/0e03a000 level 2
   0febfc00/0e03a400 level 2
   0febfc00/0e03a800 level 2
   0febfc00/0e03ac00 level 2
   0febfc00/0e03b000 level 2
   0febfc00/0e03b400 level 2
   0febfc00/0e03b800 level 2
   0febfc00/0e03bc00 level 2
   0febfc00/0e03c000 level 2
   0febfc00/0e03c800 level 2
   0febfc00/0e03d000 level 2
   0febfc00/0e03d800 level 2
   0febfc00/0e03e000 level 2
   0febfc00/0e03e800 level 2
   0febfc00/0e03f000 level 2
   0febfc00/0e03f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e038000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e030000))
        return iemDecodeA64_UCVTF_S32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e030000))
        return iemDecodeA64_UCVTF_S64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e088000 level 2
   0febfc00/0e088800 level 2
   0febfc00/0e089000 level 2
   0febfc00/0e089800 level 2
   0febfc00/0e089c00 level 2
   0febfc00/0e08a000 level 2
   0febfc00/0e08a400 level 2
   0febfc00/0e08a800 level 2
   0febfc00/0e08ac00 level 2
   0febfc00/0e08b000 level 2
   0febfc00/0e08b400 level 2
   0febfc00/0e08b800 level 2
   0febfc00/0e08bc00 level 2
   0febfc00/0e08c000 level 2
   0febfc00/0e08c800 level 2
   0febfc00/0e08d000 level 2
   0febfc00/0e08d800 level 2
   0febfc00/0e08e000 level 2
   0febfc00/0e08e800 level 2
   0febfc00/0e08f000 level 2
   0febfc00/0e08f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e088000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e180000))
        return iemDecodeA64_FCVTZS_32S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e180000))
        return iemDecodeA64_FCVTZS_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e098000 level 2
   0febfc00/0e098800 level 2
   0febfc00/0e099000 level 2
   0febfc00/0e099800 level 2
   0febfc00/0e099c00 level 2
   0febfc00/0e09a000 level 2
   0febfc00/0e09a400 level 2
   0febfc00/0e09a800 level 2
   0febfc00/0e09ac00 level 2
   0febfc00/0e09b000 level 2
   0febfc00/0e09b400 level 2
   0febfc00/0e09b800 level 2
   0febfc00/0e09bc00 level 2
   0febfc00/0e09c000 level 2
   0febfc00/0e09c800 level 2
   0febfc00/0e09d000 level 2
   0febfc00/0e09d800 level 2
   0febfc00/0e09e000 level 2
   0febfc00/0e09e800 level 2
   0febfc00/0e09f000 level 2
   0febfc00/0e09f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e098000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e190000))
        return iemDecodeA64_FCVTZU_32S_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e190000))
        return iemDecodeA64_FCVTZU_64S_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06008000 level 1
   07e0fc00/06008800 level 1
   07e0fc00/06009000 level 1
   07e0fc00/06009800 level 1
   07e0fc00/06009c00 level 1
   07e0fc00/0600a000 level 1
   07e0fc00/0600a400 level 1
   07e0fc00/0600a800 level 1
   07e0fc00/0600ac00 level 1
   07e0fc00/0600b000 level 1
   07e0fc00/0600b400 level 1
   07e0fc00/0600b800 level 1
   07e0fc00/0600bc00 level 1
   07e0fc00/0600c000 level 1
   07e0fc00/0600c800 level 1
   07e0fc00/0600d000 level 1
   07e0fc00/0600d800 level 1
   07e0fc00/0600e000 level 1
   07e0fc00/0600e800 level 1
   07e0fc00/0600f000 level 1
   07e0fc00/0600f800 level 1
   mask=0x80b0000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%0 (0x0) multi-if=%75 (0xc) reuse=%50 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06008000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_0febfc00_0e028000_2,
        iemDecodeA64_0febfc00_0e038000_2,
        iemDecodeA64_0febfc00_0e088000_2,
        iemDecodeA64_0febfc00_0e098000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06008400 level 1
   mask=0xf0010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06008400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_f7e1fc00_16001c00_2,
        iemDecodeA64_f7e1fc00_16011c00_2,
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_SQRDMLAH_asisdsame2_only,
        iemDecodeA64_SQRDMLAH_asisdsame2_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e1fc00_96001c00_2,
        iemDecodeA64_f7e1fc00_96011c00_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06008c00 level 1
   mask=0xf0010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06008c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_f7e1fc00_16001c00_2,
        iemDecodeA64_f7e1fc00_16011c00_2,
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_SQRDMLSH_asisdsame2_only,
        iemDecodeA64_SQRDMLSH_asisdsame2_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e1fc00_96001c00_2,
        iemDecodeA64_f7e1fc00_96011c00_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06009400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06009400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0600c400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0600c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FMLALLBB_asimdsame2_G,
        iemDecodeA64_FMLALLBB_asimdsame2_G,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FMLALLTB_asimdsame2_G,
        iemDecodeA64_FMLALLTB_asimdsame2_G,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0600cc00 level 1
   07e0fc00/0600d400 level 1
   07e0fc00/0600dc00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0600cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0600e400 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0600e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0600ec00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0600ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FMMLA_asimd_FP8FP16,
        iemDecodeA64_FMMLA_asimd_FP8FP16,
        iemDecodeA64_FMMLA_asimd_FP8FP16,
        iemDecodeA64_FMMLA_asimd_FP8FP16,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0600f400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0600f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FCVTN_asimdsame2_H,
        iemDecodeA64_FCVTN_asimdsame2_H,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe5fc00_1e000000_2,
        iemDecodeA64_7fe5fc00_1e010000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FCVTN_asimdsame2_H,
        iemDecodeA64_FCVTN_asimdsame2_H,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0600fc00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0600fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_FDOT_asimdsame2_DD,
        iemDecodeA64_FDOT_asimdsame2_DD,
        iemDecodeA64_FDOT_asimdsame2_DD,
        iemDecodeA64_FDOT_asimdsame2_DD,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_5fe6fc00_1e000800_2,
        iemDecodeA64_5fe6fc00_1e020800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/0e200000 level 2
   1ff7fc00/0e210000 level 2
   1ff7fc00/0e220000 level 2
   1ff7fc00/0e230000 level 2
   1ff7fc00/0e240000 level 2
   1ff7fc00/0e250000 level 2
   1ff7fc00/0e260000 level 2
   1ff7fc00/0e270000 level 2
   1ff7fc00/0e300000 level 2
   1ff7fc00/0e310000 level 2
   1ff7fc00/0e320000 level 2
   1ff7fc00/0e330000 level 2
   1ff7fc00/0e340000 level 2
   1ff7fc00/0e350000 level 2
   1ff7fc00/0e360000 level 2
   1ff7fc00/0e370000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_0e200000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e200000))
        return iemDecodeA64_SADDL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e200000))
        return iemDecodeA64_UADDL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce200000))
        return iemDecodeA64_BCAX_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/16370000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_16370000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xd63f0000))
        return iemDecodeA64_BLR_64_branch_reg(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e200000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e200000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e200000))
        return iemDecodeA64_FCVTNS_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e280000))
        return iemDecodeA64_FCVTPS_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e200000))
        return iemDecodeA64_FCVTNS_64S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e280000))
        return iemDecodeA64_FCVTPS_64S_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e210000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e210000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e210000))
        return iemDecodeA64_FCVTNU_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e290000))
        return iemDecodeA64_FCVTPU_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e210000))
        return iemDecodeA64_FCVTNU_64S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e290000))
        return iemDecodeA64_FCVTPU_64S_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e220000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e220000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e220000))
        return iemDecodeA64_SCVTF_S32_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e220000))
        return iemDecodeA64_SCVTF_S64_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e2a0000))
        return iemDecodeA64_FCVTNS_sisd_64S(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e230000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e230000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e230000))
        return iemDecodeA64_UCVTF_S32_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e230000))
        return iemDecodeA64_UCVTF_S64_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e2b0000))
        return iemDecodeA64_FCVTNU_sisd_64S(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e240000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e240000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e240000))
        return iemDecodeA64_FCVTAS_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e240000))
        return iemDecodeA64_FCVTAS_64S_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e250000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e250000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e250000))
        return iemDecodeA64_FCVTAU_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e250000))
        return iemDecodeA64_FCVTAU_64S_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e300000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e300000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e300000))
        return iemDecodeA64_FCVTMS_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e380000))
        return iemDecodeA64_FCVTZS_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e300000))
        return iemDecodeA64_FCVTMS_64S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e380000))
        return iemDecodeA64_FCVTZS_64S_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e310000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e310000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e310000))
        return iemDecodeA64_FCVTMU_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e390000))
        return iemDecodeA64_FCVTZU_32S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e310000))
        return iemDecodeA64_FCVTMU_64S_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e390000))
        return iemDecodeA64_FCVTZU_64S_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e320000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e320000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e320000))
        return iemDecodeA64_FCVTPS_sisd_64S(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e3a0000))
        return iemDecodeA64_FCVTAS_sisd_64S(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e330000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e330000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e330000))
        return iemDecodeA64_FCVTPU_sisd_64S(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e3b0000))
        return iemDecodeA64_FCVTAU_sisd_64S(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e340000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e340000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e340000))
        return iemDecodeA64_FCVTMS_sisd_64S(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e3c0000))
        return iemDecodeA64_SCVTF_sisd_64S(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e350000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e350000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e350000))
        return iemDecodeA64_FCVTMU_sisd_64S(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e3d0000))
        return iemDecodeA64_UCVTF_sisd_64S(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x6200000/0x18170000
   mask=0x18170000 entries=0x40 children=0x30 valid=%75 (0x30) leaf=%6 (0x4) multi-if=%69 (0x2c) reuse=%47 (0x1e) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06200000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_1ff7fc00_0e200000_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_1ff7fc00_16370000_2,
        iemDecodeA64_1ff7fc00_1e200000_2,
        iemDecodeA64_1ff7fc00_1e210000_2,
        iemDecodeA64_1ff7fc00_1e220000_2,
        iemDecodeA64_1ff7fc00_1e230000_2,
        iemDecodeA64_1ff7fc00_1e240000_2,
        iemDecodeA64_1ff7fc00_1e250000_2,
        iemDecodeA64_FMOV_32S_float2int,
        iemDecodeA64_FMOV_S32_float2int,
        iemDecodeA64_1ff7fc00_1e300000_2,
        iemDecodeA64_1ff7fc00_1e310000_2,
        iemDecodeA64_1ff7fc00_1e320000_2,
        iemDecodeA64_1ff7fc00_1e330000_2,
        iemDecodeA64_1ff7fc00_1e340000_2,
        iemDecodeA64_1ff7fc00_1e350000_2,
        iemDecodeA64_FCVTZS_sisd_64S,
        iemDecodeA64_FCVTZU_sisd_64S,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x18170000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000030)) /* bit 27 L 2 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e200400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e200400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e200400))
        return iemDecodeA64_SHADD_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06200400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06200400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e200400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UHADD_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06200800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06200800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_REV64_asimdmisc_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMUL_S_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_REV32_asimdmisc_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_REV64_asimdmisc_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SHA1H_SS_cryptosha2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_REV32_asimdmisc_R,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_BLRAAZ_64_branch_reg,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06200c00 level 1
   mask=0xf8000000 entries=0x20 children=0xd valid=%41 (0xd) leaf=%41 (0xd) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06200c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQADD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQADD_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQADD_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UQADD_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQADD_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_BLRABZ_64_branch_reg,
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e201000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e201000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e201000))
        return iemDecodeA64_SADDW_asimddiff_W(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe01fe0)) == UINT32_C(0x1e201000))
        return iemDecodeA64_FMOV_S_floatimm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06201000 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06201000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e201000_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UADDW_asimddiff_W,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e201400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e201400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e201400))
        return iemDecodeA64_SRHADD_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06201400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06201400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e201400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_URHADD_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* b7e0fc00/16201800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_b7e0fc00_16201800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e201800))
        return iemDecodeA64_FDIV_S_floatdp2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e281800))
        return iemDecodeA64_SHA1SU1_VV_cryptosha2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06201800 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06201800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_REV16_asimdmisc_R,
        iemDecodeA64_b7e0fc00_16201800_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e201c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e201c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e201c00))
        return iemDecodeA64_AND_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e200c00))
        return iemDecodeA64_FCSEL_S_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06201c00 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06201c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e201c00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_EOR_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1e202000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1e202000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x1e202000))
        return iemDecodeA64_FCMP_S_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x1e202010))
        return iemDecodeA64_FCMPE_S_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0x1e202008))
        return iemDecodeA64_FCMP_SZ_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0x1e202018))
        return iemDecodeA64_FCMPE_SZ_floatcmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06202000 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06202000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSUBL_asimddiff_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1e202000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USUBL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e202400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e202400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e202400))
        return iemDecodeA64_SHSUB_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06202400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06202400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e202400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UHSUB_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0e202800 level 2
   ffe0fc00/4e202800 level 2
   7fe0fc00/0e602800 level 2
   7fe0fc00/4e602800 level 2
   7fe0fc00/0ea02800 level 2
   7fe0fc00/4ea02800 level 2
   7fe0fc00/0ee02800 level 2
   7fe0fc00/4ee02800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0e202800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e202800))
        return iemDecodeA64_SADDLP_asimdmisc_P(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e212800))
        return iemDecodeA64_XTN_asimdmisc_N(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/2e202800 level 2
   ffe0fc00/6e202800 level 2
   7fe0fc00/2e602800 level 2
   7fe0fc00/6e602800 level 2
   7fe0fc00/2ea02800 level 2
   7fe0fc00/6ea02800 level 2
   7fe0fc00/2ee02800 level 2
   7fe0fc00/6ee02800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2e202800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e202800))
        return iemDecodeA64_UADDLP_asimdmisc_P(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e212800))
        return iemDecodeA64_SQXTUN_asimdmisc_N(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06202800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%25 (0x8) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06202800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e202800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FADD_S_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2e202800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0e202800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SHA256SU0_VV_cryptosha2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2e202800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQXTUN_asisdmisc_N,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06202c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06202c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSUB_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQSUB_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQSUB_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UQSUB_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQSUB_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e203000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e203000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e203000))
        return iemDecodeA64_SSUBW_asimddiff_W(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe01fe0)) == UINT32_C(0x1e201000))
        return iemDecodeA64_FMOV_S_floatimm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06203000 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06203000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e203000_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_USUBW_asimddiff_W,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e203400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e203400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e203400))
        return iemDecodeA64_CMGT_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06203400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06203400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e203400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_CMHI_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe2fc00/0e203800 level 2
   ffe0fc00/0e603800 level 2
   ffe0fc00/4e603800 level 2
   ffe0fc00/0ee03800 level 2
   ffe0fc00/4ee03800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe2fc00_0e203800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e203800))
        return iemDecodeA64_SUQADD_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e303800))
        return iemDecodeA64_SADDLV_asimdall_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe2fc00/1e203800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe2fc00_1e203800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff3ffc00)) == UINT32_C(0x5e203800))
        return iemDecodeA64_SUQADD_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e203800))
        return iemDecodeA64_FSUB_S_floatdp2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe2fc00/2e203800 level 2
   ffe0fc00/2e603800 level 2
   ffe0fc00/6e603800 level 2
   ffe0fc00/2ee03800 level 2
   ffe0fc00/6ee03800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe2fc00_2e203800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e203800))
        return iemDecodeA64_USQADD_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e213800))
        return iemDecodeA64_SHLL_asimdmisc_S(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e303800))
        return iemDecodeA64_UADDLV_asimdall_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06203800 level 1
   mask=0xb8020000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%38 (0xc) multi-if=%9 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06203800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bfe2fc00_0e203800_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe2fc00_1e203800_2,
        iemDecodeA64_FSUB_S_floatdp2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_bfe2fc00_2e203800_2,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_USQADD_asisdmisc_R,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8020000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000001)) /* bit 17 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e203c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e203c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e203c00))
        return iemDecodeA64_CMGE_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e200c00))
        return iemDecodeA64_FCSEL_S_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06203c00 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06203c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e203c00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_CMHS_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe6fc00/0e204000 level 2
   5fe6fc00/0e224000 level 2
   5fe6fc00/0e244000 level 2
   5fe6fc00/0e264000 level 2
   5fecfc00/0e604000 level 2
   5fecfc00/0e644000 level 2
   5fecfc00/0e684000 level 2
   5fecfc00/0e6c4000 level 2
   5fecfc00/4e604000 level 2
   5fecfc00/4e644000 level 2
   5fecfc00/4e684000 level 2
   5fecfc00/4e6c4000 level 2
   0febfc00/0ee84000 level 2
   0febfc00/0ee94000 level 2
   0febfc00/0eea4000 level 2
   0febfc00/0eeb4000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_0e204000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e204000))
        return iemDecodeA64_ADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e204000))
        return iemDecodeA64_RADDHN_asimddiff_N(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe6fc00/1e204000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_1e204000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e204000))
        return iemDecodeA64_FMOV_S_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e214000))
        return iemDecodeA64_FNEG_S_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e284000))
        return iemDecodeA64_FRINT32Z_S_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e294000))
        return iemDecodeA64_FRINT64Z_S_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe6fc00/1e244000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_1e244000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e244000))
        return iemDecodeA64_FRINTN_S_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e254000))
        return iemDecodeA64_FRINTM_S_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe6fc00/1e264000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_1e264000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e264000))
        return iemDecodeA64_FRINTA_S_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e274000))
        return iemDecodeA64_FRINTX_S_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe6fc00/4e204000 level 2
   5fe6fc00/4e224000 level 2
   5fe6fc00/4e244000 level 2
   5fe6fc00/4e264000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe6fc00_4e204000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e204000))
        return iemDecodeA64_ADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e204000))
        return iemDecodeA64_RADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce200000))
        return iemDecodeA64_BCAX_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06204000 level 1
   mask=0x58060000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%0 (0x0) multi-if=%47 (0xf) reuse=%31 (0xa) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06204000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_1e204000_2,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_5fe6fc00_1e244000_2,
        iemDecodeA64_5fe6fc00_1e264000_2,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_5fe6fc00_4e204000_2,
        iemDecodeA64_5fe6fc00_4e204000_2,
        iemDecodeA64_5fe6fc00_4e204000_2,
        iemDecodeA64_5fe6fc00_4e204000_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x58060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000000c)) /* bit 27 L 2 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e204400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e204400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e204400))
        return iemDecodeA64_SSHL_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06204400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06204400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e204400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_USHL_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0e204800 level 2
   7fe0fc00/0e604800 level 2
   7fe0fc00/4e604800 level 2
   7fe0fc00/0ee04800 level 2
   7fe0fc00/4ee04800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0e204800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e204800))
        return iemDecodeA64_CLS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e214800))
        return iemDecodeA64_SQXTN_asimdmisc_N(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/2e204800 level 2
   ffe0fc00/6e204800 level 2
   7fe0fc00/2e604800 level 2
   7fe0fc00/6e604800 level 2
   7fe0fc00/2ee04800 level 2
   7fe0fc00/6ee04800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2e204800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e204800))
        return iemDecodeA64_CLZ_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e214800))
        return iemDecodeA64_UQXTN_asimdmisc_N(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/4e204800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_4e204800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e204800))
        return iemDecodeA64_CLS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e214800))
        return iemDecodeA64_SQXTN_asimdmisc_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x4e284800))
        return iemDecodeA64_AESE_B_cryptoaes(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06204800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%25 (0x8) multi-if=%12 (0x4) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06204800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e204800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMAX_S_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2e204800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_4e204800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQXTN_asisdmisc_N,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2e204800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQXTN_asisdmisc_N,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06204c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06204c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UQSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e205000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e205000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e205000))
        return iemDecodeA64_SABAL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe01fe0)) == UINT32_C(0x1e201000))
        return iemDecodeA64_FMOV_S_floatimm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06205000 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06205000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e205000_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UABAL_asimddiff_L,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e205400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e205400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e205400))
        return iemDecodeA64_SRSHL_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06205400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06205400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e205400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_URSHL_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e205800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e205800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e205800))
        return iemDecodeA64_CNT_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x1e205800))
        return iemDecodeA64_FMIN_S_floatdp2(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x4e285800))
        return iemDecodeA64_AESD_B_cryptoaes(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06205800 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06205800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e205800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_NOT_asimdmisc_R,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06205c00 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%38 (0xc) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06205c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQRSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQRSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQRSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UQRSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQRSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/4e206000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_4e206000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e206000))
        return iemDecodeA64_SUBHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce200000))
        return iemDecodeA64_BCAX_VVV16_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06206000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%25 (0x4) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06206000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SUBHN_asimddiff_N,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_RSUBHN_asimddiff_N,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_4e206000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_RSUBHN_asimddiff_N,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e206400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e206400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e206400))
        return iemDecodeA64_SMAX_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06206400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06206400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e206400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UMAX_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0e206800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0e206800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e206800))
        return iemDecodeA64_SADALP_asimdmisc_P(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e216800))
        return iemDecodeA64_FCVTN_asimdmisc_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x4e286800))
        return iemDecodeA64_AESMC_B_cryptoaes(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06206800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06206800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0e206800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMAXNM_S_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UADALP_asimdmisc_P,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e206c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e206c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e206c00))
        return iemDecodeA64_SMIN_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e200c00))
        return iemDecodeA64_FCSEL_S_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06206c00 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06206c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e206c00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UMIN_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e207000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e207000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e207000))
        return iemDecodeA64_SABDL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe01fe0)) == UINT32_C(0x1e201000))
        return iemDecodeA64_FMOV_S_floatimm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06207000 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06207000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e207000_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UABDL_asimddiff_L,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e207400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e207400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e207400))
        return iemDecodeA64_SABD_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06207400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06207400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e207400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UABD_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0e207800 level 2
   7fe0fc00/0e607800 level 2
   7fe0fc00/4e607800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0e207800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e207800))
        return iemDecodeA64_SQABS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e217800))
        return iemDecodeA64_FCVTL_asimdmisc_L(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/2e207800 level 2
   ffe0fc00/6e207800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2e207800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e207800))
        return iemDecodeA64_SQNEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e217800))
        return iemDecodeA64_F1CVTL_asimdmisc_V(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/4e207800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_4e207800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e207800))
        return iemDecodeA64_SQABS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e217800))
        return iemDecodeA64_FCVTL_asimdmisc_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x4e287800))
        return iemDecodeA64_AESIMC_B_cryptoaes(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06207800 level 1
   mask=0xf8000000 entries=0x20 children=0xc valid=%38 (0xc) leaf=%25 (0x8) multi-if=%12 (0x4) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06207800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e207800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMINNM_S_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2e207800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_4e207800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQABS_asisdmisc_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2e207800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQNEG_asisdmisc_R,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e207c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e207c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e207c00))
        return iemDecodeA64_SABA_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e200c00))
        return iemDecodeA64_FCSEL_S_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06207c00 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06207c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e207c00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UABA_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BCAX_VVV16_crypto4,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06208000 level 1
   07e0fc00/06a08000 level 1
   07e0fc00/06e08000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06208000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimddiff_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* b7e0fc00/16208400 level 2
   b7e0fc00/16209400 level 2
   b7e0fc00/1620a400 level 2
   b7e0fc00/1620c400 level 2
   b7e0fc00/1620d400 level 2
   b7e0fc00/1620f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_b7e0fc00_16208400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06208400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06208400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_ADD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16208400_2,
        iemDecodeA64_SUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/0e208800 level 2
   7fe0fc00/4e208800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_0e208800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e208800))
        return iemDecodeA64_CMGT_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e218800))
        return iemDecodeA64_FRINTN_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc00/2e208800 level 2
   7fe0fc00/6e208800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_2e208800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e208800))
        return iemDecodeA64_CMGE_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e218800))
        return iemDecodeA64_FRINTA_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06208800 level 1
   mask=0x78000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%12 (0x2) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06208800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_7fe0fc00_0e208800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMUL_S_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_7fe0fc00_2e208800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_0e208800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_7fe0fc00_2e208800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06208c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06208c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CMTST_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMEQ_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06209000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06209000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLAL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_S_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMLAL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMLAL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06209400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06209400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_MLA_asimdsame_only,
        iemDecodeA64_b7e0fc00_16208400_2,
        iemDecodeA64_MLS_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/0e209800 level 2
   7fe0fc00/4e209800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_0e209800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e209800))
        return iemDecodeA64_CMEQ_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e219800))
        return iemDecodeA64_FRINTM_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc00/2e209800 level 2
   7fe0fc00/6e209800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_2e209800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e209800))
        return iemDecodeA64_CMLE_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e219800))
        return iemDecodeA64_FRINTX_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06209800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%6 (0x1) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06209800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_7fe0fc00_0e209800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_7fe0fc00_2e209800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_0e209800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_7fe0fc00_2e209800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06209c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06209c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MUL_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_PMUL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620a000 level 1
   07e0fc00/0660a000 level 1
   07e0fc00/06a0a000 level 1
   07e0fc00/06e0a000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLSL_asimddiff_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLSL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620a400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SMAXP_asimdsame_only,
        iemDecodeA64_b7e0fc00_16208400_2,
        iemDecodeA64_UMAXP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/0620a800 level 2
   f7e0fc00/4620a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_0620a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e20a800))
        return iemDecodeA64_CMLT_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e30a800))
        return iemDecodeA64_SMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e31a800))
        return iemDecodeA64_SMINV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21a800))
        return iemDecodeA64_FCVTNS_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/2620a800 level 2
   f7e0fc00/6620a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_2620a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e30a800))
        return iemDecodeA64_UMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e31a800))
        return iemDecodeA64_UMINV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21a800))
        return iemDecodeA64_FCVTNU_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620a800 level 1
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%38 (0x6) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_0620a800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_2620a800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_0620a800_2,
        iemDecodeA64_FCVTNS_asisdmisc_R,
        iemDecodeA64_f7e0fc00_2620a800_2,
        iemDecodeA64_FCVTNU_asisdmisc_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620ac00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMINP_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMINP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620b000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLSL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_S_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMLSL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMLSL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/1e20b400 level 2
   ffe0fc00/1e20e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_1e20b400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200400))
        return iemDecodeA64_FCCMP_S_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e200410))
        return iemDecodeA64_FCCMPE_S_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620b400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1e20b400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMULH_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SQRDMULH_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQRDMULH_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/0620b800 level 2
   f7e0fc00/4620b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_0620b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e20b800))
        return iemDecodeA64_ABS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e31b800))
        return iemDecodeA64_ADDV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21b800))
        return iemDecodeA64_FCVTMS_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/2620b800 level 2
   f7e0fc00/6620b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_2620b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e20b800))
        return iemDecodeA64_NEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21b800))
        return iemDecodeA64_FCVTMU_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620b800 level 1
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%38 (0x6) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_0620b800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_2620b800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_0620b800_2,
        iemDecodeA64_FCVTMS_asisdmisc_R,
        iemDecodeA64_f7e0fc00_2620b800_2,
        iemDecodeA64_FCVTMU_asisdmisc_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620bc00 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADDP_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ADDP_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0febfc00/0e20c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e20c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
        return iemDecodeA64_SMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
        return iemDecodeA64_UMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e20c000))
        return iemDecodeA64_FABS_S_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e24c000))
        return iemDecodeA64_FRINTP_S_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e21c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e21c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
        return iemDecodeA64_SMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
        return iemDecodeA64_UMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e21c000))
        return iemDecodeA64_FSQRT_S_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e25c000))
        return iemDecodeA64_FRINTZ_S_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e22c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e22c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
        return iemDecodeA64_SMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
        return iemDecodeA64_UMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e22c000))
        return iemDecodeA64_FCVT_DS_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e23c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e23c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
        return iemDecodeA64_SMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
        return iemDecodeA64_UMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e23c000))
        return iemDecodeA64_FCVT_HS_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e27c000))
        return iemDecodeA64_FRINTI_S_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e28c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e28c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
        return iemDecodeA64_SMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
        return iemDecodeA64_UMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e28c000))
        return iemDecodeA64_FRINT32X_S_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e29c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e29c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
        return iemDecodeA64_SMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
        return iemDecodeA64_UMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e29c000))
        return iemDecodeA64_FRINT64X_S_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e2ac000 level 2
   0febfc00/0e2bc000 level 2
   5fe3fc00/0e60c000 level 2
   5fe3fc00/0e61c000 level 2
   5fe3fc00/0e62c000 level 2
   5fe3fc00/0e63c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e2ac000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
        return iemDecodeA64_SMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
        return iemDecodeA64_UMULL_asimddiff_L(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620c000 level 1
   mask=0x80b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%0 (0x0) multi-if=%100 (0x10) reuse=%56 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_0febfc00_0e20c000_2,
        iemDecodeA64_0febfc00_0e21c000_2,
        iemDecodeA64_0febfc00_0e22c000_2,
        iemDecodeA64_0febfc00_0e23c000_2,
        iemDecodeA64_0febfc00_0e28c000_2,
        iemDecodeA64_0febfc00_0e29c000_2,
        iemDecodeA64_0febfc00_0e2ac000_2,
        iemDecodeA64_0febfc00_0e2ac000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620c400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FMAXNM_asimdsame_only,
        iemDecodeA64_b7e0fc00_16208400_2,
        iemDecodeA64_FMAXNMP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 6fe3fc00/4e20c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_6fe3fc00_4e20c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0e30c800))
        return iemDecodeA64_FMAXNMV_asimdall_only_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e30c800))
        return iemDecodeA64_FMAXNMP_asisdpair_only_H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 6fe3fc00/4e21c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_6fe3fc00_4e21c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21c800))
        return iemDecodeA64_FCVTAS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5e21c800))
        return iemDecodeA64_FCVTAS_asisdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 6fe3fc00/6e20c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_6fe3fc00_6e20c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e30c800))
        return iemDecodeA64_FMAXNMP_asisdpair_only_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x6e30c800))
        return iemDecodeA64_FMAXNMV_asimdall_only_SD(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 6fe3fc00/6e21c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_6fe3fc00_6e21c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21c800))
        return iemDecodeA64_FCVTAU_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e21c800))
        return iemDecodeA64_FCVTAU_asisdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620c800 level 1
   mask=0x68030000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%22 (0x7) multi-if=%25 (0x8) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMAXNMV_asimdall_only_H,
        iemDecodeA64_FCVTAS_asimdmisc_R,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_FCVTAU_asimdmisc_R,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_6fe3fc00_4e20c800_2,
        iemDecodeA64_6fe3fc00_4e21c800_2,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_6fe3fc00_6e20c800_2,
        iemDecodeA64_6fe3fc00_6e21c800_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x68030000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x00000004)) /* bit 27 L 1 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000018)) /* bit 29 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620cc00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLA_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMLAL2_asimdsame_F,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620d000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_S_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620d400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FADD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16208400_2,
        iemDecodeA64_FADDP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620d800 level 1
   mask=0x38030000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SCVTF_asimdmisc_R,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FADDP_asisdpair_only_H,
        iemDecodeA64_SCVTF_asisdmisc_R,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_UCVTF_asimdmisc_R,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FADDP_asisdpair_only_SD,
        iemDecodeA64_UCVTF_asisdmisc_R,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38030000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e20dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e20dc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20dc00))
        return iemDecodeA64_FAMAX_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0e20dc00))
        return iemDecodeA64_FMULX_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x5e20dc00))
        return iemDecodeA64_FMULX_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e200c00))
        return iemDecodeA64_FCSEL_S_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* afe0fc00/2e20dc00 level 2
   afe0fc00/2e60dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_2e20dc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20dc00))
        return iemDecodeA64_FAMIN_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2e20dc00))
        return iemDecodeA64_FMUL_asimdsame_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620dc00 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e20dc00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_afe0fc00_2e20dc00_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620e000 level 1
   07e0fc00/0660e000 level 1
   07e0fc00/06a0e000 level 1
   07e0fc00/06e0e000 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620e000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20e000))
        return iemDecodeA64_PMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620e400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FCMEQ_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1e20b400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCMGE_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_FCMEQ_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_FCMEQ_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_FCMGE_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_FCMGE_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620e800 level 1
   07e0fc00/0660e800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FRINT32Z_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FRINT32X_asimdmisc_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_FRINT32Z_asimdmisc_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_FRINT32X_asimdmisc_R,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620ec00 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLAL_asimdsame_F,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_S_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FACGE_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FACGE_asisdsame_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0620f000 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620f000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe01fe0)) == UINT32_C(0x1e201000))
        return iemDecodeA64_FMOV_S_floatimm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620f400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FMAX_asimdsame_only,
        iemDecodeA64_b7e0fc00_16208400_2,
        iemDecodeA64_FMAXP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/0620f800 level 2
   77e0fc00/4620f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_0620f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21f800))
        return iemDecodeA64_FRINT64Z_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0e30f800))
        return iemDecodeA64_FMAXV_asimdall_only_H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e0fc00/6620f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_6620f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21f800))
        return iemDecodeA64_FRINT64X_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x6e30f800))
        return iemDecodeA64_FMAXV_asimdall_only_SD(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620f800 level 1
   mask=0x70000000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%50 (0x4) multi-if=%50 (0x4) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_77e0fc00_0620f800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FRINT64X_asimdmisc_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_77e0fc00_0620f800_2,
        iemDecodeA64_FMAXP_asisdpair_only_H,
        iemDecodeA64_77e0fc00_6620f800_2,
        iemDecodeA64_FMAXP_asisdpair_only_SD,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1e20fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1e20fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x5e20fc00))
        return iemDecodeA64_FRECPS_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e200c00))
        return iemDecodeA64_FCSEL_S_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2e20fc00 level 2
   bfe0fc00/2e60fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2e20fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20fc00))
        return iemDecodeA64_FSCALE_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x2e20fc00))
        return iemDecodeA64_FDIV_asimdsame_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0620fc00 level 1
   mask=0xb8000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%31 (0x5) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0620fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FRECPS_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1e20fc00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2e20fc00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/16460000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_16460000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0xd65f0000))
        return iemDecodeA64_RET_64R_branch_reg(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe6fc00/1e400000 level 2
   3fe6fc00/1e400800 level 2
   3fe6fc00/1e400c00 level 2
   3fe6fc00/1e401000 level 2
   3fe6fc00/1e401800 level 2
   7fe6fc00/1e401c00 level 2
   3fe6fc00/1e402000 level 2
   3fe6fc00/1e402800 level 2
   3fe6fc00/1e403000 level 2
   3fe6fc00/1e403800 level 2
   7fe6fc00/1e403c00 level 2
   3fe6fc00/1e404000 level 2
   3fe6fc00/1e404400 level 2
   3fe6fc00/1e404800 level 2
   3fe6fc00/1e404c00 level 2
   3fe6fc00/1e405000 level 2
   3fe6fc00/1e405400 level 2
   3fe6fc00/1e405800 level 2
   3fe6fc00/1e405c00 level 2
   3fe6fc00/1e406000 level 2
   3fe6fc00/1e406400 level 2
   3fe6fc00/1e406800 level 2
   3fe6fc00/1e406c00 level 2
   3fe6fc00/1e407000 level 2
   3fe6fc00/1e407400 level 2
   3fe6fc00/1e407800 level 2
   3fe6fc00/1e407c00 level 2
   3fe6fc00/1e408000 level 2
   3fe6fc00/1e408800 level 2
   3fe6fc00/1e409000 level 2
   3fe6fc00/1e409800 level 2
   3fe6fc00/1e409c00 level 2
   3fe6fc00/1e40a000 level 2
   3fe6fc00/1e40a400 level 2
   3fe6fc00/1e40a800 level 2
   3fe6fc00/1e40ac00 level 2
   3fe6fc00/1e40b000 level 2
   3fe6fc00/1e40b400 level 2
   3fe6fc00/1e40b800 level 2
   3fe6fc00/1e40bc00 level 2
   3fe6fc00/1e40cc00 level 2
   3fe6fc00/1e40d400 level 2
   3fe6fc00/1e40dc00 level 2
   3fe6fc00/1e40e400 level 2
   3fe6fc00/1e40ec00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_1e400000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e580000))
        return iemDecodeA64_FCVTZS_32D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e590000))
        return iemDecodeA64_FCVTZU_32D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e580000))
        return iemDecodeA64_FCVTZS_64D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e590000))
        return iemDecodeA64_FCVTZU_64D_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe6fc00/1e420000 level 2
   3fe6fc00/1e420800 level 2
   3fe6fc00/1e420c00 level 2
   3fe6fc00/1e421000 level 2
   3fe6fc00/1e421800 level 2
   7fe6fc00/1e421c00 level 2
   3fe6fc00/1e422000 level 2
   3fe6fc00/1e422800 level 2
   3fe6fc00/1e423000 level 2
   3fe6fc00/1e423800 level 2
   7fe6fc00/1e423c00 level 2
   3fe6fc00/1e424000 level 2
   3fe6fc00/1e424400 level 2
   3fe6fc00/1e424800 level 2
   3fe6fc00/1e424c00 level 2
   3fe6fc00/1e425000 level 2
   3fe6fc00/1e425400 level 2
   3fe6fc00/1e425800 level 2
   3fe6fc00/1e425c00 level 2
   3fe6fc00/1e426000 level 2
   3fe6fc00/1e426400 level 2
   3fe6fc00/1e426800 level 2
   3fe6fc00/1e426c00 level 2
   3fe6fc00/1e427000 level 2
   3fe6fc00/1e427400 level 2
   3fe6fc00/1e427800 level 2
   3fe6fc00/1e427c00 level 2
   3fe6fc00/1e428000 level 2
   3fe6fc00/1e428800 level 2
   3fe6fc00/1e429000 level 2
   3fe6fc00/1e429800 level 2
   3fe6fc00/1e429c00 level 2
   3fe6fc00/1e42a000 level 2
   3fe6fc00/1e42a400 level 2
   3fe6fc00/1e42a800 level 2
   3fe6fc00/1e42ac00 level 2
   3fe6fc00/1e42b000 level 2
   3fe6fc00/1e42b400 level 2
   3fe6fc00/1e42b800 level 2
   3fe6fc00/1e42bc00 level 2
   3fe6fc00/1e42cc00 level 2
   3fe6fc00/1e42d400 level 2
   3fe6fc00/1e42dc00 level 2
   3fe6fc00/1e42e400 level 2
   3fe6fc00/1e42ec00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_1e420000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e420000))
        return iemDecodeA64_SCVTF_D32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e430000))
        return iemDecodeA64_UCVTF_D32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e420000))
        return iemDecodeA64_SCVTF_D64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e430000))
        return iemDecodeA64_UCVTF_D64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06400000 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06400000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_16460000_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/1e400400 level 2
   7fe1fc00/1e401400 level 2
   7fe1fc00/1e402c00 level 2
   7fe1fc00/1e403400 level 2
   7fe1fc00/1e408400 level 2
   7fe1fc00/1e408c00 level 2
   7fe1fc00/1e409400 level 2
   7fe1fc00/1e40c400 level 2
   7fe1fc00/1e40f400 level 2
   7fe1fc00/1e40fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_1e400400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e420000))
        return iemDecodeA64_SCVTF_D32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e580000))
        return iemDecodeA64_FCVTZS_32D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e420000))
        return iemDecodeA64_SCVTF_D64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e580000))
        return iemDecodeA64_FCVTZS_64D_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe1fc00/1e410400 level 2
   7fe1fc00/1e411400 level 2
   7fe1fc00/1e412c00 level 2
   7fe1fc00/1e413400 level 2
   7fe1fc00/1e418400 level 2
   7fe1fc00/1e418c00 level 2
   7fe1fc00/1e419400 level 2
   7fe1fc00/1e41c400 level 2
   7fe1fc00/1e41f400 level 2
   7fe1fc00/1e41fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_1e410400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e430000))
        return iemDecodeA64_UCVTF_D32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e590000))
        return iemDecodeA64_FCVTZU_32D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e430000))
        return iemDecodeA64_UCVTF_D64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e590000))
        return iemDecodeA64_FCVTZU_64D_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe1fc00/4e400400 level 2
   7fe1fc00/4e410400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e400400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e400400))
        return iemDecodeA64_FMAXNM_asimdsamefp16_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06400400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%9 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06400400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FMAXNM_asimdsamefp16_only,
        iemDecodeA64_FMAXNM_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FMAXNMP_asimdsamefp16_only,
        iemDecodeA64_FMAXNMP_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e400400_2,
        iemDecodeA64_7fe1fc00_4e400400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FMAXNMP_asimdsamefp16_only,
        iemDecodeA64_FMAXNMP_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/16460800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_16460800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xd65f0be0))
        return iemDecodeA64_RETAASPPCR_64M_branch_reg(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd65f0bff))
        return iemDecodeA64_RETAA_64E_branch_reg(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06400800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06400800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_16460800_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e400c00 level 2
   3fe6fc00/0e420c00 level 2
   3fe6fc00/0e440c00 level 2
   3fe6fc00/0e460c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e400c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e400c00))
        return iemDecodeA64_FMLA_asimdsamefp16_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe6fc00/16460c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_16460c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffe0)) == UINT32_C(0xd65f0fe0))
        return iemDecodeA64_RETABSPPCR_64M_branch_reg(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd65f0fff))
        return iemDecodeA64_RETAB_64E_branch_reg(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06400c00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%25 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06400c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e400c00_2,
        iemDecodeA64_3fe6fc00_0e400c00_2,
        iemDecodeA64_3fe6fc00_0e400c00_2,
        iemDecodeA64_3fe6fc00_0e400c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_16460c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e401000 level 2
   3fe6fc00/0e421000 level 2
   3fe6fc00/0e441000 level 2
   3fe6fc00/0e461000 level 2
   3fe6fc00/0e403000 level 2
   3fe6fc00/0e423000 level 2
   3fe6fc00/0e443000 level 2
   3fe6fc00/0e463000 level 2
   3fe6fc00/0e405000 level 2
   3fe6fc00/0e425000 level 2
   3fe6fc00/0e445000 level 2
   3fe6fc00/0e465000 level 2
   3fe6fc00/0e407000 level 2
   3fe6fc00/0e427000 level 2
   3fe6fc00/0e447000 level 2
   3fe6fc00/0e467000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e401000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe09c00)) == UINT32_C(0x4e401000))
        return iemDecodeA64_LUTI4_asimdtbl_L7(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06401000 level 1
   07e0fc00/06403000 level 1
   07e0fc00/06405000 level 1
   07e0fc00/06407000 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06401000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e401000_2,
        iemDecodeA64_3fe6fc00_0e401000_2,
        iemDecodeA64_3fe6fc00_0e401000_2,
        iemDecodeA64_3fe6fc00_0e401000_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e401400 level 2
   7fe1fc00/4e411400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e401400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e401400))
        return iemDecodeA64_FADD_asimdsamefp16_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06401400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06401400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FADD_asimdsamefp16_only,
        iemDecodeA64_FADD_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FADDP_asimdsamefp16_only,
        iemDecodeA64_FADDP_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e401400_2,
        iemDecodeA64_7fe1fc00_4e401400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FADDP_asimdsamefp16_only,
        iemDecodeA64_FADDP_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e401800 level 2
   3fe6fc00/0e421800 level 2
   3fe6fc00/0e441800 level 2
   3fe6fc00/0e461800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e401800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e001800))
        return iemDecodeA64_UZP1_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06401800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06401800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e401800_2,
        iemDecodeA64_3fe6fc00_0e401800_2,
        iemDecodeA64_3fe6fc00_0e401800_2,
        iemDecodeA64_3fe6fc00_0e401800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/4e401c00 level 2
   7fe6fc00/4e421c00 level 2
   7fe6fc00/4e441c00 level 2
   7fe6fc00/4e461c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_4e401c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e401c00))
        return iemDecodeA64_FMULX_asimdsamefp16_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06401c00 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%31 (0x14) multi-if=%16 (0xa) reuse=%14 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06401c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_FMULX_asimdsamefp16_only,
        iemDecodeA64_FMULX_asimdsamefp16_only,
        iemDecodeA64_FMULX_asimdsamefp16_only,
        iemDecodeA64_FMULX_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FMUL_asimdsamefp16_only,
        iemDecodeA64_FMUL_asimdsamefp16_only,
        iemDecodeA64_FMUL_asimdsamefp16_only,
        iemDecodeA64_FMUL_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe6fc00_4e401c00_2,
        iemDecodeA64_7fe6fc00_4e401c00_2,
        iemDecodeA64_7fe6fc00_4e401c00_2,
        iemDecodeA64_7fe6fc00_4e401c00_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_FMULX_asisdsamefp16_only,
        iemDecodeA64_FMULX_asisdsamefp16_only,
        iemDecodeA64_FMULX_asisdsamefp16_only,
        iemDecodeA64_FMULX_asisdsamefp16_only,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_FMUL_asimdsamefp16_only,
        iemDecodeA64_FMUL_asimdsamefp16_only,
        iemDecodeA64_FMUL_asimdsamefp16_only,
        iemDecodeA64_FMUL_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e402000 level 2
   3fe6fc00/0e422000 level 2
   3fe6fc00/0e442000 level 2
   3fe6fc00/0e462000 level 2
   3fe6fc00/0e406000 level 2
   3fe6fc00/0e426000 level 2
   3fe6fc00/0e446000 level 2
   3fe6fc00/0e466000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e402000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0bc00)) == UINT32_C(0x4e402000))
        return iemDecodeA64_LUTI4_asimdtbl_L5(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06402000 level 1
   07e0fc00/06406000 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06402000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e402000_2,
        iemDecodeA64_3fe6fc00_0e402000_2,
        iemDecodeA64_3fe6fc00_0e402000_2,
        iemDecodeA64_3fe6fc00_0e402000_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* dfe4fc00/0e402400 level 2
   dfe4fc00/0e442400 level 2
   dfe4fc00/4e402400 level 2
   dfe4fc00/4e442400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe4fc00_0e402400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e402400))
        return iemDecodeA64_FCMEQ_asimdsamefp16_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x2e402400))
        return iemDecodeA64_FCMGE_asimdsamefp16_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe4fc00/16402400 level 2
   dfe4fc00/16442400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe4fc00_16402400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe4fc00/1e402400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe4fc00_1e402400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e420000))
        return iemDecodeA64_SCVTF_D32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e430000))
        return iemDecodeA64_UCVTF_D32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e580000))
        return iemDecodeA64_FCVTZS_32D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e590000))
        return iemDecodeA64_FCVTZU_32D_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe4fc00/5e402400 level 2
   dfe4fc00/5e442400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe4fc00_5e402400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5e402400))
        return iemDecodeA64_FCMEQ_asisdsamefp16_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x7e402400))
        return iemDecodeA64_FCMGE_asisdsamefp16_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe4fc00/96402400 level 2
   dfe4fc00/96442400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe4fc00_96402400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* dfe4fc00/9e402400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_dfe4fc00_9e402400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e420000))
        return iemDecodeA64_SCVTF_D64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e430000))
        return iemDecodeA64_UCVTF_D64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e580000))
        return iemDecodeA64_FCVTZS_64D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e590000))
        return iemDecodeA64_FCVTZU_64D_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06402400 level 1
   mask=0xd8040000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%6 (0x2) multi-if=%38 (0xc) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06402400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_dfe4fc00_0e402400_2,
        iemDecodeA64_dfe4fc00_0e402400_2,
        iemDecodeA64_dfe4fc00_16402400_2,
        iemDecodeA64_dfe4fc00_16402400_2,
        iemDecodeA64_dfe4fc00_1e402400_2,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_dfe4fc00_0e402400_2,
        iemDecodeA64_dfe4fc00_0e402400_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_dfe4fc00_5e402400_2,
        iemDecodeA64_dfe4fc00_5e402400_2,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_dfe4fc00_96402400_2,
        iemDecodeA64_dfe4fc00_96402400_2,
        iemDecodeA64_dfe4fc00_9e402400_2,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xd8040000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000006)) /* bit 27 L 2 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000018)) /* bit 30 L 2 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e402800 level 2
   3fe6fc00/0e422800 level 2
   3fe6fc00/0e442800 level 2
   3fe6fc00/0e462800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e402800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e002800))
        return iemDecodeA64_TRN1_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06402800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06402800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e402800_2,
        iemDecodeA64_3fe6fc00_0e402800_2,
        iemDecodeA64_3fe6fc00_0e402800_2,
        iemDecodeA64_3fe6fc00_0e402800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06402c00 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06402c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FACGE_asimdsamefp16_only,
        iemDecodeA64_FACGE_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FACGE_asimdsamefp16_only,
        iemDecodeA64_FACGE_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_FACGE_asisdsamefp16_only,
        iemDecodeA64_FACGE_asisdsamefp16_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e403400 level 2
   7fe1fc00/4e413400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e403400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e403400))
        return iemDecodeA64_FMAX_asimdsamefp16_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06403400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06403400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FMAX_asimdsamefp16_only,
        iemDecodeA64_FMAX_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FMAXP_asimdsamefp16_only,
        iemDecodeA64_FMAXP_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e403400_2,
        iemDecodeA64_7fe1fc00_4e403400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FMAXP_asimdsamefp16_only,
        iemDecodeA64_FMAXP_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e403800 level 2
   3fe6fc00/0e423800 level 2
   3fe6fc00/0e443800 level 2
   3fe6fc00/0e463800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e403800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e003800))
        return iemDecodeA64_ZIP1_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06403800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06403800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e403800_2,
        iemDecodeA64_3fe6fc00_0e403800_2,
        iemDecodeA64_3fe6fc00_0e403800_2,
        iemDecodeA64_3fe6fc00_0e403800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe6fc00/4e403c00 level 2
   7fe6fc00/4e423c00 level 2
   7fe6fc00/4e443c00 level 2
   7fe6fc00/4e463c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe6fc00_4e403c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfe0fc00)) == UINT32_C(0x0e403c00))
        return iemDecodeA64_FRECPS_asimdsamefp16_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06403c00 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%31 (0x14) multi-if=%16 (0xa) reuse=%14 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06403c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_FRECPS_asimdsamefp16_only,
        iemDecodeA64_FRECPS_asimdsamefp16_only,
        iemDecodeA64_FRECPS_asimdsamefp16_only,
        iemDecodeA64_FRECPS_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FDIV_asimdsamefp16_only,
        iemDecodeA64_FDIV_asimdsamefp16_only,
        iemDecodeA64_FDIV_asimdsamefp16_only,
        iemDecodeA64_FDIV_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_7fe6fc00_4e403c00_2,
        iemDecodeA64_7fe6fc00_4e403c00_2,
        iemDecodeA64_7fe6fc00_4e403c00_2,
        iemDecodeA64_7fe6fc00_4e403c00_2,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_FRECPS_asisdsamefp16_only,
        iemDecodeA64_FRECPS_asisdsamefp16_only,
        iemDecodeA64_FRECPS_asisdsamefp16_only,
        iemDecodeA64_FRECPS_asisdsamefp16_only,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_FDIV_asimdsamefp16_only,
        iemDecodeA64_FDIV_asimdsamefp16_only,
        iemDecodeA64_FDIV_asimdsamefp16_only,
        iemDecodeA64_FDIV_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06404000 level 1
   07e0fc00/06404400 level 1
   07e0fc00/06404800 level 1
   07e0fc00/06404c00 level 1
   07e0fc00/06405400 level 1
   07e0fc00/06405c00 level 1
   07e0fc00/06406400 level 1
   07e0fc00/06406c00 level 1
   07e0fc00/06407400 level 1
   07e0fc00/06407c00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06404000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_SM3SS1_VVV4_crypto4,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e405800 level 2
   3fe6fc00/0e425800 level 2
   3fe6fc00/0e445800 level 2
   3fe6fc00/0e465800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e405800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e005800))
        return iemDecodeA64_UZP2_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06405800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06405800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e405800_2,
        iemDecodeA64_3fe6fc00_0e405800_2,
        iemDecodeA64_3fe6fc00_0e405800_2,
        iemDecodeA64_3fe6fc00_0e405800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e406800 level 2
   3fe6fc00/0e426800 level 2
   3fe6fc00/0e446800 level 2
   3fe6fc00/0e466800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e406800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e006800))
        return iemDecodeA64_TRN2_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06406800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06406800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e406800_2,
        iemDecodeA64_3fe6fc00_0e406800_2,
        iemDecodeA64_3fe6fc00_0e406800_2,
        iemDecodeA64_3fe6fc00_0e406800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/0e407800 level 2
   3fe6fc00/0e427800 level 2
   3fe6fc00/0e447800 level 2
   3fe6fc00/0e467800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_0e407800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e007800))
        return iemDecodeA64_ZIP2_asimdperm_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0xce400000))
        return iemDecodeA64_SM3SS1_VVV4_crypto4(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06407800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%31 (0xa) reuse=%28 (0x9) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06407800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe6fc00_0e407800_2,
        iemDecodeA64_3fe6fc00_0e407800_2,
        iemDecodeA64_3fe6fc00_0e407800_2,
        iemDecodeA64_3fe6fc00_0e407800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06408000 level 1
   07e0fc00/06409000 level 1
   07e0fc00/0640a000 level 1
   07e0fc00/0640b000 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06408000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SM3TT1A_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT1A_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT1A_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT1A_VVV4_crypto3_imm2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06408400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06408400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_SM3TT1B_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT1B_VVV4_crypto3_imm2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_SQRDMLAH_asisdsame2_only,
        iemDecodeA64_SQRDMLAH_asisdsame2_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06408800 level 1
   07e0fc00/06409800 level 1
   07e0fc00/0640a800 level 1
   07e0fc00/0640b800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06408800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SM3TT2A_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT2A_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT2A_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT2A_VVV4_crypto3_imm2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06408c00 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06408c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_SM3TT2B_VVV_crypto3_imm2,
        iemDecodeA64_SM3TT2B_VVV_crypto3_imm2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_SQRDMLSH_asisdsame2_only,
        iemDecodeA64_SQRDMLSH_asisdsame2_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/4e409400 level 2
   7fe1fc00/4e419400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_4e409400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e009400))
        return iemDecodeA64_SDOT_asimdsame2_D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0cc00)) == UINT32_C(0xce408400))
        return iemDecodeA64_SM3TT1B_VVV4_crypto3_imm2(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06409400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%16 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06409400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_7fe1fc00_4e409400_2,
        iemDecodeA64_7fe1fc00_4e409400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06409c00 level 1
   07e0fc00/0640ac00 level 1
   07e0fc00/0640bc00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06409c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SM3TT2B_VVV_crypto3_imm2,
        iemDecodeA64_SM3TT2B_VVV_crypto3_imm2,
        iemDecodeA64_SM3TT2B_VVV_crypto3_imm2,
        iemDecodeA64_SM3TT2B_VVV_crypto3_imm2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0640a400 level 1
   07e0fc00/0640b400 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0640a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SM3TT1B_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT1B_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT1B_VVV4_crypto3_imm2,
        iemDecodeA64_SM3TT1B_VVV4_crypto3_imm2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0febfc00/0e42c000 level 2
   0febfc00/0e42c800 level 2
   0febfc00/0e42d000 level 2
   0febfc00/0e42d800 level 2
   0febfc00/0e42e000 level 2
   0febfc00/0e42e800 level 2
   0febfc00/0e42f000 level 2
   0febfc00/0e42f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e42c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e420000))
        return iemDecodeA64_SCVTF_D32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e420000))
        return iemDecodeA64_SCVTF_D64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e43c000 level 2
   0febfc00/0e43c800 level 2
   0febfc00/0e43d000 level 2
   0febfc00/0e43d800 level 2
   0febfc00/0e43e000 level 2
   0febfc00/0e43e800 level 2
   0febfc00/0e43f000 level 2
   0febfc00/0e43f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e43c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e430000))
        return iemDecodeA64_UCVTF_D32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e430000))
        return iemDecodeA64_UCVTF_D64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e48c000 level 2
   0febfc00/0e48c800 level 2
   0febfc00/0e48d000 level 2
   0febfc00/0e48d800 level 2
   0febfc00/0e48e000 level 2
   0febfc00/0e48e800 level 2
   0febfc00/0e48f000 level 2
   0febfc00/0e48f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e48c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e580000))
        return iemDecodeA64_FCVTZS_32D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e580000))
        return iemDecodeA64_FCVTZS_64D_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e49c000 level 2
   0febfc00/0e49c800 level 2
   0febfc00/0e49d000 level 2
   0febfc00/0e49d800 level 2
   0febfc00/0e49e000 level 2
   0febfc00/0e49e800 level 2
   0febfc00/0e49f000 level 2
   0febfc00/0e49f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e49c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1e590000))
        return iemDecodeA64_FCVTZU_32D_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9e590000))
        return iemDecodeA64_FCVTZU_64D_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0640c000 level 1
   07e0fc00/0640c800 level 1
   07e0fc00/0640d000 level 1
   07e0fc00/0640d800 level 1
   07e0fc00/0640e000 level 1
   07e0fc00/0640e800 level 1
   07e0fc00/0640f000 level 1
   07e0fc00/0640f800 level 1
   mask=0x80b0000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%0 (0x0) multi-if=%75 (0xc) reuse=%50 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0640c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_0febfc00_0e42c000_2,
        iemDecodeA64_0febfc00_0e43c000_2,
        iemDecodeA64_0febfc00_0e48c000_2,
        iemDecodeA64_0febfc00_0e49c000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0640c400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0640c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FMLALLBT_asimdsame2_G,
        iemDecodeA64_FMLALLBT_asimdsame2_G,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FMLALLTT_asimdsame2_G,
        iemDecodeA64_FMLALLTT_asimdsame2_G,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0640cc00 level 1
   07e0fc00/0640d400 level 1
   07e0fc00/0640dc00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0640cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0640e400 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0640e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0640ec00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0640ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1e400000_2,
        iemDecodeA64_3fe6fc00_1e420000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BFMMLA_asimdsame2_E,
        iemDecodeA64_BFMMLA_asimdsame2_E,
        iemDecodeA64_BFMMLA_asimdsame2_E,
        iemDecodeA64_BFMMLA_asimdsame2_E,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0640f400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0640f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FCVTN_asimdsame2_D,
        iemDecodeA64_FCVTN_asimdsame2_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FCVTN_asimdsame2_D,
        iemDecodeA64_FCVTN_asimdsame2_D,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0640fc00 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0640fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FDOT_asimdsame2_D,
        iemDecodeA64_FDOT_asimdsame2_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1e400400_2,
        iemDecodeA64_7fe1fc00_1e410400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BFDOT_asimdsame2_D,
        iemDecodeA64_BFDOT_asimdsame2_D,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FDOT_asimdsame2_D,
        iemDecodeA64_FDOT_asimdsame2_D,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BFDOT_asimdsame2_D,
        iemDecodeA64_BFDOT_asimdsame2_D,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/0e600000 level 2
   1ff7fc00/0e610000 level 2
   1ff7fc00/0e620000 level 2
   1ff7fc00/0e630000 level 2
   1ff7fc00/0e640000 level 2
   1ff7fc00/0e650000 level 2
   1ff7fc00/0e660000 level 2
   1ff7fc00/0e670000 level 2
   1ff7fc00/0e700000 level 2
   1ff7fc00/0e710000 level 2
   1ff7fc00/0e720000 level 2
   1ff7fc00/0e730000 level 2
   1ff7fc00/0e740000 level 2
   1ff7fc00/0e750000 level 2
   1ff7fc00/0e760000 level 2
   1ff7fc00/0e770000 level 2
   1ff7fc00/0ee00000 level 2
   1ff7fc00/0ee10000 level 2
   1ff7fc00/0ee20000 level 2
   1ff7fc00/0ee30000 level 2
   1ff7fc00/0ee40000 level 2
   1ff7fc00/0ee50000 level 2
   1ff7fc00/0ee60000 level 2
   1ff7fc00/0ee70000 level 2
   1ff7fc00/0ef00000 level 2
   1ff7fc00/0ef10000 level 2
   1ff7fc00/0ef20000 level 2
   1ff7fc00/0ef30000 level 2
   1ff7fc00/0ef40000 level 2
   1ff7fc00/0ef50000 level 2
   1ff7fc00/0ef60000 level 2
   1ff7fc00/0ef70000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_0e600000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e200000))
        return iemDecodeA64_SADDL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e200000))
        return iemDecodeA64_UADDL_asimddiff_L(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e600000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e600000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e600000))
        return iemDecodeA64_FCVTNS_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e680000))
        return iemDecodeA64_FCVTPS_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e600000))
        return iemDecodeA64_FCVTNS_64D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e680000))
        return iemDecodeA64_FCVTPS_64D_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e610000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e610000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e610000))
        return iemDecodeA64_FCVTNU_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e690000))
        return iemDecodeA64_FCVTPU_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e610000))
        return iemDecodeA64_FCVTNU_64D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e690000))
        return iemDecodeA64_FCVTPU_64D_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e620000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e620000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e620000))
        return iemDecodeA64_SCVTF_D32_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e6a0000))
        return iemDecodeA64_FCVTNS_sisd_32D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e620000))
        return iemDecodeA64_SCVTF_D64_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e630000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e630000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e630000))
        return iemDecodeA64_UCVTF_D32_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e6b0000))
        return iemDecodeA64_FCVTNU_sisd_32D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e630000))
        return iemDecodeA64_UCVTF_D64_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e640000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e640000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e640000))
        return iemDecodeA64_FCVTAS_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e640000))
        return iemDecodeA64_FCVTAS_64D_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e650000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e650000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e650000))
        return iemDecodeA64_FCVTAU_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e650000))
        return iemDecodeA64_FCVTAU_64D_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e700000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e700000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e700000))
        return iemDecodeA64_FCVTMS_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e780000))
        return iemDecodeA64_FCVTZS_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e700000))
        return iemDecodeA64_FCVTMS_64D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e780000))
        return iemDecodeA64_FCVTZS_64D_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e710000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e710000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e710000))
        return iemDecodeA64_FCVTMU_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e790000))
        return iemDecodeA64_FCVTZU_32D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e710000))
        return iemDecodeA64_FCVTMU_64D_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9e790000))
        return iemDecodeA64_FCVTZU_64D_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e720000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e720000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e720000))
        return iemDecodeA64_FCVTPS_sisd_32D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e7a0000))
        return iemDecodeA64_FCVTAS_sisd_32D(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e730000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e730000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e730000))
        return iemDecodeA64_FCVTPU_sisd_32D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e7b0000))
        return iemDecodeA64_FCVTAU_sisd_32D(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e740000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e740000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e740000))
        return iemDecodeA64_FCVTMS_sisd_32D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e7c0000))
        return iemDecodeA64_SCVTF_sisd_32D(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e750000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e750000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e750000))
        return iemDecodeA64_FCVTMU_sisd_32D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e7d0000))
        return iemDecodeA64_UCVTF_sisd_32D(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1e760000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1e760000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e760000))
        return iemDecodeA64_FCVTZS_sisd_32D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e7e0000))
        return iemDecodeA64_FJCVTZS_32D_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x6600000/0x18170000
   mask=0x18170000 entries=0x40 children=0x30 valid=%75 (0x30) leaf=%5 (0x3) multi-if=%70 (0x2d) reuse=%48 (0x1f) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06600000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_1ff7fc00_1e600000_2,
        iemDecodeA64_1ff7fc00_1e610000_2,
        iemDecodeA64_1ff7fc00_1e620000_2,
        iemDecodeA64_1ff7fc00_1e630000_2,
        iemDecodeA64_1ff7fc00_1e640000_2,
        iemDecodeA64_1ff7fc00_1e650000_2,
        iemDecodeA64_FMOV_64D_float2int,
        iemDecodeA64_FMOV_D64_float2int,
        iemDecodeA64_1ff7fc00_1e700000_2,
        iemDecodeA64_1ff7fc00_1e710000_2,
        iemDecodeA64_1ff7fc00_1e720000_2,
        iemDecodeA64_1ff7fc00_1e730000_2,
        iemDecodeA64_1ff7fc00_1e740000_2,
        iemDecodeA64_1ff7fc00_1e750000_2,
        iemDecodeA64_1ff7fc00_1e760000_2,
        iemDecodeA64_FCVTZU_sisd_32D,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x18170000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000030)) /* bit 27 L 2 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* b7e0fc00/16600400 level 2
   b7e0fc00/16601400 level 2
   b7e0fc00/16602400 level 2
   b7e0fc00/16603400 level 2
   b7e0fc00/16604400 level 2
   b7e0fc00/16605400 level 2
   b7e0fc00/16606400 level 2
   b7e0fc00/16607400 level 2
   b7e0fc00/16609400 level 2
   b7e0fc00/1660a400 level 2
   b7e0fc00/1660d400 level 2
   b7e0fc00/1660f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_b7e0fc00_16600400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e600400))
        return iemDecodeA64_FCCMP_D_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e600410))
        return iemDecodeA64_FCCMPE_D_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06600400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06600400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SHADD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_UHADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06600800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06600800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_REV64_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMUL_D_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_REV32_asimdmisc_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1e600c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1e600c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e200c00))
        return iemDecodeA64_SQADD_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e600c00))
        return iemDecodeA64_FCSEL_D_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06600c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06600c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQADD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1e600c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UQADD_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06601000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06601000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SADDW_asimddiff_W,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_D_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UADDW_asimddiff_W,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06601400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06601400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SRHADD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_URHADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06601800 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06601800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_REV16_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FDIV_D_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_REV16_asimdmisc_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06601c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06601c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_BIC_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BSL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0fc00/1e602000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fc00_1e602000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x1e602000))
        return iemDecodeA64_FCMP_D_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x1e602010))
        return iemDecodeA64_FCMPE_D_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0x1e602008))
        return iemDecodeA64_FCMP_DZ_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0x1e602018))
        return iemDecodeA64_FCMPE_DZ_floatcmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06602000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%38 (0x3) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06602000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSUBL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe0fc00_1e602000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USUBL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06602400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06602400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SHSUB_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_UHSUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06602800 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%19 (0x3) multi-if=%31 (0x5) reuse=%31 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06602800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e202800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FADD_D_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2e202800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0e202800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2e202800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQXTUN_asisdmisc_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1e602c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1e602c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e202c00))
        return iemDecodeA64_SQSUB_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e600c00))
        return iemDecodeA64_FCSEL_D_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06602c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06602c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSUB_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1e602c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UQSUB_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06603000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06603000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSUBW_asimddiff_W,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_D_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USUBW_asimddiff_W,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06603400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06603400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_CMGT_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_CMHI_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06603800 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%22 (0x7) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06603800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe2fc00_0e203800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FSUB_D_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe2fc00_2e203800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_bfe2fc00_0e203800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SUQADD_asisdmisc_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_bfe2fc00_2e203800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_USQADD_asisdmisc_R,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06603c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06603c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CMGE_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMHS_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fecfc00/1e604000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fecfc00_1e604000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e604000))
        return iemDecodeA64_FMOV_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e614000))
        return iemDecodeA64_FNEG_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e624000))
        return iemDecodeA64_FCVT_SD_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e634000))
        return iemDecodeA64_BFCVT_BS_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fecfc00/1e644000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fecfc00_1e644000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e644000))
        return iemDecodeA64_FRINTN_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e654000))
        return iemDecodeA64_FRINTM_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e664000))
        return iemDecodeA64_FRINTA_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e674000))
        return iemDecodeA64_FRINTX_D_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fecfc00/1e684000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fecfc00_1e684000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e684000))
        return iemDecodeA64_FRINT32Z_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e694000))
        return iemDecodeA64_FRINT64Z_D_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06604000 level 1
   mask=0x580c0000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%0 (0x0) multi-if=%47 (0xf) reuse=%38 (0xc) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06604000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fecfc00_1e604000_2,
        iemDecodeA64_5fecfc00_1e644000_2,
        iemDecodeA64_5fecfc00_1e684000_2,
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x580c0000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000003)) /* bit 18 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000000c)) /* bit 27 L 2 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06604400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06604400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SSHL_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_USHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06604800 level 1
   mask=0x78000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%25 (0x4) multi-if=%31 (0x5) reuse=%31 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06604800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e204800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMAX_D_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2e204800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0e204800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQXTN_asisdmisc_N,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2e204800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQXTN_asisdmisc_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1e604c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1e604c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e204c00))
        return iemDecodeA64_SQSHL_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e600c00))
        return iemDecodeA64_FCSEL_D_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06604c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06604c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1e604c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UQSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06605000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06605000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABAL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_D_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABAL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06605400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06605400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SRSHL_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_URSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06605800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06605800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CNT_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMIN_D_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_RBIT_asimdmisc_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1e605c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1e605c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e205c00))
        return iemDecodeA64_SQRSHL_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e600c00))
        return iemDecodeA64_FCSEL_D_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06605c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06605c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1e605c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQRSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UQRSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06606000 level 1
   07e0fc00/06a06000 level 1
   07e0fc00/06e06000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06606000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SUBHN_asimddiff_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_RSUBHN_asimddiff_N,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06606400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06606400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SMAX_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_UMAX_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/0e606800 level 2
   7fe0fc00/4e606800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_0e606800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e206800))
        return iemDecodeA64_SADALP_asimdmisc_P(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e216800))
        return iemDecodeA64_FCVTN_asimdmisc_N(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc00/2e606800 level 2
   7fe0fc00/6e606800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_2e606800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e206800))
        return iemDecodeA64_UADALP_asimdmisc_P(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e616800))
        return iemDecodeA64_FCVTXN_asimdmisc_N(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06606800 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%19 (0x3) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06606800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_7fe0fc00_0e606800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMAXNM_D_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_7fe0fc00_2e606800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_0e606800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_7fe0fc00_2e606800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_FCVTXN_asisdmisc_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06606c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06606c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMIN_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMIN_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06607000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06607000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABDL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_D_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABDL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06607400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06607400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SABD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_UABD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/2e607800 level 2
   7fe0fc00/6e607800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_2e607800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e207800))
        return iemDecodeA64_SQNEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e617800))
        return iemDecodeA64_F2CVTL_asimdmisc_V(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06607800 level 1
   mask=0x78000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%25 (0x4) multi-if=%31 (0x5) reuse=%25 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06607800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e207800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMINNM_D_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_7fe0fc00_2e607800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0e207800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQABS_asisdmisc_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_7fe0fc00_2e607800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQNEG_asisdmisc_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06607c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06607c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABA_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABA_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/4e608000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_4e608000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e208000))
        return iemDecodeA64_SMLAL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce608000))
        return iemDecodeA64_SHA512H_QQV_cryptosha512_3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06608000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%25 (0x4) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06608000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_4e608000_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UMLAL_asimddiff_L,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e608400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e608400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e208400))
        return iemDecodeA64_ADD_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e600400))
        return iemDecodeA64_FCCMP_D_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e600410))
        return iemDecodeA64_FCCMPE_D_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06608400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06608400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e608400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_SUB_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SHA512H2_QQV_cryptosha512_3,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe2fc00/0e608800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe2fc00_0e608800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e208800))
        return iemDecodeA64_CMGT_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e218800))
        return iemDecodeA64_FRINTN_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0e798800))
        return iemDecodeA64_FRINTN_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe2fc00/2e608800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe2fc00_2e608800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e208800))
        return iemDecodeA64_CMGE_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e218800))
        return iemDecodeA64_FRINTA_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e798800))
        return iemDecodeA64_FRINTA_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06608800 level 1
   mask=0xb8020000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%38 (0xc) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06608800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_bfe2fc00_0e608800_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FNMUL_D_floatdp2,
        iemDecodeA64_FNMUL_D_floatdp2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_bfe2fc00_2e608800_2,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_SHA512SU1_VVV2_cryptosha512_3,
        iemDecodeA64_SHA512SU1_VVV2_cryptosha512_3,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8020000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000001)) /* bit 17 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e608c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e608c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e208c00))
        return iemDecodeA64_CMTST_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e600c00))
        return iemDecodeA64_FCSEL_D_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06608c00 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06608c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e608c00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_CMEQ_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_RAX1_VVV2_cryptosha512_3,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06609000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06609000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLAL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_D_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMLAL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMLAL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06609400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06609400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_MLA_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_MLS_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06609800 level 1
   mask=0x38090000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06609800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_CMEQ_asimdmisc_Z,
        iemDecodeA64_FRINTM_asimdmisc_R,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_FRINTM_asimdmiscfp16_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_CMLE_asimdmisc_Z,
        iemDecodeA64_FRINTX_asimdmisc_R,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_FRINTX_asimdmiscfp16_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38090000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000002)) /* bit 19 L 1 -> 1 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06609c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06609c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MUL_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_PMUL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660a400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SMAXP_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_UMAXP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e6fc00/0660a800 level 2
   77e6fc00/4660a800 level 2
   mask=0x190000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%62 (0x5) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_77e6fc00_0660a800_2, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_CMLT_asimdmisc_Z,
        iemDecodeA64_FCVTNS_asimdmisc_R,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SMAXV_asimdall_only,
        iemDecodeA64_SMINV_asimdall_only,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_FCVTNS_asimdmiscfp16_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x00190000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e6fc00/2660a800 level 2
   77e6fc00/6660a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e6fc00_2660a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e30a800))
        return iemDecodeA64_UMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e31a800))
        return iemDecodeA64_UMINV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21a800))
        return iemDecodeA64_FCVTNU_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e79a800))
        return iemDecodeA64_FCVTNU_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e6fc00/5660a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e6fc00_5660a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5e21a800))
        return iemDecodeA64_FCVTNS_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e79a800))
        return iemDecodeA64_FCVTNS_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 77e6fc00/7660a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e6fc00_7660a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e21a800))
        return iemDecodeA64_FCVTNU_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7e79a800))
        return iemDecodeA64_FCVTNU_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660a800 level 1
   mask=0x70060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%12 (0x4) multi-if=%25 (0x8) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_77e6fc00_0660a800_2,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_77e6fc00_2660a800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_77e6fc00_0660a800_2,
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_77e6fc00_5660a800_2,
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_77e6fc00_2660a800_2,
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_77e6fc00_7660a800_2,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x70060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001c)) /* bit 28 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660ac00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMINP_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMINP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660b000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLSL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_D_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMLSL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMLSL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/1e60b400 level 2
   ffe0fc00/1e60e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_1e60b400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e600400))
        return iemDecodeA64_FCCMP_D_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e600410))
        return iemDecodeA64_FCCMPE_D_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660b400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1e60b400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMULH_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SQRDMULH_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQRDMULH_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe3fc00/0e61b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_0e61b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e31b800))
        return iemDecodeA64_ADDV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21b800))
        return iemDecodeA64_FCVTMS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0e79b800))
        return iemDecodeA64_FCVTMS_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/1e61b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_1e61b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5e21b800))
        return iemDecodeA64_FCVTMS_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e79b800))
        return iemDecodeA64_FCVTMS_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/2e61b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_2e61b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21b800))
        return iemDecodeA64_FCVTMU_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e79b800))
        return iemDecodeA64_FCVTMU_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/3e61b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_3e61b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e21b800))
        return iemDecodeA64_FCVTMU_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7e79b800))
        return iemDecodeA64_FCVTMU_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660b800 level 1
   mask=0x38030000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%19 (0x6) multi-if=%25 (0x8) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ABS_asimdmisc_R,
        iemDecodeA64_3fe3fc00_0e61b800_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_3fe3fc00_1e61b800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_NEG_asimdmisc_R,
        iemDecodeA64_3fe3fc00_2e61b800_2,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_3fe3fc00_3e61b800_2,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38030000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660bc00 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADDP_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ADDP_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 5fe3fc00/1e60c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe3fc00_1e60c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e60c000))
        return iemDecodeA64_FABS_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e64c000))
        return iemDecodeA64_FRINTP_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e68c000))
        return iemDecodeA64_FRINT32X_D_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe3fc00/1e61c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe3fc00_1e61c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e61c000))
        return iemDecodeA64_FSQRT_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e65c000))
        return iemDecodeA64_FRINTZ_D_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e69c000))
        return iemDecodeA64_FRINT64X_D_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe3fc00/1e63c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe3fc00_1e63c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e63c000))
        return iemDecodeA64_FCVT_HD_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1e67c000))
        return iemDecodeA64_FRINTI_D_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 5fe3fc00/4e60c000 level 2
   5fe3fc00/4e61c000 level 2
   5fe3fc00/4e62c000 level 2
   5fe3fc00/4e63c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_5fe3fc00_4e60c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20c000))
        return iemDecodeA64_SMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e20c000))
        return iemDecodeA64_UMULL_asimddiff_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce60c000))
        return iemDecodeA64_SM3PARTW1_VVV4_cryptosha512_3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660c000 level 1
   mask=0x58030000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%0 (0x0) multi-if=%47 (0xf) reuse=%34 (0xb) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_0febfc00_0e2ac000_2,
        iemDecodeA64_0febfc00_0e2ac000_2,
        iemDecodeA64_0febfc00_0e2ac000_2,
        iemDecodeA64_0febfc00_0e2ac000_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe3fc00_1e60c000_2,
        iemDecodeA64_5fe3fc00_1e61c000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_5fe3fc00_1e63c000_2,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_5fe3fc00_4e60c000_2,
        iemDecodeA64_5fe3fc00_4e60c000_2,
        iemDecodeA64_5fe3fc00_4e60c000_2,
        iemDecodeA64_5fe3fc00_4e60c000_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x58030000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000000c)) /* bit 27 L 2 -> 2 */
                        | ((uOpcode >> 26) & UINT32_C(0x00000010)) /* bit 30 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e60c400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e60c400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0e20c400))
        return iemDecodeA64_FMAXNM_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e600400))
        return iemDecodeA64_FCCMP_D_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1e600410))
        return iemDecodeA64_FCCMPE_D_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660c400 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e60c400_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FMAXNMP_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_SM3PARTW2_VVV4_cryptosha512_3,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3febfc00/0e61c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3febfc00_0e61c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21c800))
        return iemDecodeA64_FCVTAS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce60c800))
        return iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3febfc00/0e69c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3febfc00_0e69c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0e79c800))
        return iemDecodeA64_FCVTAS_asimdmiscfp16_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0xce60c800))
        return iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660c800 level 1
   mask=0x380b0000 entries=0x40 children=0x1f valid=%48 (0x1f) leaf=%33 (0x15) multi-if=%16 (0xa) reuse=%12 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3,
        iemDecodeA64_3febfc00_0e61c800_2,
        iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3,
        iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3,
        iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3,
        iemDecodeA64_3febfc00_0e69c800_2,
        iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3,
        iemDecodeA64_SM4EKEY_VVV4_cryptosha512_3,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_FCVTAS_asisdmisc_R,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_FCVTAS_asisdmiscfp16_R,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_FCVTAU_asimdmisc_R,
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_FCVTAU_asimdmiscfp16_R,
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FMAXNMP_asisdpair_only_SD,
        iemDecodeA64_FCVTAU_asisdmisc_R,
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_FCVTAU_asisdmiscfp16_R,
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x380b0000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000038)) /* bit 27 L 3 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660cc00 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLA_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_FMLA_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660d000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_D_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660d400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FADD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_FADDP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0febfc00/0e61d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e61d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0e21d800))
        return iemDecodeA64_SCVTF_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2e21d800))
        return iemDecodeA64_UCVTF_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5e21d800))
        return iemDecodeA64_SCVTF_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7e21d800))
        return iemDecodeA64_UCVTF_asisdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0e69d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0e69d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0e79d800))
        return iemDecodeA64_SCVTF_asimdmiscfp16_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2e79d800))
        return iemDecodeA64_UCVTF_asimdmiscfp16_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5e79d800))
        return iemDecodeA64_SCVTF_asisdmiscfp16_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7e79d800))
        return iemDecodeA64_UCVTF_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660d800 level 1
   mask=0x80b0000 entries=0x10 children=0xb valid=%69 (0xb) leaf=%6 (0x1) multi-if=%62 (0xa) reuse=%50 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_FADDP_asisdpair_only_SD,
        iemDecodeA64_0febfc00_0e61d800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_0febfc00_0e69d800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0e60dc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0e60dc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20dc00))
        return iemDecodeA64_FAMAX_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0e20dc00))
        return iemDecodeA64_FMULX_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x5e20dc00))
        return iemDecodeA64_FMULX_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e600c00))
        return iemDecodeA64_FCSEL_D_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660dc00 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%50 (0x4) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0e60dc00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_afe0fc00_2e20dc00_2,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660e400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FCMEQ_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1e60b400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCMGE_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_FCMEQ_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_FCMEQ_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_FCMGE_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_FCMGE_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660ec00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_D_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FACGE_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FACGE_asisdsame_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660f000 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660f000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe01fe0)) == UINT32_C(0x1e601000))
        return iemDecodeA64_FMOV_D_floatimm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660f400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FMAX_asimdsame_only,
        iemDecodeA64_b7e0fc00_16600400_2,
        iemDecodeA64_FMAXP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0660f800 level 1
   mask=0x70000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FRINT64Z_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FRINT64X_asimdmisc_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FRINT64Z_asimdmisc_R,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_FRINT64X_asimdmisc_R,
        iemDecodeA64_FMAXP_asisdpair_only_SD,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1e60fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1e60fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x5e20fc00))
        return iemDecodeA64_FRECPS_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1e600c00))
        return iemDecodeA64_FCSEL_D_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0660fc00 level 1
   mask=0xb8000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%31 (0x5) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0660fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FRECPS_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1e60fc00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2e20fc00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06800000 level 1
   mask=0xe8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06800000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ERET_64E_branch_reg,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xe8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000e)) /* bit 29 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06800400 level 1
   07e0fc00/06801400 level 1
   07e0fc00/06801c00 level 1
   07e0fc00/06802000 level 1
   07e0fc00/06802400 level 1
   07e0fc00/06802c00 level 1
   07e0fc00/06803400 level 1
   07e0fc00/06803c00 level 1
   07e0fc00/06804000 level 1
   07e0fc00/06804400 level 1
   07e0fc00/06804800 level 1
   07e0fc00/06804c00 level 1
   07e0fc00/06805400 level 1
   07e0fc00/06805c00 level 1
   07e0fc00/06806000 level 1
   07e0fc00/06806400 level 1
   07e0fc00/06806c00 level 1
   07e0fc00/06807400 level 1
   07e0fc00/06807c00 level 1
   07e0fc00/06808000 level 1
   07e0fc00/06808800 level 1
   07e0fc00/06809000 level 1
   07e0fc00/06809800 level 1
   07e0fc00/0680a000 level 1
   07e0fc00/0680a800 level 1
   07e0fc00/0680b000 level 1
   07e0fc00/0680b400 level 1
   07e0fc00/0680b800 level 1
   07e0fc00/0680bc00 level 1
   07e0fc00/0680c000 level 1
   07e0fc00/0680c800 level 1
   07e0fc00/0680d000 level 1
   07e0fc00/0680d800 level 1
   07e0fc00/0680e000 level 1
   07e0fc00/0680e800 level 1
   07e0fc00/0680f000 level 1
   07e0fc00/0680f800 level 1
   07e0fc00/0680fc00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06800400_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00000)) == UINT32_C(0xce800000))
        return iemDecodeA64_XAR_VVV2_crypto3_imm6(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06800800 level 1
   mask=0xe8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06800800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ERETAA_64E_branch_reg,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xe8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000e)) /* bit 29 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06800c00 level 1
   mask=0xe8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06800c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_ERETAB_64E_branch_reg,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xe8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000e)) /* bit 29 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06801000 level 1
   07e0fc00/06803000 level 1
   07e0fc00/06805000 level 1
   07e0fc00/06807000 level 1
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06801000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_LUTI2_asimdtbl_L5,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06801800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06801800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_UZP1_asimdperm_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06802800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06802800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_TRN1_asimdperm_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06803800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06803800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ZIP1_asimdperm_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06805800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06805800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_UZP2_asimdperm_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06806800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06806800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_TRN2_asimdperm_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06807800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06807800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ZIP2_asimdperm_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06808400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06808400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_SQRDMLAH_asisdsame2_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06808c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06808c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_SQRDMLSH_asisdsame2_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/4e809400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_4e809400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e009400))
        return iemDecodeA64_SDOT_asimdsame2_D(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00000)) == UINT32_C(0xce800000))
        return iemDecodeA64_XAR_VVV2_crypto3_imm6(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06809400 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%25 (0x4) multi-if=%12 (0x2) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06809400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_4e809400_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06809c00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06809c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_USDOT_asimdsame2_D,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0680a400 level 1
   mask=0xe0000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%88 (0x7) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0680a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_SMMLA_asimdsame2_G,
        iemDecodeA64_UMMLA_asimdsame2_G,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0680ac00 level 1
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0680ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_USMMLA_asimdsame2_G,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0680c400 level 1
   07e0fc00/0680cc00 level 1
   07e0fc00/0680d400 level 1
   07e0fc00/0680dc00 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0680c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0680e400 level 1
   07e0fc00/0680f400 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0680e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0680ec00 level 1
   mask=0xe0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0680ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_FMMLA_asimd_FP8FP32,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_XAR_VVV2_crypto3_imm6,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xe0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 29) & UINT32_C(0x00000007)) /* bit 29 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/86a00000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_86a00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffffffff)) == UINT32_C(0xd6bf03e0))
        return iemDecodeA64_DRPS_64E_branch_reg(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* afe0fc00/8ea00000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_8ea00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9eae0000))
        return iemDecodeA64_FMOV_64VX_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9eaf0000))
        return iemDecodeA64_FMOV_V64I_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a00000 level 1
   mask=0xa8000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%62 (0x5) multi-if=%25 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_SADDL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UADDL_asimddiff_L,
        iemDecodeA64_afe0fc00_86a00000_2,
        iemDecodeA64_afe0fc00_8ea00000_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a00400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SHADD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UHADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a00800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_REV64_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_REV32_asimdmisc_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_REV64_asimdmisc_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_REV32_asimdmisc_R,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a00c00 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQADD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQADD_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQADD_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UQADD_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQADD_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a01000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SADDW_asimddiff_W,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UADDW_asimddiff_W,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a01400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRHADD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URHADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a01800 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a01800_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e201800))
        return iemDecodeA64_REV16_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a01c00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ORR_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BIT_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a02000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSUBL_asimddiff_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USUBL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a02400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SHSUB_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UHSUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a02800 level 1
   mask=0x78000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%12 (0x2) multi-if=%31 (0x5) reuse=%31 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e202800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2e202800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0e202800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2e202800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQXTUN_asisdmisc_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a02c00 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSUB_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQSUB_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQSUB_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UQSUB_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQSUB_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a03000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSUBW_asimddiff_W,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USUBW_asimddiff_W,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a03400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CMGT_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMHI_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a03800 level 1
   mask=0x38110000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%34 (0xb) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_SUQADD_asimdmisc_R,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_SADDLV_asimdall_only,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_SUQADD_asisdmisc_R,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_USQADD_asimdmisc_R,
        iemDecodeA64_SHLL_asimdmisc_S,
        iemDecodeA64_UADDLV_asimdall_only,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_USQADD_asisdmisc_R,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38110000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 19) & UINT32_C(0x00000002)) /* bit 20 L 1 -> 1 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a03c00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a03c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CMGE_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMHS_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a04000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADDHN_asimddiff_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_RADDHN_asimddiff_N,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a04400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a04800 level 1
   mask=0x38030000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_CLS_asimdmisc_R,
        iemDecodeA64_SQXTN_asimdmisc_N,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SQXTN_asisdmisc_N,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_CLZ_asimdmisc_R,
        iemDecodeA64_UQXTN_asimdmisc_N,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_UQXTN_asisdmisc_N,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38030000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a04c00 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UQSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a05000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABAL_asimddiff_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABAL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a05400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a05800 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a05800_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e205800))
        return iemDecodeA64_CNT_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a05c00 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQRSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQRSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQRSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UQRSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQRSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a06400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMAX_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMAX_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/0ea06800 level 2
   7fe0fc00/4ea06800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_0ea06800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e206800))
        return iemDecodeA64_SADALP_asimdmisc_P(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ea16800))
        return iemDecodeA64_BFCVTN_asimdmisc_4S(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a06800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%19 (0x3) multi-if=%19 (0x3) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_7fe0fc00_0ea06800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UADALP_asimdmisc_P,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_0ea06800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_UADALP_asimdmisc_P,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a06c00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMIN_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMIN_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a07000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABDL_asimddiff_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABDL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a07400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/26a07800 level 2
   77e0fc00/66a07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_26a07800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e207800))
        return iemDecodeA64_SQNEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ea17800))
        return iemDecodeA64_BF1CVTL_asimdmisc_V(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a07800 level 1
   mask=0x70000000 entries=0x8 children=0x8 valid=%100 (0x8) leaf=%62 (0x5) multi-if=%38 (0x3) reuse=%25 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SQABS_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_77e0fc00_26a07800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_SQABS_asimdmisc_R,
        iemDecodeA64_SQABS_asisdmisc_R,
        iemDecodeA64_77e0fc00_26a07800_2,
        iemDecodeA64_SQNEG_asisdmisc_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a07c00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABA_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABA_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a08400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/0ea08800 level 2
   7fe0fc00/4ea08800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_0ea08800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e208800))
        return iemDecodeA64_CMGT_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea18800))
        return iemDecodeA64_FRINTP_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a08800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%19 (0x3) multi-if=%19 (0x3) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_7fe0fc00_0ea08800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMGE_asimdmisc_Z,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_0ea08800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_CMGE_asimdmisc_Z,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a08c00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CMTST_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMEQ_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a09000 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLAL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMLAL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMLAL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a09400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MLA_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_MLS_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/0ea09800 level 2
   7fe0fc00/4ea09800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_0ea09800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e209800))
        return iemDecodeA64_CMEQ_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea19800))
        return iemDecodeA64_FRINTZ_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe0fc00/2ea09800 level 2
   7fe0fc00/6ea09800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_2ea09800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e209800))
        return iemDecodeA64_CMLE_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea19800))
        return iemDecodeA64_FRINTI_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a09800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%6 (0x1) multi-if=%31 (0x5) reuse=%19 (0x3) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a09800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_7fe0fc00_0ea09800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_7fe0fc00_2ea09800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_0ea09800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_7fe0fc00_2ea09800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a09c00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a09c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MUL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_PMUL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0a400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMAXP_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMAXP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/06a0a800 level 2
   f7e0fc00/46a0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_06a0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e20a800))
        return iemDecodeA64_CMLT_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e30a800))
        return iemDecodeA64_SMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e31a800))
        return iemDecodeA64_SMINV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea1a800))
        return iemDecodeA64_FCVTPS_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/26a0a800 level 2
   f7e0fc00/66a0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_26a0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e30a800))
        return iemDecodeA64_UMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e31a800))
        return iemDecodeA64_UMINV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1a800))
        return iemDecodeA64_FCVTPU_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a0a800 level 1
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%38 (0x6) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_06a0a800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_26a0a800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_06a0a800_2,
        iemDecodeA64_FCVTPS_asisdmisc_R,
        iemDecodeA64_f7e0fc00_26a0a800_2,
        iemDecodeA64_FCVTPU_asisdmisc_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0ac00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMINP_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMINP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0b000 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLSL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMLSL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMLSL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0b400 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMULH_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SQRDMULH_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQRDMULH_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/06a0b800 level 2
   f7e0fc00/46a0b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_06a0b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e20b800))
        return iemDecodeA64_ABS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e31b800))
        return iemDecodeA64_ADDV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea1b800))
        return iemDecodeA64_FCVTZS_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/26a0b800 level 2
   f7e0fc00/66a0b800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_26a0b800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e20b800))
        return iemDecodeA64_NEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1b800))
        return iemDecodeA64_FCVTZU_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a0b800 level 1
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%38 (0x6) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_06a0b800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_26a0b800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_06a0b800_2,
        iemDecodeA64_FCVTZS_asisdmisc_R,
        iemDecodeA64_f7e0fc00_26a0b800_2,
        iemDecodeA64_FCVTZU_asisdmisc_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0bc00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0bc00_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e20bc00))
        return iemDecodeA64_ADDP_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a0c000 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMULL_asimddiff_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMULL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0c400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMINNM_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMINNMP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe3fc00/0ea0c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_0ea0c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea0c800))
        return iemDecodeA64_FCMGT_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0eb0c800))
        return iemDecodeA64_FMINNMV_asimdall_only_H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/1ea0c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_1ea0c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea0c800))
        return iemDecodeA64_FCMGT_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5eb0c800))
        return iemDecodeA64_FMINNMP_asisdpair_only_H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/2ea0c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_2ea0c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea0c800))
        return iemDecodeA64_FCMGE_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x6eb0c800))
        return iemDecodeA64_FMINNMV_asimdall_only_SD(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/3ea0c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_3ea0c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7ea0c800))
        return iemDecodeA64_FCMGE_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7eb0c800))
        return iemDecodeA64_FMINNMP_asisdpair_only_SD(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a0c800 level 1
   mask=0x38030000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%19 (0x6) multi-if=%25 (0x8) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe3fc00_0ea0c800_2,
        iemDecodeA64_URECPE_asimdmisc_R,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe3fc00_1ea0c800_2,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_3fe3fc00_2ea0c800_2,
        iemDecodeA64_URSQRTE_asimdmisc_R,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_3fe3fc00_3ea0c800_2,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38030000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0cc00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLS_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMLSL2_asimdsame_F,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0d000 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0d400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FSUB_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FABD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FABD_asisdsame_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/06a0d800 level 2
   f7e0fc00/46a0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_06a0d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea0d800))
        return iemDecodeA64_FCMEQ_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea1d800))
        return iemDecodeA64_FRECPE_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/26a0d800 level 2
   f7e0fc00/66a0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_26a0d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea0d800))
        return iemDecodeA64_FCMLE_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1d800))
        return iemDecodeA64_FRSQRTE_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/56a0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_56a0d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea0d800))
        return iemDecodeA64_FCMEQ_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea1d800))
        return iemDecodeA64_FRECPE_asisdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/76a0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_76a0d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7ea0d800))
        return iemDecodeA64_FCMLE_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7ea1d800))
        return iemDecodeA64_FRSQRTE_asisdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a0d800 level 1
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%25 (0x4) multi-if=%38 (0x6) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_06a0d800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_26a0d800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_06a0d800_2,
        iemDecodeA64_f7e0fc00_56a0d800_2,
        iemDecodeA64_f7e0fc00_26a0d800_2,
        iemDecodeA64_f7e0fc00_76a0d800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0dc00 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FAMAX_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FAMIN_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0e400 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCMGT_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_FCMGT_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_FCMGT_asisdsame_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0e800 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FCMLT_asimdmisc_FZ,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_FCMLT_asimdmisc_FZ,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_FCMLT_asisdmisc_FZ,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0ec00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLSL_asimdsame_F,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FACGT_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FACGT_asisdsame_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0f400 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMIN_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMINP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/06a0f800 level 2
   f7e0fc00/46a0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_06a0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea0f800))
        return iemDecodeA64_FABS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0eb0f800))
        return iemDecodeA64_FMINV_asimdall_only_H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/26a0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_26a0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea0f800))
        return iemDecodeA64_FNEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1f800))
        return iemDecodeA64_FSQRT_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/56a0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_56a0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea1f800))
        return iemDecodeA64_FRECPX_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5eb0f800))
        return iemDecodeA64_FMINP_asisdpair_only_H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/66a0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_66a0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea0f800))
        return iemDecodeA64_FNEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1f800))
        return iemDecodeA64_FSQRT_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x6eb0f800))
        return iemDecodeA64_FMINV_asimdall_only_SD(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06a0f800 level 1
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%31 (0x5) multi-if=%31 (0x5) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_06a0f800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_26a0f800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_06a0f800_2,
        iemDecodeA64_f7e0fc00_56a0f800_2,
        iemDecodeA64_f7e0fc00_66a0f800_2,
        iemDecodeA64_FMINP_asisdpair_only_SD,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06a0fc00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06a0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FRSQRTS_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FRSQRTS_asisdsame_only,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FSCALE_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe6fc00/1ec00000 level 2
   3fe6fc00/1ec00c00 level 2
   3fe6fc00/1ec01000 level 2
   7fe6fc00/1ec01400 level 2
   3fe6fc00/1ec01800 level 2
   3fe6fc00/1ec02000 level 2
   3fe6fc00/1ec02800 level 2
   3fe6fc00/1ec03000 level 2
   3fe6fc00/1ec03800 level 2
   7fe6fc00/1ec03c00 level 2
   3fe6fc00/1ec04000 level 2
   3fe6fc00/1ec05000 level 2
   3fe6fc00/1ec05800 level 2
   3fe6fc00/1ec06000 level 2
   3fe6fc00/1ec06800 level 2
   3fe6fc00/1ec07000 level 2
   3fe6fc00/1ec07800 level 2
   3fe6fc00/1ec0c400 level 2
   3fe6fc00/1ec0cc00 level 2
   3fe6fc00/1ec0d400 level 2
   3fe6fc00/1ec0dc00 level 2
   3fe6fc00/1ec0e400 level 2
   3fe6fc00/1ec0f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_1ec00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed80000))
        return iemDecodeA64_FCVTZS_32H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed90000))
        return iemDecodeA64_FCVTZU_32H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed80000))
        return iemDecodeA64_FCVTZS_64H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed90000))
        return iemDecodeA64_FCVTZU_64H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe6fc00/1ec20000 level 2
   3fe6fc00/1ec20c00 level 2
   3fe6fc00/1ec21000 level 2
   7fe6fc00/1ec21400 level 2
   3fe6fc00/1ec21800 level 2
   3fe6fc00/1ec22000 level 2
   3fe6fc00/1ec22800 level 2
   3fe6fc00/1ec23000 level 2
   3fe6fc00/1ec23800 level 2
   7fe6fc00/1ec23c00 level 2
   3fe6fc00/1ec24000 level 2
   3fe6fc00/1ec25000 level 2
   3fe6fc00/1ec25800 level 2
   3fe6fc00/1ec26000 level 2
   3fe6fc00/1ec26800 level 2
   3fe6fc00/1ec27000 level 2
   3fe6fc00/1ec27800 level 2
   3fe6fc00/1ec2c400 level 2
   3fe6fc00/1ec2cc00 level 2
   3fe6fc00/1ec2d400 level 2
   3fe6fc00/1ec2dc00 level 2
   3fe6fc00/1ec2e400 level 2
   3fe6fc00/1ec2f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe6fc00_1ec20000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec20000))
        return iemDecodeA64_SCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec30000))
        return iemDecodeA64_UCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec20000))
        return iemDecodeA64_SCVTF_H64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec30000))
        return iemDecodeA64_UCVTF_H64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06c00000 level 1
   07e0fc00/06c01000 level 1
   07e0fc00/06c02000 level 1
   07e0fc00/06c03000 level 1
   07e0fc00/06c04000 level 1
   07e0fc00/06c05000 level 1
   07e0fc00/06c06000 level 1
   07e0fc00/06c07000 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_LUTI2_asimdtbl_L6,
        iemDecodeA64_LUTI2_asimdtbl_L6,
        iemDecodeA64_LUTI2_asimdtbl_L6,
        iemDecodeA64_LUTI2_asimdtbl_L6,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/1ec00400 level 2
   7fe1fc00/1ec01c00 level 2
   7fe1fc00/1ec03400 level 2
   7fe1fc00/1ec09400 level 2
   7fe1fc00/1ec0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_1ec00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec20000))
        return iemDecodeA64_SCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed80000))
        return iemDecodeA64_FCVTZS_32H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec20000))
        return iemDecodeA64_SCVTF_H64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed80000))
        return iemDecodeA64_FCVTZS_64H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe1fc00/1ec10400 level 2
   7fe1fc00/1ec11c00 level 2
   7fe1fc00/1ec13400 level 2
   7fe1fc00/1ec19400 level 2
   7fe1fc00/1ec1fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_1ec10400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec30000))
        return iemDecodeA64_UCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed90000))
        return iemDecodeA64_FCVTZU_32H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec30000))
        return iemDecodeA64_UCVTF_H64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed90000))
        return iemDecodeA64_FCVTZU_64H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06c00400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FMINNM_asimdsamefp16_only,
        iemDecodeA64_FMINNM_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1ec00400_2,
        iemDecodeA64_7fe1fc00_1ec10400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FMINNMP_asimdsamefp16_only,
        iemDecodeA64_FMINNMP_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FMINNM_asimdsamefp16_only,
        iemDecodeA64_FMINNM_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FMINNMP_asimdsamefp16_only,
        iemDecodeA64_FMINNMP_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0febfc00/0ec20800 level 2
   0febfc00/0ec24400 level 2
   0febfc00/0ec24800 level 2
   0febfc00/0ec24c00 level 2
   0febfc00/0ec25400 level 2
   0febfc00/0ec25c00 level 2
   0febfc00/0ec26400 level 2
   0febfc00/0ec26c00 level 2
   0febfc00/0ec27400 level 2
   0febfc00/0ec27c00 level 2
   0febfc00/0ec28000 level 2
   0febfc00/0ec28800 level 2
   0febfc00/0ec29000 level 2
   0febfc00/0ec29800 level 2
   0febfc00/0ec29c00 level 2
   0febfc00/0ec2a000 level 2
   0febfc00/0ec2a400 level 2
   0febfc00/0ec2a800 level 2
   0febfc00/0ec2ac00 level 2
   0febfc00/0ec2b000 level 2
   0febfc00/0ec2b400 level 2
   0febfc00/0ec2b800 level 2
   0febfc00/0ec2bc00 level 2
   0febfc00/0ec2c000 level 2
   0febfc00/0ec2c800 level 2
   0febfc00/0ec2d000 level 2
   0febfc00/0ec2d800 level 2
   0febfc00/0ec2e000 level 2
   0febfc00/0ec2e800 level 2
   0febfc00/0ec2ec00 level 2
   0febfc00/0ec2f000 level 2
   0febfc00/0ec2f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0ec20800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec20000))
        return iemDecodeA64_SCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec20000))
        return iemDecodeA64_SCVTF_H64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0ec30800 level 2
   0febfc00/0ec34400 level 2
   0febfc00/0ec34800 level 2
   0febfc00/0ec34c00 level 2
   0febfc00/0ec35400 level 2
   0febfc00/0ec35c00 level 2
   0febfc00/0ec36400 level 2
   0febfc00/0ec36c00 level 2
   0febfc00/0ec37400 level 2
   0febfc00/0ec37c00 level 2
   0febfc00/0ec38000 level 2
   0febfc00/0ec38800 level 2
   0febfc00/0ec39000 level 2
   0febfc00/0ec39800 level 2
   0febfc00/0ec39c00 level 2
   0febfc00/0ec3a000 level 2
   0febfc00/0ec3a400 level 2
   0febfc00/0ec3a800 level 2
   0febfc00/0ec3ac00 level 2
   0febfc00/0ec3b000 level 2
   0febfc00/0ec3b400 level 2
   0febfc00/0ec3b800 level 2
   0febfc00/0ec3bc00 level 2
   0febfc00/0ec3c000 level 2
   0febfc00/0ec3c800 level 2
   0febfc00/0ec3d000 level 2
   0febfc00/0ec3d800 level 2
   0febfc00/0ec3e000 level 2
   0febfc00/0ec3e800 level 2
   0febfc00/0ec3ec00 level 2
   0febfc00/0ec3f000 level 2
   0febfc00/0ec3f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0ec30800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec30000))
        return iemDecodeA64_UCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec30000))
        return iemDecodeA64_UCVTF_H64_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0ec80800 level 2
   0febfc00/0ec84400 level 2
   0febfc00/0ec84800 level 2
   0febfc00/0ec84c00 level 2
   0febfc00/0ec85400 level 2
   0febfc00/0ec85c00 level 2
   0febfc00/0ec86400 level 2
   0febfc00/0ec86c00 level 2
   0febfc00/0ec87400 level 2
   0febfc00/0ec87c00 level 2
   0febfc00/0ec88000 level 2
   0febfc00/0ec88800 level 2
   0febfc00/0ec89000 level 2
   0febfc00/0ec89800 level 2
   0febfc00/0ec89c00 level 2
   0febfc00/0ec8a000 level 2
   0febfc00/0ec8a400 level 2
   0febfc00/0ec8a800 level 2
   0febfc00/0ec8ac00 level 2
   0febfc00/0ec8b000 level 2
   0febfc00/0ec8b400 level 2
   0febfc00/0ec8b800 level 2
   0febfc00/0ec8bc00 level 2
   0febfc00/0ec8c000 level 2
   0febfc00/0ec8c800 level 2
   0febfc00/0ec8d000 level 2
   0febfc00/0ec8d800 level 2
   0febfc00/0ec8e000 level 2
   0febfc00/0ec8e800 level 2
   0febfc00/0ec8ec00 level 2
   0febfc00/0ec8f000 level 2
   0febfc00/0ec8f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0ec80800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed80000))
        return iemDecodeA64_FCVTZS_32H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed80000))
        return iemDecodeA64_FCVTZS_64H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0ec90800 level 2
   0febfc00/0ec94400 level 2
   0febfc00/0ec94800 level 2
   0febfc00/0ec94c00 level 2
   0febfc00/0ec95400 level 2
   0febfc00/0ec95c00 level 2
   0febfc00/0ec96400 level 2
   0febfc00/0ec96c00 level 2
   0febfc00/0ec97400 level 2
   0febfc00/0ec97c00 level 2
   0febfc00/0ec98000 level 2
   0febfc00/0ec98800 level 2
   0febfc00/0ec99000 level 2
   0febfc00/0ec99800 level 2
   0febfc00/0ec99c00 level 2
   0febfc00/0ec9a000 level 2
   0febfc00/0ec9a400 level 2
   0febfc00/0ec9a800 level 2
   0febfc00/0ec9ac00 level 2
   0febfc00/0ec9b000 level 2
   0febfc00/0ec9b400 level 2
   0febfc00/0ec9b800 level 2
   0febfc00/0ec9bc00 level 2
   0febfc00/0ec9c000 level 2
   0febfc00/0ec9c800 level 2
   0febfc00/0ec9d000 level 2
   0febfc00/0ec9d800 level 2
   0febfc00/0ec9e000 level 2
   0febfc00/0ec9e800 level 2
   0febfc00/0ec9ec00 level 2
   0febfc00/0ec9f000 level 2
   0febfc00/0ec9f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0ec90800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed90000))
        return iemDecodeA64_FCVTZU_32H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed90000))
        return iemDecodeA64_FCVTZU_64H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06c00800 level 1
   07e0fc00/06c04400 level 1
   07e0fc00/06c04800 level 1
   07e0fc00/06c04c00 level 1
   07e0fc00/06c05400 level 1
   07e0fc00/06c05c00 level 1
   07e0fc00/06c06400 level 1
   07e0fc00/06c06c00 level 1
   07e0fc00/06c07400 level 1
   07e0fc00/06c07c00 level 1
   07e0fc00/06c08800 level 1
   07e0fc00/06c09000 level 1
   07e0fc00/06c09800 level 1
   07e0fc00/06c09c00 level 1
   07e0fc00/06c0a000 level 1
   07e0fc00/06c0a400 level 1
   07e0fc00/06c0a800 level 1
   07e0fc00/06c0ac00 level 1
   07e0fc00/06c0b000 level 1
   07e0fc00/06c0b400 level 1
   07e0fc00/06c0b800 level 1
   07e0fc00/06c0bc00 level 1
   07e0fc00/06c0c000 level 1
   07e0fc00/06c0c800 level 1
   07e0fc00/06c0d000 level 1
   07e0fc00/06c0d800 level 1
   07e0fc00/06c0e000 level 1
   07e0fc00/06c0e800 level 1
   07e0fc00/06c0ec00 level 1
   07e0fc00/06c0f000 level 1
   07e0fc00/06c0f800 level 1
   mask=0x80b0000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%0 (0x0) multi-if=%75 (0xc) reuse=%50 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_0febfc00_0ec20800_2,
        iemDecodeA64_0febfc00_0ec30800_2,
        iemDecodeA64_0febfc00_0ec80800_2,
        iemDecodeA64_0febfc00_0ec90800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c00c00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_FMLS_asimdsamefp16_only,
        iemDecodeA64_FMLS_asimdsamefp16_only,
        iemDecodeA64_FMLS_asimdsamefp16_only,
        iemDecodeA64_FMLS_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c01400 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%38 (0x18) multi-if=%9 (0x6) reuse=%9 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_FSUB_asimdsamefp16_only,
        iemDecodeA64_FSUB_asimdsamefp16_only,
        iemDecodeA64_FSUB_asimdsamefp16_only,
        iemDecodeA64_FSUB_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FABD_asimdsamefp16_only,
        iemDecodeA64_FABD_asimdsamefp16_only,
        iemDecodeA64_FABD_asimdsamefp16_only,
        iemDecodeA64_FABD_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_FSUB_asimdsamefp16_only,
        iemDecodeA64_FSUB_asimdsamefp16_only,
        iemDecodeA64_FSUB_asimdsamefp16_only,
        iemDecodeA64_FSUB_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_Invalid, // 47
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_FABD_asimdsamefp16_only,
        iemDecodeA64_FABD_asimdsamefp16_only,
        iemDecodeA64_FABD_asimdsamefp16_only,
        iemDecodeA64_FABD_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_FABD_asisdsamefp16_only,
        iemDecodeA64_FABD_asisdsamefp16_only,
        iemDecodeA64_FABD_asisdsamefp16_only,
        iemDecodeA64_FABD_asisdsamefp16_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c01800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_UZP1_asimdperm_only,
        iemDecodeA64_UZP1_asimdperm_only,
        iemDecodeA64_UZP1_asimdperm_only,
        iemDecodeA64_UZP1_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c01c00 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FAMAX_asimdsamefp16_only,
        iemDecodeA64_FAMAX_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1ec00400_2,
        iemDecodeA64_7fe1fc00_1ec10400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FAMIN_asimdsamefp16_only,
        iemDecodeA64_FAMIN_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FAMAX_asimdsamefp16_only,
        iemDecodeA64_FAMAX_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FAMIN_asimdsamefp16_only,
        iemDecodeA64_FAMIN_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e1fc00/16c02400 level 2
   f7e1fc00/16c02c00 level 2
   f7e1fc00/16c08c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e1fc00_16c02400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec20000))
        return iemDecodeA64_SCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed80000))
        return iemDecodeA64_FCVTZS_32H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e1fc00/16c12400 level 2
   f7e1fc00/16c12c00 level 2
   f7e1fc00/16c18c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e1fc00_16c12400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec30000))
        return iemDecodeA64_UCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed90000))
        return iemDecodeA64_FCVTZU_32H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e1fc00/96c02400 level 2
   f7e1fc00/96c02c00 level 2
   f7e1fc00/96c08c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e1fc00_96c02400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec20000))
        return iemDecodeA64_SCVTF_H64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed80000))
        return iemDecodeA64_FCVTZS_64H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e1fc00/96c12400 level 2
   f7e1fc00/96c12c00 level 2
   f7e1fc00/96c18c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e1fc00_96c12400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec30000))
        return iemDecodeA64_UCVTF_H64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed90000))
        return iemDecodeA64_FCVTZU_64H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06c02400 level 1
   mask=0xf0010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_f7e1fc00_16c02400_2,
        iemDecodeA64_f7e1fc00_16c12400_2,
        iemDecodeA64_FCMGT_asimdsamefp16_only,
        iemDecodeA64_FCMGT_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_FCMGT_asimdsamefp16_only,
        iemDecodeA64_FCMGT_asimdsamefp16_only,
        iemDecodeA64_FCMGT_asisdsamefp16_only,
        iemDecodeA64_FCMGT_asisdsamefp16_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e1fc00_96c02400_2,
        iemDecodeA64_f7e1fc00_96c12400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c02800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TRN1_asimdperm_only,
        iemDecodeA64_TRN1_asimdperm_only,
        iemDecodeA64_TRN1_asimdperm_only,
        iemDecodeA64_TRN1_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c02c00 level 1
   mask=0xf0010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_f7e1fc00_16c02400_2,
        iemDecodeA64_f7e1fc00_16c12400_2,
        iemDecodeA64_FACGT_asimdsamefp16_only,
        iemDecodeA64_FACGT_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_FACGT_asimdsamefp16_only,
        iemDecodeA64_FACGT_asimdsamefp16_only,
        iemDecodeA64_FACGT_asisdsamefp16_only,
        iemDecodeA64_FACGT_asisdsamefp16_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e1fc00_96c02400_2,
        iemDecodeA64_f7e1fc00_96c12400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c03400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FMIN_asimdsamefp16_only,
        iemDecodeA64_FMIN_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1ec00400_2,
        iemDecodeA64_7fe1fc00_1ec10400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_FMINP_asimdsamefp16_only,
        iemDecodeA64_FMINP_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FMIN_asimdsamefp16_only,
        iemDecodeA64_FMIN_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_FMINP_asimdsamefp16_only,
        iemDecodeA64_FMINP_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c03800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ZIP1_asimdperm_only,
        iemDecodeA64_ZIP1_asimdperm_only,
        iemDecodeA64_ZIP1_asimdperm_only,
        iemDecodeA64_ZIP1_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c03c00 level 1
   mask=0x78060000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%38 (0x18) multi-if=%9 (0x6) reuse=%9 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c03c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_FRSQRTS_asimdsamefp16_only,
        iemDecodeA64_FRSQRTS_asimdsamefp16_only,
        iemDecodeA64_FRSQRTS_asimdsamefp16_only,
        iemDecodeA64_FRSQRTS_asimdsamefp16_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FSCALE_asimdsamefp16_only,
        iemDecodeA64_FSCALE_asimdsamefp16_only,
        iemDecodeA64_FSCALE_asimdsamefp16_only,
        iemDecodeA64_FSCALE_asimdsamefp16_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_FRSQRTS_asimdsamefp16_only,
        iemDecodeA64_FRSQRTS_asimdsamefp16_only,
        iemDecodeA64_FRSQRTS_asimdsamefp16_only,
        iemDecodeA64_FRSQRTS_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 40
        iemDecodeA64_Invalid, // 41
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_FRSQRTS_asisdsamefp16_only,
        iemDecodeA64_FRSQRTS_asisdsamefp16_only,
        iemDecodeA64_FRSQRTS_asisdsamefp16_only,
        iemDecodeA64_FRSQRTS_asisdsamefp16_only,
        iemDecodeA64_Invalid, // 48
        iemDecodeA64_Invalid, // 49
        iemDecodeA64_Invalid, // 50
        iemDecodeA64_Invalid, // 51
        iemDecodeA64_FSCALE_asimdsamefp16_only,
        iemDecodeA64_FSCALE_asimdsamefp16_only,
        iemDecodeA64_FSCALE_asimdsamefp16_only,
        iemDecodeA64_FSCALE_asimdsamefp16_only,
        iemDecodeA64_Invalid, // 56
        iemDecodeA64_Invalid, // 57
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_Invalid, // 63
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x78060000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000003c)) /* bit 27 L 4 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c05800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_UZP2_asimdperm_only,
        iemDecodeA64_UZP2_asimdperm_only,
        iemDecodeA64_UZP2_asimdperm_only,
        iemDecodeA64_UZP2_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c06800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_TRN2_asimdperm_only,
        iemDecodeA64_TRN2_asimdperm_only,
        iemDecodeA64_TRN2_asimdperm_only,
        iemDecodeA64_TRN2_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c07800 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_ZIP2_asimdperm_only,
        iemDecodeA64_ZIP2_asimdperm_only,
        iemDecodeA64_ZIP2_asimdperm_only,
        iemDecodeA64_ZIP2_asimdperm_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c08000 level 1
   mask=0x80b0000 entries=0x10 children=0xd valid=%81 (0xd) leaf=%6 (0x1) multi-if=%75 (0xc) reuse=%75 (0xc) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_SHA512SU0_VV2_cryptosha512_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_0febfc00_0ec20800_2,
        iemDecodeA64_0febfc00_0ec30800_2,
        iemDecodeA64_0febfc00_0ec80800_2,
        iemDecodeA64_0febfc00_0ec90800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe4fc00/1ec08400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe4fc00_1ec08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec20000))
        return iemDecodeA64_SCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ec30000))
        return iemDecodeA64_UCVTF_H32_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed80000))
        return iemDecodeA64_FCVTZS_32H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x1ed90000))
        return iemDecodeA64_FCVTZU_32H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe4fc00/9ec08400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe4fc00_9ec08400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec20000))
        return iemDecodeA64_SCVTF_H64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ec30000))
        return iemDecodeA64_UCVTF_H64_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed80000))
        return iemDecodeA64_FCVTZS_64H_float2fix(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffff0000)) == UINT32_C(0x9ed90000))
        return iemDecodeA64_FCVTZU_64H_float2fix(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06c08400 level 1
   mask=0xb8040000 entries=0x20 children=0xf valid=%47 (0xf) leaf=%41 (0xd) multi-if=%6 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe4fc00_1ec08400_2,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_SQRDMLAH_asimdsame2_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_SQRDMLAH_asisdsame2_only,
        iemDecodeA64_SQRDMLAH_asisdsame2_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_SM4E_VV4_cryptosha512_2,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_bfe4fc00_9ec08400_2,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xb8040000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 18) & UINT32_C(0x00000001)) /* bit 18 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000e)) /* bit 27 L 3 -> 1 */
                        | ((uOpcode >> 27) & UINT32_C(0x00000010)) /* bit 31 L 1 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c08c00 level 1
   mask=0xf0010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_f7e1fc00_16c02400_2,
        iemDecodeA64_f7e1fc00_16c12400_2,
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_SQRDMLSH_asimdsame2_only,
        iemDecodeA64_SQRDMLSH_asisdsame2_only,
        iemDecodeA64_SQRDMLSH_asisdsame2_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_f7e1fc00_96c02400_2,
        iemDecodeA64_f7e1fc00_96c12400_2,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf0010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000001e)) /* bit 28 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c09400 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1ec00400_2,
        iemDecodeA64_7fe1fc00_1ec10400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_SDOT_asimdsame2_D,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_UDOT_asimdsame2_D,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c0c400 level 1
   07e0fc00/06c0cc00 level 1
   07e0fc00/06c0d400 level 1
   07e0fc00/06c0dc00 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_FCMLA_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c0e400 level 1
   07e0fc00/06c0f400 level 1
   mask=0x38060000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%25 (0x8) multi-if=%19 (0x6) reuse=%19 (0x6) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe6fc00_1ec00000_2,
        iemDecodeA64_3fe6fc00_1ec20000_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_FCADD_asimdsame2_C,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38060000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 17) & UINT32_C(0x00000003)) /* bit 17 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06c0fc00 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06c0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_FMLALB_asimdsame2_J,
        iemDecodeA64_FMLALB_asimdsame2_J,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1ec00400_2,
        iemDecodeA64_7fe1fc00_1ec10400_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BFMLAL_asimdsame2_F,
        iemDecodeA64_BFMLAL_asimdsame2_F,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_FMLALT_asimdsame2_J,
        iemDecodeA64_FMLALT_asimdsame2_J,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_BFMLAL_asimdsame2_F,
        iemDecodeA64_BFMLAL_asimdsame2_F,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 1ff7fc00/1ee00000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ee00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee00000))
        return iemDecodeA64_FCVTNS_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee80000))
        return iemDecodeA64_FCVTPS_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee00000))
        return iemDecodeA64_FCVTNS_64H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee80000))
        return iemDecodeA64_FCVTPS_64H_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ee10000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ee10000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee10000))
        return iemDecodeA64_FCVTNU_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee90000))
        return iemDecodeA64_FCVTPU_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee10000))
        return iemDecodeA64_FCVTNU_64H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee90000))
        return iemDecodeA64_FCVTPU_64H_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ee20000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ee20000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee20000))
        return iemDecodeA64_SCVTF_H32_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1eea0000))
        return iemDecodeA64_FCVTNS_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee20000))
        return iemDecodeA64_SCVTF_H64_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9eea0000))
        return iemDecodeA64_FCVTNS_sisd_64H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ee30000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ee30000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee30000))
        return iemDecodeA64_UCVTF_H32_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1eeb0000))
        return iemDecodeA64_FCVTNU_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee30000))
        return iemDecodeA64_UCVTF_H64_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9eeb0000))
        return iemDecodeA64_FCVTNU_sisd_64H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ee40000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ee40000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee40000))
        return iemDecodeA64_FCVTAS_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee40000))
        return iemDecodeA64_FCVTAS_64H_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ee50000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ee50000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee50000))
        return iemDecodeA64_FCVTAU_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee50000))
        return iemDecodeA64_FCVTAU_64H_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ee60000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ee60000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee60000))
        return iemDecodeA64_FMOV_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee60000))
        return iemDecodeA64_FMOV_64H_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ee70000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ee70000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee70000))
        return iemDecodeA64_FMOV_H32_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ee70000))
        return iemDecodeA64_FMOV_H64_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ef00000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ef00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef00000))
        return iemDecodeA64_FCVTMS_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef80000))
        return iemDecodeA64_FCVTZS_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef00000))
        return iemDecodeA64_FCVTMS_64H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef80000))
        return iemDecodeA64_FCVTZS_64H_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ef10000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ef10000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef10000))
        return iemDecodeA64_FCVTMU_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef90000))
        return iemDecodeA64_FCVTZU_32H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef10000))
        return iemDecodeA64_FCVTMU_64H_float2int(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef90000))
        return iemDecodeA64_FCVTZU_64H_float2int(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ef20000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ef20000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef20000))
        return iemDecodeA64_FCVTPS_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1efa0000))
        return iemDecodeA64_FCVTAS_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef20000))
        return iemDecodeA64_FCVTPS_sisd_64H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9efa0000))
        return iemDecodeA64_FCVTAS_sisd_64H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ef30000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ef30000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef30000))
        return iemDecodeA64_FCVTPU_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1efb0000))
        return iemDecodeA64_FCVTAU_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef30000))
        return iemDecodeA64_FCVTPU_sisd_64H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9efb0000))
        return iemDecodeA64_FCVTAU_sisd_64H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ef40000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ef40000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef40000))
        return iemDecodeA64_FCVTMS_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1efc0000))
        return iemDecodeA64_SCVTF_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef40000))
        return iemDecodeA64_FCVTMS_sisd_64H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9efc0000))
        return iemDecodeA64_SCVTF_sisd_64H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ef50000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ef50000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef50000))
        return iemDecodeA64_FCVTMU_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1efd0000))
        return iemDecodeA64_UCVTF_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef50000))
        return iemDecodeA64_FCVTMU_sisd_64H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9efd0000))
        return iemDecodeA64_UCVTF_sisd_64H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ef60000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ef60000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef60000))
        return iemDecodeA64_FCVTZS_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef60000))
        return iemDecodeA64_FCVTZS_sisd_64H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 1ff7fc00/1ef70000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_1ff7fc00_1ef70000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ef70000))
        return iemDecodeA64_FCVTZU_sisd_32H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x9ef70000))
        return iemDecodeA64_FCVTZU_sisd_64H(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* --decoder-hint1 0x7e0fc00/0x6e00000/0x18170000
   mask=0x18170000 entries=0x40 children=0x30 valid=%75 (0x30) leaf=%0 (0x0) multi-if=%75 (0x30) reuse=%50 (0x20) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_1ff7fc00_0e600000_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_1ff7fc00_1ee00000_2,
        iemDecodeA64_1ff7fc00_1ee10000_2,
        iemDecodeA64_1ff7fc00_1ee20000_2,
        iemDecodeA64_1ff7fc00_1ee30000_2,
        iemDecodeA64_1ff7fc00_1ee40000_2,
        iemDecodeA64_1ff7fc00_1ee50000_2,
        iemDecodeA64_1ff7fc00_1ee60000_2,
        iemDecodeA64_1ff7fc00_1ee70000_2,
        iemDecodeA64_1ff7fc00_1ef00000_2,
        iemDecodeA64_1ff7fc00_1ef10000_2,
        iemDecodeA64_1ff7fc00_1ef20000_2,
        iemDecodeA64_1ff7fc00_1ef30000_2,
        iemDecodeA64_1ff7fc00_1ef40000_2,
        iemDecodeA64_1ff7fc00_1ef50000_2,
        iemDecodeA64_1ff7fc00_1ef60000_2,
        iemDecodeA64_1ff7fc00_1ef70000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x18170000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000007)) /* bit 16 L 3 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000008)) /* bit 20 L 1 -> 3 */
                        | ((uOpcode >> 23) & UINT32_C(0x00000030)) /* bit 27 L 2 -> 4 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* b7e0fc00/16e00400 level 2
   b7e0fc00/16e01400 level 2
   b7e0fc00/16e02400 level 2
   b7e0fc00/16e06400 level 2
   b7e0fc00/16e07400 level 2
   b7e0fc00/16e09400 level 2
   b7e0fc00/16e0a400 level 2
   b7e0fc00/16e0c400 level 2
   f7e0fc00/16e0e400 level 2
   b7e0fc00/16e0f400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_b7e0fc00_16e00400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1ee00400))
        return iemDecodeA64_FCCMP_H_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1ee00410))
        return iemDecodeA64_FCCMPE_H_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e00400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e00400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SHADD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_UHADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e00800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e00800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_REV64_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMUL_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_REV32_asimdmisc_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1ee00c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1ee00c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e200c00))
        return iemDecodeA64_SQADD_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1ee00c00))
        return iemDecodeA64_FCSEL_H_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e00c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e00c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQADD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1ee00c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UQADD_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e01000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SADDW_asimddiff_W,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_H_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UADDW_asimddiff_W,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e01400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e01400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SRHADD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_URHADD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e01800 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e01800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_REV16_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FDIV_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_REV16_asimdmisc_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e01c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e01c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ORN_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BIF_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe0fc00/1ee02000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe0fc00_1ee02000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x1ee02000))
        return iemDecodeA64_FCMP_H_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc1f)) == UINT32_C(0x1ee02010))
        return iemDecodeA64_FCMPE_H_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0x1ee02008))
        return iemDecodeA64_FCMP_HZ_floatcmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc1f)) == UINT32_C(0x1ee02018))
        return iemDecodeA64_FCMPE_HZ_floatcmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e02000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%38 (0x3) multi-if=%25 (0x2) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSUBL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe0fc00_1ee02000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USUBL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e02400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e02400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SHSUB_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_UHSUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e02800 level 1
   mask=0x78000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%19 (0x3) multi-if=%31 (0x5) reuse=%31 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e02800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e202800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FADD_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2e202800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0e202800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2e202800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQXTUN_asisdmisc_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1ee02c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1ee02c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e202c00))
        return iemDecodeA64_SQSUB_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1ee00c00))
        return iemDecodeA64_FCSEL_H_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e02c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e02c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSUB_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1ee02c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UQSUB_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e03000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSUBW_asimddiff_W,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_H_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USUBW_asimddiff_W,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/1ee03400 level 2
   ffe0fc00/1ee04400 level 2
   ffe0fc00/1ee05400 level 2
   ffe0fc00/1ee08400 level 2
   ffe0fc00/1ee0b400 level 2
   bfe0fc00/1ee0d400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_1ee03400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1ee00400))
        return iemDecodeA64_FCCMP_H_floatccmp(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c10)) == UINT32_C(0x1ee00410))
        return iemDecodeA64_FCCMPE_H_floatccmp(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e03400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e03400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CMGT_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1ee03400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMHI_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_CMGT_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CMGT_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_CMHI_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CMHI_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e03800 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%22 (0x7) multi-if=%12 (0x4) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e03800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe2fc00_0e203800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FSUB_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe2fc00_2e203800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_bfe2fc00_0e203800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SUQADD_asisdmisc_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_bfe2fc00_2e203800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_USQADD_asisdmisc_R,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1ee03c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1ee03c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1ee00c00))
        return iemDecodeA64_FCSEL_H_floatsel(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5ee03c00))
        return iemDecodeA64_CMGE_asisdsame_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e03c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e03c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CMGE_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1ee03c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMHS_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_CMHS_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 0febfc00/0ee04000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0ee04000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e204000))
        return iemDecodeA64_ADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e204000))
        return iemDecodeA64_RADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee04000))
        return iemDecodeA64_FMOV_H_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee44000))
        return iemDecodeA64_FRINTN_H_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0ee14000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0ee14000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e204000))
        return iemDecodeA64_ADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e204000))
        return iemDecodeA64_RADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee14000))
        return iemDecodeA64_FNEG_H_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee54000))
        return iemDecodeA64_FRINTM_H_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0ee24000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0ee24000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e204000))
        return iemDecodeA64_ADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e204000))
        return iemDecodeA64_RADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee24000))
        return iemDecodeA64_FCVT_SH_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee64000))
        return iemDecodeA64_FRINTA_H_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 0febfc00/0ee34000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_0febfc00_0ee34000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x0e204000))
        return iemDecodeA64_ADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf20fc00)) == UINT32_C(0x2e204000))
        return iemDecodeA64_RADDHN_asimddiff_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee74000))
        return iemDecodeA64_FRINTX_H_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e04000 level 1
   mask=0x80b0000 entries=0x10 children=0x10 valid=%100 (0x10) leaf=%0 (0x0) multi-if=%100 (0x10) reuse=%75 (0xc) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_5fe6fc00_16000800_2,
        iemDecodeA64_0febfc00_0ee04000_2,
        iemDecodeA64_0febfc00_0ee14000_2,
        iemDecodeA64_0febfc00_0ee24000_2,
        iemDecodeA64_0febfc00_0ee34000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
        iemDecodeA64_5fe6fc00_0e204000_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x080b0000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 17) & UINT32_C(0x00000004)) /* bit 19 L 1 -> 2 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000008)) /* bit 27 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e04400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e04400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1ee03400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_USHL_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_USHL_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e04800 level 1
   mask=0x78000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%25 (0x4) multi-if=%31 (0x5) reuse=%31 (0x5) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e04800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0e204800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMAX_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2e204800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0e204800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQXTN_asisdmisc_N,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2e204800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UQXTN_asisdmisc_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1ee04c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1ee04c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e204c00))
        return iemDecodeA64_SQSHL_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1ee00c00))
        return iemDecodeA64_FCSEL_H_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e04c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e04c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1ee04c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UQSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e05000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABAL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_H_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABAL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e05400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e05400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1ee03400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SRSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SRSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_URSHL_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_URSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e05800 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e05800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CNT_asimdmisc_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMIN_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_CNT_asimdmisc_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1ee05c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1ee05c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff20fc00)) == UINT32_C(0x5e205c00))
        return iemDecodeA64_SQRSHL_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1ee00c00))
        return iemDecodeA64_FCSEL_H_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e05c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e05c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRSHL_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1ee05c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQRSHL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_UQRSHL_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e06400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e06400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SMAX_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_UMAX_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e06800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e06800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SADALP_asimdmisc_P,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMAXNM_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UADALP_asimdmisc_P,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e06c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e06c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMIN_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMIN_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e07000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABDL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_H_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABDL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e07400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e07400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SABD_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_UABD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/2ee07800 level 2
   ffe0fc00/6ee07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2ee07800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e207800))
        return iemDecodeA64_SQNEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ee17800))
        return iemDecodeA64_BF2CVTL_asimdmisc_V(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e07800 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%28 (0x9) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e07800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQABS_asimdmisc_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMINNM_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2ee07800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQABS_asimdmisc_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQABS_asisdmisc_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_2ee07800_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQNEG_asisdmisc_R,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e07c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e07c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SABA_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UABA_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e08400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e08400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADD_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1ee03400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SUB_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ADD_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_ADD_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SUB_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SUB_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe0fc00/0ee08800 level 2
   7fe0fc00/4ee08800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe0fc00_0ee08800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e208800))
        return iemDecodeA64_CMGT_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea18800))
        return iemDecodeA64_FRINTP_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef98800))
        return iemDecodeA64_FRINTP_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e08800 level 1
   mask=0x78000000 entries=0x10 children=0x9 valid=%56 (0x9) leaf=%38 (0x6) multi-if=%19 (0x3) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e08800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_7fe0fc00_0ee08800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMUL_H_floatdp2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMGE_asimdmisc_Z,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_7fe0fc00_0ee08800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_CMGT_asisdmisc_Z,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_CMGE_asimdmisc_Z,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_CMGE_asisdmisc_Z,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1ee08c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1ee08c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1ee00c00))
        return iemDecodeA64_FCSEL_H_floatsel(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe0fc00)) == UINT32_C(0x5ee08c00))
        return iemDecodeA64_CMTST_asisdsame_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e08c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e08c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_CMTST_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1ee08c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_CMEQ_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_CMEQ_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e09000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLAL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_H_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMLAL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMLAL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e09400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e09400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_MLA_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_MLS_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/06e09800 level 2
   f7e0fc00/46e09800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_06e09800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e209800))
        return iemDecodeA64_CMEQ_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea19800))
        return iemDecodeA64_FRINTZ_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef99800))
        return iemDecodeA64_FRINTZ_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/26e09800 level 2
   f7e0fc00/66e09800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_26e09800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e209800))
        return iemDecodeA64_CMLE_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea19800))
        return iemDecodeA64_FRINTI_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef99800))
        return iemDecodeA64_FRINTI_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e09800 level 1
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%38 (0x6) multi-if=%25 (0x4) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e09800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_06e09800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_26e09800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_06e09800_2,
        iemDecodeA64_CMEQ_asisdmisc_Z,
        iemDecodeA64_f7e0fc00_26e09800_2,
        iemDecodeA64_CMLE_asisdmisc_Z,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e09c00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e09c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MUL_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_PMUL_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0a400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_SMAXP_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_UMAXP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 67f8fc00/06e0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_06e0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e20a800))
        return iemDecodeA64_CMLT_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea1a800))
        return iemDecodeA64_FCVTPS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/06f0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_06f0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e30a800))
        return iemDecodeA64_SMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e31a800))
        return iemDecodeA64_SMINV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/06f8a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_06f8a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef9a800))
        return iemDecodeA64_FCVTPS_asimdmiscfp16_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/26e0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_26e0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1a800))
        return iemDecodeA64_FCVTPU_asimdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/26f0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_26f0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e30a800))
        return iemDecodeA64_UMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e31a800))
        return iemDecodeA64_UMINV_asimdall_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/26f8a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_26f8a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef9a800))
        return iemDecodeA64_FCVTPU_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/46e0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_46e0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e20a800))
        return iemDecodeA64_CMLT_asimdmisc_Z(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea1a800))
        return iemDecodeA64_FCVTPS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea1a800))
        return iemDecodeA64_FCVTPS_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ee0a800))
        return iemDecodeA64_CMLT_asisdmisc_Z(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/46f0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_46f0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e30a800))
        return iemDecodeA64_SMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x0e31a800))
        return iemDecodeA64_SMINV_asimdall_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/46f8a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_46f8a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef9a800))
        return iemDecodeA64_FCVTPS_asimdmiscfp16_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ef9a800))
        return iemDecodeA64_FCVTPS_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/66e0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_66e0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1a800))
        return iemDecodeA64_FCVTPU_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7ea1a800))
        return iemDecodeA64_FCVTPU_asisdmisc_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/66f0a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_66f0a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e30a800))
        return iemDecodeA64_UMAXV_asimdall_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbf3ffc00)) == UINT32_C(0x2e31a800))
        return iemDecodeA64_UMINV_asimdall_only(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 67f8fc00/66f8a800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_67f8fc00_66f8a800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef9a800))
        return iemDecodeA64_FCVTPU_asimdmiscfp16_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7ef9a800))
        return iemDecodeA64_FCVTPU_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e0a800 level 1
   mask=0x60180000 entries=0x10 children=0xe valid=%88 (0xe) leaf=%6 (0x1) multi-if=%81 (0xd) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0a800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_67f8fc00_06e0a800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_67f8fc00_06f0a800_2,
        iemDecodeA64_67f8fc00_06f8a800_2,
        iemDecodeA64_67f8fc00_26e0a800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_67f8fc00_26f0a800_2,
        iemDecodeA64_67f8fc00_26f8a800_2,
        iemDecodeA64_67f8fc00_46e0a800_2,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_67f8fc00_46f0a800_2,
        iemDecodeA64_67f8fc00_46f8a800_2,
        iemDecodeA64_67f8fc00_66e0a800_2,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_67f8fc00_66f0a800_2,
        iemDecodeA64_67f8fc00_66f8a800_2,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x60180000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 19) & UINT32_C(0x00000003)) /* bit 19 L 2 -> 0 */
                        | ((uOpcode >> 27) & UINT32_C(0x0000000c)) /* bit 29 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0ac00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0ac00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMINP_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMINP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0b000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLSL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_H_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMLSL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMLSL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0b400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%31 (0xa) multi-if=%3 (0x1) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1ee03400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMULH_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdsame_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SQRDMULH_asimdsame_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQRDMULH_asisdsame_only,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0b800 level 1
   mask=0x38190000 entries=0x40 children=0x1e valid=%47 (0x1e) leaf=%34 (0x16) multi-if=%12 (0x8) reuse=%12 (0x8) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0b800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_ABS_asimdmisc_R,
        iemDecodeA64_FCVTZS_asimdmisc_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ADDV_asimdall_only,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_FCVTZS_asimdmiscfp16_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_ABS_asisdmisc_R,
        iemDecodeA64_FCVTZS_asisdmisc_R,
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_ADDP_asisdpair_only,
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_FCVTZS_asisdmiscfp16_R,
        iemDecodeA64_Invalid, // 32
        iemDecodeA64_Invalid, // 33
        iemDecodeA64_Invalid, // 34
        iemDecodeA64_Invalid, // 35
        iemDecodeA64_Invalid, // 36
        iemDecodeA64_Invalid, // 37
        iemDecodeA64_Invalid, // 38
        iemDecodeA64_Invalid, // 39
        iemDecodeA64_NEG_asimdmisc_R,
        iemDecodeA64_FCVTZU_asimdmisc_R,
        iemDecodeA64_Invalid, // 42
        iemDecodeA64_Invalid, // 43
        iemDecodeA64_Invalid, // 44
        iemDecodeA64_Invalid, // 45
        iemDecodeA64_Invalid, // 46
        iemDecodeA64_FCVTZU_asimdmiscfp16_R,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_NEG_asisdmisc_R,
        iemDecodeA64_FCVTZU_asisdmisc_R,
        iemDecodeA64_Invalid, // 58
        iemDecodeA64_Invalid, // 59
        iemDecodeA64_Invalid, // 60
        iemDecodeA64_Invalid, // 61
        iemDecodeA64_Invalid, // 62
        iemDecodeA64_FCVTZU_asisdmiscfp16_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x40);

    /* fMask=0x38190000 -> 0x0000003f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 18) & UINT32_C(0x00000006)) /* bit 19 L 2 -> 1 */
                        | ((uOpcode >> 24) & UINT32_C(0x00000038)) /* bit 27 L 3 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0bc00 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0bc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ADDP_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ADDP_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 7fe1fc00/1ee0c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_1ee0c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee0c000))
        return iemDecodeA64_FABS_H_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee2c000))
        return iemDecodeA64_FCVT_DH_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee4c000))
        return iemDecodeA64_FRINTP_H_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 7fe1fc00/1ee1c000 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_7fe1fc00_1ee1c000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee1c000))
        return iemDecodeA64_FSQRT_H_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee5c000))
        return iemDecodeA64_FRINTZ_H_floatdp1(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x1ee7c000))
        return iemDecodeA64_FRINTI_H_floatdp1(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e0c000 level 1
   mask=0x78010000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%31 (0xa) multi-if=%12 (0x4) reuse=%6 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_SMULL_asimddiff_L,
        iemDecodeA64_SMULL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe1fc00_1ee0c000_2,
        iemDecodeA64_7fe1fc00_1ee1c000_2,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_UMULL_asimddiff_L,
        iemDecodeA64_UMULL_asimddiff_L,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_SMULL_asimddiff_L,
        iemDecodeA64_SMULL_asimddiff_L,
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_UMULL_asimddiff_L,
        iemDecodeA64_UMULL_asimddiff_L,
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x78010000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000001)) /* bit 16 L 1 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000001e)) /* bit 27 L 4 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0c400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FMINNM_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_FMINNMP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 3fe3fc00/0ee0c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_0ee0c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea0c800))
        return iemDecodeA64_FCMGT_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef8c800))
        return iemDecodeA64_FCMGT_asimdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/1ee0c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_1ee0c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea0c800))
        return iemDecodeA64_FCMGT_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ef8c800))
        return iemDecodeA64_FCMGT_asisdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/2ee0c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_2ee0c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea0c800))
        return iemDecodeA64_FCMGE_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef8c800))
        return iemDecodeA64_FCMGE_asimdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 3fe3fc00/3ee0c800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_3fe3fc00_3ee0c800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7ea0c800))
        return iemDecodeA64_FCMGE_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7eb0c800))
        return iemDecodeA64_FMINNMP_asisdpair_only_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7ef8c800))
        return iemDecodeA64_FCMGE_asisdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e0c800 level 1
   mask=0x38030000 entries=0x20 children=0xe valid=%44 (0xe) leaf=%19 (0x6) multi-if=%25 (0x8) reuse=%12 (0x4) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0c800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_3fe3fc00_0ee0c800_2,
        iemDecodeA64_URECPE_asimdmisc_R,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_3fe3fc00_1ee0c800_2,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_Invalid, // 18
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_3fe3fc00_2ee0c800_2,
        iemDecodeA64_URSQRTE_asimdmisc_R,
        iemDecodeA64_Invalid, // 22
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_3fe3fc00_3ee0c800_2,
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0x38030000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 25) & UINT32_C(0x0000001c)) /* bit 27 L 3 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0cc00 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0cc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLS_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_FMLS_asimdsame_only,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0d000 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimddiff_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMOV_H_floatimm,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimddiff_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisddiff_only,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0d400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0d400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FSUB_asimdsame_only,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_ffe0fc00_1ee03400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FABD_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FABD_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 37e3fc00/06e0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_37e3fc00_06e0d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea0d800))
        return iemDecodeA64_FCMEQ_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef8d800))
        return iemDecodeA64_FCMEQ_asimdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 37e3fc00/06e1d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_37e3fc00_06e1d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea1d800))
        return iemDecodeA64_FRECPE_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef9d800))
        return iemDecodeA64_FRECPE_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 37e3fc00/16e0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_37e3fc00_16e0d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea0d800))
        return iemDecodeA64_FCMEQ_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ef8d800))
        return iemDecodeA64_FCMEQ_asisdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 37e3fc00/16e1d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_37e3fc00_16e1d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea1d800))
        return iemDecodeA64_FRECPE_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ef9d800))
        return iemDecodeA64_FRECPE_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 37e3fc00/26e0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_37e3fc00_26e0d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea0d800))
        return iemDecodeA64_FCMLE_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef8d800))
        return iemDecodeA64_FCMLE_asimdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 37e3fc00/26e1d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_37e3fc00_26e1d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1d800))
        return iemDecodeA64_FRSQRTE_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef9d800))
        return iemDecodeA64_FRSQRTE_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 37e3fc00/36e0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_37e3fc00_36e0d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7ea0d800))
        return iemDecodeA64_FCMLE_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7ef8d800))
        return iemDecodeA64_FCMLE_asisdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 37e3fc00/36e1d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_37e3fc00_36e1d800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x7ea1d800))
        return iemDecodeA64_FRSQRTE_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x7ef9d800))
        return iemDecodeA64_FRSQRTE_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e0d800 level 1
   mask=0x30030000 entries=0x10 children=0xc valid=%75 (0xc) leaf=%12 (0x2) multi-if=%62 (0xa) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0d800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_37e3fc00_06e0d800_2,
        iemDecodeA64_37e3fc00_06e1d800_2,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_37e3fc00_16e0d800_2,
        iemDecodeA64_37e3fc00_16e1d800_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_37e3fc00_26e0d800_2,
        iemDecodeA64_37e3fc00_26e1d800_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_37e3fc00_36e0d800_2,
        iemDecodeA64_37e3fc00_36e1d800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x30030000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 16) & UINT32_C(0x00000003)) /* bit 16 L 2 -> 0 */
                        | ((uOpcode >> 26) & UINT32_C(0x0000000c)) /* bit 28 L 2 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0dc00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0dc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FAMAX_asimdsame_only,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FAMIN_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0e400 level 1
   mask=0xf0000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%38 (0x6) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_FCMGT_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_FCMGT_asimdsame_only,
        iemDecodeA64_FCMGT_asisdsame_only,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/06e0e800 level 2
   f7e0fc00/46e0e800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_06e0e800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea0e800))
        return iemDecodeA64_FCMLT_asimdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef8e800))
        return iemDecodeA64_FCMLT_asimdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/56e0e800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_56e0e800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea0e800))
        return iemDecodeA64_FCMLT_asisdmisc_FZ(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ef8e800))
        return iemDecodeA64_FCMLT_asisdmiscfp16_FZ(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e0e800 level 1
   mask=0xf0000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%25 (0x4) multi-if=%19 (0x3) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0e800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_06e0e800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 2
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_06e0e800_2,
        iemDecodeA64_f7e0fc00_56e0e800_2,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0ec00 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0ec00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FCSEL_H_floatsel,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FACGT_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FACGT_asisdsame_only,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/06e0f000 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0f000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x36000000))
        return iemDecodeA64_TBZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe01fe0)) == UINT32_C(0x1ee01000))
        return iemDecodeA64_FMOV_H_floatimm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e0f400 level 1
   mask=0xb0000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FMIN_asimdsame_only,
        iemDecodeA64_b7e0fc00_16e00400_2,
        iemDecodeA64_FMINP_asimdsame_only,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_TBZ_only_testbranch,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xb0000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000003)) /* bit 28 L 2 -> 0 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* f7e0fc00/06e0f800 level 2
   f7e0fc00/46e0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_06e0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x0ea0f800))
        return iemDecodeA64_FABS_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x0ef8f800))
        return iemDecodeA64_FABS_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/26e0f800 level 2
   f7e0fc00/66e0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_26e0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea0f800))
        return iemDecodeA64_FNEG_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbfbffc00)) == UINT32_C(0x2ea1f800))
        return iemDecodeA64_FSQRT_asimdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef8f800))
        return iemDecodeA64_FNEG_asimdmiscfp16_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbffffc00)) == UINT32_C(0x2ef9f800))
        return iemDecodeA64_FSQRT_asimdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* f7e0fc00/56e0f800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_f7e0fc00_56e0f800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffbffc00)) == UINT32_C(0x5ea1f800))
        return iemDecodeA64_FRECPX_asisdmisc_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfffffc00)) == UINT32_C(0x5ef9f800))
        return iemDecodeA64_FRECPX_asisdmiscfp16_R(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e0f800 level 1
   mask=0xf0000000 entries=0x10 children=0xa valid=%62 (0xa) leaf=%31 (0x5) multi-if=%31 (0x5) reuse=%12 (0x2) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0f800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_f7e0fc00_06e0f800_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_f7e0fc00_26e0f800_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_f7e0fc00_06e0f800_2,
        iemDecodeA64_f7e0fc00_56e0f800_2,
        iemDecodeA64_f7e0fc00_26e0f800_2,
        iemDecodeA64_FMINP_asisdpair_only_SD,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xf0000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x0000000f)) /* bit 28 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0ee0fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0ee0fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfa0fc00)) == UINT32_C(0x0ea0fc00))
        return iemDecodeA64_FRSQRTS_asimdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffa0fc00)) == UINT32_C(0x5ea0fc00))
        return iemDecodeA64_FRSQRTS_asisdsame_only(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe00c00)) == UINT32_C(0x1ee00c00))
        return iemDecodeA64_FCSEL_H_floatsel(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/06e0fc00 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_06e0fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0ee0fc00_2,
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_FSCALE_asimdsame_only,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07000000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07000000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f000400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f000400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f000400))
        return iemDecodeA64_SSHR_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x0f000400))
        return iemDecodeA64_MOVI_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f000400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f000400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f000400))
        return iemDecodeA64_SSHR_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f000400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f000400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f000400))
        return iemDecodeA64_USHR_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x2f000400))
        return iemDecodeA64_MVNI_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07000400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%31 (0x5) multi-if=%19 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07000400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f000400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f000400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f000400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_USHR_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/17000800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_17000800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07000800 level 1
   mask=0x70000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07000800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FDOT_asimdelem_D,
        iemDecodeA64_77e0fc00_17000800_2,
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FDOT_asimdelem_D,
        iemDecodeA64_BRAA_64P_branch_reg,
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07000c00 level 1
   mask=0xe8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07000c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMADD_S_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_BRAB_64P_branch_reg,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xe8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000e)) /* bit 29 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f001000 level 2
   afe0fc00/0f001800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f001000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f001000))
        return iemDecodeA64_FMLA_asimdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x5f001000))
        return iemDecodeA64_FMLA_asisdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07001000 level 1
   07e0fc00/07001800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07001000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f001000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f001400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f001400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f001400))
        return iemDecodeA64_SSRA_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x0f001400))
        return iemDecodeA64_ORR_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f001400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f001400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f001400))
        return iemDecodeA64_SSRA_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f001400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f001400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f001400))
        return iemDecodeA64_USRA_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x2f001400))
        return iemDecodeA64_BIC_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07001400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%31 (0x5) multi-if=%19 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07001400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f001400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f001400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f001400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_USRA_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07001c00 level 1
   07e0fc00/07002c00 level 1
   07e0fc00/07003c00 level 1
   07e0fc00/07004c00 level 1
   07e0fc00/07005c00 level 1
   07e0fc00/07006c00 level 1
   07e0fc00/07007c00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07001c00_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07002000 level 1
   07e0fc00/07002800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07002000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f002400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f002400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f002400))
        return iemDecodeA64_SRSHR_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x0f000400))
        return iemDecodeA64_MOVI_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f002400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f002400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f002400))
        return iemDecodeA64_SRSHR_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f002400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f002400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f002400))
        return iemDecodeA64_URSHR_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x2f000400))
        return iemDecodeA64_MVNI_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07002400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%31 (0x5) multi-if=%19 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07002400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f002400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f002400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f002400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_URSHR_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f003000 level 2
   afe0fc00/0f003800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f003000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f003000))
        return iemDecodeA64_SQDMLAL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f003000))
        return iemDecodeA64_SQDMLAL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07003000 level 1
   07e0fc00/07003800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07003000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f003000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f003400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f003400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f003400))
        return iemDecodeA64_SRSRA_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x0f001400))
        return iemDecodeA64_ORR_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f003400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f003400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f003400))
        return iemDecodeA64_SRSRA_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f003400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f003400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f003400))
        return iemDecodeA64_URSRA_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x2f001400))
        return iemDecodeA64_BIC_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07003400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%31 (0x5) multi-if=%19 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07003400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f003400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f003400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f003400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_URSRA_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07004000 level 1
   07e0fc00/07004800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07004000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMADD_S_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MLS_asimdelem_R,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/2f004400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f004400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f004400))
        return iemDecodeA64_SRI_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x2f000400))
        return iemDecodeA64_MVNI_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07004400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07004400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MOVI_asimdimm_L_sl,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f004400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SRI_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f005000 level 2
   afe0fc00/0f005800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f005000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f005000))
        return iemDecodeA64_FMLS_asimdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x5f005000))
        return iemDecodeA64_FMLS_asisdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07005000 level 1
   07e0fc00/07005800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07005000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f005000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f005400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f005400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f005400))
        return iemDecodeA64_SHL_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x0f001400))
        return iemDecodeA64_ORR_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f005400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f005400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f005400))
        return iemDecodeA64_SHL_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f005400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f005400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f005400))
        return iemDecodeA64_SLI_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x2f001400))
        return iemDecodeA64_BIC_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07005400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%31 (0x5) multi-if=%19 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07005400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f005400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f005400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f005400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SLI_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07006000 level 1
   07e0fc00/07006800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07006000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLSL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLSL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/2f006400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f006400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f006400))
        return iemDecodeA64_SQSHLU_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x2f000400))
        return iemDecodeA64_MVNI_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07006400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07006400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MOVI_asimdimm_L_sl,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f006400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQSHLU_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f007000 level 2
   afe0fc00/0f007800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f007000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f007000))
        return iemDecodeA64_SQDMLSL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f007000))
        return iemDecodeA64_SQDMLSL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07007000 level 1
   07e0fc00/07007800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07007000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f007000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f007400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f007400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f007400))
        return iemDecodeA64_SQSHL_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x0f001400))
        return iemDecodeA64_ORR_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f007400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f007400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f007400))
        return iemDecodeA64_SQSHL_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f000000))
        return iemDecodeA64_FMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f007400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f007400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f007400))
        return iemDecodeA64_UQSHL_asimdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff89c00)) == UINT32_C(0x2f001400))
        return iemDecodeA64_BIC_asimdimm_L_sl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07007400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%31 (0x5) multi-if=%19 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07007400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f007400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f007400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f007400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQSHL_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/17008000 level 2
   77e0fc00/17008800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_17008000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f008000))
        return iemDecodeA64_FMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07008000 level 1
   07e0fc00/07008800 level 1
   mask=0x70000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07008000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_77e0fc00_17008000_2,
        iemDecodeA64_FMLALLBB_asimdelem_J,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_FMLALLTB_asimdelem_J,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f008400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f008400))
        return iemDecodeA64_SHRN_asimdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff8dc00)) == UINT32_C(0x0f008400))
        return iemDecodeA64_MOVI_asimdimm_L_hl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f008400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f008400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f008400))
        return iemDecodeA64_SQSHRUN_asimdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff8dc00)) == UINT32_C(0x2f008400))
        return iemDecodeA64_MVNI_asimdimm_L_hl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07008400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%38 (0x6) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07008400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f008400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f008400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQSHRUN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07008c00 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07008c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_RSHRN_asimdshf_N,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRSHRUN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRSHRUN_asisdshf_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f009000 level 2
   bfe0fc00/1f009800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f009000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x5f009000))
        return iemDecodeA64_FMUL_asisdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f008000))
        return iemDecodeA64_FMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07009000 level 1
   07e0fc00/07009800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07009000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMUL_asimdelem_RH_H,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f009000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMULX_asimdelem_RH_H,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FMULX_asisdelem_RH_H,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f009400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f009400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f009400))
        return iemDecodeA64_SQSHRN_asimdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff8dc00)) == UINT32_C(0x0f009400))
        return iemDecodeA64_ORR_asimdimm_L_hl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f009400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f009400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f009400))
        return iemDecodeA64_SQSHRN_asisdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f008000))
        return iemDecodeA64_FMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f009400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f009400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f009400))
        return iemDecodeA64_UQSHRN_asimdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff8dc00)) == UINT32_C(0x2f009400))
        return iemDecodeA64_BIC_asimdimm_L_hl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07009400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%31 (0x5) multi-if=%19 (0x3) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07009400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f009400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f009400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f009400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQSHRN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f009c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f009c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f009c00))
        return iemDecodeA64_SQRSHRN_asisdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f008000))
        return iemDecodeA64_FMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07009c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07009c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRSHRN_asimdshf_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f009c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQRSHRN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQRSHRN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0700a000 level 1
   07e0fc00/0700a800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMULL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/0f00a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_0f00a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f00a400))
        return iemDecodeA64_SSHLL_asimdshf_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff8dc00)) == UINT32_C(0x0f008400))
        return iemDecodeA64_MOVI_asimdimm_L_hl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/2f00a400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_2f00a400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f00a400))
        return iemDecodeA64_USHLL_asimdshf_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff8dc00)) == UINT32_C(0x2f008400))
        return iemDecodeA64_MVNI_asimdimm_L_hl(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0700a400 level 1
   mask=0xb8000000 entries=0x10 children=0x7 valid=%44 (0x7) leaf=%31 (0x5) multi-if=%12 (0x2) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_bfe0fc00_0f00a400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_bfe0fc00_2f00a400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0700ac00 level 1
   07e0fc00/0700bc00 level 1
   07e0fc00/0700cc00 level 1
   07e0fc00/0700dc00 level 1
   07e0fc00/0700ec00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700ac00_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f008000))
        return iemDecodeA64_FMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0700b000 level 1
   07e0fc00/0700b800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisdelem_L,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0700b400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700b400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ORR_asimdimm_L_hl,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_BIC_asimdimm_L_hl,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0700c000 level 1
   07e0fc00/0700c800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdelem_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0700c400 level 1
   07e0fc00/0700d400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700c400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MOVI_asimdimm_M_sm,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_MVNI_asimdimm_M_sm,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f00d000 level 2
   bfe0fc00/1f00d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f00d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f00d000))
        return iemDecodeA64_SQRDMULH_asisdelem_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f008000))
        return iemDecodeA64_FMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0700d000 level 1
   07e0fc00/0700d800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRDMULH_asimdelem_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f00d000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLAH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLAH_asisdelem_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0700e000 level 1
   07e0fc00/0700e800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UDOT_asimdelem_D,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0f00e400 level 2
   ffe0fc00/4f00e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0f00e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f00e400))
        return iemDecodeA64_SCVTF_asimdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff8fc00)) == UINT32_C(0x0f00e400))
        return iemDecodeA64_MOVI_asimdimm_N_b(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/2f00e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_2f00e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f00e400))
        return iemDecodeA64_UCVTF_asimdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff8fc00)) == UINT32_C(0x2f00e400))
        return iemDecodeA64_MOVI_asimdimm_D_ds(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* ffe0fc00/6f00e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_6f00e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x2f00e400))
        return iemDecodeA64_UCVTF_asimdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfff8fc00)) == UINT32_C(0x6f00e400))
        return iemDecodeA64_MOVI_asimdimm_D2_d(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0700e400 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%22 (0x7) multi-if=%12 (0x4) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0f00e400_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_ffe0fc00_2f00e400_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0f00e400_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SCVTF_asisdshf_C,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_ffe0fc00_6f00e400_2,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_UCVTF_asisdshf_C,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0700f000 level 1
   07e0fc00/0700f800 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SUDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLSH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLSH_asisdelem_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0700f400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700f400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMOV_asimdimm_S_s,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMOV_asimdimm_D2_d,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* ffe0fc00/0f00fc00 level 2
   ffe0fc00/4f00fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_ffe0fc00_0f00fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80fc00)) == UINT32_C(0x0f00fc00))
        return iemDecodeA64_FCVTZS_asimdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xbff8fc00)) == UINT32_C(0x0f00fc00))
        return iemDecodeA64_FMOV_asimdimm_H_h(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0700fc00 level 1
   mask=0xf8000000 entries=0x20 children=0xb valid=%34 (0xb) leaf=%28 (0x9) multi-if=%6 (0x2) reuse=%3 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0700fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_ffe0fc00_0f00fc00_2,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCVTZU_asimdshf_C,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_ffe0fc00_0f00fc00_2,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_FCVTZS_asisdshf_C,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_FCVTZU_asimdshf_C,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_FCVTZU_asisdshf_C,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07200000 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07200000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f200400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f200400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f000400))
        return iemDecodeA64_SSHR_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07200400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07200400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSHR_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f200400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USHR_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_USHR_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/17200800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_17200800_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07200800 level 1
   mask=0x70000000 entries=0x8 children=0x7 valid=%88 (0x7) leaf=%75 (0x6) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07200800_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FDOT_asimdelem_D,
        iemDecodeA64_77e0fc00_17200800_2,
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FDOT_asimdelem_D,
        iemDecodeA64_BLRAA_64P_branch_reg,
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07200c00 level 1
   mask=0xe8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07200c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FNMADD_S_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_Invalid, // 6
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_BLRAB_64P_branch_reg,
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xe8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x0000000e)) /* bit 29 L 3 -> 1 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f201000 level 2
   afe0fc00/0f201800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f201000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f001000))
        return iemDecodeA64_FMLA_asimdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x5f001000))
        return iemDecodeA64_FMLA_asisdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07201000 level 1
   07e0fc00/07201800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07201000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f201000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f201400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f201400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f001400))
        return iemDecodeA64_SSRA_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07201400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07201400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSRA_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f201400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USRA_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_USRA_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07201c00 level 1
   07e0fc00/07202c00 level 1
   07e0fc00/07203c00 level 1
   07e0fc00/07204c00 level 1
   07e0fc00/07205c00 level 1
   07e0fc00/07206c00 level 1
   07e0fc00/07207c00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07201c00_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07202000 level 1
   07e0fc00/07202800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07202000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f202400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f202400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f002400))
        return iemDecodeA64_SRSHR_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07202400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07202400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRSHR_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f202400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URSHR_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_URSHR_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f203000 level 2
   afe0fc00/0f203800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f203000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f003000))
        return iemDecodeA64_SQDMLAL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f003000))
        return iemDecodeA64_SQDMLAL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07203000 level 1
   07e0fc00/07203800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07203000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f203000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f203400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f203400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f003400))
        return iemDecodeA64_SRSRA_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07203400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07203400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRSRA_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f203400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URSRA_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_URSRA_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07204000 level 1
   07e0fc00/07204800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07204000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FNMADD_S_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MLS_asimdelem_R,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07204400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07204400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SRI_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SRI_asisdshf_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f205000 level 2
   afe0fc00/0f205800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f205000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbfc0f400)) == UINT32_C(0x0f005000))
        return iemDecodeA64_FMLS_asimdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x5f005000))
        return iemDecodeA64_FMLS_asisdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07205000 level 1
   07e0fc00/07205800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07205000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f205000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f205400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f205400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f005400))
        return iemDecodeA64_SHL_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07205400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07205400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SHL_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f205400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SLI_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SLI_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07206000 level 1
   07e0fc00/07206800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07206000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLSL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLSL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07206400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07206400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQSHLU_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQSHLU_asisdshf_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f207000 level 2
   afe0fc00/0f207800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f207000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f007000))
        return iemDecodeA64_SQDMLSL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f007000))
        return iemDecodeA64_SQDMLSL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07207000 level 1
   07e0fc00/07207800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07207000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f207000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f207400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f207400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f007400))
        return iemDecodeA64_SQSHL_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f200000))
        return iemDecodeA64_FNMADD_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07207400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07207400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHL_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f207400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHL_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQSHL_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/17208000 level 2
   77e0fc00/17208800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_17208000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f208000))
        return iemDecodeA64_FNMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07208000 level 1
   07e0fc00/07208800 level 1
   mask=0x70000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07208000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_77e0fc00_17208000_2,
        iemDecodeA64_FMLALLBB_asimdelem_J,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_FMLALLTB_asimdelem_J,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07208400 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07208400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SHRN_asimdshf_N,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQSHRUN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQSHRUN_asisdshf_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07208c00 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07208c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_RSHRN_asimdshf_N,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRSHRUN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRSHRUN_asisdshf_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f209000 level 2
   bfe0fc00/1f209800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f209000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xffc0f400)) == UINT32_C(0x5f009000))
        return iemDecodeA64_FMUL_asisdelem_RH_H(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f208000))
        return iemDecodeA64_FNMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07209000 level 1
   07e0fc00/07209800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07209000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMUL_asimdelem_RH_H,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f209000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMULX_asimdelem_RH_H,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FMULX_asisdelem_RH_H,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f209400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f209400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f009400))
        return iemDecodeA64_SQSHRN_asisdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f208000))
        return iemDecodeA64_FNMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07209400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07209400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHRN_asimdshf_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f209400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHRN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQSHRN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f209c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f209c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f009c00))
        return iemDecodeA64_SQRSHRN_asisdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f208000))
        return iemDecodeA64_FNMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07209c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07209c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRSHRN_asimdshf_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f209c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQRSHRN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQRSHRN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0720a000 level 1
   07e0fc00/0720a800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMULL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0720a400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSHLL_asimdshf_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USHLL_asimdshf_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0720ac00 level 1
   07e0fc00/0720b400 level 1
   07e0fc00/0720bc00 level 1
   07e0fc00/0720c400 level 1
   07e0fc00/0720cc00 level 1
   07e0fc00/0720d400 level 1
   07e0fc00/0720dc00 level 1
   07e0fc00/0720ec00 level 1
   07e0fc00/0720f400 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720ac00_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f208000))
        return iemDecodeA64_FNMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0720b000 level 1
   07e0fc00/0720b800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisdelem_L,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0720c000 level 1
   07e0fc00/0720c800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdelem_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f20d000 level 2
   bfe0fc00/1f20d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f20d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f00d000))
        return iemDecodeA64_SQRDMULH_asisdelem_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f208000))
        return iemDecodeA64_FNMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0720d000 level 1
   07e0fc00/0720d800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRDMULH_asimdelem_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f20d000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLAH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLAH_asisdelem_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0720e000 level 1
   07e0fc00/0720e800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UDOT_asimdelem_D,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f20e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f20e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f00e400))
        return iemDecodeA64_SCVTF_asisdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f208000))
        return iemDecodeA64_FNMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0720e400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SCVTF_asimdshf_C,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f20e400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UCVTF_asimdshf_C,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UCVTF_asisdshf_C,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0720f000 level 1
   07e0fc00/0720f800 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SUDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_S_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLSH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLSH_asisdelem_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f20fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f20fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f00fc00))
        return iemDecodeA64_FCVTZS_asisdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f208000))
        return iemDecodeA64_FNMSUB_S_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0720fc00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0720fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FCVTZS_asimdshf_C,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f20fc00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCVTZU_asimdshf_C,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCVTZU_asisdshf_C,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07400000 level 1
   07e0fc00/07400800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07400000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FDOT_asimdelem_G,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f400400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f400400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f000400))
        return iemDecodeA64_SSHR_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07400400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07400400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSHR_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f400400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USHR_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_USHR_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07400c00 level 1
   07e0fc00/07401c00 level 1
   07e0fc00/07402c00 level 1
   07e0fc00/07403c00 level 1
   07e0fc00/07404c00 level 1
   07e0fc00/07405c00 level 1
   07e0fc00/07406c00 level 1
   07e0fc00/07407c00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07400c00_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07401000 level 1
   07e0fc00/07401800 level 1
   07e0fc00/07405000 level 1
   07e0fc00/07405800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07401000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMADD_D_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f401400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f401400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f001400))
        return iemDecodeA64_SSRA_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07401400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07401400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSRA_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f401400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USRA_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_USRA_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07402000 level 1
   07e0fc00/07402800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07402000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f402400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f402400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f002400))
        return iemDecodeA64_SRSHR_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07402400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07402400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRSHR_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f402400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URSHR_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_URSHR_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f403000 level 2
   afe0fc00/0f403800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f403000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f003000))
        return iemDecodeA64_SQDMLAL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f003000))
        return iemDecodeA64_SQDMLAL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07403000 level 1
   07e0fc00/07403800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07403000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f403000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f403400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f403400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f003400))
        return iemDecodeA64_SRSRA_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07403400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07403400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRSRA_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f403400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URSRA_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_URSRA_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07404000 level 1
   07e0fc00/07404800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07404000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMADD_D_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MLS_asimdelem_R,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07404400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07404400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SRI_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SRI_asisdshf_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f405400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f405400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f005400))
        return iemDecodeA64_SHL_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07405400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07405400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SHL_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f405400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SLI_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SLI_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07406000 level 1
   07e0fc00/07406800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07406000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLSL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLSL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07406400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07406400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQSHLU_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQSHLU_asisdshf_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f407000 level 2
   afe0fc00/0f407800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f407000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f007000))
        return iemDecodeA64_SQDMLSL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f007000))
        return iemDecodeA64_SQDMLSL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07407000 level 1
   07e0fc00/07407800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07407000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f407000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f407400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f407400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f007400))
        return iemDecodeA64_SQSHL_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f400000))
        return iemDecodeA64_FMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07407400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07407400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHL_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f407400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHL_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQSHL_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/17408000 level 2
   77e0fc00/17408800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_17408000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f408000))
        return iemDecodeA64_FMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07408000 level 1
   07e0fc00/07408800 level 1
   mask=0x70000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07408000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_77e0fc00_17408000_2,
        iemDecodeA64_FMLALLBT_asimdelem_J,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_FMLALLTT_asimdelem_J,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07408400 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07408400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SHRN_asimdshf_N,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQSHRUN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQSHRUN_asisdshf_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07408c00 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07408c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_RSHRN_asimdshf_N,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRSHRUN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRSHRUN_asisdshf_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07409000 level 1
   07e0fc00/07409800 level 1
   07e0fc00/0740ac00 level 1
   07e0fc00/0740b400 level 1
   07e0fc00/0740bc00 level 1
   07e0fc00/0740c400 level 1
   07e0fc00/0740cc00 level 1
   07e0fc00/0740d400 level 1
   07e0fc00/0740dc00 level 1
   07e0fc00/0740ec00 level 1
   07e0fc00/0740f400 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07409000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f408000))
        return iemDecodeA64_FMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f409400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f409400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f009400))
        return iemDecodeA64_SQSHRN_asisdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f408000))
        return iemDecodeA64_FMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07409400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07409400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHRN_asimdshf_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f409400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHRN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQSHRN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f409c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f409c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f009c00))
        return iemDecodeA64_SQRSHRN_asisdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f408000))
        return iemDecodeA64_FMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07409c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07409c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRSHRN_asimdshf_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f409c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQRSHRN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQRSHRN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0740a000 level 1
   07e0fc00/0740a800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMULL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0740a400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSHLL_asimdshf_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USHLL_asimdshf_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0740b000 level 1
   07e0fc00/0740b800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisdelem_L,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0740c000 level 1
   07e0fc00/0740c800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdelem_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f40d000 level 2
   bfe0fc00/1f40d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f40d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f00d000))
        return iemDecodeA64_SQRDMULH_asisdelem_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f408000))
        return iemDecodeA64_FMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0740d000 level 1
   07e0fc00/0740d800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRDMULH_asimdelem_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f40d000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLAH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLAH_asisdelem_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0740e000 level 1
   07e0fc00/0740e800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UDOT_asimdelem_D,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f40e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f40e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f00e400))
        return iemDecodeA64_SCVTF_asisdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f408000))
        return iemDecodeA64_FMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0740e400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SCVTF_asimdshf_C,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f40e400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UCVTF_asimdshf_C,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UCVTF_asisdshf_C,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0740f000 level 1
   07e0fc00/0740f800 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_BFDOT_asimdelem_E,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLSH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLSH_asisdelem_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f40fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f40fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f00fc00))
        return iemDecodeA64_FCVTZS_asisdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f408000))
        return iemDecodeA64_FMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0740fc00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0740fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FCVTZS_asimdshf_C,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f40fc00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCVTZU_asimdshf_C,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCVTZU_asisdshf_C,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07600000 level 1
   07e0fc00/07600800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07600000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FDOT_asimdelem_G,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f600400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f600400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f000400))
        return iemDecodeA64_SSHR_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07600400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07600400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSHR_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f600400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USHR_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_USHR_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07600c00 level 1
   07e0fc00/07601c00 level 1
   07e0fc00/07602c00 level 1
   07e0fc00/07603c00 level 1
   07e0fc00/07604c00 level 1
   07e0fc00/07605c00 level 1
   07e0fc00/07606c00 level 1
   07e0fc00/07607c00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07600c00_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07601000 level 1
   07e0fc00/07601800 level 1
   07e0fc00/07605000 level 1
   07e0fc00/07605800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07601000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FNMADD_D_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f601400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f601400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f001400))
        return iemDecodeA64_SSRA_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07601400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07601400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSRA_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f601400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USRA_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_USRA_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07602000 level 1
   07e0fc00/07602800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07602000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f602400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f602400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f002400))
        return iemDecodeA64_SRSHR_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07602400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07602400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRSHR_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f602400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URSHR_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_URSHR_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f603000 level 2
   afe0fc00/0f603800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f603000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f003000))
        return iemDecodeA64_SQDMLAL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f003000))
        return iemDecodeA64_SQDMLAL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07603000 level 1
   07e0fc00/07603800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07603000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f603000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f603400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f603400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f003400))
        return iemDecodeA64_SRSRA_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07603400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07603400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SRSRA_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f603400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_URSRA_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_URSRA_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07604000 level 1
   07e0fc00/07604800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07604000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FNMADD_D_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MLS_asimdelem_R,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07604400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07604400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SRI_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SRI_asisdshf_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f605400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f605400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f005400))
        return iemDecodeA64_SHL_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07605400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07605400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SHL_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f605400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SLI_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SLI_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07606000 level 1
   07e0fc00/07606800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07606000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLSL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLSL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07606400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07606400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_Invalid, // 1
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQSHLU_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQSHLU_asisdshf_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0f607000 level 2
   afe0fc00/0f607800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0f607000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f007000))
        return iemDecodeA64_SQDMLSL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f007000))
        return iemDecodeA64_SQDMLSL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07607000 level 1
   07e0fc00/07607800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07607000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0f607000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f607400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f607400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f007400))
        return iemDecodeA64_SQSHL_asisdshf_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f600000))
        return iemDecodeA64_FNMADD_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07607400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07607400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHL_asimdshf_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f607400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHL_asimdshf_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQSHL_asisdshf_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/17608000 level 2
   77e0fc00/17608800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_17608000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f608000))
        return iemDecodeA64_FNMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07608000 level 1
   07e0fc00/07608800 level 1
   mask=0x70000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07608000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_77e0fc00_17608000_2,
        iemDecodeA64_FMLALLBT_asimdelem_J,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_FMLALLTT_asimdelem_J,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07608400 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07608400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SHRN_asimdshf_N,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQSHRUN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQSHRUN_asisdshf_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07608c00 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07608c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_RSHRN_asimdshf_N,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRSHRUN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRSHRUN_asisdshf_N,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07609000 level 1
   07e0fc00/07609800 level 1
   07e0fc00/0760ac00 level 1
   07e0fc00/0760b400 level 1
   07e0fc00/0760bc00 level 1
   07e0fc00/0760c400 level 1
   07e0fc00/0760cc00 level 1
   07e0fc00/0760d400 level 1
   07e0fc00/0760dc00 level 1
   07e0fc00/0760ec00 level 1
   07e0fc00/0760f400 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07609000_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f608000))
        return iemDecodeA64_FNMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1f609400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f609400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f009400))
        return iemDecodeA64_SQSHRN_asisdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f608000))
        return iemDecodeA64_FNMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07609400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07609400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQSHRN_asimdshf_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f609400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQSHRN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQSHRN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f609c00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f609c00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f009c00))
        return iemDecodeA64_SQRSHRN_asisdshf_N(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f608000))
        return iemDecodeA64_FNMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07609c00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07609c00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRSHRN_asimdshf_N,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f609c00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UQRSHRN_asimdshf_N,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UQRSHRN_asisdshf_N,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0760a000 level 1
   07e0fc00/0760a800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMULL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0760a400 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760a400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SSHLL_asimdshf_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_USHLL_asimdshf_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0760b000 level 1
   07e0fc00/0760b800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisdelem_L,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0760c000 level 1
   07e0fc00/0760c800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdelem_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f60d000 level 2
   bfe0fc00/1f60d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f60d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f00d000))
        return iemDecodeA64_SQRDMULH_asisdelem_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f608000))
        return iemDecodeA64_FNMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0760d000 level 1
   07e0fc00/0760d800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRDMULH_asimdelem_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f60d000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLAH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLAH_asisdelem_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0760e000 level 1
   07e0fc00/0760e800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UDOT_asimdelem_D,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f60e400 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f60e400_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f00e400))
        return iemDecodeA64_SCVTF_asisdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f608000))
        return iemDecodeA64_FNMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0760e400 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760e400_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SCVTF_asimdshf_C,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f60e400_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UCVTF_asimdshf_C,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_UCVTF_asisdshf_C,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0760f000 level 1
   07e0fc00/0760f800 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_BFDOT_asimdelem_E,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_D_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLSH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLSH_asisdelem_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1f60fc00 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1f60fc00_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80fc00)) == UINT32_C(0x5f00fc00))
        return iemDecodeA64_FCVTZS_asisdshf_C(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1f608000))
        return iemDecodeA64_FNMSUB_D_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/0760fc00 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0760fc00_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FCVTZS_asimdshf_C,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1f60fc00_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCVTZU_asimdshf_C,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCVTZU_asisdshf_C,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07800000 level 1
   07e0fc00/07800800 level 1
   07e0fc00/07a00000 level 1
   07e0fc00/07a00800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07800000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLAL_asimdelem_LH,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07800400 level 1
   07e0fc00/07800c00 level 1
   07e0fc00/07801400 level 1
   07e0fc00/07801c00 level 1
   07e0fc00/07802400 level 1
   07e0fc00/07802c00 level 1
   07e0fc00/07803400 level 1
   07e0fc00/07803c00 level 1
   07e0fc00/07804400 level 1
   07e0fc00/07804c00 level 1
   07e0fc00/07805400 level 1
   07e0fc00/07805c00 level 1
   07e0fc00/07806400 level 1
   07e0fc00/07806c00 level 1
   07e0fc00/07807400 level 1
   07e0fc00/07807c00 level 1
   07e0fc00/07808400 level 1
   07e0fc00/07808c00 level 1
   07e0fc00/07809400 level 1
   07e0fc00/07809c00 level 1
   07e0fc00/0780a400 level 1
   07e0fc00/0780ac00 level 1
   07e0fc00/0780b400 level 1
   07e0fc00/0780bc00 level 1
   07e0fc00/0780c400 level 1
   07e0fc00/0780cc00 level 1
   07e0fc00/0780d400 level 1
   07e0fc00/0780dc00 level 1
   07e0fc00/0780e400 level 1
   07e0fc00/0780ec00 level 1
   07e0fc00/0780f400 level 1
   07e0fc00/0780fc00 level 1
   07e0fc00/07a00400 level 1
   07e0fc00/07a00c00 level 1
   07e0fc00/07a01400 level 1
   07e0fc00/07a01c00 level 1
   07e0fc00/07a02400 level 1
   07e0fc00/07a02c00 level 1
   07e0fc00/07a03400 level 1
   07e0fc00/07a03c00 level 1
   07e0fc00/07a04400 level 1
   07e0fc00/07a04c00 level 1
   07e0fc00/07a05400 level 1
   07e0fc00/07a05c00 level 1
   07e0fc00/07a06400 level 1
   07e0fc00/07a06c00 level 1
   07e0fc00/07a07400 level 1
   07e0fc00/07a07c00 level 1
   07e0fc00/07a08400 level 1
   07e0fc00/07a08c00 level 1
   07e0fc00/07a09400 level 1
   07e0fc00/07a09c00 level 1
   07e0fc00/07a0a400 level 1
   07e0fc00/07a0ac00 level 1
   07e0fc00/07a0b400 level 1
   07e0fc00/07a0bc00 level 1
   07e0fc00/07a0c400 level 1
   07e0fc00/07a0cc00 level 1
   07e0fc00/07a0d400 level 1
   07e0fc00/07a0dc00 level 1
   07e0fc00/07a0e400 level 1
   07e0fc00/07a0ec00 level 1
   07e0fc00/07a0f400 level 1
   07e0fc00/07a0fc00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07800400_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07801000 level 1
   07e0fc00/07801800 level 1
   07e0fc00/07a01000 level 1
   07e0fc00/07a01800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07801000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLA_asimdelem_R_SD,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMLA_asisdelem_R_SD,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07802000 level 1
   07e0fc00/07802800 level 1
   07e0fc00/07a02000 level 1
   07e0fc00/07a02800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07802000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimdelem_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07803000 level 1
   07e0fc00/07803800 level 1
   07e0fc00/07a03000 level 1
   07e0fc00/07a03800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07803000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLAL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_SQDMLAL_asisdelem_L,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07804000 level 1
   07e0fc00/07804800 level 1
   07e0fc00/07a04000 level 1
   07e0fc00/07a04800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07804000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLSL_asimdelem_LH,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_MLS_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07805000 level 1
   07e0fc00/07805800 level 1
   07e0fc00/07a05000 level 1
   07e0fc00/07a05800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07805000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMLS_asimdelem_R_SD,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMLS_asisdelem_R_SD,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07806000 level 1
   07e0fc00/07806800 level 1
   07e0fc00/07a06000 level 1
   07e0fc00/07a06800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07806000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLSL_asimdelem_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLSL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07807000 level 1
   07e0fc00/07807800 level 1
   07e0fc00/07a07000 level 1
   07e0fc00/07a07800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07807000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMLSL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_SQDMLSL_asisdelem_L,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07808000 level 1
   07e0fc00/07808800 level 1
   07e0fc00/07a08000 level 1
   07e0fc00/07a08800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07808000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMLAL2_asimdelem_LH,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07809000 level 1
   07e0fc00/07809800 level 1
   07e0fc00/07a09000 level 1
   07e0fc00/07a09800 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07809000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMUL_asimdelem_R_SD,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMULX_asimdelem_R_SD,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_FMUL_asimdelem_R_SD,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_FMUL_asisdelem_R_SD,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_FMULX_asimdelem_R_SD,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_FMULX_asisdelem_R_SD,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0780a000 level 1
   07e0fc00/0780a800 level 1
   07e0fc00/07a0a000 level 1
   07e0fc00/07a0a800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0780a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMULL_asimdelem_L,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMULL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0780b000 level 1
   07e0fc00/0780b800 level 1
   07e0fc00/07a0b000 level 1
   07e0fc00/07a0b800 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0780b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisdelem_L,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0780c000 level 1
   07e0fc00/0780c800 level 1
   07e0fc00/07a0c000 level 1
   07e0fc00/07a0c800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0780c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_SQDMULH_asisdelem_R,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMLSL2_asimdelem_LH,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0780d000 level 1
   07e0fc00/0780d800 level 1
   07e0fc00/07a0d000 level 1
   07e0fc00/07a0d800 level 1
   mask=0xf8000000 entries=0x20 children=0xa valid=%31 (0xa) leaf=%31 (0xa) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0780d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRDMULH_asimdelem_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLAH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQRDMULH_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQRDMULH_asisdelem_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_SQRDMLAH_asimdelem_R,
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_SQRDMLAH_asisdelem_R,
        iemDecodeA64_Invalid, // 16
        iemDecodeA64_Invalid, // 17
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 19
        iemDecodeA64_Invalid, // 20
        iemDecodeA64_Invalid, // 21
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 23
        iemDecodeA64_Invalid, // 24
        iemDecodeA64_Invalid, // 25
        iemDecodeA64_Invalid, // 26
        iemDecodeA64_Invalid, // 27
        iemDecodeA64_Invalid, // 28
        iemDecodeA64_Invalid, // 29
        iemDecodeA64_Invalid, // 30
        iemDecodeA64_Invalid, // 31
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x20);

    /* fMask=0xf8000000 -> 0x0000001f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000001f)) /* bit 27 L 5 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0780e000 level 1
   07e0fc00/0780e800 level 1
   07e0fc00/07a0e000 level 1
   07e0fc00/07a0e800 level 1
   mask=0xb8000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%38 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0780e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SDOT_asimdelem_D,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UDOT_asimdelem_D,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/0780f000 level 1
   07e0fc00/0780f800 level 1
   07e0fc00/07a0f000 level 1
   07e0fc00/07a0f800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_0780f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_USDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_Invalid, // 3
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLSH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLSH_asisdelem_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/17c00000 level 2
   77e0fc00/17c00800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_17c00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc00000))
        return iemDecodeA64_FMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07c00000 level 1
   07e0fc00/07c00800 level 1
   mask=0x70000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FMLALB_asimdelem_H,
        iemDecodeA64_77e0fc00_17c00000_2,
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FMLALT_asimdelem_H,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c00400 level 1
   07e0fc00/07c00c00 level 1
   07e0fc00/07c01400 level 1
   07e0fc00/07c01c00 level 1
   07e0fc00/07c02400 level 1
   07e0fc00/07c02c00 level 1
   07e0fc00/07c03400 level 1
   07e0fc00/07c03c00 level 1
   07e0fc00/07c04400 level 1
   07e0fc00/07c04c00 level 1
   07e0fc00/07c05400 level 1
   07e0fc00/07c05c00 level 1
   07e0fc00/07c06400 level 1
   07e0fc00/07c06c00 level 1
   07e0fc00/07c07400 level 1
   07e0fc00/07c07c00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c00400_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc00000))
        return iemDecodeA64_FMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* afe0fc00/0fc01000 level 2
   afe0fc00/0fc01800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0fc01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80f400)) == UINT32_C(0x0f801000))
        return iemDecodeA64_FMLA_asimdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff80f400)) == UINT32_C(0x5f801000))
        return iemDecodeA64_FMLA_asisdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc00000))
        return iemDecodeA64_FMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07c01000 level 1
   07e0fc00/07c01800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0fc01000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c02000 level 1
   07e0fc00/07c02800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0fc03000 level 2
   afe0fc00/0fc03800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0fc03000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f003000))
        return iemDecodeA64_SQDMLAL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f003000))
        return iemDecodeA64_SQDMLAL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc00000))
        return iemDecodeA64_FMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07c03000 level 1
   07e0fc00/07c03800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0fc03000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c04000 level 1
   07e0fc00/07c04800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FMADD_H_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MLS_asimdelem_R,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0fc05000 level 2
   afe0fc00/0fc05800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0fc05000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80f400)) == UINT32_C(0x0f805000))
        return iemDecodeA64_FMLS_asimdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff80f400)) == UINT32_C(0x5f805000))
        return iemDecodeA64_FMLS_asisdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc00000))
        return iemDecodeA64_FMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07c05000 level 1
   07e0fc00/07c05800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0fc05000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c06000 level 1
   07e0fc00/07c06800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLSL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMADD_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLSL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0fc07000 level 2
   afe0fc00/0fc07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0fc07000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f007000))
        return iemDecodeA64_SQDMLSL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f007000))
        return iemDecodeA64_SQDMLSL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc00000))
        return iemDecodeA64_FMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07c07000 level 1
   07e0fc00/07c07800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0fc07000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c08000 level 1
   07e0fc00/07c08800 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c08400 level 1
   07e0fc00/07c08c00 level 1
   07e0fc00/07c09400 level 1
   07e0fc00/07c09c00 level 1
   07e0fc00/07c0a400 level 1
   07e0fc00/07c0ac00 level 1
   07e0fc00/07c0b400 level 1
   07e0fc00/07c0bc00 level 1
   07e0fc00/07c0c400 level 1
   07e0fc00/07c0cc00 level 1
   07e0fc00/07c0d400 level 1
   07e0fc00/07c0dc00 level 1
   07e0fc00/07c0e400 level 1
   07e0fc00/07c0ec00 level 1
   07e0fc00/07c0f400 level 1
   07e0fc00/07c0fc00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c08400_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc08000))
        return iemDecodeA64_FMSUB_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1fc09000 level 2
   bfe0fc00/1fc09800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1fc09000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80f400)) == UINT32_C(0x5f809000))
        return iemDecodeA64_FMUL_asisdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc08000))
        return iemDecodeA64_FMSUB_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07c09000 level 1
   07e0fc00/07c09800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMUL_asimdelem_R_SD,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1fc09000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMULX_asimdelem_R_SD,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FMULX_asisdelem_R_SD,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c0a000 level 1
   07e0fc00/07c0a800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMULL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c0b000 level 1
   07e0fc00/07c0b800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisdelem_L,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c0c000 level 1
   07e0fc00/07c0c800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdelem_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1fc0d000 level 2
   bfe0fc00/1fc0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1fc0d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f00d000))
        return iemDecodeA64_SQRDMULH_asisdelem_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fc08000))
        return iemDecodeA64_FMSUB_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07c0d000 level 1
   07e0fc00/07c0d800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRDMULH_asimdelem_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1fc0d000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLAH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLAH_asisdelem_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c0e000 level 1
   07e0fc00/07c0e800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UDOT_asimdelem_D,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07c0f000 level 1
   07e0fc00/07c0f800 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07c0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_BFMLAL_asimdelem_F,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLSH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLSH_asisdelem_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 77e0fc00/17e00000 level 2
   77e0fc00/17e00800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_77e0fc00_17e00000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe00000))
        return iemDecodeA64_FNMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07e00000 level 1
   07e0fc00/07e00800 level 1
   mask=0x70000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e00000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_FMLALB_asimdelem_H,
        iemDecodeA64_77e0fc00_17e00000_2,
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FMLALT_asimdelem_H,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_MLA_asimdelem_R,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x70000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 28) & UINT32_C(0x00000007)) /* bit 28 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e00400 level 1
   07e0fc00/07e00c00 level 1
   07e0fc00/07e01400 level 1
   07e0fc00/07e01c00 level 1
   07e0fc00/07e02400 level 1
   07e0fc00/07e02c00 level 1
   07e0fc00/07e03400 level 1
   07e0fc00/07e03c00 level 1
   07e0fc00/07e04400 level 1
   07e0fc00/07e04c00 level 1
   07e0fc00/07e05400 level 1
   07e0fc00/07e05c00 level 1
   07e0fc00/07e06400 level 1
   07e0fc00/07e06c00 level 1
   07e0fc00/07e07400 level 1
   07e0fc00/07e07c00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e00400_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe00000))
        return iemDecodeA64_FNMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* afe0fc00/0fe01000 level 2
   afe0fc00/0fe01800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0fe01000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80f400)) == UINT32_C(0x0f801000))
        return iemDecodeA64_FMLA_asimdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff80f400)) == UINT32_C(0x5f801000))
        return iemDecodeA64_FMLA_asisdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe00000))
        return iemDecodeA64_FNMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07e01000 level 1
   07e0fc00/07e01800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e01000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0fe01000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e02000 level 1
   07e0fc00/07e02800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e02000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLAL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLAL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0fe03000 level 2
   afe0fc00/0fe03800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0fe03000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f003000))
        return iemDecodeA64_SQDMLAL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f003000))
        return iemDecodeA64_SQDMLAL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe00000))
        return iemDecodeA64_FNMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07e03000 level 1
   07e0fc00/07e03800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e03000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0fe03000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e04000 level 1
   07e0fc00/07e04800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%75 (0x6) multi-if=%0 (0x0) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e04000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_FNMADD_H_floatdp3,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_MLS_asimdelem_R,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0fe05000 level 2
   afe0fc00/0fe05800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0fe05000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf80f400)) == UINT32_C(0x0f805000))
        return iemDecodeA64_FMLS_asimdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff80f400)) == UINT32_C(0x5f805000))
        return iemDecodeA64_FMLS_asisdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe00000))
        return iemDecodeA64_FNMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07e05000 level 1
   07e0fc00/07e05800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e05000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0fe05000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e06000 level 1
   07e0fc00/07e06800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e06000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMLSL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMADD_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMLSL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* afe0fc00/0fe07000 level 2
   afe0fc00/0fe07800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_afe0fc00_0fe07000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xbf00f400)) == UINT32_C(0x0f007000))
        return iemDecodeA64_SQDMLSL_asimdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f007000))
        return iemDecodeA64_SQDMLSL_asisdelem_L(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe00000))
        return iemDecodeA64_FNMADD_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07e07000 level 1
   07e0fc00/07e07800 level 1
   mask=0xa8000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e07000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_afe0fc00_0fe07000_2,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FCMLA_advsimd_elt,
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0xa8000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000001)) /* bit 27 L 1 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000002)) /* bit 29 L 1 -> 1 */
                        | ((uOpcode >> 29) & UINT32_C(0x00000004)) /* bit 31 L 1 -> 2 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e08000 level 1
   07e0fc00/07e08800 level 1
   mask=0x78000000 entries=0x10 children=0x5 valid=%31 (0x5) leaf=%25 (0x4) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e08000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_MUL_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e08400 level 1
   07e0fc00/07e08c00 level 1
   07e0fc00/07e09400 level 1
   07e0fc00/07e09c00 level 1
   07e0fc00/07e0a400 level 1
   07e0fc00/07e0ac00 level 1
   07e0fc00/07e0b400 level 1
   07e0fc00/07e0bc00 level 1
   07e0fc00/07e0c400 level 1
   07e0fc00/07e0cc00 level 1
   07e0fc00/07e0d400 level 1
   07e0fc00/07e0dc00 level 1
   07e0fc00/07e0e400 level 1
   07e0fc00/07e0ec00 level 1
   07e0fc00/07e0f400 level 1
   07e0fc00/07e0fc00 level 1 */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e08400_1, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0x7f000000)) == UINT32_C(0x37000000))
        return iemDecodeA64_TBNZ_only_testbranch(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x14000000))
        return iemDecodeA64_B_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xfc000000)) == UINT32_C(0x94000000))
        return iemDecodeA64_BL_only_branch_imm(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe08000))
        return iemDecodeA64_FNMSUB_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* bfe0fc00/1fe09000 level 2
   bfe0fc00/1fe09800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1fe09000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff80f400)) == UINT32_C(0x5f809000))
        return iemDecodeA64_FMUL_asisdelem_R_SD(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe08000))
        return iemDecodeA64_FNMSUB_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07e09000 level 1
   07e0fc00/07e09800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e09000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_FMUL_asimdelem_R_SD,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1fe09000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_FMULX_asimdelem_R_SD,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_FMULX_asisdelem_R_SD,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e0a000 level 1
   07e0fc00/07e0a800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e0a000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UMULL_asimdelem_L,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e0b000 level 1
   07e0fc00/07e0b800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e0b000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULL_asimdelem_L,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULL_asisdelem_L,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e0c000 level 1
   07e0fc00/07e0c800 level 1
   mask=0x78000000 entries=0x10 children=0x6 valid=%38 (0x6) leaf=%31 (0x5) multi-if=%6 (0x1) reuse=%6 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e0c000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_Invalid, // 5
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_SQDMULH_asimdelem_R,
        iemDecodeA64_Invalid, // 10
        iemDecodeA64_SQDMULH_asisdelem_R,
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_Invalid, // 14
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0x78000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x0000000f)) /* bit 27 L 4 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* bfe0fc00/1fe0d000 level 2
   bfe0fc00/1fe0d800 level 2 */
FNIEMOP_DEF_1(iemDecodeA64_bfe0fc00_1fe0d000_2, uint32_t, uOpcode)
{
    if ((uOpcode & UINT32_C(0xff00f400)) == UINT32_C(0x5f00d000))
        return iemDecodeA64_SQRDMULH_asisdelem_R(pVCpu, uOpcode);
    if ((uOpcode & UINT32_C(0xffe08000)) == UINT32_C(0x1fe08000))
        return iemDecodeA64_FNMSUB_H_floatdp3(pVCpu, uOpcode);
    return iemDecodeA64_Invalid(pVCpu, uOpcode);
}

/* 07e0fc00/07e0d000 level 1
   07e0fc00/07e0d800 level 1
   mask=0xb8000000 entries=0x10 children=0x8 valid=%50 (0x8) leaf=%44 (0x7) multi-if=%6 (0x1) reuse=%0 (0x0) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e0d000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SQRDMULH_asimdelem_R,
        iemDecodeA64_B_only_branch_imm,
        iemDecodeA64_bfe0fc00_1fe0d000_2,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLAH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLAH_asisdelem_R,
        iemDecodeA64_Invalid, // 8
        iemDecodeA64_Invalid, // 9
        iemDecodeA64_BL_only_branch_imm,
        iemDecodeA64_Invalid, // 11
        iemDecodeA64_Invalid, // 12
        iemDecodeA64_Invalid, // 13
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 15
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x10);

    /* fMask=0xb8000000 -> 0x0000000f */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */
                        | ((uOpcode >> 28) & UINT32_C(0x00000008)) /* bit 31 L 1 -> 3 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e0e000 level 1
   07e0fc00/07e0e800 level 1
   mask=0x38000000 entries=0x8 children=0x5 valid=%62 (0x5) leaf=%50 (0x4) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e0e000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_SDOT_asimdelem_D,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_UDOT_asimdelem_D,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_Invalid, // 7
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* 07e0fc00/07e0f000 level 1
   07e0fc00/07e0f800 level 1
   mask=0x38000000 entries=0x8 children=0x6 valid=%75 (0x6) leaf=%62 (0x5) multi-if=%12 (0x1) reuse=%12 (0x1) */
FNIEMOP_DEF_1(iemDecodeA64_07e0fc00_07e0f000_1, uint32_t, uOpcode)
{
    static PFIEMOPU32 const s_apfn[] =
    {
        iemDecodeA64_Invalid, // 0
        iemDecodeA64_BFMLAL_asimdelem_F,
        iemDecodeA64_7fe7fc00_15809c00_2,
        iemDecodeA64_FNMSUB_H_floatdp3,
        iemDecodeA64_Invalid, // 4
        iemDecodeA64_SQRDMLSH_asimdelem_R,
        iemDecodeA64_TBNZ_only_testbranch,
        iemDecodeA64_SQRDMLSH_asisdelem_R,
    };
    AssertCompile(RT_ELEMENTS(s_apfn) == 0x8);

    /* fMask=0x38000000 -> 0x00000007 */
    uintptr_t const idx = ((uOpcode >> 27) & UINT32_C(0x00000007)) /* bit 27 L 3 -> 0 */;
    return s_apfn[idx](pVCpu, uOpcode);
}

/* --decoder-hint0 0x7e0fc00
   mask=0x7e0fc00 entries=0x1000 children=0xfc0 valid=%98 (0xfc0) leaf=%0 (0x0) multi-if=%9 (0x173) reuse=%46 (0x748) */
PFIEMOPU32 const g_apfnIemInterpretOnlyA64[] =
{
    iemDecodeA64_07e0fc00_00000000_1,
    iemDecodeA64_07e0fc00_00000400_1,
    iemDecodeA64_07e0fc00_00000800_1,
    iemDecodeA64_07e0fc00_00000c00_1,
    iemDecodeA64_07e0fc00_00001000_1,
    iemDecodeA64_07e0fc00_00001400_1,
    iemDecodeA64_07e0fc00_00001800_1,
    iemDecodeA64_07e0fc00_00001c00_1,
    iemDecodeA64_07e0fc00_00002000_1,
    iemDecodeA64_07e0fc00_00002400_1,
    iemDecodeA64_07e0fc00_00002800_1,
    iemDecodeA64_07e0fc00_00002c00_1,
    iemDecodeA64_07e0fc00_00003000_1,
    iemDecodeA64_07e0fc00_00003400_1,
    iemDecodeA64_07e0fc00_00003800_1,
    iemDecodeA64_07e0fc00_00003c00_1,
    iemDecodeA64_07e0fc00_00004000_1,
    iemDecodeA64_07e0fc00_00004400_1,
    iemDecodeA64_07e0fc00_00004800_1,
    iemDecodeA64_07e0fc00_00004c00_1,
    iemDecodeA64_07e0fc00_00005000_1,
    iemDecodeA64_07e0fc00_00005400_1,
    iemDecodeA64_07e0fc00_00005800_1,
    iemDecodeA64_07e0fc00_00005c00_1,
    iemDecodeA64_07e0fc00_00006000_1,
    iemDecodeA64_07e0fc00_00006400_1,
    iemDecodeA64_07e0fc00_00006800_1,
    iemDecodeA64_07e0fc00_00006c00_1,
    iemDecodeA64_07e0fc00_00007000_1,
    iemDecodeA64_07e0fc00_00007400_1,
    iemDecodeA64_07e0fc00_00007800_1,
    iemDecodeA64_07e0fc00_00007c00_1,
    iemDecodeA64_07e0fc00_00008000_1,
    iemDecodeA64_07e0fc00_00008400_1,
    iemDecodeA64_07e0fc00_00008800_1,
    iemDecodeA64_07e0fc00_00008c00_1,
    iemDecodeA64_07e0fc00_00009000_1,
    iemDecodeA64_07e0fc00_00009400_1,
    iemDecodeA64_07e0fc00_00008800_1,
    iemDecodeA64_07e0fc00_00008c00_1,
    iemDecodeA64_07e0fc00_0000a000_1,
    iemDecodeA64_07e0fc00_0000a400_1,
    iemDecodeA64_07e0fc00_0000a800_1,
    iemDecodeA64_07e0fc00_0000ac00_1,
    iemDecodeA64_07e0fc00_0000b000_1,
    iemDecodeA64_07e0fc00_0000b400_1,
    iemDecodeA64_07e0fc00_0000a800_1,
    iemDecodeA64_07e0fc00_0000ac00_1,
    iemDecodeA64_07e0fc00_0000c000_1,
    iemDecodeA64_07e0fc00_0000c400_1,
    iemDecodeA64_07e0fc00_0000c800_1,
    iemDecodeA64_07e0fc00_0000cc00_1,
    iemDecodeA64_07e0fc00_0000d000_1,
    iemDecodeA64_07e0fc00_0000d400_1,
    iemDecodeA64_07e0fc00_0000c800_1,
    iemDecodeA64_07e0fc00_0000cc00_1,
    iemDecodeA64_07e0fc00_0000e000_1,
    iemDecodeA64_07e0fc00_0000e400_1,
    iemDecodeA64_07e0fc00_0000e800_1,
    iemDecodeA64_07e0fc00_0000ec00_1,
    iemDecodeA64_07e0fc00_0000f000_1,
    iemDecodeA64_07e0fc00_0000f400_1,
    iemDecodeA64_07e0fc00_0000e800_1,
    iemDecodeA64_07e0fc00_0000fc00_1,
    iemDecodeA64_07e0fc00_00200000_1,
    iemDecodeA64_07e0fc00_00200400_1,
    iemDecodeA64_07e0fc00_00200800_1,
    iemDecodeA64_07e0fc00_00200c00_1,
    iemDecodeA64_07e0fc00_00201000_1,
    iemDecodeA64_07e0fc00_00200400_1,
    iemDecodeA64_07e0fc00_00200800_1,
    iemDecodeA64_07e0fc00_00200c00_1,
    iemDecodeA64_07e0fc00_00202000_1,
    iemDecodeA64_07e0fc00_00202400_1,
    iemDecodeA64_07e0fc00_00202800_1,
    iemDecodeA64_07e0fc00_00202c00_1,
    iemDecodeA64_07e0fc00_00203000_1,
    iemDecodeA64_07e0fc00_00202400_1,
    iemDecodeA64_07e0fc00_00202800_1,
    iemDecodeA64_07e0fc00_00202c00_1,
    iemDecodeA64_07e0fc00_00204000_1,
    iemDecodeA64_07e0fc00_00204400_1,
    iemDecodeA64_07e0fc00_00204800_1,
    iemDecodeA64_07e0fc00_00204c00_1,
    iemDecodeA64_07e0fc00_00205000_1,
    iemDecodeA64_07e0fc00_00204400_1,
    iemDecodeA64_07e0fc00_00204800_1,
    iemDecodeA64_07e0fc00_00204c00_1,
    iemDecodeA64_07e0fc00_00206000_1,
    iemDecodeA64_07e0fc00_00206400_1,
    iemDecodeA64_07e0fc00_00206800_1,
    iemDecodeA64_07e0fc00_00206c00_1,
    iemDecodeA64_07e0fc00_00207000_1,
    iemDecodeA64_07e0fc00_00206400_1,
    iemDecodeA64_07e0fc00_00206800_1,
    iemDecodeA64_07e0fc00_00207c00_1,
    iemDecodeA64_07e0fc00_00208000_1,
    iemDecodeA64_07e0fc00_00208400_1,
    iemDecodeA64_07e0fc00_00208800_1,
    iemDecodeA64_07e0fc00_00208c00_1,
    iemDecodeA64_07e0fc00_00209000_1,
    iemDecodeA64_07e0fc00_00208400_1,
    iemDecodeA64_07e0fc00_00208800_1,
    iemDecodeA64_07e0fc00_00208c00_1,
    iemDecodeA64_07e0fc00_0020a000_1,
    iemDecodeA64_07e0fc00_0020a400_1,
    iemDecodeA64_07e0fc00_0020a800_1,
    iemDecodeA64_07e0fc00_0020ac00_1,
    iemDecodeA64_07e0fc00_0020b000_1,
    iemDecodeA64_07e0fc00_0020a400_1,
    iemDecodeA64_07e0fc00_0020a800_1,
    iemDecodeA64_07e0fc00_0020ac00_1,
    iemDecodeA64_07e0fc00_0020c000_1,
    iemDecodeA64_07e0fc00_0020c400_1,
    iemDecodeA64_07e0fc00_0020c800_1,
    iemDecodeA64_07e0fc00_0020cc00_1,
    iemDecodeA64_07e0fc00_0020d000_1,
    iemDecodeA64_07e0fc00_0020c400_1,
    iemDecodeA64_07e0fc00_0020c800_1,
    iemDecodeA64_07e0fc00_0020cc00_1,
    iemDecodeA64_07e0fc00_0020e000_1,
    iemDecodeA64_07e0fc00_0020e400_1,
    iemDecodeA64_07e0fc00_0020e800_1,
    iemDecodeA64_07e0fc00_0020ec00_1,
    iemDecodeA64_07e0fc00_0020e000_1,
    iemDecodeA64_07e0fc00_0020e400_1,
    iemDecodeA64_07e0fc00_0020e800_1,
    iemDecodeA64_07e0fc00_0020fc00_1,
    iemDecodeA64_07e0fc00_00400000_1,
    iemDecodeA64_07e0fc00_00400400_1,
    iemDecodeA64_07e0fc00_00400800_1,
    iemDecodeA64_07e0fc00_00400c00_1,
    iemDecodeA64_07e0fc00_00401000_1,
    iemDecodeA64_07e0fc00_00401400_1,
    iemDecodeA64_07e0fc00_00400800_1,
    iemDecodeA64_07e0fc00_00400c00_1,
    iemDecodeA64_07e0fc00_00402000_1,
    iemDecodeA64_07e0fc00_00402400_1,
    iemDecodeA64_07e0fc00_00402800_1,
    iemDecodeA64_07e0fc00_00402c00_1,
    iemDecodeA64_07e0fc00_00403000_1,
    iemDecodeA64_07e0fc00_00403400_1,
    iemDecodeA64_07e0fc00_00402800_1,
    iemDecodeA64_07e0fc00_00402c00_1,
    iemDecodeA64_07e0fc00_00404000_1,
    iemDecodeA64_07e0fc00_00404400_1,
    iemDecodeA64_07e0fc00_00404800_1,
    iemDecodeA64_07e0fc00_00404c00_1,
    iemDecodeA64_07e0fc00_00405000_1,
    iemDecodeA64_07e0fc00_00405400_1,
    iemDecodeA64_07e0fc00_00404800_1,
    iemDecodeA64_07e0fc00_00404c00_1,
    iemDecodeA64_07e0fc00_00406000_1,
    iemDecodeA64_07e0fc00_00406400_1,
    iemDecodeA64_07e0fc00_00406800_1,
    iemDecodeA64_07e0fc00_00406c00_1,
    iemDecodeA64_07e0fc00_00407000_1,
    iemDecodeA64_07e0fc00_00407400_1,
    iemDecodeA64_07e0fc00_00406800_1,
    iemDecodeA64_07e0fc00_00407c00_1,
    iemDecodeA64_07e0fc00_00408000_1,
    iemDecodeA64_07e0fc00_00408400_1,
    iemDecodeA64_07e0fc00_00408800_1,
    iemDecodeA64_07e0fc00_00408c00_1,
    iemDecodeA64_07e0fc00_00409000_1,
    iemDecodeA64_07e0fc00_00409400_1,
    iemDecodeA64_07e0fc00_00408800_1,
    iemDecodeA64_07e0fc00_00408c00_1,
    iemDecodeA64_07e0fc00_0040a000_1,
    iemDecodeA64_07e0fc00_0040a400_1,
    iemDecodeA64_07e0fc00_0040a800_1,
    iemDecodeA64_07e0fc00_0040ac00_1,
    iemDecodeA64_07e0fc00_0040b000_1,
    iemDecodeA64_07e0fc00_0040b400_1,
    iemDecodeA64_07e0fc00_0040a800_1,
    iemDecodeA64_07e0fc00_0040ac00_1,
    iemDecodeA64_07e0fc00_0040c000_1,
    iemDecodeA64_07e0fc00_0040c400_1,
    iemDecodeA64_07e0fc00_0040c800_1,
    iemDecodeA64_07e0fc00_0040cc00_1,
    iemDecodeA64_07e0fc00_0040d000_1,
    iemDecodeA64_07e0fc00_0040d400_1,
    iemDecodeA64_07e0fc00_0040c800_1,
    iemDecodeA64_07e0fc00_0040cc00_1,
    iemDecodeA64_07e0fc00_0040e000_1,
    iemDecodeA64_07e0fc00_0040e400_1,
    iemDecodeA64_07e0fc00_0040e800_1,
    iemDecodeA64_07e0fc00_0040ec00_1,
    iemDecodeA64_07e0fc00_0040f000_1,
    iemDecodeA64_07e0fc00_0040f400_1,
    iemDecodeA64_07e0fc00_0040e800_1,
    iemDecodeA64_07e0fc00_0040fc00_1,
    iemDecodeA64_07e0fc00_00600000_1,
    iemDecodeA64_07e0fc00_00600400_1,
    iemDecodeA64_07e0fc00_00600800_1,
    iemDecodeA64_07e0fc00_00600c00_1,
    iemDecodeA64_07e0fc00_00601000_1,
    iemDecodeA64_07e0fc00_00600400_1,
    iemDecodeA64_07e0fc00_00600800_1,
    iemDecodeA64_07e0fc00_00600c00_1,
    iemDecodeA64_07e0fc00_00602000_1,
    iemDecodeA64_07e0fc00_00602400_1,
    iemDecodeA64_07e0fc00_00602800_1,
    iemDecodeA64_07e0fc00_00602c00_1,
    iemDecodeA64_07e0fc00_00603000_1,
    iemDecodeA64_07e0fc00_00602400_1,
    iemDecodeA64_07e0fc00_00602800_1,
    iemDecodeA64_07e0fc00_00602c00_1,
    iemDecodeA64_07e0fc00_00604000_1,
    iemDecodeA64_07e0fc00_00604400_1,
    iemDecodeA64_07e0fc00_00604800_1,
    iemDecodeA64_07e0fc00_00604c00_1,
    iemDecodeA64_07e0fc00_00605000_1,
    iemDecodeA64_07e0fc00_00604400_1,
    iemDecodeA64_07e0fc00_00604800_1,
    iemDecodeA64_07e0fc00_00604c00_1,
    iemDecodeA64_07e0fc00_00606000_1,
    iemDecodeA64_07e0fc00_00606400_1,
    iemDecodeA64_07e0fc00_00606800_1,
    iemDecodeA64_07e0fc00_00606c00_1,
    iemDecodeA64_07e0fc00_00607000_1,
    iemDecodeA64_07e0fc00_00606400_1,
    iemDecodeA64_07e0fc00_00606800_1,
    iemDecodeA64_07e0fc00_00607c00_1,
    iemDecodeA64_07e0fc00_00608000_1,
    iemDecodeA64_07e0fc00_00608400_1,
    iemDecodeA64_07e0fc00_00608800_1,
    iemDecodeA64_07e0fc00_00608c00_1,
    iemDecodeA64_07e0fc00_00609000_1,
    iemDecodeA64_07e0fc00_00608400_1,
    iemDecodeA64_07e0fc00_00608800_1,
    iemDecodeA64_07e0fc00_00608c00_1,
    iemDecodeA64_07e0fc00_0060a000_1,
    iemDecodeA64_07e0fc00_0060a400_1,
    iemDecodeA64_07e0fc00_0060a800_1,
    iemDecodeA64_07e0fc00_0060ac00_1,
    iemDecodeA64_07e0fc00_0060b000_1,
    iemDecodeA64_07e0fc00_0060a400_1,
    iemDecodeA64_07e0fc00_0060a800_1,
    iemDecodeA64_07e0fc00_0060ac00_1,
    iemDecodeA64_07e0fc00_0060c000_1,
    iemDecodeA64_07e0fc00_0060c400_1,
    iemDecodeA64_07e0fc00_0060c800_1,
    iemDecodeA64_07e0fc00_0060cc00_1,
    iemDecodeA64_07e0fc00_0060c000_1,
    iemDecodeA64_07e0fc00_0060c400_1,
    iemDecodeA64_07e0fc00_0060c800_1,
    iemDecodeA64_07e0fc00_0060cc00_1,
    iemDecodeA64_07e0fc00_0060e000_1,
    iemDecodeA64_07e0fc00_0060e400_1,
    iemDecodeA64_07e0fc00_0060e800_1,
    iemDecodeA64_07e0fc00_0060ec00_1,
    iemDecodeA64_07e0fc00_0060e000_1,
    iemDecodeA64_07e0fc00_0060e400_1,
    iemDecodeA64_07e0fc00_0060e800_1,
    iemDecodeA64_07e0fc00_0060fc00_1,
    iemDecodeA64_07e0fc00_00800000_1,
    iemDecodeA64_07e0fc00_00800400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00801000_1,
    iemDecodeA64_07e0fc00_00801400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00800000_1,
    iemDecodeA64_07e0fc00_00800400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00801000_1,
    iemDecodeA64_07e0fc00_00801400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00804000_1,
    iemDecodeA64_07e0fc00_00800400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00805000_1,
    iemDecodeA64_07e0fc00_00801400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00804000_1,
    iemDecodeA64_07e0fc00_00800400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00805000_1,
    iemDecodeA64_07e0fc00_00801400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00807c00_1,
    iemDecodeA64_07e0fc00_00808000_1,
    iemDecodeA64_07e0fc00_00800400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00809000_1,
    iemDecodeA64_07e0fc00_00801400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00808000_1,
    iemDecodeA64_07e0fc00_00800400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00809000_1,
    iemDecodeA64_07e0fc00_00801400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00804000_1,
    iemDecodeA64_07e0fc00_00800400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00805000_1,
    iemDecodeA64_07e0fc00_00801400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00804000_1,
    iemDecodeA64_07e0fc00_00800400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_00800c00_1,
    iemDecodeA64_07e0fc00_00805000_1,
    iemDecodeA64_07e0fc00_00801400_1,
    iemDecodeA64_07e0fc00_00800800_1,
    iemDecodeA64_07e0fc00_0080fc00_1,
    iemDecodeA64_07e0fc00_00a00000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a01000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a02000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a03000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a04000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a05000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a06000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a06800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a07000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a06800_1,
    iemDecodeA64_07e0fc00_00a07c00_1,
    iemDecodeA64_07e0fc00_00a08000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a09000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a0a000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a0b000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a0c000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a0d000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a0d000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a00c00_1,
    iemDecodeA64_07e0fc00_00a0d000_1,
    iemDecodeA64_07e0fc00_00a00400_1,
    iemDecodeA64_07e0fc00_00a00800_1,
    iemDecodeA64_07e0fc00_00a0fc00_1,
    iemDecodeA64_07e0fc00_00c00000_1,
    iemDecodeA64_07e0fc00_00c00400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c01000_1,
    iemDecodeA64_07e0fc00_00c01400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c02000_1,
    iemDecodeA64_07e0fc00_00c00400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c01000_1,
    iemDecodeA64_07e0fc00_00c01400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c02000_1,
    iemDecodeA64_07e0fc00_00c00400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c01000_1,
    iemDecodeA64_07e0fc00_00c01400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c02000_1,
    iemDecodeA64_07e0fc00_00c00400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c01000_1,
    iemDecodeA64_07e0fc00_00c01400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c07c00_1,
    iemDecodeA64_07e0fc00_00c02000_1,
    iemDecodeA64_07e0fc00_00c00400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c01000_1,
    iemDecodeA64_07e0fc00_00c01400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c02000_1,
    iemDecodeA64_07e0fc00_00c00400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c01000_1,
    iemDecodeA64_07e0fc00_00c01400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c02000_1,
    iemDecodeA64_07e0fc00_00c00400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c01000_1,
    iemDecodeA64_07e0fc00_00c01400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c02000_1,
    iemDecodeA64_07e0fc00_00c00400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c00c00_1,
    iemDecodeA64_07e0fc00_00c01000_1,
    iemDecodeA64_07e0fc00_00c01400_1,
    iemDecodeA64_07e0fc00_00c00800_1,
    iemDecodeA64_07e0fc00_00c0fc00_1,
    iemDecodeA64_07e0fc00_00e00000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e01000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e02000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e03000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e04000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e05000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e06000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e06800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e07000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e06800_1,
    iemDecodeA64_07e0fc00_00e07c00_1,
    iemDecodeA64_07e0fc00_00e08000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e09000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e0a000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e0b000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e0c000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e0c000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e0c000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e00c00_1,
    iemDecodeA64_07e0fc00_00e0c000_1,
    iemDecodeA64_07e0fc00_00e00400_1,
    iemDecodeA64_07e0fc00_00e00800_1,
    iemDecodeA64_07e0fc00_00e0fc00_1,
    iemDecodeA64_07e0fc00_01000000_1,
    iemDecodeA64_07e0fc00_01000400_1,
    iemDecodeA64_07e0fc00_01000800_1,
    iemDecodeA64_07e0fc00_01000c00_1,
    iemDecodeA64_07e0fc00_01001000_1,
    iemDecodeA64_07e0fc00_01001400_1,
    iemDecodeA64_07e0fc00_01001800_1,
    iemDecodeA64_07e0fc00_01001c00_1,
    iemDecodeA64_07e0fc00_01002000_1,
    iemDecodeA64_07e0fc00_01002400_1,
    iemDecodeA64_07e0fc00_01002800_1,
    iemDecodeA64_07e0fc00_01002800_1,
    iemDecodeA64_07e0fc00_01003000_1,
    iemDecodeA64_07e0fc00_01003400_1,
    iemDecodeA64_07e0fc00_01003800_1,
    iemDecodeA64_07e0fc00_01003800_1,
    iemDecodeA64_07e0fc00_01004000_1,
    iemDecodeA64_07e0fc00_01004400_1,
    iemDecodeA64_07e0fc00_01004800_1,
    iemDecodeA64_07e0fc00_01004800_1,
    iemDecodeA64_07e0fc00_01005000_1,
    iemDecodeA64_07e0fc00_01005400_1,
    iemDecodeA64_07e0fc00_01005800_1,
    iemDecodeA64_07e0fc00_01005800_1,
    iemDecodeA64_07e0fc00_01006000_1,
    iemDecodeA64_07e0fc00_01006400_1,
    iemDecodeA64_07e0fc00_01006800_1,
    iemDecodeA64_07e0fc00_01006800_1,
    iemDecodeA64_07e0fc00_01007000_1,
    iemDecodeA64_07e0fc00_01007400_1,
    iemDecodeA64_07e0fc00_01007800_1,
    iemDecodeA64_07e0fc00_01007c00_1,
    iemDecodeA64_07e0fc00_01008000_1,
    iemDecodeA64_07e0fc00_01008400_1,
    iemDecodeA64_07e0fc00_01008800_1,
    iemDecodeA64_07e0fc00_01008800_1,
    iemDecodeA64_07e0fc00_01009000_1,
    iemDecodeA64_07e0fc00_01009400_1,
    iemDecodeA64_07e0fc00_01009800_1,
    iemDecodeA64_07e0fc00_01009800_1,
    iemDecodeA64_07e0fc00_0100a000_1,
    iemDecodeA64_07e0fc00_0100a400_1,
    iemDecodeA64_07e0fc00_0100a800_1,
    iemDecodeA64_07e0fc00_0100a800_1,
    iemDecodeA64_07e0fc00_0100b000_1,
    iemDecodeA64_07e0fc00_0100b400_1,
    iemDecodeA64_07e0fc00_0100b800_1,
    iemDecodeA64_07e0fc00_0100b800_1,
    iemDecodeA64_07e0fc00_0100c000_1,
    iemDecodeA64_07e0fc00_0100c400_1,
    iemDecodeA64_07e0fc00_0100c800_1,
    iemDecodeA64_07e0fc00_0100c800_1,
    iemDecodeA64_07e0fc00_0100d000_1,
    iemDecodeA64_07e0fc00_0100d400_1,
    iemDecodeA64_07e0fc00_0100d800_1,
    iemDecodeA64_07e0fc00_0100d800_1,
    iemDecodeA64_07e0fc00_0100e000_1,
    iemDecodeA64_07e0fc00_0100e400_1,
    iemDecodeA64_07e0fc00_0100e800_1,
    iemDecodeA64_07e0fc00_0100e800_1,
    iemDecodeA64_07e0fc00_0100f000_1,
    iemDecodeA64_07e0fc00_0100f400_1,
    iemDecodeA64_07e0fc00_0100f800_1,
    iemDecodeA64_07e0fc00_0100fc00_1,
    iemDecodeA64_07e0fc00_01200000_1,
    iemDecodeA64_07e0fc00_01200400_1,
    iemDecodeA64_07e0fc00_01200800_1,
    iemDecodeA64_07e0fc00_01200c00_1,
    iemDecodeA64_07e0fc00_01201000_1,
    iemDecodeA64_07e0fc00_01201400_1,
    iemDecodeA64_07e0fc00_01201800_1,
    iemDecodeA64_07e0fc00_01201c00_1,
    iemDecodeA64_07e0fc00_01202000_1,
    iemDecodeA64_07e0fc00_01202400_1,
    iemDecodeA64_07e0fc00_01202800_1,
    iemDecodeA64_07e0fc00_01202c00_1,
    iemDecodeA64_07e0fc00_01203000_1,
    iemDecodeA64_07e0fc00_01203400_1,
    iemDecodeA64_07e0fc00_01203800_1,
    iemDecodeA64_07e0fc00_01203c00_1,
    iemDecodeA64_07e0fc00_01204000_1,
    iemDecodeA64_07e0fc00_01204400_1,
    iemDecodeA64_07e0fc00_01204800_1,
    iemDecodeA64_07e0fc00_01204c00_1,
    iemDecodeA64_07e0fc00_01205000_1,
    iemDecodeA64_07e0fc00_01205400_1,
    iemDecodeA64_07e0fc00_01205800_1,
    iemDecodeA64_07e0fc00_01205c00_1,
    iemDecodeA64_07e0fc00_01206000_1,
    iemDecodeA64_07e0fc00_01206400_1,
    iemDecodeA64_07e0fc00_01206800_1,
    iemDecodeA64_07e0fc00_01206c00_1,
    iemDecodeA64_07e0fc00_01207000_1,
    iemDecodeA64_07e0fc00_01207400_1,
    iemDecodeA64_07e0fc00_01207800_1,
    iemDecodeA64_07e0fc00_01207c00_1,
    iemDecodeA64_07e0fc00_01208000_1,
    iemDecodeA64_07e0fc00_01208400_1,
    iemDecodeA64_07e0fc00_01208800_1,
    iemDecodeA64_07e0fc00_01208c00_1,
    iemDecodeA64_07e0fc00_01209000_1,
    iemDecodeA64_07e0fc00_01209400_1,
    iemDecodeA64_07e0fc00_01208800_1,
    iemDecodeA64_07e0fc00_01208c00_1,
    iemDecodeA64_07e0fc00_0120a000_1,
    iemDecodeA64_07e0fc00_0120a400_1,
    iemDecodeA64_07e0fc00_0120a800_1,
    iemDecodeA64_07e0fc00_0120ac00_1,
    iemDecodeA64_07e0fc00_0120b000_1,
    iemDecodeA64_07e0fc00_0120b400_1,
    iemDecodeA64_07e0fc00_0120b800_1,
    iemDecodeA64_07e0fc00_0120bc00_1,
    iemDecodeA64_07e0fc00_0120c000_1,
    iemDecodeA64_07e0fc00_0120c400_1,
    iemDecodeA64_07e0fc00_0120c800_1,
    iemDecodeA64_07e0fc00_0120cc00_1,
    iemDecodeA64_07e0fc00_0120d000_1,
    iemDecodeA64_07e0fc00_0120d400_1,
    iemDecodeA64_07e0fc00_0120d800_1,
    iemDecodeA64_07e0fc00_0120dc00_1,
    iemDecodeA64_07e0fc00_0120e000_1,
    iemDecodeA64_07e0fc00_0120e400_1,
    iemDecodeA64_07e0fc00_0120e800_1,
    iemDecodeA64_07e0fc00_0120ec00_1,
    iemDecodeA64_07e0fc00_0120f000_1,
    iemDecodeA64_07e0fc00_0120f400_1,
    iemDecodeA64_07e0fc00_0120f800_1,
    iemDecodeA64_07e0fc00_0120ec00_1,
    iemDecodeA64_07e0fc00_01400000_1,
    iemDecodeA64_07e0fc00_01400400_1,
    iemDecodeA64_07e0fc00_01400800_1,
    iemDecodeA64_07e0fc00_01400c00_1,
    iemDecodeA64_07e0fc00_01401000_1,
    iemDecodeA64_07e0fc00_01401400_1,
    iemDecodeA64_07e0fc00_01401800_1,
    iemDecodeA64_07e0fc00_01401c00_1,
    iemDecodeA64_07e0fc00_01402000_1,
    iemDecodeA64_07e0fc00_01402400_1,
    iemDecodeA64_07e0fc00_01402800_1,
    iemDecodeA64_07e0fc00_01402800_1,
    iemDecodeA64_07e0fc00_01403000_1,
    iemDecodeA64_07e0fc00_01403400_1,
    iemDecodeA64_07e0fc00_01403800_1,
    iemDecodeA64_07e0fc00_01403800_1,
    iemDecodeA64_07e0fc00_01404000_1,
    iemDecodeA64_07e0fc00_01404400_1,
    iemDecodeA64_07e0fc00_01404800_1,
    iemDecodeA64_07e0fc00_01404800_1,
    iemDecodeA64_07e0fc00_01405000_1,
    iemDecodeA64_07e0fc00_01405400_1,
    iemDecodeA64_07e0fc00_01405800_1,
    iemDecodeA64_07e0fc00_01405800_1,
    iemDecodeA64_07e0fc00_01406000_1,
    iemDecodeA64_07e0fc00_01406400_1,
    iemDecodeA64_07e0fc00_01406800_1,
    iemDecodeA64_07e0fc00_01406800_1,
    iemDecodeA64_07e0fc00_01407000_1,
    iemDecodeA64_07e0fc00_01407400_1,
    iemDecodeA64_07e0fc00_01407800_1,
    iemDecodeA64_07e0fc00_01407c00_1,
    iemDecodeA64_07e0fc00_01408000_1,
    iemDecodeA64_07e0fc00_01408400_1,
    iemDecodeA64_07e0fc00_01408800_1,
    iemDecodeA64_07e0fc00_01408800_1,
    iemDecodeA64_07e0fc00_01409000_1,
    iemDecodeA64_07e0fc00_01409400_1,
    iemDecodeA64_07e0fc00_01409800_1,
    iemDecodeA64_07e0fc00_01409800_1,
    iemDecodeA64_07e0fc00_0140a000_1,
    iemDecodeA64_07e0fc00_0140a400_1,
    iemDecodeA64_07e0fc00_0140a800_1,
    iemDecodeA64_07e0fc00_0140a800_1,
    iemDecodeA64_07e0fc00_0140b000_1,
    iemDecodeA64_07e0fc00_0140b400_1,
    iemDecodeA64_07e0fc00_0140b800_1,
    iemDecodeA64_07e0fc00_0140b800_1,
    iemDecodeA64_07e0fc00_0140c000_1,
    iemDecodeA64_07e0fc00_0140c400_1,
    iemDecodeA64_07e0fc00_0140c800_1,
    iemDecodeA64_07e0fc00_0140c800_1,
    iemDecodeA64_07e0fc00_0140d000_1,
    iemDecodeA64_07e0fc00_0140d400_1,
    iemDecodeA64_07e0fc00_0140d800_1,
    iemDecodeA64_07e0fc00_0140d800_1,
    iemDecodeA64_07e0fc00_0140e000_1,
    iemDecodeA64_07e0fc00_0140e400_1,
    iemDecodeA64_07e0fc00_0140e800_1,
    iemDecodeA64_07e0fc00_0140e800_1,
    iemDecodeA64_07e0fc00_0140f000_1,
    iemDecodeA64_07e0fc00_0140f400_1,
    iemDecodeA64_07e0fc00_0140f800_1,
    iemDecodeA64_07e0fc00_0140fc00_1,
    iemDecodeA64_07e0fc00_01600000_1,
    iemDecodeA64_07e0fc00_01600400_1,
    iemDecodeA64_07e0fc00_01600800_1,
    iemDecodeA64_07e0fc00_01600c00_1,
    iemDecodeA64_07e0fc00_01601000_1,
    iemDecodeA64_07e0fc00_01601400_1,
    iemDecodeA64_07e0fc00_01601800_1,
    iemDecodeA64_07e0fc00_01601c00_1,
    iemDecodeA64_07e0fc00_01602000_1,
    iemDecodeA64_07e0fc00_01602400_1,
    iemDecodeA64_07e0fc00_01602800_1,
    iemDecodeA64_07e0fc00_01602c00_1,
    iemDecodeA64_07e0fc00_01603000_1,
    iemDecodeA64_07e0fc00_01603400_1,
    iemDecodeA64_07e0fc00_01603800_1,
    iemDecodeA64_07e0fc00_01603c00_1,
    iemDecodeA64_07e0fc00_01604000_1,
    iemDecodeA64_07e0fc00_01604400_1,
    iemDecodeA64_07e0fc00_01604800_1,
    iemDecodeA64_07e0fc00_01604c00_1,
    iemDecodeA64_07e0fc00_01605000_1,
    iemDecodeA64_07e0fc00_01605400_1,
    iemDecodeA64_07e0fc00_01605800_1,
    iemDecodeA64_07e0fc00_01605c00_1,
    iemDecodeA64_07e0fc00_01606000_1,
    iemDecodeA64_07e0fc00_01606400_1,
    iemDecodeA64_07e0fc00_01606800_1,
    iemDecodeA64_07e0fc00_01606c00_1,
    iemDecodeA64_07e0fc00_01607000_1,
    iemDecodeA64_07e0fc00_01607400_1,
    iemDecodeA64_07e0fc00_01607800_1,
    iemDecodeA64_07e0fc00_01607c00_1,
    iemDecodeA64_07e0fc00_01608000_1,
    iemDecodeA64_07e0fc00_01608400_1,
    iemDecodeA64_07e0fc00_01608800_1,
    iemDecodeA64_07e0fc00_01608c00_1,
    iemDecodeA64_07e0fc00_01609000_1,
    iemDecodeA64_07e0fc00_01609400_1,
    iemDecodeA64_07e0fc00_01608800_1,
    iemDecodeA64_07e0fc00_01608c00_1,
    iemDecodeA64_07e0fc00_0160a000_1,
    iemDecodeA64_07e0fc00_0160a400_1,
    iemDecodeA64_07e0fc00_0160a800_1,
    iemDecodeA64_07e0fc00_0160ac00_1,
    iemDecodeA64_07e0fc00_0160b000_1,
    iemDecodeA64_07e0fc00_0160b400_1,
    iemDecodeA64_07e0fc00_0160b800_1,
    iemDecodeA64_07e0fc00_0160bc00_1,
    iemDecodeA64_07e0fc00_0160c000_1,
    iemDecodeA64_07e0fc00_0160c400_1,
    iemDecodeA64_07e0fc00_0160c800_1,
    iemDecodeA64_07e0fc00_0160cc00_1,
    iemDecodeA64_07e0fc00_0160d000_1,
    iemDecodeA64_07e0fc00_0160d400_1,
    iemDecodeA64_07e0fc00_0160d800_1,
    iemDecodeA64_07e0fc00_0160dc00_1,
    iemDecodeA64_07e0fc00_0160e000_1,
    iemDecodeA64_07e0fc00_0160e400_1,
    iemDecodeA64_07e0fc00_0160e800_1,
    iemDecodeA64_07e0fc00_0160ec00_1,
    iemDecodeA64_07e0fc00_0160f000_1,
    iemDecodeA64_07e0fc00_0160f400_1,
    iemDecodeA64_07e0fc00_0160f800_1,
    iemDecodeA64_07e0fc00_0160ec00_1,
    iemDecodeA64_07e0fc00_01800000_1,
    iemDecodeA64_07e0fc00_01800400_1,
    iemDecodeA64_07e0fc00_01800800_1,
    iemDecodeA64_07e0fc00_01800c00_1,
    iemDecodeA64_07e0fc00_01801000_1,
    iemDecodeA64_07e0fc00_01801400_1,
    iemDecodeA64_07e0fc00_01801800_1,
    iemDecodeA64_07e0fc00_01801800_1,
    iemDecodeA64_07e0fc00_01800000_1,
    iemDecodeA64_07e0fc00_01802400_1,
    iemDecodeA64_07e0fc00_01800c00_1,
    iemDecodeA64_07e0fc00_01800c00_1,
    iemDecodeA64_07e0fc00_01801000_1,
    iemDecodeA64_07e0fc00_01803400_1,
    iemDecodeA64_07e0fc00_01801800_1,
    iemDecodeA64_07e0fc00_01801800_1,
    iemDecodeA64_07e0fc00_01804000_1,
    iemDecodeA64_07e0fc00_01804400_1,
    iemDecodeA64_07e0fc00_01804800_1,
    iemDecodeA64_07e0fc00_01804800_1,
    iemDecodeA64_07e0fc00_01805000_1,
    iemDecodeA64_07e0fc00_01805400_1,
    iemDecodeA64_07e0fc00_01805800_1,
    iemDecodeA64_07e0fc00_01805800_1,
    iemDecodeA64_07e0fc00_01804000_1,
    iemDecodeA64_07e0fc00_01806400_1,
    iemDecodeA64_07e0fc00_01804800_1,
    iemDecodeA64_07e0fc00_01804800_1,
    iemDecodeA64_07e0fc00_01805000_1,
    iemDecodeA64_07e0fc00_01807400_1,
    iemDecodeA64_07e0fc00_01805800_1,
    iemDecodeA64_07e0fc00_01807c00_1,
    iemDecodeA64_07e0fc00_01808000_1,
    iemDecodeA64_07e0fc00_01808400_1,
    iemDecodeA64_07e0fc00_01808800_1,
    iemDecodeA64_07e0fc00_01808800_1,
    iemDecodeA64_07e0fc00_01809000_1,
    iemDecodeA64_07e0fc00_01809400_1,
    iemDecodeA64_07e0fc00_01809800_1,
    iemDecodeA64_07e0fc00_01809800_1,
    iemDecodeA64_07e0fc00_01808000_1,
    iemDecodeA64_07e0fc00_0180a400_1,
    iemDecodeA64_07e0fc00_01808800_1,
    iemDecodeA64_07e0fc00_01808800_1,
    iemDecodeA64_07e0fc00_01809000_1,
    iemDecodeA64_07e0fc00_0180b400_1,
    iemDecodeA64_07e0fc00_01809800_1,
    iemDecodeA64_07e0fc00_01809800_1,
    iemDecodeA64_07e0fc00_01808000_1,
    iemDecodeA64_07e0fc00_0180c400_1,
    iemDecodeA64_07e0fc00_01808800_1,
    iemDecodeA64_07e0fc00_01808800_1,
    iemDecodeA64_07e0fc00_01809000_1,
    iemDecodeA64_07e0fc00_0180d400_1,
    iemDecodeA64_07e0fc00_01809800_1,
    iemDecodeA64_07e0fc00_01809800_1,
    iemDecodeA64_07e0fc00_01808000_1,
    iemDecodeA64_07e0fc00_0180e400_1,
    iemDecodeA64_07e0fc00_01808800_1,
    iemDecodeA64_07e0fc00_01808800_1,
    iemDecodeA64_07e0fc00_01809000_1,
    iemDecodeA64_07e0fc00_0180f400_1,
    iemDecodeA64_07e0fc00_01809800_1,
    iemDecodeA64_07e0fc00_0180fc00_1,
    iemDecodeA64_07e0fc00_01a00000_1,
    iemDecodeA64_07e0fc00_01a00400_1,
    iemDecodeA64_07e0fc00_01a00800_1,
    iemDecodeA64_07e0fc00_01a00c00_1,
    iemDecodeA64_07e0fc00_01a01000_1,
    iemDecodeA64_07e0fc00_01a01400_1,
    iemDecodeA64_07e0fc00_01a01800_1,
    iemDecodeA64_07e0fc00_01a01c00_1,
    iemDecodeA64_07e0fc00_01a02000_1,
    iemDecodeA64_07e0fc00_01a02400_1,
    iemDecodeA64_07e0fc00_01a02800_1,
    iemDecodeA64_07e0fc00_01a02c00_1,
    iemDecodeA64_07e0fc00_01a03000_1,
    iemDecodeA64_07e0fc00_01a03400_1,
    iemDecodeA64_07e0fc00_01a01800_1,
    iemDecodeA64_07e0fc00_01a01c00_1,
    iemDecodeA64_07e0fc00_01a04000_1,
    iemDecodeA64_07e0fc00_01a04400_1,
    iemDecodeA64_07e0fc00_01a04800_1,
    iemDecodeA64_07e0fc00_01a04c00_1,
    iemDecodeA64_07e0fc00_01a05000_1,
    iemDecodeA64_07e0fc00_01a05400_1,
    iemDecodeA64_07e0fc00_01a05800_1,
    iemDecodeA64_07e0fc00_01a05c00_1,
    iemDecodeA64_07e0fc00_01a04000_1,
    iemDecodeA64_07e0fc00_01a04400_1,
    iemDecodeA64_07e0fc00_01a04800_1,
    iemDecodeA64_07e0fc00_01a04c00_1,
    iemDecodeA64_07e0fc00_01a05000_1,
    iemDecodeA64_07e0fc00_01a05400_1,
    iemDecodeA64_07e0fc00_01a05800_1,
    iemDecodeA64_07e0fc00_01a05c00_1,
    iemDecodeA64_07e0fc00_01a08000_1,
    iemDecodeA64_07e0fc00_01a08400_1,
    iemDecodeA64_07e0fc00_01a08800_1,
    iemDecodeA64_07e0fc00_01a08c00_1,
    iemDecodeA64_07e0fc00_01a09000_1,
    iemDecodeA64_07e0fc00_01a09400_1,
    iemDecodeA64_07e0fc00_01a08800_1,
    iemDecodeA64_07e0fc00_01a08c00_1,
    iemDecodeA64_07e0fc00_01a0a000_1,
    iemDecodeA64_07e0fc00_01a0a400_1,
    iemDecodeA64_07e0fc00_01a0a800_1,
    iemDecodeA64_07e0fc00_01a0ac00_1,
    iemDecodeA64_07e0fc00_01a0b000_1,
    iemDecodeA64_07e0fc00_01a0b400_1,
    iemDecodeA64_07e0fc00_01a0b800_1,
    iemDecodeA64_07e0fc00_01a0bc00_1,
    iemDecodeA64_07e0fc00_01a0c000_1,
    iemDecodeA64_07e0fc00_01a0c400_1,
    iemDecodeA64_07e0fc00_01a0c800_1,
    iemDecodeA64_07e0fc00_01a0cc00_1,
    iemDecodeA64_07e0fc00_01a0d000_1,
    iemDecodeA64_07e0fc00_01a04400_1,
    iemDecodeA64_07e0fc00_01a0d800_1,
    iemDecodeA64_07e0fc00_01a0dc00_1,
    iemDecodeA64_07e0fc00_01a0e000_1,
    iemDecodeA64_07e0fc00_01a0e400_1,
    iemDecodeA64_07e0fc00_01a0e800_1,
    iemDecodeA64_07e0fc00_01a04c00_1,
    iemDecodeA64_07e0fc00_01a0f000_1,
    iemDecodeA64_07e0fc00_01a04400_1,
    iemDecodeA64_07e0fc00_01a0f800_1,
    iemDecodeA64_07e0fc00_01a04c00_1,
    iemDecodeA64_07e0fc00_01c00000_1,
    iemDecodeA64_07e0fc00_01c00400_1,
    iemDecodeA64_07e0fc00_01c00800_1,
    iemDecodeA64_07e0fc00_01c00c00_1,
    iemDecodeA64_07e0fc00_01c01000_1,
    iemDecodeA64_07e0fc00_01c01400_1,
    iemDecodeA64_07e0fc00_01c01800_1,
    iemDecodeA64_07e0fc00_01c01800_1,
    iemDecodeA64_07e0fc00_01c02000_1,
    iemDecodeA64_07e0fc00_01c02400_1,
    iemDecodeA64_07e0fc00_01c00c00_1,
    iemDecodeA64_07e0fc00_01c00c00_1,
    iemDecodeA64_07e0fc00_01c01000_1,
    iemDecodeA64_07e0fc00_01c03400_1,
    iemDecodeA64_07e0fc00_01c01800_1,
    iemDecodeA64_07e0fc00_01c01800_1,
    iemDecodeA64_07e0fc00_01c02000_1,
    iemDecodeA64_07e0fc00_01c04400_1,
    iemDecodeA64_07e0fc00_01c00c00_1,
    iemDecodeA64_07e0fc00_01c00c00_1,
    iemDecodeA64_07e0fc00_01c01000_1,
    iemDecodeA64_07e0fc00_01c05400_1,
    iemDecodeA64_07e0fc00_01c01800_1,
    iemDecodeA64_07e0fc00_01c01800_1,
    iemDecodeA64_07e0fc00_01c02000_1,
    iemDecodeA64_07e0fc00_01c06400_1,
    iemDecodeA64_07e0fc00_01c00c00_1,
    iemDecodeA64_07e0fc00_01c00c00_1,
    iemDecodeA64_07e0fc00_01c01000_1,
    iemDecodeA64_07e0fc00_01c07400_1,
    iemDecodeA64_07e0fc00_01c01800_1,
    iemDecodeA64_07e0fc00_01c07c00_1,
    iemDecodeA64_07e0fc00_01c08000_1,
    iemDecodeA64_07e0fc00_01c08400_1,
    iemDecodeA64_07e0fc00_01c08800_1,
    iemDecodeA64_07e0fc00_01c08800_1,
    iemDecodeA64_07e0fc00_01c09000_1,
    iemDecodeA64_07e0fc00_01c09400_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c08000_1,
    iemDecodeA64_07e0fc00_01c0a400_1,
    iemDecodeA64_07e0fc00_01c08800_1,
    iemDecodeA64_07e0fc00_01c08800_1,
    iemDecodeA64_07e0fc00_01c09000_1,
    iemDecodeA64_07e0fc00_01c0b400_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c08000_1,
    iemDecodeA64_07e0fc00_01c0c400_1,
    iemDecodeA64_07e0fc00_01c08800_1,
    iemDecodeA64_07e0fc00_01c08800_1,
    iemDecodeA64_07e0fc00_01c09000_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c08000_1,
    iemDecodeA64_07e0fc00_01c0c400_1,
    iemDecodeA64_07e0fc00_01c08800_1,
    iemDecodeA64_07e0fc00_01c08800_1,
    iemDecodeA64_07e0fc00_01c09000_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c09800_1,
    iemDecodeA64_07e0fc00_01c0fc00_1,
    iemDecodeA64_07e0fc00_01e00000_1,
    iemDecodeA64_07e0fc00_01e00400_1,
    iemDecodeA64_07e0fc00_01e00800_1,
    iemDecodeA64_07e0fc00_01e00c00_1,
    iemDecodeA64_07e0fc00_01e01000_1,
    iemDecodeA64_07e0fc00_01e01400_1,
    iemDecodeA64_07e0fc00_01e01800_1,
    iemDecodeA64_07e0fc00_01e01c00_1,
    iemDecodeA64_07e0fc00_01e02000_1,
    iemDecodeA64_07e0fc00_01e02400_1,
    iemDecodeA64_07e0fc00_01e02800_1,
    iemDecodeA64_07e0fc00_01e02c00_1,
    iemDecodeA64_07e0fc00_01e03000_1,
    iemDecodeA64_07e0fc00_01e03400_1,
    iemDecodeA64_07e0fc00_01e01800_1,
    iemDecodeA64_07e0fc00_01e01c00_1,
    iemDecodeA64_07e0fc00_01e02000_1,
    iemDecodeA64_07e0fc00_01e02400_1,
    iemDecodeA64_07e0fc00_01e02800_1,
    iemDecodeA64_07e0fc00_01e02c00_1,
    iemDecodeA64_07e0fc00_01e05000_1,
    iemDecodeA64_07e0fc00_01e05400_1,
    iemDecodeA64_07e0fc00_01e01800_1,
    iemDecodeA64_07e0fc00_01e01c00_1,
    iemDecodeA64_07e0fc00_01e02000_1,
    iemDecodeA64_07e0fc00_01e02400_1,
    iemDecodeA64_07e0fc00_01e02800_1,
    iemDecodeA64_07e0fc00_01e02c00_1,
    iemDecodeA64_07e0fc00_01e05000_1,
    iemDecodeA64_07e0fc00_01e05400_1,
    iemDecodeA64_07e0fc00_01e01800_1,
    iemDecodeA64_07e0fc00_01e01c00_1,
    iemDecodeA64_07e0fc00_01e08000_1,
    iemDecodeA64_07e0fc00_01e08400_1,
    iemDecodeA64_07e0fc00_01e08800_1,
    iemDecodeA64_07e0fc00_01e08c00_1,
    iemDecodeA64_07e0fc00_01e09000_1,
    iemDecodeA64_07e0fc00_01e09400_1,
    iemDecodeA64_07e0fc00_01e08800_1,
    iemDecodeA64_07e0fc00_01e08c00_1,
    iemDecodeA64_07e0fc00_01e0a000_1,
    iemDecodeA64_07e0fc00_01e0a400_1,
    iemDecodeA64_07e0fc00_01e0a800_1,
    iemDecodeA64_07e0fc00_01e0ac00_1,
    iemDecodeA64_07e0fc00_01e0b000_1,
    iemDecodeA64_07e0fc00_01e0b400_1,
    iemDecodeA64_07e0fc00_01e0b800_1,
    iemDecodeA64_07e0fc00_01e0bc00_1,
    iemDecodeA64_07e0fc00_01e0c000_1,
    iemDecodeA64_07e0fc00_01e0c400_1,
    iemDecodeA64_07e0fc00_01e0c800_1,
    iemDecodeA64_07e0fc00_01e0cc00_1,
    iemDecodeA64_07e0fc00_01e0d000_1,
    iemDecodeA64_07e0fc00_01e0d400_1,
    iemDecodeA64_07e0fc00_01e0d800_1,
    iemDecodeA64_07e0fc00_01e0dc00_1,
    iemDecodeA64_07e0fc00_01e0e000_1,
    iemDecodeA64_07e0fc00_01e0e400_1,
    iemDecodeA64_07e0fc00_01e0e800_1,
    iemDecodeA64_07e0fc00_01e02c00_1,
    iemDecodeA64_07e0fc00_01e0f000_1,
    iemDecodeA64_07e0fc00_01e02400_1,
    iemDecodeA64_07e0fc00_01e0f800_1,
    iemDecodeA64_07e0fc00_01e02c00_1,
    iemDecodeA64_07e0fc00_02000000_1,
    iemDecodeA64_07e0fc00_02000400_1,
    iemDecodeA64_07e0fc00_02000800_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02002000_1,
    iemDecodeA64_07e0fc00_02002000_1,
    iemDecodeA64_07e0fc00_02002000_1,
    iemDecodeA64_07e0fc00_02002000_1,
    iemDecodeA64_07e0fc00_02002000_1,
    iemDecodeA64_07e0fc00_02002000_1,
    iemDecodeA64_07e0fc00_02002000_1,
    iemDecodeA64_07e0fc00_02002000_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02004800_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000400_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02000c00_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02200000_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400000_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02400800_1,
    iemDecodeA64_07e0fc00_02400400_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02600000_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800000_1,
    iemDecodeA64_07e0fc00_02800400_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02800800_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02a00000_1,
    iemDecodeA64_07e0fc00_02c00000_1,
    iemDecodeA64_07e0fc00_02c00400_1,
    iemDecodeA64_07e0fc00_02c00800_1,
    iemDecodeA64_07e0fc00_02c00c00_1,
    iemDecodeA64_07e0fc00_02c01000_1,
    iemDecodeA64_07e0fc00_02c01400_1,
    iemDecodeA64_07e0fc00_02c01800_1,
    iemDecodeA64_07e0fc00_02c01c00_1,
    iemDecodeA64_07e0fc00_02c02000_1,
    iemDecodeA64_07e0fc00_02c02400_1,
    iemDecodeA64_07e0fc00_02c02800_1,
    iemDecodeA64_07e0fc00_02c02c00_1,
    iemDecodeA64_07e0fc00_02c03000_1,
    iemDecodeA64_07e0fc00_02c03400_1,
    iemDecodeA64_07e0fc00_02c03800_1,
    iemDecodeA64_07e0fc00_02c03c00_1,
    iemDecodeA64_07e0fc00_02c04000_1,
    iemDecodeA64_07e0fc00_02c04400_1,
    iemDecodeA64_07e0fc00_02c04800_1,
    iemDecodeA64_07e0fc00_02c04c00_1,
    iemDecodeA64_07e0fc00_02c05000_1,
    iemDecodeA64_07e0fc00_02c05400_1,
    iemDecodeA64_07e0fc00_02c05800_1,
    iemDecodeA64_07e0fc00_02c05c00_1,
    iemDecodeA64_07e0fc00_02c06000_1,
    iemDecodeA64_07e0fc00_02c06400_1,
    iemDecodeA64_07e0fc00_02c06800_1,
    iemDecodeA64_07e0fc00_02c06c00_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c08000_1,
    iemDecodeA64_07e0fc00_02c08400_1,
    iemDecodeA64_07e0fc00_02c08800_1,
    iemDecodeA64_07e0fc00_02c08c00_1,
    iemDecodeA64_07e0fc00_02c09000_1,
    iemDecodeA64_07e0fc00_02c09400_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c0a000_1,
    iemDecodeA64_07e0fc00_02c0a400_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c0b800_1,
    iemDecodeA64_07e0fc00_02c0bc00_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02c07000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_02e00000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03000000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03008000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03200000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03208000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03407c00_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03400000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03600000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03608000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03800000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03808000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a00000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03a08000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c07c00_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_07e0fc00_03c00000_1,
    iemDecodeA64_Invalid, // 1984
    iemDecodeA64_Invalid, // 1985
    iemDecodeA64_Invalid, // 1986
    iemDecodeA64_Invalid, // 1987
    iemDecodeA64_Invalid, // 1988
    iemDecodeA64_Invalid, // 1989
    iemDecodeA64_Invalid, // 1990
    iemDecodeA64_Invalid, // 1991
    iemDecodeA64_Invalid, // 1992
    iemDecodeA64_Invalid, // 1993
    iemDecodeA64_Invalid, // 1994
    iemDecodeA64_Invalid, // 1995
    iemDecodeA64_Invalid, // 1996
    iemDecodeA64_Invalid, // 1997
    iemDecodeA64_Invalid, // 1998
    iemDecodeA64_Invalid, // 1999
    iemDecodeA64_Invalid, // 2000
    iemDecodeA64_Invalid, // 2001
    iemDecodeA64_Invalid, // 2002
    iemDecodeA64_Invalid, // 2003
    iemDecodeA64_Invalid, // 2004
    iemDecodeA64_Invalid, // 2005
    iemDecodeA64_Invalid, // 2006
    iemDecodeA64_Invalid, // 2007
    iemDecodeA64_Invalid, // 2008
    iemDecodeA64_Invalid, // 2009
    iemDecodeA64_Invalid, // 2010
    iemDecodeA64_Invalid, // 2011
    iemDecodeA64_Invalid, // 2012
    iemDecodeA64_Invalid, // 2013
    iemDecodeA64_Invalid, // 2014
    iemDecodeA64_Invalid, // 2015
    iemDecodeA64_Invalid, // 2016
    iemDecodeA64_Invalid, // 2017
    iemDecodeA64_Invalid, // 2018
    iemDecodeA64_Invalid, // 2019
    iemDecodeA64_Invalid, // 2020
    iemDecodeA64_Invalid, // 2021
    iemDecodeA64_Invalid, // 2022
    iemDecodeA64_Invalid, // 2023
    iemDecodeA64_Invalid, // 2024
    iemDecodeA64_Invalid, // 2025
    iemDecodeA64_Invalid, // 2026
    iemDecodeA64_Invalid, // 2027
    iemDecodeA64_Invalid, // 2028
    iemDecodeA64_Invalid, // 2029
    iemDecodeA64_Invalid, // 2030
    iemDecodeA64_Invalid, // 2031
    iemDecodeA64_Invalid, // 2032
    iemDecodeA64_Invalid, // 2033
    iemDecodeA64_Invalid, // 2034
    iemDecodeA64_Invalid, // 2035
    iemDecodeA64_Invalid, // 2036
    iemDecodeA64_Invalid, // 2037
    iemDecodeA64_Invalid, // 2038
    iemDecodeA64_Invalid, // 2039
    iemDecodeA64_Invalid, // 2040
    iemDecodeA64_Invalid, // 2041
    iemDecodeA64_Invalid, // 2042
    iemDecodeA64_Invalid, // 2043
    iemDecodeA64_Invalid, // 2044
    iemDecodeA64_Invalid, // 2045
    iemDecodeA64_Invalid, // 2046
    iemDecodeA64_Invalid, // 2047
    iemDecodeA64_07e0fc00_04000000_1,
    iemDecodeA64_07e0fc00_04000400_1,
    iemDecodeA64_07e0fc00_04000800_1,
    iemDecodeA64_07e0fc00_04000c00_1,
    iemDecodeA64_07e0fc00_04001000_1,
    iemDecodeA64_07e0fc00_04001400_1,
    iemDecodeA64_07e0fc00_04001800_1,
    iemDecodeA64_07e0fc00_04001c00_1,
    iemDecodeA64_07e0fc00_04002000_1,
    iemDecodeA64_07e0fc00_04002400_1,
    iemDecodeA64_07e0fc00_04002800_1,
    iemDecodeA64_07e0fc00_04002c00_1,
    iemDecodeA64_07e0fc00_04003000_1,
    iemDecodeA64_07e0fc00_04003400_1,
    iemDecodeA64_07e0fc00_04003800_1,
    iemDecodeA64_07e0fc00_04003c00_1,
    iemDecodeA64_07e0fc00_04004000_1,
    iemDecodeA64_07e0fc00_04004400_1,
    iemDecodeA64_07e0fc00_04004800_1,
    iemDecodeA64_07e0fc00_04004c00_1,
    iemDecodeA64_07e0fc00_04005000_1,
    iemDecodeA64_07e0fc00_04005400_1,
    iemDecodeA64_07e0fc00_04005800_1,
    iemDecodeA64_07e0fc00_04005c00_1,
    iemDecodeA64_07e0fc00_04006000_1,
    iemDecodeA64_07e0fc00_04006400_1,
    iemDecodeA64_07e0fc00_04006800_1,
    iemDecodeA64_07e0fc00_04006c00_1,
    iemDecodeA64_07e0fc00_04007000_1,
    iemDecodeA64_07e0fc00_04007400_1,
    iemDecodeA64_07e0fc00_04007800_1,
    iemDecodeA64_07e0fc00_04007c00_1,
    iemDecodeA64_07e0fc00_04008000_1,
    iemDecodeA64_07e0fc00_04008400_1,
    iemDecodeA64_07e0fc00_04008800_1,
    iemDecodeA64_07e0fc00_04008c00_1,
    iemDecodeA64_07e0fc00_04009000_1,
    iemDecodeA64_07e0fc00_04009400_1,
    iemDecodeA64_07e0fc00_04009800_1,
    iemDecodeA64_07e0fc00_04009c00_1,
    iemDecodeA64_07e0fc00_0400a000_1,
    iemDecodeA64_07e0fc00_0400a400_1,
    iemDecodeA64_07e0fc00_0400a800_1,
    iemDecodeA64_07e0fc00_0400ac00_1,
    iemDecodeA64_07e0fc00_0400b000_1,
    iemDecodeA64_07e0fc00_0400b400_1,
    iemDecodeA64_07e0fc00_0400b800_1,
    iemDecodeA64_07e0fc00_0400bc00_1,
    iemDecodeA64_07e0fc00_0400c000_1,
    iemDecodeA64_07e0fc00_0400c400_1,
    iemDecodeA64_07e0fc00_0400c800_1,
    iemDecodeA64_07e0fc00_0400cc00_1,
    iemDecodeA64_07e0fc00_0400d000_1,
    iemDecodeA64_07e0fc00_0400d400_1,
    iemDecodeA64_07e0fc00_0400d800_1,
    iemDecodeA64_07e0fc00_0400dc00_1,
    iemDecodeA64_07e0fc00_0400e000_1,
    iemDecodeA64_07e0fc00_0400e400_1,
    iemDecodeA64_07e0fc00_0400e800_1,
    iemDecodeA64_07e0fc00_0400ec00_1,
    iemDecodeA64_07e0fc00_0400f000_1,
    iemDecodeA64_07e0fc00_0400f400_1,
    iemDecodeA64_07e0fc00_0400f800_1,
    iemDecodeA64_07e0fc00_0400fc00_1,
    iemDecodeA64_07e0fc00_04200000_1,
    iemDecodeA64_07e0fc00_04200400_1,
    iemDecodeA64_07e0fc00_04200800_1,
    iemDecodeA64_07e0fc00_04200c00_1,
    iemDecodeA64_07e0fc00_04201000_1,
    iemDecodeA64_07e0fc00_04201400_1,
    iemDecodeA64_07e0fc00_04201800_1,
    iemDecodeA64_07e0fc00_04201c00_1,
    iemDecodeA64_07e0fc00_04202000_1,
    iemDecodeA64_07e0fc00_04202400_1,
    iemDecodeA64_07e0fc00_04202800_1,
    iemDecodeA64_07e0fc00_04202c00_1,
    iemDecodeA64_07e0fc00_04203000_1,
    iemDecodeA64_07e0fc00_04203400_1,
    iemDecodeA64_07e0fc00_04203800_1,
    iemDecodeA64_07e0fc00_04203c00_1,
    iemDecodeA64_07e0fc00_04204000_1,
    iemDecodeA64_07e0fc00_04204400_1,
    iemDecodeA64_07e0fc00_04204800_1,
    iemDecodeA64_07e0fc00_04204c00_1,
    iemDecodeA64_07e0fc00_04205000_1,
    iemDecodeA64_07e0fc00_04205400_1,
    iemDecodeA64_07e0fc00_04205800_1,
    iemDecodeA64_07e0fc00_04205c00_1,
    iemDecodeA64_07e0fc00_04206000_1,
    iemDecodeA64_07e0fc00_04206400_1,
    iemDecodeA64_07e0fc00_04206800_1,
    iemDecodeA64_07e0fc00_04206c00_1,
    iemDecodeA64_07e0fc00_04207000_1,
    iemDecodeA64_07e0fc00_04207400_1,
    iemDecodeA64_07e0fc00_04207800_1,
    iemDecodeA64_07e0fc00_04207c00_1,
    iemDecodeA64_07e0fc00_04208000_1,
    iemDecodeA64_07e0fc00_04208400_1,
    iemDecodeA64_07e0fc00_04208800_1,
    iemDecodeA64_07e0fc00_04208c00_1,
    iemDecodeA64_07e0fc00_04209000_1,
    iemDecodeA64_07e0fc00_04209400_1,
    iemDecodeA64_07e0fc00_04209800_1,
    iemDecodeA64_07e0fc00_04209c00_1,
    iemDecodeA64_07e0fc00_0420a000_1,
    iemDecodeA64_07e0fc00_0420a000_1,
    iemDecodeA64_07e0fc00_0420a800_1,
    iemDecodeA64_07e0fc00_0420a000_1,
    iemDecodeA64_07e0fc00_0420b000_1,
    iemDecodeA64_07e0fc00_0420b400_1,
    iemDecodeA64_07e0fc00_0420b800_1,
    iemDecodeA64_07e0fc00_0420bc00_1,
    iemDecodeA64_07e0fc00_0420c000_1,
    iemDecodeA64_07e0fc00_0420c400_1,
    iemDecodeA64_07e0fc00_0420c800_1,
    iemDecodeA64_07e0fc00_0420c400_1,
    iemDecodeA64_07e0fc00_0420d000_1,
    iemDecodeA64_07e0fc00_0420d400_1,
    iemDecodeA64_07e0fc00_0420d800_1,
    iemDecodeA64_07e0fc00_0420d400_1,
    iemDecodeA64_07e0fc00_0420e000_1,
    iemDecodeA64_07e0fc00_0420e400_1,
    iemDecodeA64_07e0fc00_0420e800_1,
    iemDecodeA64_07e0fc00_0420ec00_1,
    iemDecodeA64_07e0fc00_0420f000_1,
    iemDecodeA64_07e0fc00_0420f400_1,
    iemDecodeA64_07e0fc00_0420f800_1,
    iemDecodeA64_07e0fc00_0420fc00_1,
    iemDecodeA64_07e0fc00_04400000_1,
    iemDecodeA64_07e0fc00_04400400_1,
    iemDecodeA64_07e0fc00_04400800_1,
    iemDecodeA64_07e0fc00_04400c00_1,
    iemDecodeA64_07e0fc00_04401000_1,
    iemDecodeA64_07e0fc00_04401400_1,
    iemDecodeA64_07e0fc00_04401800_1,
    iemDecodeA64_07e0fc00_04401c00_1,
    iemDecodeA64_07e0fc00_04402000_1,
    iemDecodeA64_07e0fc00_04402400_1,
    iemDecodeA64_07e0fc00_04402800_1,
    iemDecodeA64_07e0fc00_04402c00_1,
    iemDecodeA64_07e0fc00_04403000_1,
    iemDecodeA64_07e0fc00_04403400_1,
    iemDecodeA64_07e0fc00_04403800_1,
    iemDecodeA64_07e0fc00_04403c00_1,
    iemDecodeA64_07e0fc00_04404000_1,
    iemDecodeA64_07e0fc00_04404400_1,
    iemDecodeA64_07e0fc00_04404800_1,
    iemDecodeA64_07e0fc00_04404c00_1,
    iemDecodeA64_07e0fc00_04405000_1,
    iemDecodeA64_07e0fc00_04405400_1,
    iemDecodeA64_07e0fc00_04405800_1,
    iemDecodeA64_07e0fc00_04405c00_1,
    iemDecodeA64_07e0fc00_04406000_1,
    iemDecodeA64_07e0fc00_04406400_1,
    iemDecodeA64_07e0fc00_04406800_1,
    iemDecodeA64_07e0fc00_04406c00_1,
    iemDecodeA64_07e0fc00_04407000_1,
    iemDecodeA64_07e0fc00_04407400_1,
    iemDecodeA64_07e0fc00_04407800_1,
    iemDecodeA64_07e0fc00_04407c00_1,
    iemDecodeA64_07e0fc00_04408000_1,
    iemDecodeA64_07e0fc00_04408400_1,
    iemDecodeA64_07e0fc00_04408800_1,
    iemDecodeA64_07e0fc00_04408c00_1,
    iemDecodeA64_07e0fc00_04409000_1,
    iemDecodeA64_07e0fc00_04409400_1,
    iemDecodeA64_07e0fc00_04409800_1,
    iemDecodeA64_07e0fc00_04409c00_1,
    iemDecodeA64_07e0fc00_0440a000_1,
    iemDecodeA64_07e0fc00_0440a400_1,
    iemDecodeA64_07e0fc00_0440a800_1,
    iemDecodeA64_07e0fc00_0440ac00_1,
    iemDecodeA64_07e0fc00_0440b000_1,
    iemDecodeA64_07e0fc00_0440b400_1,
    iemDecodeA64_07e0fc00_0440b800_1,
    iemDecodeA64_07e0fc00_0440bc00_1,
    iemDecodeA64_07e0fc00_0440c000_1,
    iemDecodeA64_07e0fc00_0440c400_1,
    iemDecodeA64_07e0fc00_0440c800_1,
    iemDecodeA64_07e0fc00_0440cc00_1,
    iemDecodeA64_07e0fc00_0440d000_1,
    iemDecodeA64_07e0fc00_0440d400_1,
    iemDecodeA64_07e0fc00_0440c800_1,
    iemDecodeA64_07e0fc00_0440cc00_1,
    iemDecodeA64_07e0fc00_0440e000_1,
    iemDecodeA64_07e0fc00_0440e400_1,
    iemDecodeA64_07e0fc00_0440e800_1,
    iemDecodeA64_07e0fc00_0440ec00_1,
    iemDecodeA64_07e0fc00_0440f000_1,
    iemDecodeA64_07e0fc00_0440f400_1,
    iemDecodeA64_07e0fc00_0440f800_1,
    iemDecodeA64_07e0fc00_0440fc00_1,
    iemDecodeA64_07e0fc00_04600000_1,
    iemDecodeA64_07e0fc00_04600400_1,
    iemDecodeA64_07e0fc00_04600800_1,
    iemDecodeA64_07e0fc00_04600c00_1,
    iemDecodeA64_07e0fc00_04601000_1,
    iemDecodeA64_07e0fc00_04601400_1,
    iemDecodeA64_07e0fc00_04601800_1,
    iemDecodeA64_07e0fc00_04601c00_1,
    iemDecodeA64_07e0fc00_04602000_1,
    iemDecodeA64_07e0fc00_04602400_1,
    iemDecodeA64_07e0fc00_04602800_1,
    iemDecodeA64_07e0fc00_04602c00_1,
    iemDecodeA64_07e0fc00_04603000_1,
    iemDecodeA64_07e0fc00_04603400_1,
    iemDecodeA64_07e0fc00_04603800_1,
    iemDecodeA64_07e0fc00_04603c00_1,
    iemDecodeA64_07e0fc00_04604000_1,
    iemDecodeA64_07e0fc00_04604400_1,
    iemDecodeA64_07e0fc00_04604800_1,
    iemDecodeA64_07e0fc00_04604c00_1,
    iemDecodeA64_07e0fc00_04605000_1,
    iemDecodeA64_07e0fc00_04605400_1,
    iemDecodeA64_07e0fc00_04605800_1,
    iemDecodeA64_07e0fc00_04605c00_1,
    iemDecodeA64_07e0fc00_04606000_1,
    iemDecodeA64_07e0fc00_04606400_1,
    iemDecodeA64_07e0fc00_04606800_1,
    iemDecodeA64_07e0fc00_04606c00_1,
    iemDecodeA64_07e0fc00_04607000_1,
    iemDecodeA64_07e0fc00_04607400_1,
    iemDecodeA64_07e0fc00_04607800_1,
    iemDecodeA64_07e0fc00_04606400_1,
    iemDecodeA64_07e0fc00_04608000_1,
    iemDecodeA64_07e0fc00_04608400_1,
    iemDecodeA64_07e0fc00_04608800_1,
    iemDecodeA64_07e0fc00_04608c00_1,
    iemDecodeA64_07e0fc00_04609000_1,
    iemDecodeA64_07e0fc00_04609400_1,
    iemDecodeA64_07e0fc00_04608800_1,
    iemDecodeA64_07e0fc00_04609c00_1,
    iemDecodeA64_07e0fc00_0460a000_1,
    iemDecodeA64_07e0fc00_0460a000_1,
    iemDecodeA64_07e0fc00_0460a800_1,
    iemDecodeA64_07e0fc00_0460a000_1,
    iemDecodeA64_07e0fc00_0460b000_1,
    iemDecodeA64_07e0fc00_0460b400_1,
    iemDecodeA64_07e0fc00_0460b800_1,
    iemDecodeA64_07e0fc00_0460b400_1,
    iemDecodeA64_07e0fc00_0460c000_1,
    iemDecodeA64_07e0fc00_0460c400_1,
    iemDecodeA64_07e0fc00_0460c800_1,
    iemDecodeA64_07e0fc00_0460cc00_1,
    iemDecodeA64_07e0fc00_0460d000_1,
    iemDecodeA64_07e0fc00_0460d400_1,
    iemDecodeA64_07e0fc00_0460d800_1,
    iemDecodeA64_07e0fc00_0460d400_1,
    iemDecodeA64_07e0fc00_0460e000_1,
    iemDecodeA64_07e0fc00_0460e400_1,
    iemDecodeA64_07e0fc00_0460e800_1,
    iemDecodeA64_07e0fc00_0460ec00_1,
    iemDecodeA64_07e0fc00_0460f000_1,
    iemDecodeA64_07e0fc00_0460f400_1,
    iemDecodeA64_07e0fc00_0460f800_1,
    iemDecodeA64_07e0fc00_0460fc00_1,
    iemDecodeA64_07e0fc00_04800000_1,
    iemDecodeA64_07e0fc00_04800400_1,
    iemDecodeA64_07e0fc00_04800800_1,
    iemDecodeA64_07e0fc00_04800c00_1,
    iemDecodeA64_07e0fc00_04801000_1,
    iemDecodeA64_07e0fc00_04801400_1,
    iemDecodeA64_07e0fc00_04801800_1,
    iemDecodeA64_07e0fc00_04801c00_1,
    iemDecodeA64_07e0fc00_04802000_1,
    iemDecodeA64_07e0fc00_04802400_1,
    iemDecodeA64_07e0fc00_04802800_1,
    iemDecodeA64_07e0fc00_04802c00_1,
    iemDecodeA64_07e0fc00_04803000_1,
    iemDecodeA64_07e0fc00_04803400_1,
    iemDecodeA64_07e0fc00_04803800_1,
    iemDecodeA64_07e0fc00_04803c00_1,
    iemDecodeA64_07e0fc00_04804000_1,
    iemDecodeA64_07e0fc00_04804400_1,
    iemDecodeA64_07e0fc00_04804800_1,
    iemDecodeA64_07e0fc00_04804c00_1,
    iemDecodeA64_07e0fc00_04805000_1,
    iemDecodeA64_07e0fc00_04805400_1,
    iemDecodeA64_07e0fc00_04805800_1,
    iemDecodeA64_07e0fc00_04805c00_1,
    iemDecodeA64_07e0fc00_04806000_1,
    iemDecodeA64_07e0fc00_04806400_1,
    iemDecodeA64_07e0fc00_04806800_1,
    iemDecodeA64_07e0fc00_04806c00_1,
    iemDecodeA64_07e0fc00_04807000_1,
    iemDecodeA64_07e0fc00_04807400_1,
    iemDecodeA64_07e0fc00_04807800_1,
    iemDecodeA64_07e0fc00_04807c00_1,
    iemDecodeA64_07e0fc00_04808000_1,
    iemDecodeA64_07e0fc00_04808400_1,
    iemDecodeA64_07e0fc00_04808800_1,
    iemDecodeA64_07e0fc00_04808c00_1,
    iemDecodeA64_07e0fc00_04809000_1,
    iemDecodeA64_07e0fc00_04809400_1,
    iemDecodeA64_07e0fc00_04809800_1,
    iemDecodeA64_07e0fc00_04809c00_1,
    iemDecodeA64_07e0fc00_0480a000_1,
    iemDecodeA64_07e0fc00_0480a400_1,
    iemDecodeA64_07e0fc00_0480a800_1,
    iemDecodeA64_07e0fc00_0480ac00_1,
    iemDecodeA64_07e0fc00_0480b000_1,
    iemDecodeA64_07e0fc00_0480b400_1,
    iemDecodeA64_07e0fc00_0480b800_1,
    iemDecodeA64_07e0fc00_0480bc00_1,
    iemDecodeA64_07e0fc00_0480c000_1,
    iemDecodeA64_07e0fc00_0480c400_1,
    iemDecodeA64_07e0fc00_0480c800_1,
    iemDecodeA64_07e0fc00_0480cc00_1,
    iemDecodeA64_07e0fc00_0480d000_1,
    iemDecodeA64_07e0fc00_0480d400_1,
    iemDecodeA64_07e0fc00_0480d800_1,
    iemDecodeA64_07e0fc00_0480dc00_1,
    iemDecodeA64_07e0fc00_0480e000_1,
    iemDecodeA64_07e0fc00_0480e400_1,
    iemDecodeA64_07e0fc00_0480e800_1,
    iemDecodeA64_07e0fc00_0480ec00_1,
    iemDecodeA64_07e0fc00_0480f000_1,
    iemDecodeA64_07e0fc00_0480f400_1,
    iemDecodeA64_07e0fc00_0480f800_1,
    iemDecodeA64_07e0fc00_0480fc00_1,
    iemDecodeA64_07e0fc00_04a00000_1,
    iemDecodeA64_07e0fc00_04a00400_1,
    iemDecodeA64_07e0fc00_04a00800_1,
    iemDecodeA64_07e0fc00_04a00c00_1,
    iemDecodeA64_07e0fc00_04a01000_1,
    iemDecodeA64_07e0fc00_04a01400_1,
    iemDecodeA64_07e0fc00_04a01800_1,
    iemDecodeA64_07e0fc00_04a01c00_1,
    iemDecodeA64_07e0fc00_04a02000_1,
    iemDecodeA64_07e0fc00_04a02400_1,
    iemDecodeA64_07e0fc00_04a02800_1,
    iemDecodeA64_07e0fc00_04a02c00_1,
    iemDecodeA64_07e0fc00_04a03000_1,
    iemDecodeA64_07e0fc00_04a03400_1,
    iemDecodeA64_07e0fc00_04a03800_1,
    iemDecodeA64_07e0fc00_04a03c00_1,
    iemDecodeA64_07e0fc00_04a04000_1,
    iemDecodeA64_07e0fc00_04a04400_1,
    iemDecodeA64_07e0fc00_04a04800_1,
    iemDecodeA64_07e0fc00_04a04c00_1,
    iemDecodeA64_07e0fc00_04a05000_1,
    iemDecodeA64_07e0fc00_04a05400_1,
    iemDecodeA64_07e0fc00_04a05800_1,
    iemDecodeA64_07e0fc00_04a05c00_1,
    iemDecodeA64_07e0fc00_04a06000_1,
    iemDecodeA64_07e0fc00_04a06400_1,
    iemDecodeA64_07e0fc00_04a06800_1,
    iemDecodeA64_07e0fc00_04a06c00_1,
    iemDecodeA64_07e0fc00_04a07000_1,
    iemDecodeA64_07e0fc00_04a07400_1,
    iemDecodeA64_07e0fc00_04a07800_1,
    iemDecodeA64_07e0fc00_04a07c00_1,
    iemDecodeA64_07e0fc00_04a08000_1,
    iemDecodeA64_07e0fc00_04a08400_1,
    iemDecodeA64_07e0fc00_04a08800_1,
    iemDecodeA64_07e0fc00_04a08c00_1,
    iemDecodeA64_07e0fc00_04a09000_1,
    iemDecodeA64_07e0fc00_04a09400_1,
    iemDecodeA64_07e0fc00_04a09800_1,
    iemDecodeA64_07e0fc00_04a09c00_1,
    iemDecodeA64_07e0fc00_04a0a000_1,
    iemDecodeA64_07e0fc00_04a0a400_1,
    iemDecodeA64_07e0fc00_04a0a800_1,
    iemDecodeA64_07e0fc00_04a0ac00_1,
    iemDecodeA64_07e0fc00_04a0b000_1,
    iemDecodeA64_07e0fc00_04a0b400_1,
    iemDecodeA64_07e0fc00_04a0b800_1,
    iemDecodeA64_07e0fc00_04a0b400_1,
    iemDecodeA64_07e0fc00_04a0c000_1,
    iemDecodeA64_07e0fc00_04a0c400_1,
    iemDecodeA64_07e0fc00_04a0c800_1,
    iemDecodeA64_07e0fc00_04a0cc00_1,
    iemDecodeA64_07e0fc00_04a0d000_1,
    iemDecodeA64_07e0fc00_04a0d400_1,
    iemDecodeA64_07e0fc00_04a0d800_1,
    iemDecodeA64_07e0fc00_04a0d400_1,
    iemDecodeA64_07e0fc00_04a0e000_1,
    iemDecodeA64_07e0fc00_04a0e400_1,
    iemDecodeA64_07e0fc00_04a0e800_1,
    iemDecodeA64_07e0fc00_04a0ec00_1,
    iemDecodeA64_07e0fc00_04a0f000_1,
    iemDecodeA64_07e0fc00_04a0f400_1,
    iemDecodeA64_07e0fc00_04a0f800_1,
    iemDecodeA64_07e0fc00_04a0fc00_1,
    iemDecodeA64_07e0fc00_04c00000_1,
    iemDecodeA64_07e0fc00_04c00400_1,
    iemDecodeA64_07e0fc00_04c00800_1,
    iemDecodeA64_07e0fc00_04c00c00_1,
    iemDecodeA64_07e0fc00_04c01000_1,
    iemDecodeA64_07e0fc00_04c01400_1,
    iemDecodeA64_07e0fc00_04c01800_1,
    iemDecodeA64_07e0fc00_04c01c00_1,
    iemDecodeA64_07e0fc00_04c02000_1,
    iemDecodeA64_07e0fc00_04c02400_1,
    iemDecodeA64_07e0fc00_04c02800_1,
    iemDecodeA64_07e0fc00_04c02c00_1,
    iemDecodeA64_07e0fc00_04c03000_1,
    iemDecodeA64_07e0fc00_04c03400_1,
    iemDecodeA64_07e0fc00_04c03800_1,
    iemDecodeA64_07e0fc00_04c03c00_1,
    iemDecodeA64_07e0fc00_04c04000_1,
    iemDecodeA64_07e0fc00_04c04400_1,
    iemDecodeA64_07e0fc00_04c04800_1,
    iemDecodeA64_07e0fc00_04c04c00_1,
    iemDecodeA64_07e0fc00_04c05000_1,
    iemDecodeA64_07e0fc00_04c05400_1,
    iemDecodeA64_07e0fc00_04c05800_1,
    iemDecodeA64_07e0fc00_04c05c00_1,
    iemDecodeA64_07e0fc00_04c06000_1,
    iemDecodeA64_07e0fc00_04c06400_1,
    iemDecodeA64_07e0fc00_04c06800_1,
    iemDecodeA64_07e0fc00_04c06c00_1,
    iemDecodeA64_07e0fc00_04c07000_1,
    iemDecodeA64_07e0fc00_04c07400_1,
    iemDecodeA64_07e0fc00_04c07800_1,
    iemDecodeA64_07e0fc00_04c07c00_1,
    iemDecodeA64_07e0fc00_04c08000_1,
    iemDecodeA64_07e0fc00_04c08400_1,
    iemDecodeA64_07e0fc00_04c08800_1,
    iemDecodeA64_07e0fc00_04c08c00_1,
    iemDecodeA64_07e0fc00_04c09000_1,
    iemDecodeA64_07e0fc00_04c09400_1,
    iemDecodeA64_07e0fc00_04c09800_1,
    iemDecodeA64_07e0fc00_04c09c00_1,
    iemDecodeA64_07e0fc00_04c0a000_1,
    iemDecodeA64_07e0fc00_04c0a400_1,
    iemDecodeA64_07e0fc00_04c0a800_1,
    iemDecodeA64_07e0fc00_04c0ac00_1,
    iemDecodeA64_07e0fc00_04c0b000_1,
    iemDecodeA64_07e0fc00_04c0b400_1,
    iemDecodeA64_07e0fc00_04c0b800_1,
    iemDecodeA64_07e0fc00_04c0bc00_1,
    iemDecodeA64_07e0fc00_04c0c000_1,
    iemDecodeA64_07e0fc00_04c0c400_1,
    iemDecodeA64_07e0fc00_04c0c800_1,
    iemDecodeA64_07e0fc00_04c0cc00_1,
    iemDecodeA64_07e0fc00_04c0d000_1,
    iemDecodeA64_07e0fc00_04c0d400_1,
    iemDecodeA64_07e0fc00_04c0d800_1,
    iemDecodeA64_07e0fc00_04c0cc00_1,
    iemDecodeA64_07e0fc00_04c0e000_1,
    iemDecodeA64_07e0fc00_04c0e400_1,
    iemDecodeA64_07e0fc00_04c0e800_1,
    iemDecodeA64_07e0fc00_04c0ec00_1,
    iemDecodeA64_07e0fc00_04c0f000_1,
    iemDecodeA64_07e0fc00_04c0f400_1,
    iemDecodeA64_07e0fc00_04c0f800_1,
    iemDecodeA64_07e0fc00_04c0fc00_1,
    iemDecodeA64_07e0fc00_04e00000_1,
    iemDecodeA64_07e0fc00_04e00400_1,
    iemDecodeA64_07e0fc00_04e00800_1,
    iemDecodeA64_07e0fc00_04e00c00_1,
    iemDecodeA64_07e0fc00_04e01000_1,
    iemDecodeA64_07e0fc00_04e01400_1,
    iemDecodeA64_07e0fc00_04e01800_1,
    iemDecodeA64_07e0fc00_04e01c00_1,
    iemDecodeA64_07e0fc00_04e02000_1,
    iemDecodeA64_07e0fc00_04e02400_1,
    iemDecodeA64_07e0fc00_04e02800_1,
    iemDecodeA64_07e0fc00_04e02c00_1,
    iemDecodeA64_07e0fc00_04e03000_1,
    iemDecodeA64_07e0fc00_04e03400_1,
    iemDecodeA64_07e0fc00_04e03800_1,
    iemDecodeA64_07e0fc00_04e03c00_1,
    iemDecodeA64_07e0fc00_04e04000_1,
    iemDecodeA64_07e0fc00_04e04400_1,
    iemDecodeA64_07e0fc00_04e04800_1,
    iemDecodeA64_07e0fc00_04e04c00_1,
    iemDecodeA64_07e0fc00_04e05000_1,
    iemDecodeA64_07e0fc00_04e05400_1,
    iemDecodeA64_07e0fc00_04e05800_1,
    iemDecodeA64_07e0fc00_04e05400_1,
    iemDecodeA64_07e0fc00_04e06000_1,
    iemDecodeA64_07e0fc00_04e06400_1,
    iemDecodeA64_07e0fc00_04e06800_1,
    iemDecodeA64_07e0fc00_04e06c00_1,
    iemDecodeA64_07e0fc00_04e07000_1,
    iemDecodeA64_07e0fc00_04e07400_1,
    iemDecodeA64_07e0fc00_04e07800_1,
    iemDecodeA64_07e0fc00_04e07c00_1,
    iemDecodeA64_07e0fc00_04e08000_1,
    iemDecodeA64_07e0fc00_04e08400_1,
    iemDecodeA64_07e0fc00_04e08800_1,
    iemDecodeA64_07e0fc00_04e08c00_1,
    iemDecodeA64_07e0fc00_04e09000_1,
    iemDecodeA64_07e0fc00_04e09400_1,
    iemDecodeA64_07e0fc00_04e09800_1,
    iemDecodeA64_07e0fc00_04e09c00_1,
    iemDecodeA64_07e0fc00_04e0a000_1,
    iemDecodeA64_07e0fc00_04e0a400_1,
    iemDecodeA64_07e0fc00_04e0a800_1,
    iemDecodeA64_07e0fc00_04e0ac00_1,
    iemDecodeA64_07e0fc00_04e0b000_1,
    iemDecodeA64_07e0fc00_04e0b400_1,
    iemDecodeA64_07e0fc00_04e0b800_1,
    iemDecodeA64_07e0fc00_04e0b400_1,
    iemDecodeA64_07e0fc00_04e0c000_1,
    iemDecodeA64_07e0fc00_04e0c400_1,
    iemDecodeA64_07e0fc00_04e0c800_1,
    iemDecodeA64_07e0fc00_04e0cc00_1,
    iemDecodeA64_07e0fc00_04e0d000_1,
    iemDecodeA64_07e0fc00_04e0d400_1,
    iemDecodeA64_07e0fc00_04e0d800_1,
    iemDecodeA64_07e0fc00_04e0d400_1,
    iemDecodeA64_07e0fc00_04e0e000_1,
    iemDecodeA64_07e0fc00_04e0e400_1,
    iemDecodeA64_07e0fc00_04e0e800_1,
    iemDecodeA64_07e0fc00_04e0ec00_1,
    iemDecodeA64_07e0fc00_04e0f000_1,
    iemDecodeA64_07e0fc00_04e0f400_1,
    iemDecodeA64_07e0fc00_04e0f800_1,
    iemDecodeA64_07e0fc00_04e0fc00_1,
    iemDecodeA64_07e0fc00_05000000_1,
    iemDecodeA64_07e0fc00_05000400_1,
    iemDecodeA64_07e0fc00_05000800_1,
    iemDecodeA64_07e0fc00_05000c00_1,
    iemDecodeA64_07e0fc00_05001000_1,
    iemDecodeA64_07e0fc00_05001400_1,
    iemDecodeA64_07e0fc00_05001800_1,
    iemDecodeA64_07e0fc00_05001c00_1,
    iemDecodeA64_07e0fc00_05002000_1,
    iemDecodeA64_07e0fc00_05002400_1,
    iemDecodeA64_07e0fc00_05002800_1,
    iemDecodeA64_07e0fc00_05002c00_1,
    iemDecodeA64_07e0fc00_05003000_1,
    iemDecodeA64_07e0fc00_05003400_1,
    iemDecodeA64_07e0fc00_05003800_1,
    iemDecodeA64_07e0fc00_05003c00_1,
    iemDecodeA64_07e0fc00_05004000_1,
    iemDecodeA64_07e0fc00_05004400_1,
    iemDecodeA64_07e0fc00_05004800_1,
    iemDecodeA64_07e0fc00_05004c00_1,
    iemDecodeA64_07e0fc00_05005000_1,
    iemDecodeA64_07e0fc00_05005400_1,
    iemDecodeA64_07e0fc00_05005800_1,
    iemDecodeA64_07e0fc00_05005c00_1,
    iemDecodeA64_07e0fc00_05006000_1,
    iemDecodeA64_07e0fc00_05006400_1,
    iemDecodeA64_07e0fc00_05006800_1,
    iemDecodeA64_07e0fc00_05006c00_1,
    iemDecodeA64_07e0fc00_05007000_1,
    iemDecodeA64_07e0fc00_05007400_1,
    iemDecodeA64_07e0fc00_05007800_1,
    iemDecodeA64_07e0fc00_05007c00_1,
    iemDecodeA64_07e0fc00_05008000_1,
    iemDecodeA64_07e0fc00_05008400_1,
    iemDecodeA64_07e0fc00_05008800_1,
    iemDecodeA64_07e0fc00_05008c00_1,
    iemDecodeA64_07e0fc00_05009000_1,
    iemDecodeA64_07e0fc00_05009400_1,
    iemDecodeA64_07e0fc00_05009800_1,
    iemDecodeA64_07e0fc00_05009c00_1,
    iemDecodeA64_07e0fc00_0500a000_1,
    iemDecodeA64_07e0fc00_0500a400_1,
    iemDecodeA64_07e0fc00_0500a800_1,
    iemDecodeA64_07e0fc00_0500ac00_1,
    iemDecodeA64_07e0fc00_0500b000_1,
    iemDecodeA64_07e0fc00_0500b400_1,
    iemDecodeA64_07e0fc00_0500b800_1,
    iemDecodeA64_07e0fc00_0500bc00_1,
    iemDecodeA64_07e0fc00_0500c000_1,
    iemDecodeA64_07e0fc00_0500c400_1,
    iemDecodeA64_07e0fc00_0500c800_1,
    iemDecodeA64_07e0fc00_0500cc00_1,
    iemDecodeA64_07e0fc00_0500d000_1,
    iemDecodeA64_07e0fc00_0500d400_1,
    iemDecodeA64_07e0fc00_0500d800_1,
    iemDecodeA64_07e0fc00_0500dc00_1,
    iemDecodeA64_07e0fc00_0500e000_1,
    iemDecodeA64_07e0fc00_0500e400_1,
    iemDecodeA64_07e0fc00_0500e800_1,
    iemDecodeA64_07e0fc00_0500ec00_1,
    iemDecodeA64_07e0fc00_0500f000_1,
    iemDecodeA64_07e0fc00_0500f400_1,
    iemDecodeA64_07e0fc00_0500f800_1,
    iemDecodeA64_07e0fc00_0500fc00_1,
    iemDecodeA64_07e0fc00_05200000_1,
    iemDecodeA64_07e0fc00_05200400_1,
    iemDecodeA64_07e0fc00_05200800_1,
    iemDecodeA64_07e0fc00_05200c00_1,
    iemDecodeA64_07e0fc00_05201000_1,
    iemDecodeA64_07e0fc00_05201400_1,
    iemDecodeA64_07e0fc00_05201800_1,
    iemDecodeA64_07e0fc00_05201c00_1,
    iemDecodeA64_07e0fc00_05202000_1,
    iemDecodeA64_07e0fc00_05202400_1,
    iemDecodeA64_07e0fc00_05202800_1,
    iemDecodeA64_07e0fc00_05202c00_1,
    iemDecodeA64_07e0fc00_05203000_1,
    iemDecodeA64_07e0fc00_05203400_1,
    iemDecodeA64_07e0fc00_05203800_1,
    iemDecodeA64_07e0fc00_05203c00_1,
    iemDecodeA64_07e0fc00_05204000_1,
    iemDecodeA64_07e0fc00_05204400_1,
    iemDecodeA64_07e0fc00_05204800_1,
    iemDecodeA64_07e0fc00_05204c00_1,
    iemDecodeA64_07e0fc00_05205000_1,
    iemDecodeA64_07e0fc00_05205400_1,
    iemDecodeA64_07e0fc00_05205800_1,
    iemDecodeA64_07e0fc00_05205c00_1,
    iemDecodeA64_07e0fc00_05206000_1,
    iemDecodeA64_07e0fc00_05206400_1,
    iemDecodeA64_07e0fc00_05206800_1,
    iemDecodeA64_07e0fc00_05206c00_1,
    iemDecodeA64_07e0fc00_05207000_1,
    iemDecodeA64_07e0fc00_05207400_1,
    iemDecodeA64_07e0fc00_05207800_1,
    iemDecodeA64_07e0fc00_05207c00_1,
    iemDecodeA64_07e0fc00_05208000_1,
    iemDecodeA64_07e0fc00_05208400_1,
    iemDecodeA64_07e0fc00_05208800_1,
    iemDecodeA64_07e0fc00_05208c00_1,
    iemDecodeA64_07e0fc00_05209000_1,
    iemDecodeA64_07e0fc00_05209400_1,
    iemDecodeA64_07e0fc00_05209400_1,
    iemDecodeA64_07e0fc00_05209400_1,
    iemDecodeA64_07e0fc00_0520a000_1,
    iemDecodeA64_07e0fc00_0520a400_1,
    iemDecodeA64_07e0fc00_0520a800_1,
    iemDecodeA64_07e0fc00_0520ac00_1,
    iemDecodeA64_07e0fc00_0520b000_1,
    iemDecodeA64_07e0fc00_0520b400_1,
    iemDecodeA64_07e0fc00_0520a800_1,
    iemDecodeA64_07e0fc00_0520bc00_1,
    iemDecodeA64_07e0fc00_0520c000_1,
    iemDecodeA64_07e0fc00_0520c000_1,
    iemDecodeA64_07e0fc00_0520c000_1,
    iemDecodeA64_07e0fc00_0520c000_1,
    iemDecodeA64_07e0fc00_0520c000_1,
    iemDecodeA64_07e0fc00_0520c000_1,
    iemDecodeA64_07e0fc00_0520c000_1,
    iemDecodeA64_07e0fc00_0520c000_1,
    iemDecodeA64_07e0fc00_0520e000_1,
    iemDecodeA64_07e0fc00_0520e400_1,
    iemDecodeA64_07e0fc00_0520e800_1,
    iemDecodeA64_07e0fc00_0520ec00_1,
    iemDecodeA64_07e0fc00_0520f000_1,
    iemDecodeA64_07e0fc00_0520f400_1,
    iemDecodeA64_07e0fc00_0520f800_1,
    iemDecodeA64_07e0fc00_0520fc00_1,
    iemDecodeA64_07e0fc00_05400000_1,
    iemDecodeA64_07e0fc00_05400400_1,
    iemDecodeA64_07e0fc00_05400800_1,
    iemDecodeA64_07e0fc00_05400c00_1,
    iemDecodeA64_07e0fc00_05401000_1,
    iemDecodeA64_07e0fc00_05401400_1,
    iemDecodeA64_07e0fc00_05401800_1,
    iemDecodeA64_07e0fc00_05401c00_1,
    iemDecodeA64_07e0fc00_05402000_1,
    iemDecodeA64_07e0fc00_05402400_1,
    iemDecodeA64_07e0fc00_05402800_1,
    iemDecodeA64_07e0fc00_05402000_1,
    iemDecodeA64_07e0fc00_05403000_1,
    iemDecodeA64_07e0fc00_05403400_1,
    iemDecodeA64_07e0fc00_05403800_1,
    iemDecodeA64_07e0fc00_05403c00_1,
    iemDecodeA64_07e0fc00_05404000_1,
    iemDecodeA64_07e0fc00_05404400_1,
    iemDecodeA64_07e0fc00_05404800_1,
    iemDecodeA64_07e0fc00_05404c00_1,
    iemDecodeA64_07e0fc00_05405000_1,
    iemDecodeA64_07e0fc00_05405400_1,
    iemDecodeA64_07e0fc00_05405800_1,
    iemDecodeA64_07e0fc00_05405c00_1,
    iemDecodeA64_07e0fc00_05406000_1,
    iemDecodeA64_07e0fc00_05406400_1,
    iemDecodeA64_07e0fc00_05406800_1,
    iemDecodeA64_07e0fc00_05406c00_1,
    iemDecodeA64_07e0fc00_05407000_1,
    iemDecodeA64_07e0fc00_05407400_1,
    iemDecodeA64_07e0fc00_05407800_1,
    iemDecodeA64_07e0fc00_05407c00_1,
    iemDecodeA64_07e0fc00_05408000_1,
    iemDecodeA64_07e0fc00_05408400_1,
    iemDecodeA64_07e0fc00_05408800_1,
    iemDecodeA64_07e0fc00_05408c00_1,
    iemDecodeA64_07e0fc00_05409000_1,
    iemDecodeA64_07e0fc00_05409400_1,
    iemDecodeA64_07e0fc00_05409800_1,
    iemDecodeA64_07e0fc00_05409c00_1,
    iemDecodeA64_07e0fc00_0540a000_1,
    iemDecodeA64_07e0fc00_0540a400_1,
    iemDecodeA64_07e0fc00_0540a800_1,
    iemDecodeA64_07e0fc00_0540ac00_1,
    iemDecodeA64_07e0fc00_0540b000_1,
    iemDecodeA64_07e0fc00_0540b400_1,
    iemDecodeA64_07e0fc00_0540b800_1,
    iemDecodeA64_07e0fc00_0540bc00_1,
    iemDecodeA64_07e0fc00_0540c000_1,
    iemDecodeA64_07e0fc00_0540c400_1,
    iemDecodeA64_07e0fc00_0540c800_1,
    iemDecodeA64_07e0fc00_0540cc00_1,
    iemDecodeA64_07e0fc00_0540d000_1,
    iemDecodeA64_07e0fc00_0540d400_1,
    iemDecodeA64_07e0fc00_0540d800_1,
    iemDecodeA64_07e0fc00_0540dc00_1,
    iemDecodeA64_07e0fc00_0540e000_1,
    iemDecodeA64_07e0fc00_0540e400_1,
    iemDecodeA64_07e0fc00_0540e800_1,
    iemDecodeA64_07e0fc00_0540ec00_1,
    iemDecodeA64_07e0fc00_0540f000_1,
    iemDecodeA64_07e0fc00_0540f400_1,
    iemDecodeA64_07e0fc00_0540f800_1,
    iemDecodeA64_07e0fc00_0540fc00_1,
    iemDecodeA64_07e0fc00_05600000_1,
    iemDecodeA64_07e0fc00_05600400_1,
    iemDecodeA64_07e0fc00_05600800_1,
    iemDecodeA64_07e0fc00_05600c00_1,
    iemDecodeA64_07e0fc00_05601000_1,
    iemDecodeA64_07e0fc00_05601400_1,
    iemDecodeA64_07e0fc00_05601800_1,
    iemDecodeA64_07e0fc00_05601c00_1,
    iemDecodeA64_07e0fc00_05602000_1,
    iemDecodeA64_07e0fc00_05602400_1,
    iemDecodeA64_07e0fc00_05602800_1,
    iemDecodeA64_07e0fc00_05602c00_1,
    iemDecodeA64_07e0fc00_05603000_1,
    iemDecodeA64_07e0fc00_05603400_1,
    iemDecodeA64_07e0fc00_05603800_1,
    iemDecodeA64_07e0fc00_05603c00_1,
    iemDecodeA64_07e0fc00_05604000_1,
    iemDecodeA64_07e0fc00_05604400_1,
    iemDecodeA64_07e0fc00_05604800_1,
    iemDecodeA64_07e0fc00_05604c00_1,
    iemDecodeA64_07e0fc00_05605000_1,
    iemDecodeA64_07e0fc00_05605400_1,
    iemDecodeA64_07e0fc00_05605800_1,
    iemDecodeA64_07e0fc00_05605c00_1,
    iemDecodeA64_07e0fc00_05606000_1,
    iemDecodeA64_07e0fc00_05606400_1,
    iemDecodeA64_07e0fc00_05606800_1,
    iemDecodeA64_07e0fc00_05606c00_1,
    iemDecodeA64_07e0fc00_05607000_1,
    iemDecodeA64_07e0fc00_05607400_1,
    iemDecodeA64_07e0fc00_05607800_1,
    iemDecodeA64_07e0fc00_05607c00_1,
    iemDecodeA64_07e0fc00_05608000_1,
    iemDecodeA64_07e0fc00_05608400_1,
    iemDecodeA64_07e0fc00_05608800_1,
    iemDecodeA64_07e0fc00_05608c00_1,
    iemDecodeA64_07e0fc00_05609000_1,
    iemDecodeA64_07e0fc00_05609400_1,
    iemDecodeA64_07e0fc00_05609400_1,
    iemDecodeA64_07e0fc00_05609400_1,
    iemDecodeA64_07e0fc00_0560a000_1,
    iemDecodeA64_07e0fc00_0560a400_1,
    iemDecodeA64_07e0fc00_0560a800_1,
    iemDecodeA64_07e0fc00_0560ac00_1,
    iemDecodeA64_07e0fc00_0560b000_1,
    iemDecodeA64_07e0fc00_0560b400_1,
    iemDecodeA64_07e0fc00_0560a800_1,
    iemDecodeA64_07e0fc00_0560bc00_1,
    iemDecodeA64_07e0fc00_0560c000_1,
    iemDecodeA64_07e0fc00_0560c000_1,
    iemDecodeA64_07e0fc00_0560c000_1,
    iemDecodeA64_07e0fc00_0560c000_1,
    iemDecodeA64_07e0fc00_0560d000_1,
    iemDecodeA64_07e0fc00_0560d000_1,
    iemDecodeA64_07e0fc00_0560d000_1,
    iemDecodeA64_07e0fc00_0560d000_1,
    iemDecodeA64_07e0fc00_0560e000_1,
    iemDecodeA64_07e0fc00_0560e000_1,
    iemDecodeA64_07e0fc00_0560e000_1,
    iemDecodeA64_07e0fc00_0560e000_1,
    iemDecodeA64_07e0fc00_0560f000_1,
    iemDecodeA64_07e0fc00_0560f000_1,
    iemDecodeA64_07e0fc00_0560f000_1,
    iemDecodeA64_07e0fc00_0560f000_1,
    iemDecodeA64_07e0fc00_05800000_1,
    iemDecodeA64_07e0fc00_05800400_1,
    iemDecodeA64_07e0fc00_05800800_1,
    iemDecodeA64_07e0fc00_05800c00_1,
    iemDecodeA64_07e0fc00_05801000_1,
    iemDecodeA64_07e0fc00_05801400_1,
    iemDecodeA64_07e0fc00_05801800_1,
    iemDecodeA64_07e0fc00_05801c00_1,
    iemDecodeA64_07e0fc00_05802000_1,
    iemDecodeA64_07e0fc00_05802400_1,
    iemDecodeA64_07e0fc00_05802800_1,
    iemDecodeA64_07e0fc00_05802000_1,
    iemDecodeA64_07e0fc00_05803000_1,
    iemDecodeA64_07e0fc00_05803400_1,
    iemDecodeA64_07e0fc00_05803800_1,
    iemDecodeA64_07e0fc00_05803c00_1,
    iemDecodeA64_07e0fc00_05804000_1,
    iemDecodeA64_07e0fc00_05804400_1,
    iemDecodeA64_07e0fc00_05804800_1,
    iemDecodeA64_07e0fc00_05804c00_1,
    iemDecodeA64_07e0fc00_05805000_1,
    iemDecodeA64_07e0fc00_05805400_1,
    iemDecodeA64_07e0fc00_05805800_1,
    iemDecodeA64_07e0fc00_05805c00_1,
    iemDecodeA64_07e0fc00_05806000_1,
    iemDecodeA64_07e0fc00_05806400_1,
    iemDecodeA64_07e0fc00_05806800_1,
    iemDecodeA64_07e0fc00_05806c00_1,
    iemDecodeA64_07e0fc00_05807000_1,
    iemDecodeA64_07e0fc00_05807400_1,
    iemDecodeA64_07e0fc00_05807800_1,
    iemDecodeA64_07e0fc00_05807c00_1,
    iemDecodeA64_07e0fc00_05808000_1,
    iemDecodeA64_07e0fc00_05808400_1,
    iemDecodeA64_07e0fc00_05808800_1,
    iemDecodeA64_07e0fc00_05808c00_1,
    iemDecodeA64_07e0fc00_05809000_1,
    iemDecodeA64_07e0fc00_05809400_1,
    iemDecodeA64_07e0fc00_05809800_1,
    iemDecodeA64_07e0fc00_05809c00_1,
    iemDecodeA64_07e0fc00_0580a000_1,
    iemDecodeA64_07e0fc00_0580a400_1,
    iemDecodeA64_07e0fc00_0580a800_1,
    iemDecodeA64_07e0fc00_0580ac00_1,
    iemDecodeA64_07e0fc00_0580b000_1,
    iemDecodeA64_07e0fc00_0580b400_1,
    iemDecodeA64_07e0fc00_0580b800_1,
    iemDecodeA64_07e0fc00_0580ac00_1,
    iemDecodeA64_07e0fc00_0580c000_1,
    iemDecodeA64_07e0fc00_0580c400_1,
    iemDecodeA64_07e0fc00_0580c800_1,
    iemDecodeA64_07e0fc00_0580cc00_1,
    iemDecodeA64_07e0fc00_0580d000_1,
    iemDecodeA64_07e0fc00_0580d400_1,
    iemDecodeA64_07e0fc00_0580d800_1,
    iemDecodeA64_07e0fc00_0580dc00_1,
    iemDecodeA64_07e0fc00_0580e000_1,
    iemDecodeA64_07e0fc00_0580e400_1,
    iemDecodeA64_07e0fc00_0580e800_1,
    iemDecodeA64_07e0fc00_0580ec00_1,
    iemDecodeA64_07e0fc00_0580f000_1,
    iemDecodeA64_07e0fc00_0580f400_1,
    iemDecodeA64_07e0fc00_0580f800_1,
    iemDecodeA64_07e0fc00_0580fc00_1,
    iemDecodeA64_07e0fc00_05a00000_1,
    iemDecodeA64_07e0fc00_05a00400_1,
    iemDecodeA64_07e0fc00_05a00800_1,
    iemDecodeA64_07e0fc00_05a00c00_1,
    iemDecodeA64_07e0fc00_05a01000_1,
    iemDecodeA64_07e0fc00_05a01400_1,
    iemDecodeA64_07e0fc00_05a01800_1,
    iemDecodeA64_07e0fc00_05a01c00_1,
    iemDecodeA64_07e0fc00_05a02000_1,
    iemDecodeA64_07e0fc00_05a02400_1,
    iemDecodeA64_07e0fc00_05a02800_1,
    iemDecodeA64_07e0fc00_05a02c00_1,
    iemDecodeA64_07e0fc00_05a03000_1,
    iemDecodeA64_07e0fc00_05a03400_1,
    iemDecodeA64_07e0fc00_05a03800_1,
    iemDecodeA64_07e0fc00_05a02400_1,
    iemDecodeA64_07e0fc00_05a04000_1,
    iemDecodeA64_07e0fc00_05a04400_1,
    iemDecodeA64_07e0fc00_05a04800_1,
    iemDecodeA64_07e0fc00_05a04c00_1,
    iemDecodeA64_07e0fc00_05a05000_1,
    iemDecodeA64_07e0fc00_05a05400_1,
    iemDecodeA64_07e0fc00_05a05800_1,
    iemDecodeA64_07e0fc00_05a05c00_1,
    iemDecodeA64_07e0fc00_05a06000_1,
    iemDecodeA64_07e0fc00_05a06400_1,
    iemDecodeA64_07e0fc00_05a06800_1,
    iemDecodeA64_07e0fc00_05a06c00_1,
    iemDecodeA64_07e0fc00_05a07000_1,
    iemDecodeA64_07e0fc00_05a07400_1,
    iemDecodeA64_07e0fc00_05a07800_1,
    iemDecodeA64_07e0fc00_05a07c00_1,
    iemDecodeA64_07e0fc00_05a08000_1,
    iemDecodeA64_07e0fc00_05a08400_1,
    iemDecodeA64_07e0fc00_05a08800_1,
    iemDecodeA64_07e0fc00_05a08c00_1,
    iemDecodeA64_07e0fc00_05a09000_1,
    iemDecodeA64_07e0fc00_05a09400_1,
    iemDecodeA64_07e0fc00_05a09400_1,
    iemDecodeA64_07e0fc00_05a09400_1,
    iemDecodeA64_07e0fc00_05a0a000_1,
    iemDecodeA64_07e0fc00_05a0a400_1,
    iemDecodeA64_07e0fc00_05a0a800_1,
    iemDecodeA64_07e0fc00_05a0ac00_1,
    iemDecodeA64_07e0fc00_05a0b000_1,
    iemDecodeA64_07e0fc00_05a0b400_1,
    iemDecodeA64_07e0fc00_05a0a800_1,
    iemDecodeA64_07e0fc00_05a0bc00_1,
    iemDecodeA64_07e0fc00_05a0c000_1,
    iemDecodeA64_07e0fc00_05a0c000_1,
    iemDecodeA64_07e0fc00_05a0c000_1,
    iemDecodeA64_07e0fc00_05a0c000_1,
    iemDecodeA64_07e0fc00_05a0c000_1,
    iemDecodeA64_07e0fc00_05a0c000_1,
    iemDecodeA64_07e0fc00_05a0c000_1,
    iemDecodeA64_07e0fc00_05a0c000_1,
    iemDecodeA64_07e0fc00_05a0e000_1,
    iemDecodeA64_07e0fc00_05a0e000_1,
    iemDecodeA64_07e0fc00_05a0e000_1,
    iemDecodeA64_07e0fc00_05a0e000_1,
    iemDecodeA64_07e0fc00_05a0e000_1,
    iemDecodeA64_07e0fc00_05a0e000_1,
    iemDecodeA64_07e0fc00_05a0e000_1,
    iemDecodeA64_07e0fc00_05a0e000_1,
    iemDecodeA64_07e0fc00_05c00000_1,
    iemDecodeA64_07e0fc00_05c00400_1,
    iemDecodeA64_07e0fc00_05c00800_1,
    iemDecodeA64_07e0fc00_05c00c00_1,
    iemDecodeA64_07e0fc00_05c01000_1,
    iemDecodeA64_07e0fc00_05c01400_1,
    iemDecodeA64_07e0fc00_05c01800_1,
    iemDecodeA64_07e0fc00_05c01c00_1,
    iemDecodeA64_07e0fc00_05c02000_1,
    iemDecodeA64_07e0fc00_05c02400_1,
    iemDecodeA64_07e0fc00_05c02800_1,
    iemDecodeA64_07e0fc00_05c02000_1,
    iemDecodeA64_07e0fc00_05c03000_1,
    iemDecodeA64_07e0fc00_05c03400_1,
    iemDecodeA64_07e0fc00_05c03800_1,
    iemDecodeA64_07e0fc00_05c03c00_1,
    iemDecodeA64_07e0fc00_05c04000_1,
    iemDecodeA64_07e0fc00_05c04400_1,
    iemDecodeA64_07e0fc00_05c04800_1,
    iemDecodeA64_07e0fc00_05c04c00_1,
    iemDecodeA64_07e0fc00_05c05000_1,
    iemDecodeA64_07e0fc00_05c05400_1,
    iemDecodeA64_07e0fc00_05c05800_1,
    iemDecodeA64_07e0fc00_05c05c00_1,
    iemDecodeA64_07e0fc00_05c06000_1,
    iemDecodeA64_07e0fc00_05c06400_1,
    iemDecodeA64_07e0fc00_05c06800_1,
    iemDecodeA64_07e0fc00_05c06c00_1,
    iemDecodeA64_07e0fc00_05c07000_1,
    iemDecodeA64_07e0fc00_05c07400_1,
    iemDecodeA64_07e0fc00_05c07800_1,
    iemDecodeA64_07e0fc00_05c07c00_1,
    iemDecodeA64_07e0fc00_05c08000_1,
    iemDecodeA64_07e0fc00_05c08400_1,
    iemDecodeA64_07e0fc00_05c08800_1,
    iemDecodeA64_07e0fc00_05c08c00_1,
    iemDecodeA64_07e0fc00_05c09000_1,
    iemDecodeA64_07e0fc00_05c09400_1,
    iemDecodeA64_07e0fc00_05c09800_1,
    iemDecodeA64_07e0fc00_05c09c00_1,
    iemDecodeA64_07e0fc00_05c0a000_1,
    iemDecodeA64_07e0fc00_05c0a400_1,
    iemDecodeA64_07e0fc00_05c0a800_1,
    iemDecodeA64_07e0fc00_05c0ac00_1,
    iemDecodeA64_07e0fc00_05c0b000_1,
    iemDecodeA64_07e0fc00_05c0b400_1,
    iemDecodeA64_07e0fc00_05c0b800_1,
    iemDecodeA64_07e0fc00_05c0ac00_1,
    iemDecodeA64_07e0fc00_05c0c000_1,
    iemDecodeA64_07e0fc00_05c0c400_1,
    iemDecodeA64_07e0fc00_05c0c800_1,
    iemDecodeA64_07e0fc00_05c0cc00_1,
    iemDecodeA64_07e0fc00_05c0d000_1,
    iemDecodeA64_07e0fc00_05c0d400_1,
    iemDecodeA64_07e0fc00_05c0d800_1,
    iemDecodeA64_07e0fc00_05c0dc00_1,
    iemDecodeA64_07e0fc00_05c0e000_1,
    iemDecodeA64_07e0fc00_05c0e400_1,
    iemDecodeA64_07e0fc00_05c0e800_1,
    iemDecodeA64_07e0fc00_05c0ec00_1,
    iemDecodeA64_07e0fc00_05c0f000_1,
    iemDecodeA64_07e0fc00_05c0f400_1,
    iemDecodeA64_07e0fc00_05c0f800_1,
    iemDecodeA64_07e0fc00_05c0fc00_1,
    iemDecodeA64_07e0fc00_05e00000_1,
    iemDecodeA64_07e0fc00_05e00400_1,
    iemDecodeA64_07e0fc00_05e00800_1,
    iemDecodeA64_07e0fc00_05e00c00_1,
    iemDecodeA64_07e0fc00_05e00000_1,
    iemDecodeA64_07e0fc00_05e00400_1,
    iemDecodeA64_07e0fc00_05e00800_1,
    iemDecodeA64_07e0fc00_05e00c00_1,
    iemDecodeA64_07e0fc00_05e02000_1,
    iemDecodeA64_07e0fc00_05e02400_1,
    iemDecodeA64_07e0fc00_05e02800_1,
    iemDecodeA64_07e0fc00_05e02c00_1,
    iemDecodeA64_07e0fc00_05e03000_1,
    iemDecodeA64_07e0fc00_05e03400_1,
    iemDecodeA64_07e0fc00_05e03800_1,
    iemDecodeA64_07e0fc00_05e02400_1,
    iemDecodeA64_07e0fc00_05e04000_1,
    iemDecodeA64_07e0fc00_05e04400_1,
    iemDecodeA64_07e0fc00_05e04800_1,
    iemDecodeA64_07e0fc00_05e04c00_1,
    iemDecodeA64_07e0fc00_05e05000_1,
    iemDecodeA64_07e0fc00_05e05400_1,
    iemDecodeA64_07e0fc00_05e05800_1,
    iemDecodeA64_07e0fc00_05e05c00_1,
    iemDecodeA64_07e0fc00_05e06000_1,
    iemDecodeA64_07e0fc00_05e06400_1,
    iemDecodeA64_07e0fc00_05e06800_1,
    iemDecodeA64_07e0fc00_05e06c00_1,
    iemDecodeA64_07e0fc00_05e07000_1,
    iemDecodeA64_07e0fc00_05e07400_1,
    iemDecodeA64_07e0fc00_05e07800_1,
    iemDecodeA64_07e0fc00_05e07c00_1,
    iemDecodeA64_07e0fc00_05e08000_1,
    iemDecodeA64_07e0fc00_05e08400_1,
    iemDecodeA64_07e0fc00_05e08800_1,
    iemDecodeA64_07e0fc00_05e08c00_1,
    iemDecodeA64_07e0fc00_05e09000_1,
    iemDecodeA64_07e0fc00_05e09400_1,
    iemDecodeA64_07e0fc00_05e09400_1,
    iemDecodeA64_07e0fc00_05e09400_1,
    iemDecodeA64_07e0fc00_05e0a000_1,
    iemDecodeA64_07e0fc00_05e0a400_1,
    iemDecodeA64_07e0fc00_05e0a800_1,
    iemDecodeA64_07e0fc00_05e0ac00_1,
    iemDecodeA64_07e0fc00_05e0b000_1,
    iemDecodeA64_07e0fc00_05e0b400_1,
    iemDecodeA64_07e0fc00_05e0a800_1,
    iemDecodeA64_07e0fc00_05e0bc00_1,
    iemDecodeA64_07e0fc00_05e0c000_1,
    iemDecodeA64_07e0fc00_05e0c000_1,
    iemDecodeA64_07e0fc00_05e0c000_1,
    iemDecodeA64_07e0fc00_05e0c000_1,
    iemDecodeA64_07e0fc00_05e0d000_1,
    iemDecodeA64_07e0fc00_05e0d000_1,
    iemDecodeA64_07e0fc00_05e0d000_1,
    iemDecodeA64_07e0fc00_05e0d000_1,
    iemDecodeA64_07e0fc00_05e0e000_1,
    iemDecodeA64_07e0fc00_05e0e000_1,
    iemDecodeA64_07e0fc00_05e0e000_1,
    iemDecodeA64_07e0fc00_05e0e000_1,
    iemDecodeA64_07e0fc00_05e0f000_1,
    iemDecodeA64_07e0fc00_05e0f000_1,
    iemDecodeA64_07e0fc00_05e0f000_1,
    iemDecodeA64_07e0fc00_05e0f000_1,
    iemDecodeA64_07e0fc00_06000000_1,
    iemDecodeA64_07e0fc00_06000400_1,
    iemDecodeA64_07e0fc00_06000800_1,
    iemDecodeA64_07e0fc00_06000c00_1,
    iemDecodeA64_07e0fc00_06001000_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06001800_1,
    iemDecodeA64_07e0fc00_06001c00_1,
    iemDecodeA64_07e0fc00_06002000_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06002800_1,
    iemDecodeA64_07e0fc00_06002c00_1,
    iemDecodeA64_07e0fc00_06003000_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06003800_1,
    iemDecodeA64_07e0fc00_06003c00_1,
    iemDecodeA64_07e0fc00_06004000_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06004800_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06005000_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06005800_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06006000_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06006800_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06007000_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06007800_1,
    iemDecodeA64_07e0fc00_06001400_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008400_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008c00_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06009400_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_0600c400_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_0600cc00_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_0600cc00_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_0600cc00_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_0600e400_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_0600ec00_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_0600f400_1,
    iemDecodeA64_07e0fc00_06008000_1,
    iemDecodeA64_07e0fc00_0600fc00_1,
    iemDecodeA64_07e0fc00_06200000_1,
    iemDecodeA64_07e0fc00_06200400_1,
    iemDecodeA64_07e0fc00_06200800_1,
    iemDecodeA64_07e0fc00_06200c00_1,
    iemDecodeA64_07e0fc00_06201000_1,
    iemDecodeA64_07e0fc00_06201400_1,
    iemDecodeA64_07e0fc00_06201800_1,
    iemDecodeA64_07e0fc00_06201c00_1,
    iemDecodeA64_07e0fc00_06202000_1,
    iemDecodeA64_07e0fc00_06202400_1,
    iemDecodeA64_07e0fc00_06202800_1,
    iemDecodeA64_07e0fc00_06202c00_1,
    iemDecodeA64_07e0fc00_06203000_1,
    iemDecodeA64_07e0fc00_06203400_1,
    iemDecodeA64_07e0fc00_06203800_1,
    iemDecodeA64_07e0fc00_06203c00_1,
    iemDecodeA64_07e0fc00_06204000_1,
    iemDecodeA64_07e0fc00_06204400_1,
    iemDecodeA64_07e0fc00_06204800_1,
    iemDecodeA64_07e0fc00_06204c00_1,
    iemDecodeA64_07e0fc00_06205000_1,
    iemDecodeA64_07e0fc00_06205400_1,
    iemDecodeA64_07e0fc00_06205800_1,
    iemDecodeA64_07e0fc00_06205c00_1,
    iemDecodeA64_07e0fc00_06206000_1,
    iemDecodeA64_07e0fc00_06206400_1,
    iemDecodeA64_07e0fc00_06206800_1,
    iemDecodeA64_07e0fc00_06206c00_1,
    iemDecodeA64_07e0fc00_06207000_1,
    iemDecodeA64_07e0fc00_06207400_1,
    iemDecodeA64_07e0fc00_06207800_1,
    iemDecodeA64_07e0fc00_06207c00_1,
    iemDecodeA64_07e0fc00_06208000_1,
    iemDecodeA64_07e0fc00_06208400_1,
    iemDecodeA64_07e0fc00_06208800_1,
    iemDecodeA64_07e0fc00_06208c00_1,
    iemDecodeA64_07e0fc00_06209000_1,
    iemDecodeA64_07e0fc00_06209400_1,
    iemDecodeA64_07e0fc00_06209800_1,
    iemDecodeA64_07e0fc00_06209c00_1,
    iemDecodeA64_07e0fc00_0620a000_1,
    iemDecodeA64_07e0fc00_0620a400_1,
    iemDecodeA64_07e0fc00_0620a800_1,
    iemDecodeA64_07e0fc00_0620ac00_1,
    iemDecodeA64_07e0fc00_0620b000_1,
    iemDecodeA64_07e0fc00_0620b400_1,
    iemDecodeA64_07e0fc00_0620b800_1,
    iemDecodeA64_07e0fc00_0620bc00_1,
    iemDecodeA64_07e0fc00_0620c000_1,
    iemDecodeA64_07e0fc00_0620c400_1,
    iemDecodeA64_07e0fc00_0620c800_1,
    iemDecodeA64_07e0fc00_0620cc00_1,
    iemDecodeA64_07e0fc00_0620d000_1,
    iemDecodeA64_07e0fc00_0620d400_1,
    iemDecodeA64_07e0fc00_0620d800_1,
    iemDecodeA64_07e0fc00_0620dc00_1,
    iemDecodeA64_07e0fc00_0620e000_1,
    iemDecodeA64_07e0fc00_0620e400_1,
    iemDecodeA64_07e0fc00_0620e800_1,
    iemDecodeA64_07e0fc00_0620ec00_1,
    iemDecodeA64_07e0fc00_0620f000_1,
    iemDecodeA64_07e0fc00_0620f400_1,
    iemDecodeA64_07e0fc00_0620f800_1,
    iemDecodeA64_07e0fc00_0620fc00_1,
    iemDecodeA64_07e0fc00_06400000_1,
    iemDecodeA64_07e0fc00_06400400_1,
    iemDecodeA64_07e0fc00_06400800_1,
    iemDecodeA64_07e0fc00_06400c00_1,
    iemDecodeA64_07e0fc00_06401000_1,
    iemDecodeA64_07e0fc00_06401400_1,
    iemDecodeA64_07e0fc00_06401800_1,
    iemDecodeA64_07e0fc00_06401c00_1,
    iemDecodeA64_07e0fc00_06402000_1,
    iemDecodeA64_07e0fc00_06402400_1,
    iemDecodeA64_07e0fc00_06402800_1,
    iemDecodeA64_07e0fc00_06402c00_1,
    iemDecodeA64_07e0fc00_06401000_1,
    iemDecodeA64_07e0fc00_06403400_1,
    iemDecodeA64_07e0fc00_06403800_1,
    iemDecodeA64_07e0fc00_06403c00_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06401000_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06405800_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06402000_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06406800_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06401000_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06407800_1,
    iemDecodeA64_07e0fc00_06404000_1,
    iemDecodeA64_07e0fc00_06408000_1,
    iemDecodeA64_07e0fc00_06408400_1,
    iemDecodeA64_07e0fc00_06408800_1,
    iemDecodeA64_07e0fc00_06408c00_1,
    iemDecodeA64_07e0fc00_06408000_1,
    iemDecodeA64_07e0fc00_06409400_1,
    iemDecodeA64_07e0fc00_06408800_1,
    iemDecodeA64_07e0fc00_06409c00_1,
    iemDecodeA64_07e0fc00_06408000_1,
    iemDecodeA64_07e0fc00_0640a400_1,
    iemDecodeA64_07e0fc00_06408800_1,
    iemDecodeA64_07e0fc00_06409c00_1,
    iemDecodeA64_07e0fc00_06408000_1,
    iemDecodeA64_07e0fc00_0640a400_1,
    iemDecodeA64_07e0fc00_06408800_1,
    iemDecodeA64_07e0fc00_06409c00_1,
    iemDecodeA64_07e0fc00_0640c000_1,
    iemDecodeA64_07e0fc00_0640c400_1,
    iemDecodeA64_07e0fc00_0640c000_1,
    iemDecodeA64_07e0fc00_0640cc00_1,
    iemDecodeA64_07e0fc00_0640c000_1,
    iemDecodeA64_07e0fc00_0640cc00_1,
    iemDecodeA64_07e0fc00_0640c000_1,
    iemDecodeA64_07e0fc00_0640cc00_1,
    iemDecodeA64_07e0fc00_0640c000_1,
    iemDecodeA64_07e0fc00_0640e400_1,
    iemDecodeA64_07e0fc00_0640c000_1,
    iemDecodeA64_07e0fc00_0640ec00_1,
    iemDecodeA64_07e0fc00_0640c000_1,
    iemDecodeA64_07e0fc00_0640f400_1,
    iemDecodeA64_07e0fc00_0640c000_1,
    iemDecodeA64_07e0fc00_0640fc00_1,
    iemDecodeA64_07e0fc00_06600000_1,
    iemDecodeA64_07e0fc00_06600400_1,
    iemDecodeA64_07e0fc00_06600800_1,
    iemDecodeA64_07e0fc00_06600c00_1,
    iemDecodeA64_07e0fc00_06601000_1,
    iemDecodeA64_07e0fc00_06601400_1,
    iemDecodeA64_07e0fc00_06601800_1,
    iemDecodeA64_07e0fc00_06601c00_1,
    iemDecodeA64_07e0fc00_06602000_1,
    iemDecodeA64_07e0fc00_06602400_1,
    iemDecodeA64_07e0fc00_06602800_1,
    iemDecodeA64_07e0fc00_06602c00_1,
    iemDecodeA64_07e0fc00_06603000_1,
    iemDecodeA64_07e0fc00_06603400_1,
    iemDecodeA64_07e0fc00_06603800_1,
    iemDecodeA64_07e0fc00_06603c00_1,
    iemDecodeA64_07e0fc00_06604000_1,
    iemDecodeA64_07e0fc00_06604400_1,
    iemDecodeA64_07e0fc00_06604800_1,
    iemDecodeA64_07e0fc00_06604c00_1,
    iemDecodeA64_07e0fc00_06605000_1,
    iemDecodeA64_07e0fc00_06605400_1,
    iemDecodeA64_07e0fc00_06605800_1,
    iemDecodeA64_07e0fc00_06605c00_1,
    iemDecodeA64_07e0fc00_06606000_1,
    iemDecodeA64_07e0fc00_06606400_1,
    iemDecodeA64_07e0fc00_06606800_1,
    iemDecodeA64_07e0fc00_06606c00_1,
    iemDecodeA64_07e0fc00_06607000_1,
    iemDecodeA64_07e0fc00_06607400_1,
    iemDecodeA64_07e0fc00_06607800_1,
    iemDecodeA64_07e0fc00_06607c00_1,
    iemDecodeA64_07e0fc00_06608000_1,
    iemDecodeA64_07e0fc00_06608400_1,
    iemDecodeA64_07e0fc00_06608800_1,
    iemDecodeA64_07e0fc00_06608c00_1,
    iemDecodeA64_07e0fc00_06609000_1,
    iemDecodeA64_07e0fc00_06609400_1,
    iemDecodeA64_07e0fc00_06609800_1,
    iemDecodeA64_07e0fc00_06609c00_1,
    iemDecodeA64_07e0fc00_0620a000_1,
    iemDecodeA64_07e0fc00_0660a400_1,
    iemDecodeA64_07e0fc00_0660a800_1,
    iemDecodeA64_07e0fc00_0660ac00_1,
    iemDecodeA64_07e0fc00_0660b000_1,
    iemDecodeA64_07e0fc00_0660b400_1,
    iemDecodeA64_07e0fc00_0660b800_1,
    iemDecodeA64_07e0fc00_0660bc00_1,
    iemDecodeA64_07e0fc00_0660c000_1,
    iemDecodeA64_07e0fc00_0660c400_1,
    iemDecodeA64_07e0fc00_0660c800_1,
    iemDecodeA64_07e0fc00_0660cc00_1,
    iemDecodeA64_07e0fc00_0660d000_1,
    iemDecodeA64_07e0fc00_0660d400_1,
    iemDecodeA64_07e0fc00_0660d800_1,
    iemDecodeA64_07e0fc00_0660dc00_1,
    iemDecodeA64_07e0fc00_0620e000_1,
    iemDecodeA64_07e0fc00_0660e400_1,
    iemDecodeA64_07e0fc00_0620e800_1,
    iemDecodeA64_07e0fc00_0660ec00_1,
    iemDecodeA64_07e0fc00_0660f000_1,
    iemDecodeA64_07e0fc00_0660f400_1,
    iemDecodeA64_07e0fc00_0660f800_1,
    iemDecodeA64_07e0fc00_0660fc00_1,
    iemDecodeA64_07e0fc00_06800000_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800800_1,
    iemDecodeA64_07e0fc00_06800c00_1,
    iemDecodeA64_07e0fc00_06801000_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06801800_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06802800_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06801000_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06803800_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06801000_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06805800_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06806800_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06801000_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06807800_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06808400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06808c00_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06809400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06809c00_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680a400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680ac00_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680c400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680c400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680c400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680c400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680e400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680ec00_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_0680e400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06800400_1,
    iemDecodeA64_07e0fc00_06a00000_1,
    iemDecodeA64_07e0fc00_06a00400_1,
    iemDecodeA64_07e0fc00_06a00800_1,
    iemDecodeA64_07e0fc00_06a00c00_1,
    iemDecodeA64_07e0fc00_06a01000_1,
    iemDecodeA64_07e0fc00_06a01400_1,
    iemDecodeA64_07e0fc00_06a01800_1,
    iemDecodeA64_07e0fc00_06a01c00_1,
    iemDecodeA64_07e0fc00_06a02000_1,
    iemDecodeA64_07e0fc00_06a02400_1,
    iemDecodeA64_07e0fc00_06a02800_1,
    iemDecodeA64_07e0fc00_06a02c00_1,
    iemDecodeA64_07e0fc00_06a03000_1,
    iemDecodeA64_07e0fc00_06a03400_1,
    iemDecodeA64_07e0fc00_06a03800_1,
    iemDecodeA64_07e0fc00_06a03c00_1,
    iemDecodeA64_07e0fc00_06a04000_1,
    iemDecodeA64_07e0fc00_06a04400_1,
    iemDecodeA64_07e0fc00_06a04800_1,
    iemDecodeA64_07e0fc00_06a04c00_1,
    iemDecodeA64_07e0fc00_06a05000_1,
    iemDecodeA64_07e0fc00_06a05400_1,
    iemDecodeA64_07e0fc00_06a05800_1,
    iemDecodeA64_07e0fc00_06a05c00_1,
    iemDecodeA64_07e0fc00_06606000_1,
    iemDecodeA64_07e0fc00_06a06400_1,
    iemDecodeA64_07e0fc00_06a06800_1,
    iemDecodeA64_07e0fc00_06a06c00_1,
    iemDecodeA64_07e0fc00_06a07000_1,
    iemDecodeA64_07e0fc00_06a07400_1,
    iemDecodeA64_07e0fc00_06a07800_1,
    iemDecodeA64_07e0fc00_06a07c00_1,
    iemDecodeA64_07e0fc00_06208000_1,
    iemDecodeA64_07e0fc00_06a08400_1,
    iemDecodeA64_07e0fc00_06a08800_1,
    iemDecodeA64_07e0fc00_06a08c00_1,
    iemDecodeA64_07e0fc00_06a09000_1,
    iemDecodeA64_07e0fc00_06a09400_1,
    iemDecodeA64_07e0fc00_06a09800_1,
    iemDecodeA64_07e0fc00_06a09c00_1,
    iemDecodeA64_07e0fc00_0620a000_1,
    iemDecodeA64_07e0fc00_06a0a400_1,
    iemDecodeA64_07e0fc00_06a0a800_1,
    iemDecodeA64_07e0fc00_06a0ac00_1,
    iemDecodeA64_07e0fc00_06a0b000_1,
    iemDecodeA64_07e0fc00_06a0b400_1,
    iemDecodeA64_07e0fc00_06a0b800_1,
    iemDecodeA64_07e0fc00_06a0bc00_1,
    iemDecodeA64_07e0fc00_06a0c000_1,
    iemDecodeA64_07e0fc00_06a0c400_1,
    iemDecodeA64_07e0fc00_06a0c800_1,
    iemDecodeA64_07e0fc00_06a0cc00_1,
    iemDecodeA64_07e0fc00_06a0d000_1,
    iemDecodeA64_07e0fc00_06a0d400_1,
    iemDecodeA64_07e0fc00_06a0d800_1,
    iemDecodeA64_07e0fc00_06a0dc00_1,
    iemDecodeA64_07e0fc00_0620e000_1,
    iemDecodeA64_07e0fc00_06a0e400_1,
    iemDecodeA64_07e0fc00_06a0e800_1,
    iemDecodeA64_07e0fc00_06a0ec00_1,
    iemDecodeA64_5fe6fc00_16000800_2,
    iemDecodeA64_07e0fc00_06a0f400_1,
    iemDecodeA64_07e0fc00_06a0f800_1,
    iemDecodeA64_07e0fc00_06a0fc00_1,
    iemDecodeA64_07e0fc00_06c00000_1,
    iemDecodeA64_07e0fc00_06c00400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00c00_1,
    iemDecodeA64_07e0fc00_06c00000_1,
    iemDecodeA64_07e0fc00_06c01400_1,
    iemDecodeA64_07e0fc00_06c01800_1,
    iemDecodeA64_07e0fc00_06c01c00_1,
    iemDecodeA64_07e0fc00_06c00000_1,
    iemDecodeA64_07e0fc00_06c02400_1,
    iemDecodeA64_07e0fc00_06c02800_1,
    iemDecodeA64_07e0fc00_06c02c00_1,
    iemDecodeA64_07e0fc00_06c00000_1,
    iemDecodeA64_07e0fc00_06c03400_1,
    iemDecodeA64_07e0fc00_06c03800_1,
    iemDecodeA64_07e0fc00_06c03c00_1,
    iemDecodeA64_07e0fc00_06c00000_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00000_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c05800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00000_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c06800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00000_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c07800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c08000_1,
    iemDecodeA64_07e0fc00_06c08400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c08c00_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c09400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c0c400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c0c400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c0c400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c0c400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c0e400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c0e400_1,
    iemDecodeA64_07e0fc00_06c00800_1,
    iemDecodeA64_07e0fc00_06c0fc00_1,
    iemDecodeA64_07e0fc00_06e00000_1,
    iemDecodeA64_07e0fc00_06e00400_1,
    iemDecodeA64_07e0fc00_06e00800_1,
    iemDecodeA64_07e0fc00_06e00c00_1,
    iemDecodeA64_07e0fc00_06e01000_1,
    iemDecodeA64_07e0fc00_06e01400_1,
    iemDecodeA64_07e0fc00_06e01800_1,
    iemDecodeA64_07e0fc00_06e01c00_1,
    iemDecodeA64_07e0fc00_06e02000_1,
    iemDecodeA64_07e0fc00_06e02400_1,
    iemDecodeA64_07e0fc00_06e02800_1,
    iemDecodeA64_07e0fc00_06e02c00_1,
    iemDecodeA64_07e0fc00_06e03000_1,
    iemDecodeA64_07e0fc00_06e03400_1,
    iemDecodeA64_07e0fc00_06e03800_1,
    iemDecodeA64_07e0fc00_06e03c00_1,
    iemDecodeA64_07e0fc00_06e04000_1,
    iemDecodeA64_07e0fc00_06e04400_1,
    iemDecodeA64_07e0fc00_06e04800_1,
    iemDecodeA64_07e0fc00_06e04c00_1,
    iemDecodeA64_07e0fc00_06e05000_1,
    iemDecodeA64_07e0fc00_06e05400_1,
    iemDecodeA64_07e0fc00_06e05800_1,
    iemDecodeA64_07e0fc00_06e05c00_1,
    iemDecodeA64_07e0fc00_06606000_1,
    iemDecodeA64_07e0fc00_06e06400_1,
    iemDecodeA64_07e0fc00_06e06800_1,
    iemDecodeA64_07e0fc00_06e06c00_1,
    iemDecodeA64_07e0fc00_06e07000_1,
    iemDecodeA64_07e0fc00_06e07400_1,
    iemDecodeA64_07e0fc00_06e07800_1,
    iemDecodeA64_07e0fc00_06e07c00_1,
    iemDecodeA64_07e0fc00_06208000_1,
    iemDecodeA64_07e0fc00_06e08400_1,
    iemDecodeA64_07e0fc00_06e08800_1,
    iemDecodeA64_07e0fc00_06e08c00_1,
    iemDecodeA64_07e0fc00_06e09000_1,
    iemDecodeA64_07e0fc00_06e09400_1,
    iemDecodeA64_07e0fc00_06e09800_1,
    iemDecodeA64_07e0fc00_06e09c00_1,
    iemDecodeA64_07e0fc00_0620a000_1,
    iemDecodeA64_07e0fc00_06e0a400_1,
    iemDecodeA64_07e0fc00_06e0a800_1,
    iemDecodeA64_07e0fc00_06e0ac00_1,
    iemDecodeA64_07e0fc00_06e0b000_1,
    iemDecodeA64_07e0fc00_06e0b400_1,
    iemDecodeA64_07e0fc00_06e0b800_1,
    iemDecodeA64_07e0fc00_06e0bc00_1,
    iemDecodeA64_07e0fc00_06e0c000_1,
    iemDecodeA64_07e0fc00_06e0c400_1,
    iemDecodeA64_07e0fc00_06e0c800_1,
    iemDecodeA64_07e0fc00_06e0cc00_1,
    iemDecodeA64_07e0fc00_06e0d000_1,
    iemDecodeA64_07e0fc00_06e0d400_1,
    iemDecodeA64_07e0fc00_06e0d800_1,
    iemDecodeA64_07e0fc00_06e0dc00_1,
    iemDecodeA64_07e0fc00_0620e000_1,
    iemDecodeA64_07e0fc00_06e0e400_1,
    iemDecodeA64_07e0fc00_06e0e800_1,
    iemDecodeA64_07e0fc00_06e0ec00_1,
    iemDecodeA64_07e0fc00_06e0f000_1,
    iemDecodeA64_07e0fc00_06e0f400_1,
    iemDecodeA64_07e0fc00_06e0f800_1,
    iemDecodeA64_07e0fc00_06e0fc00_1,
    iemDecodeA64_07e0fc00_07000000_1,
    iemDecodeA64_07e0fc00_07000400_1,
    iemDecodeA64_07e0fc00_07000800_1,
    iemDecodeA64_07e0fc00_07000c00_1,
    iemDecodeA64_07e0fc00_07001000_1,
    iemDecodeA64_07e0fc00_07001400_1,
    iemDecodeA64_07e0fc00_07001000_1,
    iemDecodeA64_07e0fc00_07001c00_1,
    iemDecodeA64_07e0fc00_07002000_1,
    iemDecodeA64_07e0fc00_07002400_1,
    iemDecodeA64_07e0fc00_07002000_1,
    iemDecodeA64_07e0fc00_07001c00_1,
    iemDecodeA64_07e0fc00_07003000_1,
    iemDecodeA64_07e0fc00_07003400_1,
    iemDecodeA64_07e0fc00_07003000_1,
    iemDecodeA64_07e0fc00_07001c00_1,
    iemDecodeA64_07e0fc00_07004000_1,
    iemDecodeA64_07e0fc00_07004400_1,
    iemDecodeA64_07e0fc00_07004000_1,
    iemDecodeA64_07e0fc00_07001c00_1,
    iemDecodeA64_07e0fc00_07005000_1,
    iemDecodeA64_07e0fc00_07005400_1,
    iemDecodeA64_07e0fc00_07005000_1,
    iemDecodeA64_07e0fc00_07001c00_1,
    iemDecodeA64_07e0fc00_07006000_1,
    iemDecodeA64_07e0fc00_07006400_1,
    iemDecodeA64_07e0fc00_07006000_1,
    iemDecodeA64_07e0fc00_07001c00_1,
    iemDecodeA64_07e0fc00_07007000_1,
    iemDecodeA64_07e0fc00_07007400_1,
    iemDecodeA64_07e0fc00_07007000_1,
    iemDecodeA64_07e0fc00_07001c00_1,
    iemDecodeA64_07e0fc00_07008000_1,
    iemDecodeA64_07e0fc00_07008400_1,
    iemDecodeA64_07e0fc00_07008000_1,
    iemDecodeA64_07e0fc00_07008c00_1,
    iemDecodeA64_07e0fc00_07009000_1,
    iemDecodeA64_07e0fc00_07009400_1,
    iemDecodeA64_07e0fc00_07009000_1,
    iemDecodeA64_07e0fc00_07009c00_1,
    iemDecodeA64_07e0fc00_0700a000_1,
    iemDecodeA64_07e0fc00_0700a400_1,
    iemDecodeA64_07e0fc00_0700a000_1,
    iemDecodeA64_07e0fc00_0700ac00_1,
    iemDecodeA64_07e0fc00_0700b000_1,
    iemDecodeA64_07e0fc00_0700b400_1,
    iemDecodeA64_07e0fc00_0700b000_1,
    iemDecodeA64_07e0fc00_0700ac00_1,
    iemDecodeA64_07e0fc00_0700c000_1,
    iemDecodeA64_07e0fc00_0700c400_1,
    iemDecodeA64_07e0fc00_0700c000_1,
    iemDecodeA64_07e0fc00_0700ac00_1,
    iemDecodeA64_07e0fc00_0700d000_1,
    iemDecodeA64_07e0fc00_0700c400_1,
    iemDecodeA64_07e0fc00_0700d000_1,
    iemDecodeA64_07e0fc00_0700ac00_1,
    iemDecodeA64_07e0fc00_0700e000_1,
    iemDecodeA64_07e0fc00_0700e400_1,
    iemDecodeA64_07e0fc00_0700e000_1,
    iemDecodeA64_07e0fc00_0700ac00_1,
    iemDecodeA64_07e0fc00_0700f000_1,
    iemDecodeA64_07e0fc00_0700f400_1,
    iemDecodeA64_07e0fc00_0700f000_1,
    iemDecodeA64_07e0fc00_0700fc00_1,
    iemDecodeA64_07e0fc00_07200000_1,
    iemDecodeA64_07e0fc00_07200400_1,
    iemDecodeA64_07e0fc00_07200800_1,
    iemDecodeA64_07e0fc00_07200c00_1,
    iemDecodeA64_07e0fc00_07201000_1,
    iemDecodeA64_07e0fc00_07201400_1,
    iemDecodeA64_07e0fc00_07201000_1,
    iemDecodeA64_07e0fc00_07201c00_1,
    iemDecodeA64_07e0fc00_07202000_1,
    iemDecodeA64_07e0fc00_07202400_1,
    iemDecodeA64_07e0fc00_07202000_1,
    iemDecodeA64_07e0fc00_07201c00_1,
    iemDecodeA64_07e0fc00_07203000_1,
    iemDecodeA64_07e0fc00_07203400_1,
    iemDecodeA64_07e0fc00_07203000_1,
    iemDecodeA64_07e0fc00_07201c00_1,
    iemDecodeA64_07e0fc00_07204000_1,
    iemDecodeA64_07e0fc00_07204400_1,
    iemDecodeA64_07e0fc00_07204000_1,
    iemDecodeA64_07e0fc00_07201c00_1,
    iemDecodeA64_07e0fc00_07205000_1,
    iemDecodeA64_07e0fc00_07205400_1,
    iemDecodeA64_07e0fc00_07205000_1,
    iemDecodeA64_07e0fc00_07201c00_1,
    iemDecodeA64_07e0fc00_07206000_1,
    iemDecodeA64_07e0fc00_07206400_1,
    iemDecodeA64_07e0fc00_07206000_1,
    iemDecodeA64_07e0fc00_07201c00_1,
    iemDecodeA64_07e0fc00_07207000_1,
    iemDecodeA64_07e0fc00_07207400_1,
    iemDecodeA64_07e0fc00_07207000_1,
    iemDecodeA64_07e0fc00_07201c00_1,
    iemDecodeA64_07e0fc00_07208000_1,
    iemDecodeA64_07e0fc00_07208400_1,
    iemDecodeA64_07e0fc00_07208000_1,
    iemDecodeA64_07e0fc00_07208c00_1,
    iemDecodeA64_07e0fc00_07209000_1,
    iemDecodeA64_07e0fc00_07209400_1,
    iemDecodeA64_07e0fc00_07209000_1,
    iemDecodeA64_07e0fc00_07209c00_1,
    iemDecodeA64_07e0fc00_0720a000_1,
    iemDecodeA64_07e0fc00_0720a400_1,
    iemDecodeA64_07e0fc00_0720a000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720b000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720b000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720c000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720c000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720d000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720d000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720e000_1,
    iemDecodeA64_07e0fc00_0720e400_1,
    iemDecodeA64_07e0fc00_0720e000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720f000_1,
    iemDecodeA64_07e0fc00_0720ac00_1,
    iemDecodeA64_07e0fc00_0720f000_1,
    iemDecodeA64_07e0fc00_0720fc00_1,
    iemDecodeA64_07e0fc00_07400000_1,
    iemDecodeA64_07e0fc00_07400400_1,
    iemDecodeA64_07e0fc00_07400000_1,
    iemDecodeA64_07e0fc00_07400c00_1,
    iemDecodeA64_07e0fc00_07401000_1,
    iemDecodeA64_07e0fc00_07401400_1,
    iemDecodeA64_07e0fc00_07401000_1,
    iemDecodeA64_07e0fc00_07400c00_1,
    iemDecodeA64_07e0fc00_07402000_1,
    iemDecodeA64_07e0fc00_07402400_1,
    iemDecodeA64_07e0fc00_07402000_1,
    iemDecodeA64_07e0fc00_07400c00_1,
    iemDecodeA64_07e0fc00_07403000_1,
    iemDecodeA64_07e0fc00_07403400_1,
    iemDecodeA64_07e0fc00_07403000_1,
    iemDecodeA64_07e0fc00_07400c00_1,
    iemDecodeA64_07e0fc00_07404000_1,
    iemDecodeA64_07e0fc00_07404400_1,
    iemDecodeA64_07e0fc00_07404000_1,
    iemDecodeA64_07e0fc00_07400c00_1,
    iemDecodeA64_07e0fc00_07401000_1,
    iemDecodeA64_07e0fc00_07405400_1,
    iemDecodeA64_07e0fc00_07401000_1,
    iemDecodeA64_07e0fc00_07400c00_1,
    iemDecodeA64_07e0fc00_07406000_1,
    iemDecodeA64_07e0fc00_07406400_1,
    iemDecodeA64_07e0fc00_07406000_1,
    iemDecodeA64_07e0fc00_07400c00_1,
    iemDecodeA64_07e0fc00_07407000_1,
    iemDecodeA64_07e0fc00_07407400_1,
    iemDecodeA64_07e0fc00_07407000_1,
    iemDecodeA64_07e0fc00_07400c00_1,
    iemDecodeA64_07e0fc00_07408000_1,
    iemDecodeA64_07e0fc00_07408400_1,
    iemDecodeA64_07e0fc00_07408000_1,
    iemDecodeA64_07e0fc00_07408c00_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_07409400_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_07409c00_1,
    iemDecodeA64_07e0fc00_0740a000_1,
    iemDecodeA64_07e0fc00_0740a400_1,
    iemDecodeA64_07e0fc00_0740a000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740b000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740b000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740c000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740c000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740d000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740d000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740e000_1,
    iemDecodeA64_07e0fc00_0740e400_1,
    iemDecodeA64_07e0fc00_0740e000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740f000_1,
    iemDecodeA64_07e0fc00_07409000_1,
    iemDecodeA64_07e0fc00_0740f000_1,
    iemDecodeA64_07e0fc00_0740fc00_1,
    iemDecodeA64_07e0fc00_07600000_1,
    iemDecodeA64_07e0fc00_07600400_1,
    iemDecodeA64_07e0fc00_07600000_1,
    iemDecodeA64_07e0fc00_07600c00_1,
    iemDecodeA64_07e0fc00_07601000_1,
    iemDecodeA64_07e0fc00_07601400_1,
    iemDecodeA64_07e0fc00_07601000_1,
    iemDecodeA64_07e0fc00_07600c00_1,
    iemDecodeA64_07e0fc00_07602000_1,
    iemDecodeA64_07e0fc00_07602400_1,
    iemDecodeA64_07e0fc00_07602000_1,
    iemDecodeA64_07e0fc00_07600c00_1,
    iemDecodeA64_07e0fc00_07603000_1,
    iemDecodeA64_07e0fc00_07603400_1,
    iemDecodeA64_07e0fc00_07603000_1,
    iemDecodeA64_07e0fc00_07600c00_1,
    iemDecodeA64_07e0fc00_07604000_1,
    iemDecodeA64_07e0fc00_07604400_1,
    iemDecodeA64_07e0fc00_07604000_1,
    iemDecodeA64_07e0fc00_07600c00_1,
    iemDecodeA64_07e0fc00_07601000_1,
    iemDecodeA64_07e0fc00_07605400_1,
    iemDecodeA64_07e0fc00_07601000_1,
    iemDecodeA64_07e0fc00_07600c00_1,
    iemDecodeA64_07e0fc00_07606000_1,
    iemDecodeA64_07e0fc00_07606400_1,
    iemDecodeA64_07e0fc00_07606000_1,
    iemDecodeA64_07e0fc00_07600c00_1,
    iemDecodeA64_07e0fc00_07607000_1,
    iemDecodeA64_07e0fc00_07607400_1,
    iemDecodeA64_07e0fc00_07607000_1,
    iemDecodeA64_07e0fc00_07600c00_1,
    iemDecodeA64_07e0fc00_07608000_1,
    iemDecodeA64_07e0fc00_07608400_1,
    iemDecodeA64_07e0fc00_07608000_1,
    iemDecodeA64_07e0fc00_07608c00_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_07609400_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_07609c00_1,
    iemDecodeA64_07e0fc00_0760a000_1,
    iemDecodeA64_07e0fc00_0760a400_1,
    iemDecodeA64_07e0fc00_0760a000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760b000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760b000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760c000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760c000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760d000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760d000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760e000_1,
    iemDecodeA64_07e0fc00_0760e400_1,
    iemDecodeA64_07e0fc00_0760e000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760f000_1,
    iemDecodeA64_07e0fc00_07609000_1,
    iemDecodeA64_07e0fc00_0760f000_1,
    iemDecodeA64_07e0fc00_0760fc00_1,
    iemDecodeA64_07e0fc00_07800000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07800000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07801000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07801000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07802000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07802000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07803000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07803000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07804000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07804000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07805000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07805000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07806000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07806000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07807000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07807000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07808000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07808000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07809000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07809000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780a000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780a000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780b000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780b000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780c000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780c000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780d000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780d000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780e000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780e000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780f000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780f000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07800000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07800000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07801000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07801000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07802000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07802000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07803000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07803000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07804000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07804000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07805000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07805000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07806000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07806000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07807000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07807000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07808000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07808000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07809000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07809000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780a000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780a000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780b000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780b000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780c000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780c000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780d000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780d000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780e000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780e000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780f000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_0780f000_1,
    iemDecodeA64_07e0fc00_07800400_1,
    iemDecodeA64_07e0fc00_07c00000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c00000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c01000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c01000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c02000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c02000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c03000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c03000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c04000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c04000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c05000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c05000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c06000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c06000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c07000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c07000_1,
    iemDecodeA64_07e0fc00_07c00400_1,
    iemDecodeA64_07e0fc00_07c08000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c08000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c09000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c09000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0a000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0a000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0b000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0b000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0c000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0c000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0d000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0d000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0e000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0e000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0f000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07c0f000_1,
    iemDecodeA64_07e0fc00_07c08400_1,
    iemDecodeA64_07e0fc00_07e00000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e00000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e01000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e01000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e02000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e02000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e03000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e03000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e04000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e04000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e05000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e05000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e06000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e06000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e07000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e07000_1,
    iemDecodeA64_07e0fc00_07e00400_1,
    iemDecodeA64_07e0fc00_07e08000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e08000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e09000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e09000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0a000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0a000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0b000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0b000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0c000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0c000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0d000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0d000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0e000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0e000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0f000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
    iemDecodeA64_07e0fc00_07e0f000_1,
    iemDecodeA64_07e0fc00_07e08400_1,
};
AssertCompile(RT_ELEMENTS(g_apfnIemInterpretOnlyA64) == 0x1000);
